# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parties.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_parties.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bsteammessages_parties.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n\x1a\x43Parties_JoinParty_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tbeacon_id\x18\x02 \x01(\x04\"H\n\x1b\x43Parties_JoinParty_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x63onnect_string\x18\x02 \x01(\t\"E\n\x17\x43Parties_BeaconLocation\x12\x15\n\rlocation_type\x18\x01 \x01(\r\x12\x13\n\x0blocation_id\x18\x02 \x01(\x04\"\x9d\x01\n\x1d\x43Parties_CreateBeacon_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\x12+\n\tlocations\x18\x03 \x03(\x0b\x32\x18.CParties_BeaconLocation\x12\x16\n\x0e\x63onnect_string\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\"3\n\x1e\x43Parties_CreateBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"R\n\'CParties_OnReservationCompleted_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"=\n(CParties_OnReservationCompleted_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"M\n\"CParties_CancelReservation_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"8\n#CParties_CancelReservation_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"P\n#CParties_ChangeNumOpenSlots_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x12\x16\n\x0enum_open_slots\x18\x02 \x01(\r\"9\n$CParties_ChangeNumOpenSlots_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"3\n\x1e\x43Parties_DestroyBeacon_Request\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\"4\n\x1f\x43Parties_DestroyBeacon_Response\x12\x11\n\tbeacon_id\x18\x01 \x01(\x04\x32\xd9\x07\n\x07Parties\x12\xb9\x01\n\tJoinParty\x12\x1b.CParties_JoinParty_Request\x1a\x1c.CParties_JoinParty_Response\"q\x82\xb5\x18mRequest to join a Party via the given Beacon ID. If successful, will be given the necessary \'connect\' string.\x12\x85\x01\n\x0c\x43reateBeacon\x12\x1e.CParties_CreateBeacon_Request\x1a\x1f.CParties_CreateBeacon_Response\"4\x82\xb5\x18\x30\x43reate a Beacon to attract people to your Party.\x12\xb7\x01\n\x16OnReservationCompleted\x12(.CParties_OnReservationCompleted_Request\x1a).CParties_OnReservationCompleted_Response\"H\x82\xb5\x18\x44Notify Steam that a user with a reservation has successfully joined.\x12\xbe\x01\n\x11\x43\x61ncelReservation\x12#.CParties_CancelReservation_Request\x1a$.CParties_CancelReservation_Response\"^\x82\xb5\x18ZNotify Steam that a user with a reservation either never showed up, or has left the party.\x12\x86\x01\n\x12\x43hangeNumOpenSlots\x12$.CParties_ChangeNumOpenSlots_Request\x1a%.CParties_ChangeNumOpenSlots_Response\"#\x82\xb5\x18\x1f\x43hange the number of open slots\x12j\n\rDestroyBeacon\x12\x1f.CParties_DestroyBeacon_Request\x1a .CParties_DestroyBeacon_Response\"\x16\x82\xb5\x18\x12\x44\x65lete the Beacon.\x1a\x1a\x82\xb5\x18\x16Party-related servicesB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CPARTIES_JOINPARTY_REQUEST = _descriptor.Descriptor(
  name='CParties_JoinParty_Request',
  full_name='CParties_JoinParty_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParties_JoinParty_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_JoinParty_Request.beacon_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=155,
)


_CPARTIES_JOINPARTY_RESPONSE = _descriptor.Descriptor(
  name='CParties_JoinParty_Response',
  full_name='CParties_JoinParty_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_JoinParty_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CParties_JoinParty_Response.connect_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=229,
)


_CPARTIES_BEACONLOCATION = _descriptor.Descriptor(
  name='CParties_BeaconLocation',
  full_name='CParties_BeaconLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_type', full_name='CParties_BeaconLocation.location_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='CParties_BeaconLocation.location_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=300,
)


_CPARTIES_CREATEBEACON_REQUEST = _descriptor.Descriptor(
  name='CParties_CreateBeacon_Request',
  full_name='CParties_CreateBeacon_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CParties_CreateBeacon_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_open_slots', full_name='CParties_CreateBeacon_Request.num_open_slots', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locations', full_name='CParties_CreateBeacon_Request.locations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CParties_CreateBeacon_Request.connect_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CParties_CreateBeacon_Request.metadata', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=460,
)


_CPARTIES_CREATEBEACON_RESPONSE = _descriptor.Descriptor(
  name='CParties_CreateBeacon_Response',
  full_name='CParties_CreateBeacon_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CreateBeacon_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=513,
)


_CPARTIES_ONRESERVATIONCOMPLETED_REQUEST = _descriptor.Descriptor(
  name='CParties_OnReservationCompleted_Request',
  full_name='CParties_OnReservationCompleted_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_OnReservationCompleted_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CParties_OnReservationCompleted_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=597,
)


_CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE = _descriptor.Descriptor(
  name='CParties_OnReservationCompleted_Response',
  full_name='CParties_OnReservationCompleted_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_OnReservationCompleted_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=660,
)


_CPARTIES_CANCELRESERVATION_REQUEST = _descriptor.Descriptor(
  name='CParties_CancelReservation_Request',
  full_name='CParties_CancelReservation_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CancelReservation_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CParties_CancelReservation_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=739,
)


_CPARTIES_CANCELRESERVATION_RESPONSE = _descriptor.Descriptor(
  name='CParties_CancelReservation_Response',
  full_name='CParties_CancelReservation_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_CancelReservation_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=797,
)


_CPARTIES_CHANGENUMOPENSLOTS_REQUEST = _descriptor.Descriptor(
  name='CParties_ChangeNumOpenSlots_Request',
  full_name='CParties_ChangeNumOpenSlots_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_ChangeNumOpenSlots_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_open_slots', full_name='CParties_ChangeNumOpenSlots_Request.num_open_slots', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=879,
)


_CPARTIES_CHANGENUMOPENSLOTS_RESPONSE = _descriptor.Descriptor(
  name='CParties_ChangeNumOpenSlots_Response',
  full_name='CParties_ChangeNumOpenSlots_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_ChangeNumOpenSlots_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=938,
)


_CPARTIES_DESTROYBEACON_REQUEST = _descriptor.Descriptor(
  name='CParties_DestroyBeacon_Request',
  full_name='CParties_DestroyBeacon_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_DestroyBeacon_Request.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=991,
)


_CPARTIES_DESTROYBEACON_RESPONSE = _descriptor.Descriptor(
  name='CParties_DestroyBeacon_Response',
  full_name='CParties_DestroyBeacon_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CParties_DestroyBeacon_Response.beacon_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1045,
)

_CPARTIES_CREATEBEACON_REQUEST.fields_by_name['locations'].message_type = _CPARTIES_BEACONLOCATION
DESCRIPTOR.message_types_by_name['CParties_JoinParty_Request'] = _CPARTIES_JOINPARTY_REQUEST
DESCRIPTOR.message_types_by_name['CParties_JoinParty_Response'] = _CPARTIES_JOINPARTY_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_BeaconLocation'] = _CPARTIES_BEACONLOCATION
DESCRIPTOR.message_types_by_name['CParties_CreateBeacon_Request'] = _CPARTIES_CREATEBEACON_REQUEST
DESCRIPTOR.message_types_by_name['CParties_CreateBeacon_Response'] = _CPARTIES_CREATEBEACON_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_OnReservationCompleted_Request'] = _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST
DESCRIPTOR.message_types_by_name['CParties_OnReservationCompleted_Response'] = _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_CancelReservation_Request'] = _CPARTIES_CANCELRESERVATION_REQUEST
DESCRIPTOR.message_types_by_name['CParties_CancelReservation_Response'] = _CPARTIES_CANCELRESERVATION_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_ChangeNumOpenSlots_Request'] = _CPARTIES_CHANGENUMOPENSLOTS_REQUEST
DESCRIPTOR.message_types_by_name['CParties_ChangeNumOpenSlots_Response'] = _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE
DESCRIPTOR.message_types_by_name['CParties_DestroyBeacon_Request'] = _CPARTIES_DESTROYBEACON_REQUEST
DESCRIPTOR.message_types_by_name['CParties_DestroyBeacon_Response'] = _CPARTIES_DESTROYBEACON_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CParties_JoinParty_Request = _reflection.GeneratedProtocolMessageType('CParties_JoinParty_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_JOINPARTY_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_JoinParty_Request)
  })
_sym_db.RegisterMessage(CParties_JoinParty_Request)

CParties_JoinParty_Response = _reflection.GeneratedProtocolMessageType('CParties_JoinParty_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_JOINPARTY_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_JoinParty_Response)
  })
_sym_db.RegisterMessage(CParties_JoinParty_Response)

CParties_BeaconLocation = _reflection.GeneratedProtocolMessageType('CParties_BeaconLocation', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_BEACONLOCATION,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_BeaconLocation)
  })
_sym_db.RegisterMessage(CParties_BeaconLocation)

CParties_CreateBeacon_Request = _reflection.GeneratedProtocolMessageType('CParties_CreateBeacon_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CREATEBEACON_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CreateBeacon_Request)
  })
_sym_db.RegisterMessage(CParties_CreateBeacon_Request)

CParties_CreateBeacon_Response = _reflection.GeneratedProtocolMessageType('CParties_CreateBeacon_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CREATEBEACON_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CreateBeacon_Response)
  })
_sym_db.RegisterMessage(CParties_CreateBeacon_Response)

CParties_OnReservationCompleted_Request = _reflection.GeneratedProtocolMessageType('CParties_OnReservationCompleted_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_ONRESERVATIONCOMPLETED_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_OnReservationCompleted_Request)
  })
_sym_db.RegisterMessage(CParties_OnReservationCompleted_Request)

CParties_OnReservationCompleted_Response = _reflection.GeneratedProtocolMessageType('CParties_OnReservationCompleted_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_OnReservationCompleted_Response)
  })
_sym_db.RegisterMessage(CParties_OnReservationCompleted_Response)

CParties_CancelReservation_Request = _reflection.GeneratedProtocolMessageType('CParties_CancelReservation_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CANCELRESERVATION_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CancelReservation_Request)
  })
_sym_db.RegisterMessage(CParties_CancelReservation_Request)

CParties_CancelReservation_Response = _reflection.GeneratedProtocolMessageType('CParties_CancelReservation_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CANCELRESERVATION_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_CancelReservation_Response)
  })
_sym_db.RegisterMessage(CParties_CancelReservation_Response)

CParties_ChangeNumOpenSlots_Request = _reflection.GeneratedProtocolMessageType('CParties_ChangeNumOpenSlots_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CHANGENUMOPENSLOTS_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_ChangeNumOpenSlots_Request)
  })
_sym_db.RegisterMessage(CParties_ChangeNumOpenSlots_Request)

CParties_ChangeNumOpenSlots_Response = _reflection.GeneratedProtocolMessageType('CParties_ChangeNumOpenSlots_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_CHANGENUMOPENSLOTS_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_ChangeNumOpenSlots_Response)
  })
_sym_db.RegisterMessage(CParties_ChangeNumOpenSlots_Response)

CParties_DestroyBeacon_Request = _reflection.GeneratedProtocolMessageType('CParties_DestroyBeacon_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_DESTROYBEACON_REQUEST,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_DestroyBeacon_Request)
  })
_sym_db.RegisterMessage(CParties_DestroyBeacon_Request)

CParties_DestroyBeacon_Response = _reflection.GeneratedProtocolMessageType('CParties_DestroyBeacon_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTIES_DESTROYBEACON_RESPONSE,
  '__module__' : 'steammessages_parties_pb2'
  # @@protoc_insertion_point(class_scope:CParties_DestroyBeacon_Response)
  })
_sym_db.RegisterMessage(CParties_DestroyBeacon_Response)


DESCRIPTOR._options = None

_PARTIES = _descriptor.ServiceDescriptor(
  name='Parties',
  full_name='Parties',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\026Party-related services',
  create_key=_descriptor._internal_create_key,
  serialized_start=1048,
  serialized_end=2033,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinParty',
    full_name='Parties.JoinParty',
    index=0,
    containing_service=None,
    input_type=_CPARTIES_JOINPARTY_REQUEST,
    output_type=_CPARTIES_JOINPARTY_RESPONSE,
    serialized_options=b'\202\265\030mRequest to join a Party via the given Beacon ID. If successful, will be given the necessary \'connect\' string.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBeacon',
    full_name='Parties.CreateBeacon',
    index=1,
    containing_service=None,
    input_type=_CPARTIES_CREATEBEACON_REQUEST,
    output_type=_CPARTIES_CREATEBEACON_RESPONSE,
    serialized_options=b'\202\265\0300Create a Beacon to attract people to your Party.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnReservationCompleted',
    full_name='Parties.OnReservationCompleted',
    index=2,
    containing_service=None,
    input_type=_CPARTIES_ONRESERVATIONCOMPLETED_REQUEST,
    output_type=_CPARTIES_ONRESERVATIONCOMPLETED_RESPONSE,
    serialized_options=b'\202\265\030DNotify Steam that a user with a reservation has successfully joined.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelReservation',
    full_name='Parties.CancelReservation',
    index=3,
    containing_service=None,
    input_type=_CPARTIES_CANCELRESERVATION_REQUEST,
    output_type=_CPARTIES_CANCELRESERVATION_RESPONSE,
    serialized_options=b'\202\265\030ZNotify Steam that a user with a reservation either never showed up, or has left the party.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeNumOpenSlots',
    full_name='Parties.ChangeNumOpenSlots',
    index=4,
    containing_service=None,
    input_type=_CPARTIES_CHANGENUMOPENSLOTS_REQUEST,
    output_type=_CPARTIES_CHANGENUMOPENSLOTS_RESPONSE,
    serialized_options=b'\202\265\030\037Change the number of open slots',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyBeacon',
    full_name='Parties.DestroyBeacon',
    index=5,
    containing_service=None,
    input_type=_CPARTIES_DESTROYBEACON_REQUEST,
    output_type=_CPARTIES_DESTROYBEACON_RESPONSE,
    serialized_options=b'\202\265\030\022Delete the Beacon.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARTIES)

DESCRIPTOR.services_by_name['Parties'] = _PARTIES

Parties = service_reflection.GeneratedServiceType('Parties', (_service.Service,), dict(
  DESCRIPTOR = _PARTIES,
  __module__ = 'steammessages_parties_pb2'
  ))

Parties_Stub = service_reflection.GeneratedServiceStubType('Parties_Stub', (Parties,), dict(
  DESCRIPTOR = _PARTIES,
  __module__ = 'steammessages_parties_pb2'
  ))


# @@protoc_insertion_point(module_scope)
