# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_uds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_uds.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_clientserver_uds.proto\x1a\x18steammessages_base.proto\"G\n\x1e\x43MsgClientUDSP2PSessionStarted\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\"\x81\x02\n\x1c\x43MsgClientUDSP2PSessionEnded\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\x12\x1a\n\x12session_length_sec\x18\x03 \x01(\x05\x12\x15\n\rsession_error\x18\x04 \x01(\x05\x12\x0f\n\x07nattype\x18\x05 \x01(\x05\x12\x12\n\nbytes_recv\x18\x06 \x01(\x05\x12\x12\n\nbytes_sent\x18\x07 \x01(\x05\x12\x18\n\x10\x62ytes_sent_relay\x18\x08 \x01(\x05\x12\x18\n\x10\x62ytes_recv_relay\x18\t \x01(\x05\x12\x1a\n\x12time_to_connect_ms\x18\n \x01(\x05\"\x1c\n\x1a\x43MsgClientGetClientDetails\"\xdb\x02\n\"CMsgClientGetClientDetailsResponse\x12\x17\n\x0fpackage_version\x18\x01 \x01(\r\x12\n\n\x02os\x18\x02 \x01(\t\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x11\n\tip_public\x18\x04 \x01(\t\x12\x12\n\nip_private\x18\x05 \x01(\t\x12?\n\rgames_running\x18\x06 \x03(\x0b\x32(.CMsgClientGetClientDetailsResponse.Game\x12\x17\n\x0f\x62ytes_available\x18\x07 \x01(\x04\x12\x18\n\x10protocol_version\x18\x08 \x01(\r\x12\x1a\n\x12\x63lientcomm_version\x18\t \x01(\r\x1a\x43\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nextra_info\x18\x02 \x01(\t\x12\x18\n\x10time_running_sec\x18\x03 \x01(\r\"\xa5\x01\n\x1a\x43MsgClientGetClientAppList\x12\r\n\x05media\x18\x01 \x01(\x08\x12\r\n\x05tools\x18\x02 \x01(\x08\x12\r\n\x05games\x18\x03 \x01(\x08\x12\x16\n\x0eonly_installed\x18\x04 \x01(\x08\x12\x15\n\ronly_changing\x18\x05 \x01(\x08\x12\x0e\n\x06\x63omics\x18\x06 \x01(\x08\x12\x1b\n\x13include_client_info\x18\x07 \x01(\x08\"\xb4\x06\n\"CMsgClientGetClientAppListResponse\x12\x35\n\x04\x61pps\x18\x01 \x03(\x0b\x32\'.CMsgClientGetClientAppListResponse.App\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x12\x38\n\x0b\x63lient_info\x18\x03 \x01(\x0b\x32#.CMsgClientGetClientDetailsResponse\x1a\x83\x05\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\n \x01(\t\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x08\x12\x11\n\tinstalled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61uto_update\x18\x05 \x01(\x08\x12\x18\n\x10\x62ytes_downloaded\x18\x06 \x01(\x04\x12\x19\n\x11\x62ytes_to_download\x18\x07 \x01(\x04\x12\x1b\n\x13\x62ytes_download_rate\x18\x08 \x01(\r\x12\x39\n\x04\x64lcs\x18\t \x03(\x0b\x32+.CMsgClientGetClientAppListResponse.App.DLC\x12\x17\n\x0f\x64ownload_paused\x18\x0b \x01(\x08\x12\x17\n\x0fnum_downloading\x18\x0c \x01(\r\x12\x12\n\nnum_paused\x18\r \x01(\r\x12\x10\n\x08\x63hanging\x18\x0e \x01(\x08\x12\x1d\n\x15\x61vailable_on_platform\x18\x0f \x01(\x08\x12\x14\n\x0c\x62ytes_staged\x18\x10 \x01(\x04\x12\x16\n\x0e\x62ytes_to_stage\x18\x11 \x01(\x04\x12\x16\n\x0e\x62ytes_required\x18\x12 \x01(\x04\x12\x16\n\x0esource_buildid\x18\x13 \x01(\r\x12\x16\n\x0etarget_buildid\x18\x14 \x01(\r\x12#\n\x1b\x65stimated_seconds_remaining\x18\x15 \x01(\r\x12\x16\n\x0equeue_position\x18\x16 \x01(\x05\x12\x14\n\x0cuninstalling\x18\x17 \x01(\x08\x12\x19\n\x11rt_time_scheduled\x18\x18 \x01(\r\x1a\'\n\x03\x44LC\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tinstalled\x18\x02 \x01(\x08\"+\n\x1a\x43MsgClientInstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"4\n\"CMsgClientInstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1c\x43MsgClientUninstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"6\n$CMsgClientUninstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"B\n!CMsgClientSetClientAppUpdateState\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06update\x18\x02 \x01(\x08\";\n)CMsgClientSetClientAppUpdateStateResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"4\n\"CMsgClientEnableOrDisableDownloads\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"<\n*CMsgClientEnableOrDisableDownloadsResponse\x12\x0e\n\x06result\x18\x01 \x01(\rB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTUDSP2PSESSIONSTARTED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionStarted',
  full_name='CMsgClientUDSP2PSessionStarted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionStarted.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionStarted.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=137,
)


_CMSGCLIENTUDSP2PSESSIONENDED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionEnded',
  full_name='CMsgClientUDSP2PSessionEnded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionEnded.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionEnded.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_length_sec', full_name='CMsgClientUDSP2PSessionEnded.session_length_sec', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_error', full_name='CMsgClientUDSP2PSessionEnded.session_error', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nattype', full_name='CMsgClientUDSP2PSessionEnded.nattype', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_recv', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_sent_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent_relay', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_recv_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv_relay', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_connect_ms', full_name='CMsgClientUDSP2PSessionEnded.time_to_connect_ms', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=397,
)


_CMSGCLIENTGETCLIENTDETAILS = _descriptor.Descriptor(
  name='CMsgClientGetClientDetails',
  full_name='CMsgClientGetClientDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=427,
)


_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CMsgClientGetClientDetailsResponse.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientDetailsResponse.Game.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='CMsgClientGetClientDetailsResponse.Game.extra_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_running_sec', full_name='CMsgClientGetClientDetailsResponse.Game.time_running_sec', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=777,
)

_CMSGCLIENTGETCLIENTDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientDetailsResponse',
  full_name='CMsgClientGetClientDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_version', full_name='CMsgClientGetClientDetailsResponse.package_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='CMsgClientGetClientDetailsResponse.os', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CMsgClientGetClientDetailsResponse.machine_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_public', full_name='CMsgClientGetClientDetailsResponse.ip_public', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_private', full_name='CMsgClientGetClientDetailsResponse.ip_private', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='games_running', full_name='CMsgClientGetClientDetailsResponse.games_running', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientDetailsResponse.bytes_available', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientGetClientDetailsResponse.protocol_version', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientcomm_version', full_name='CMsgClientGetClientDetailsResponse.clientcomm_version', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=777,
)


_CMSGCLIENTGETCLIENTAPPLIST = _descriptor.Descriptor(
  name='CMsgClientGetClientAppList',
  full_name='CMsgClientGetClientAppList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='media', full_name='CMsgClientGetClientAppList.media', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tools', full_name='CMsgClientGetClientAppList.tools', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgClientGetClientAppList.games', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_installed', full_name='CMsgClientGetClientAppList.only_installed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_changing', full_name='CMsgClientGetClientAppList.only_changing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comics', full_name='CMsgClientGetClientAppList.comics', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_client_info', full_name='CMsgClientGetClientAppList.include_client_info', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=945,
)


_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC = _descriptor.Descriptor(
  name='DLC',
  full_name='CMsgClientGetClientAppListResponse.App.DLC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.DLC.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.DLC.installed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1768,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP = _descriptor.Descriptor(
  name='App',
  full_name='CMsgClientGetClientAppListResponse.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='CMsgClientGetClientAppListResponse.App.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_type', full_name='CMsgClientGetClientAppListResponse.App.app_type', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorite', full_name='CMsgClientGetClientAppListResponse.App.favorite', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.installed', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_update', full_name='CMsgClientGetClientAppListResponse.App.auto_update', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_downloaded', full_name='CMsgClientGetClientAppListResponse.App.bytes_downloaded', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_to_download', full_name='CMsgClientGetClientAppListResponse.App.bytes_to_download', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_download_rate', full_name='CMsgClientGetClientAppListResponse.App.bytes_download_rate', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dlcs', full_name='CMsgClientGetClientAppListResponse.App.dlcs', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_paused', full_name='CMsgClientGetClientAppListResponse.App.download_paused', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_downloading', full_name='CMsgClientGetClientAppListResponse.App.num_downloading', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_paused', full_name='CMsgClientGetClientAppListResponse.App.num_paused', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changing', full_name='CMsgClientGetClientAppListResponse.App.changing', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_on_platform', full_name='CMsgClientGetClientAppListResponse.App.available_on_platform', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_staged', full_name='CMsgClientGetClientAppListResponse.App.bytes_staged', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_to_stage', full_name='CMsgClientGetClientAppListResponse.App.bytes_to_stage', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_required', full_name='CMsgClientGetClientAppListResponse.App.bytes_required', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_buildid', full_name='CMsgClientGetClientAppListResponse.App.source_buildid', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_buildid', full_name='CMsgClientGetClientAppListResponse.App.target_buildid', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimated_seconds_remaining', full_name='CMsgClientGetClientAppListResponse.App.estimated_seconds_remaining', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_position', full_name='CMsgClientGetClientAppListResponse.App.queue_position', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uninstalling', full_name='CMsgClientGetClientAppListResponse.App.uninstalling', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rt_time_scheduled', full_name='CMsgClientGetClientAppListResponse.App.rt_time_scheduled', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1768,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientAppListResponse',
  full_name='CMsgClientGetClientAppListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientGetClientAppListResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientAppListResponse.bytes_available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_info', full_name='CMsgClientGetClientAppListResponse.client_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1768,
)


_CMSGCLIENTINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientInstallClientApp',
  full_name='CMsgClientInstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientInstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=1813,
)


_CMSGCLIENTINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientInstallClientAppResponse',
  full_name='CMsgClientInstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientInstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1867,
)


_CMSGCLIENTUNINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientUninstallClientApp',
  full_name='CMsgClientUninstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUninstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1869,
  serialized_end=1914,
)


_CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUninstallClientAppResponse',
  full_name='CMsgClientUninstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientUninstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=1970,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateState',
  full_name='CMsgClientSetClientAppUpdateState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientSetClientAppUpdateState.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='CMsgClientSetClientAppUpdateState.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2038,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateStateResponse',
  full_name='CMsgClientSetClientAppUpdateStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientSetClientAppUpdateStateResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2099,
)


_CMSGCLIENTENABLEORDISABLEDOWNLOADS = _descriptor.Descriptor(
  name='CMsgClientEnableOrDisableDownloads',
  full_name='CMsgClientEnableOrDisableDownloads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='CMsgClientEnableOrDisableDownloads.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2153,
)


_CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientEnableOrDisableDownloadsResponse',
  full_name='CMsgClientEnableOrDisableDownloadsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientEnableOrDisableDownloadsResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2215,
)

_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME.containing_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
_CMSGCLIENTGETCLIENTDETAILSRESPONSE.fields_by_name['games_running'].message_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.fields_by_name['dlcs'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE.fields_by_name['apps'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE.fields_by_name['client_info'].message_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionStarted'] = _CMSGCLIENTUDSP2PSESSIONSTARTED
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionEnded'] = _CMSGCLIENTUDSP2PSESSIONENDED
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetails'] = _CMSGCLIENTGETCLIENTDETAILS
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetailsResponse'] = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppList'] = _CMSGCLIENTGETCLIENTAPPLIST
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppListResponse'] = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientApp'] = _CMSGCLIENTINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientAppResponse'] = _CMSGCLIENTINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientApp'] = _CMSGCLIENTUNINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientAppResponse'] = _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateState'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateStateResponse'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientEnableOrDisableDownloads'] = _CMSGCLIENTENABLEORDISABLEDOWNLOADS
DESCRIPTOR.message_types_by_name['CMsgClientEnableOrDisableDownloadsResponse'] = _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientUDSP2PSessionStarted = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionStarted', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUDSP2PSESSIONSTARTED,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionStarted)
  })
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionStarted)

CMsgClientUDSP2PSessionEnded = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionEnded', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUDSP2PSESSIONENDED,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionEnded)
  })
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionEnded)

CMsgClientGetClientDetails = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetails', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILS,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetails)
  })
_sym_db.RegisterMessage(CMsgClientGetClientDetails)

CMsgClientGetClientDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetailsResponse', (_message.Message,), {

  'Game' : _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME,
    '__module__' : 'steammessages_clientserver_uds_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse.Game)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILSRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse)
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse.Game)

CMsgClientGetClientAppList = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLIST,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppList)
  })
_sym_db.RegisterMessage(CMsgClientGetClientAppList)

CMsgClientGetClientAppListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppListResponse', (_message.Message,), {

  'App' : _reflection.GeneratedProtocolMessageType('App', (_message.Message,), {

    'DLC' : _reflection.GeneratedProtocolMessageType('DLC', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC,
      '__module__' : 'steammessages_clientserver_uds_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App.DLC)
      })
    ,
    'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP,
    '__module__' : 'steammessages_clientserver_uds_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App.DLC)

CMsgClientInstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTINSTALLCLIENTAPP,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientApp)
  })
_sym_db.RegisterMessage(CMsgClientInstallClientApp)

CMsgClientInstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTINSTALLCLIENTAPPRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientAppResponse)
  })
_sym_db.RegisterMessage(CMsgClientInstallClientAppResponse)

CMsgClientUninstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUNINSTALLCLIENTAPP,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientApp)
  })
_sym_db.RegisterMessage(CMsgClientUninstallClientApp)

CMsgClientUninstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientAppResponse)
  })
_sym_db.RegisterMessage(CMsgClientUninstallClientAppResponse)

CMsgClientSetClientAppUpdateState = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETCLIENTAPPUPDATESTATE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateState)
  })
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateState)

CMsgClientSetClientAppUpdateStateResponse = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateStateResponse)
  })
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateStateResponse)

CMsgClientEnableOrDisableDownloads = _reflection.GeneratedProtocolMessageType('CMsgClientEnableOrDisableDownloads', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTENABLEORDISABLEDOWNLOADS,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEnableOrDisableDownloads)
  })
_sym_db.RegisterMessage(CMsgClientEnableOrDisableDownloads)

CMsgClientEnableOrDisableDownloadsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientEnableOrDisableDownloadsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEnableOrDisableDownloadsResponse)
  })
_sym_db.RegisterMessage(CMsgClientEnableOrDisableDownloadsResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
