# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_partnerapps.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_partnerapps.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_partnerapps.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"J\n\'CPartnerApps_RequestUploadToken_Request\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"f\n(CPartnerApps_RequestUploadToken_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nrouting_id\x18\x03 \x01(\x04\"]\n!CPartnerApps_FinishUpload_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"H\n(CPartnerApps_FinishUploadKVSign_Response\x12\x1c\n\x14signed_installscript\x18\x01 \x01(\t\"\x88\x01\n*CPartnerApps_FinishUploadLegacyDRM_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12\x11\n\ttool_name\x18\x05 \x01(\t\">\n+CPartnerApps_FinishUploadLegacyDRM_Response\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\"$\n\"CPartnerApps_FinishUpload_Response\"\x89\x01\n&CPartnerApps_FinishUploadDepot_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x04 \x01(\r\x12\x13\n\x0b\x62uild_flags\x18\x05 \x01(\r\")\n\'CPartnerApps_FinishUploadDepot_Response\"T\n(CPartnerApps_GetDepotBuildResult_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\"S\n)CPartnerApps_GetDepotBuildResult_Response\x12\x13\n\x0bmanifest_id\x18\x01 \x01(\x04\x12\x11\n\terror_msg\x18\x02 \x01(\t\"5\n#CPartnerApps_FindDRMUploads_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\"\xb4\x01\n\x1e\x43PartnerApps_ExistingDRMUpload\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08\x61\x63tor_id\x18\x03 \x01(\x05\x12\x15\n\rsupplied_name\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\r\x12\x10\n\x08mod_type\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x07\x12\x14\n\x0corig_file_id\x18\t \x01(\t\"X\n$CPartnerApps_FindDRMUploads_Response\x12\x30\n\x07uploads\x18\x01 \x03(\x0b\x32\x1f.CPartnerApps_ExistingDRMUpload\"@\n\x1d\x43PartnerApps_Download_Request\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\"F\n\x1e\x43PartnerApps_Download_Response\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\x32\xa1\x0e\n\x0bPartnerApps\x12\xb1\x01\n\x18RequestKVSignUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"@\x82\xb5\x18<Request upload token for installscript file upload / signing\x12\xae\x01\n\x15RequestDRMUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"@\x82\xb5\x18<Request upload token for executable file upload / processing\x12\xb5\x01\n\x15RequestCEGUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"G\x82\xb5\x18\x43Request upload token for custom executable file upload / processing\x12\xa3\x01\n\x17RequestDepotUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"3\x82\xb5\x18/Request upload token for steampipe depot upload\x12\xab\x01\n\x12\x46inishUploadKVSign\x12\".CPartnerApps_FinishUpload_Request\x1a).CPartnerApps_FinishUploadKVSign_Response\"F\x82\xb5\x18\x42\x43ommit method to sign an installscript after an upload is complete\x12\xa4\x01\n\x15\x46inishUploadDRMUpload\x12+.CPartnerApps_FinishUploadLegacyDRM_Request\x1a,.CPartnerApps_FinishUploadLegacyDRM_Response\"0\x82\xb5\x18,Commit method for executable file processing\x12\x99\x01\n\x15\x46inishUploadCEGUpload\x12\".CPartnerApps_FinishUpload_Request\x1a#.CPartnerApps_FinishUpload_Response\"7\x82\xb5\x18\x33\x43ommit method for custom executable file processing\x12\xa5\x01\n\x17\x46inishUploadDepotUpload\x12\'.CPartnerApps_FinishUploadDepot_Request\x1a(.CPartnerApps_FinishUploadDepot_Response\"7\x82\xb5\x18\x33\x43ommit method for custom executable file processing\x12\xa4\x01\n\x13GetDepotBuildResult\x12).CPartnerApps_GetDepotBuildResult_Request\x1a*.CPartnerApps_GetDepotBuildResult_Response\"6\x82\xb5\x18\x32Get build status for previously uploaded depot ZIP\x12\x8d\x01\n\x0e\x46indDRMUploads\x12$.CPartnerApps_FindDRMUploads_Request\x1a%.CPartnerApps_FindDRMUploads_Response\".\x82\xb5\x18*Finds N most recent prior uploads by appid\x12K\n\x08\x44ownload\x12\x1e.CPartnerApps_Download_Request\x1a\x1f.CPartnerApps_Download_Response\x1a\x32\x82\xb5\x18.Service methods for app management by partnersB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_RequestUploadToken_Request',
  full_name='CPartnerApps_RequestUploadToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CPartnerApps_RequestUploadToken_Request.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPartnerApps_RequestUploadToken_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=169,
)


_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_RequestUploadToken_Response',
  full_name='CPartnerApps_RequestUploadToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_RequestUploadToken_Response.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='CPartnerApps_RequestUploadToken_Response.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_RequestUploadToken_Response.routing_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=273,
)


_CPARTNERAPPS_FINISHUPLOAD_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUpload_Request',
  full_name='CPartnerApps_FinishUpload_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUpload_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUpload_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUpload_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=368,
)


_CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadKVSign_Response',
  full_name='CPartnerApps_FinishUploadKVSign_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_installscript', full_name='CPartnerApps_FinishUploadKVSign_Response.signed_installscript', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=442,
)


_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadLegacyDRM_Request',
  full_name='CPartnerApps_FinishUploadLegacyDRM_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.flags', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tool_name', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.tool_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=581,
)


_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadLegacyDRM_Response',
  full_name='CPartnerApps_FinishUploadLegacyDRM_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Response.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=645,
)


_CPARTNERAPPS_FINISHUPLOAD_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUpload_Response',
  full_name='CPartnerApps_FinishUpload_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=683,
)


_CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadDepot_Request',
  full_name='CPartnerApps_FinishUploadDepot_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUploadDepot_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUploadDepot_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUploadDepot_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CPartnerApps_FinishUploadDepot_Request.depot_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_flags', full_name='CPartnerApps_FinishUploadDepot_Request.build_flags', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=823,
)


_CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadDepot_Response',
  full_name='CPartnerApps_FinishUploadDepot_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=866,
)


_CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_GetDepotBuildResult_Request',
  full_name='CPartnerApps_GetDepotBuildResult_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_GetDepotBuildResult_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_GetDepotBuildResult_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=952,
)


_CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_GetDepotBuildResult_Response',
  full_name='CPartnerApps_GetDepotBuildResult_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CPartnerApps_GetDepotBuildResult_Response.manifest_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='CPartnerApps_GetDepotBuildResult_Response.error_msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1037,
)


_CPARTNERAPPS_FINDDRMUPLOADS_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FindDRMUploads_Request',
  full_name='CPartnerApps_FindDRMUploads_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FindDRMUploads_Request.app_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1092,
)


_CPARTNERAPPS_EXISTINGDRMUPLOAD = _descriptor.Descriptor(
  name='CPartnerApps_ExistingDRMUpload',
  full_name='CPartnerApps_ExistingDRMUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_ExistingDRMUpload.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_ExistingDRMUpload.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='CPartnerApps_ExistingDRMUpload.actor_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supplied_name', full_name='CPartnerApps_ExistingDRMUpload.supplied_name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPartnerApps_ExistingDRMUpload.flags', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mod_type', full_name='CPartnerApps_ExistingDRMUpload.mod_type', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CPartnerApps_ExistingDRMUpload.timestamp', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orig_file_id', full_name='CPartnerApps_ExistingDRMUpload.orig_file_id', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1275,
)


_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FindDRMUploads_Response',
  full_name='CPartnerApps_FindDRMUploads_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploads', full_name='CPartnerApps_FindDRMUploads_Response.uploads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1365,
)


_CPARTNERAPPS_DOWNLOAD_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_Download_Request',
  full_name='CPartnerApps_Download_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_Download_Request.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_Download_Request.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1431,
)


_CPARTNERAPPS_DOWNLOAD_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_Download_Response',
  full_name='CPartnerApps_Download_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_url', full_name='CPartnerApps_Download_Response.download_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_Download_Response.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1503,
)

_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE.fields_by_name['uploads'].message_type = _CPARTNERAPPS_EXISTINGDRMUPLOAD
DESCRIPTOR.message_types_by_name['CPartnerApps_RequestUploadToken_Request'] = _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_RequestUploadToken_Response'] = _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUpload_Request'] = _CPARTNERAPPS_FINISHUPLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadKVSign_Response'] = _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadLegacyDRM_Request'] = _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadLegacyDRM_Response'] = _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUpload_Response'] = _CPARTNERAPPS_FINISHUPLOAD_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadDepot_Request'] = _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadDepot_Response'] = _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_GetDepotBuildResult_Request'] = _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_GetDepotBuildResult_Response'] = _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FindDRMUploads_Request'] = _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_ExistingDRMUpload'] = _CPARTNERAPPS_EXISTINGDRMUPLOAD
DESCRIPTOR.message_types_by_name['CPartnerApps_FindDRMUploads_Response'] = _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_Download_Request'] = _CPARTNERAPPS_DOWNLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_Download_Response'] = _CPARTNERAPPS_DOWNLOAD_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPartnerApps_RequestUploadToken_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_RequestUploadToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_RequestUploadToken_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_RequestUploadToken_Request)

CPartnerApps_RequestUploadToken_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_RequestUploadToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_RequestUploadToken_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_RequestUploadToken_Response)

CPartnerApps_FinishUpload_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUpload_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOAD_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUpload_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUpload_Request)

CPartnerApps_FinishUploadKVSign_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadKVSign_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadKVSign_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadKVSign_Response)

CPartnerApps_FinishUploadLegacyDRM_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadLegacyDRM_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadLegacyDRM_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadLegacyDRM_Request)

CPartnerApps_FinishUploadLegacyDRM_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadLegacyDRM_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadLegacyDRM_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadLegacyDRM_Response)

CPartnerApps_FinishUpload_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUpload_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOAD_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUpload_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUpload_Response)

CPartnerApps_FinishUploadDepot_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadDepot_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadDepot_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadDepot_Request)

CPartnerApps_FinishUploadDepot_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadDepot_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadDepot_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadDepot_Response)

CPartnerApps_GetDepotBuildResult_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_GetDepotBuildResult_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_GetDepotBuildResult_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_GetDepotBuildResult_Request)

CPartnerApps_GetDepotBuildResult_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_GetDepotBuildResult_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_GetDepotBuildResult_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_GetDepotBuildResult_Response)

CPartnerApps_FindDRMUploads_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FindDRMUploads_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FindDRMUploads_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FindDRMUploads_Request)

CPartnerApps_ExistingDRMUpload = _reflection.GeneratedProtocolMessageType('CPartnerApps_ExistingDRMUpload', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_EXISTINGDRMUPLOAD,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_ExistingDRMUpload)
  })
_sym_db.RegisterMessage(CPartnerApps_ExistingDRMUpload)

CPartnerApps_FindDRMUploads_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FindDRMUploads_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FindDRMUploads_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FindDRMUploads_Response)

CPartnerApps_Download_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_Download_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_DOWNLOAD_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_Download_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_Download_Request)

CPartnerApps_Download_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_Download_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_DOWNLOAD_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_Download_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_Download_Response)


DESCRIPTOR._options = None

_PARTNERAPPS = _descriptor.ServiceDescriptor(
  name='PartnerApps',
  full_name='PartnerApps',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030.Service methods for app management by partners',
  create_key=_descriptor._internal_create_key,
  serialized_start=1506,
  serialized_end=3331,
  methods=[
  _descriptor.MethodDescriptor(
    name='RequestKVSignUploadToken',
    full_name='PartnerApps.RequestKVSignUploadToken',
    index=0,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030<Request upload token for installscript file upload / signing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestDRMUploadToken',
    full_name='PartnerApps.RequestDRMUploadToken',
    index=1,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030<Request upload token for executable file upload / processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestCEGUploadToken',
    full_name='PartnerApps.RequestCEGUploadToken',
    index=2,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030CRequest upload token for custom executable file upload / processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestDepotUploadToken',
    full_name='PartnerApps.RequestDepotUploadToken',
    index=3,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030/Request upload token for steampipe depot upload',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadKVSign',
    full_name='PartnerApps.FinishUploadKVSign',
    index=4,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOAD_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE,
    serialized_options=b'\202\265\030BCommit method to sign an installscript after an upload is complete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadDRMUpload',
    full_name='PartnerApps.FinishUploadDRMUpload',
    index=5,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE,
    serialized_options=b'\202\265\030,Commit method for executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadCEGUpload',
    full_name='PartnerApps.FinishUploadCEGUpload',
    index=6,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOAD_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOAD_RESPONSE,
    serialized_options=b'\202\265\0303Commit method for custom executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadDepotUpload',
    full_name='PartnerApps.FinishUploadDepotUpload',
    index=7,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE,
    serialized_options=b'\202\265\0303Commit method for custom executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDepotBuildResult',
    full_name='PartnerApps.GetDepotBuildResult',
    index=8,
    containing_service=None,
    input_type=_CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST,
    output_type=_CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE,
    serialized_options=b'\202\265\0302Get build status for previously uploaded depot ZIP',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindDRMUploads',
    full_name='PartnerApps.FindDRMUploads',
    index=9,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINDDRMUPLOADS_REQUEST,
    output_type=_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE,
    serialized_options=b'\202\265\030*Finds N most recent prior uploads by appid',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='PartnerApps.Download',
    index=10,
    containing_service=None,
    input_type=_CPARTNERAPPS_DOWNLOAD_REQUEST,
    output_type=_CPARTNERAPPS_DOWNLOAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARTNERAPPS)

DESCRIPTOR.services_by_name['PartnerApps'] = _PARTNERAPPS

PartnerApps = service_reflection.GeneratedServiceType('PartnerApps', (_service.Service,), dict(
  DESCRIPTOR = _PARTNERAPPS,
  __module__ = 'steammessages_partnerapps_pb2'
  ))

PartnerApps_Stub = service_reflection.GeneratedServiceStubType('PartnerApps_Stub', (PartnerApps,), dict(
  DESCRIPTOR = _PARTNERAPPS,
  __module__ = 'steammessages_partnerapps_pb2'
  ))


# @@protoc_insertion_point(module_scope)
