# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_unified_test.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n steammessages_unified_test.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"G\n CMsgTest_MessageToClient_Request\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"H\n!CMsgTest_MessageToClient_Response\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"I\n\"CMsgTest_NotifyClient_Notification\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"G\n CMsgTest_MessageToServer_Request\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"H\n!CMsgTest_MessageToServer_Response\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"I\n\"CMsgTest_NotifyServer_Notification\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.2\x83\x02\n\x0fTestSteamClient\x12\x81\x01\n\x0fMessageToClient\x12!.CMsgTest_MessageToClient_Request\x1a\".CMsgTest_MessageToClient_Response\"\'\x82\xb5\x18#Some description - MessageToClient.\x12\x66\n\x0cNotifyClient\x12#.CMsgTest_NotifyClient_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 Some description - NotifyClient.\x1a\x04\xc0\xb5\x18\x02\x32\x82\x02\n\x14TestServerFromClient\x12\x81\x01\n\x0fMessageToServer\x12!.CMsgTest_MessageToServer_Request\x1a\".CMsgTest_MessageToServer_Response\"\'\x82\xb5\x18#Some description - MessageToServer.\x12\x66\n\x0cNotifyServer\x12#.CMsgTest_NotifyServer_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 Some description - NotifyServer.B\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CMSGTEST_MESSAGETOCLIENT_REQUEST = _descriptor.Descriptor(
  name='CMsgTest_MessageToClient_Request',
  full_name='CMsgTest_MessageToClient_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToClient_Request.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=167,
)


_CMSGTEST_MESSAGETOCLIENT_RESPONSE = _descriptor.Descriptor(
  name='CMsgTest_MessageToClient_Response',
  full_name='CMsgTest_MessageToClient_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToClient_Response.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=241,
)


_CMSGTEST_NOTIFYCLIENT_NOTIFICATION = _descriptor.Descriptor(
  name='CMsgTest_NotifyClient_Notification',
  full_name='CMsgTest_NotifyClient_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_NotifyClient_Notification.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=316,
)


_CMSGTEST_MESSAGETOSERVER_REQUEST = _descriptor.Descriptor(
  name='CMsgTest_MessageToServer_Request',
  full_name='CMsgTest_MessageToServer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToServer_Request.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=389,
)


_CMSGTEST_MESSAGETOSERVER_RESPONSE = _descriptor.Descriptor(
  name='CMsgTest_MessageToServer_Response',
  full_name='CMsgTest_MessageToServer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToServer_Response.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=463,
)


_CMSGTEST_NOTIFYSERVER_NOTIFICATION = _descriptor.Descriptor(
  name='CMsgTest_NotifyServer_Notification',
  full_name='CMsgTest_NotifyServer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_NotifyServer_Notification.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=538,
)

DESCRIPTOR.message_types_by_name['CMsgTest_MessageToClient_Request'] = _CMSGTEST_MESSAGETOCLIENT_REQUEST
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToClient_Response'] = _CMSGTEST_MESSAGETOCLIENT_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgTest_NotifyClient_Notification'] = _CMSGTEST_NOTIFYCLIENT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToServer_Request'] = _CMSGTEST_MESSAGETOSERVER_REQUEST
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToServer_Response'] = _CMSGTEST_MESSAGETOSERVER_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgTest_NotifyServer_Notification'] = _CMSGTEST_NOTIFYSERVER_NOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgTest_MessageToClient_Request = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToClient_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOCLIENT_REQUEST,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToClient_Request)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToClient_Request)

CMsgTest_MessageToClient_Response = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToClient_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOCLIENT_RESPONSE,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToClient_Response)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToClient_Response)

CMsgTest_NotifyClient_Notification = _reflection.GeneratedProtocolMessageType('CMsgTest_NotifyClient_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_NOTIFYCLIENT_NOTIFICATION,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_NotifyClient_Notification)
  })
_sym_db.RegisterMessage(CMsgTest_NotifyClient_Notification)

CMsgTest_MessageToServer_Request = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToServer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOSERVER_REQUEST,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToServer_Request)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToServer_Request)

CMsgTest_MessageToServer_Response = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToServer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOSERVER_RESPONSE,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToServer_Response)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToServer_Response)

CMsgTest_NotifyServer_Notification = _reflection.GeneratedProtocolMessageType('CMsgTest_NotifyServer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_NOTIFYSERVER_NOTIFICATION,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_NotifyServer_Notification)
  })
_sym_db.RegisterMessage(CMsgTest_NotifyServer_Notification)


DESCRIPTOR._options = None
_CMSGTEST_MESSAGETOCLIENT_REQUEST.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOCLIENT_RESPONSE.fields_by_name['some_text']._options = None
_CMSGTEST_NOTIFYCLIENT_NOTIFICATION.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOSERVER_REQUEST.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOSERVER_RESPONSE.fields_by_name['some_text']._options = None
_CMSGTEST_NOTIFYSERVER_NOTIFICATION.fields_by_name['some_text']._options = None

_TESTSTEAMCLIENT = _descriptor.ServiceDescriptor(
  name='TestSteamClient',
  full_name='TestSteamClient',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=541,
  serialized_end=800,
  methods=[
  _descriptor.MethodDescriptor(
    name='MessageToClient',
    full_name='TestSteamClient.MessageToClient',
    index=0,
    containing_service=None,
    input_type=_CMSGTEST_MESSAGETOCLIENT_REQUEST,
    output_type=_CMSGTEST_MESSAGETOCLIENT_RESPONSE,
    serialized_options=b'\202\265\030#Some description - MessageToClient.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyClient',
    full_name='TestSteamClient.NotifyClient',
    index=1,
    containing_service=None,
    input_type=_CMSGTEST_NOTIFYCLIENT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 Some description - NotifyClient.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSTEAMCLIENT)

DESCRIPTOR.services_by_name['TestSteamClient'] = _TESTSTEAMCLIENT


_TESTSERVERFROMCLIENT = _descriptor.ServiceDescriptor(
  name='TestServerFromClient',
  full_name='TestServerFromClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=803,
  serialized_end=1061,
  methods=[
  _descriptor.MethodDescriptor(
    name='MessageToServer',
    full_name='TestServerFromClient.MessageToServer',
    index=0,
    containing_service=None,
    input_type=_CMSGTEST_MESSAGETOSERVER_REQUEST,
    output_type=_CMSGTEST_MESSAGETOSERVER_RESPONSE,
    serialized_options=b'\202\265\030#Some description - MessageToServer.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyServer',
    full_name='TestServerFromClient.NotifyServer',
    index=1,
    containing_service=None,
    input_type=_CMSGTEST_NOTIFYSERVER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 Some description - NotifyServer.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSERVERFROMCLIENT)

DESCRIPTOR.services_by_name['TestServerFromClient'] = _TESTSERVERFROMCLIENT

TestSteamClient = service_reflection.GeneratedServiceType('TestSteamClient', (_service.Service,), dict(
  DESCRIPTOR = _TESTSTEAMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))

TestSteamClient_Stub = service_reflection.GeneratedServiceStubType('TestSteamClient_Stub', (TestSteamClient,), dict(
  DESCRIPTOR = _TESTSTEAMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))


TestServerFromClient = service_reflection.GeneratedServiceType('TestServerFromClient', (_service.Service,), dict(
  DESCRIPTOR = _TESTSERVERFROMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))

TestServerFromClient_Stub = service_reflection.GeneratedServiceStubType('TestServerFromClient_Stub', (TestServerFromClient,), dict(
  DESCRIPTOR = _TESTSERVERFROMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))


# @@protoc_insertion_point(module_scope)
