# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_workshop.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_workshop.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1csteammessages_workshop.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"0\n\x1f\x43Workshop_GetEULAStatus_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"u\n CWorkshop_GetEULAStatus_Response\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x18\n\x10timestamp_action\x18\x02 \x01(\r\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x03 \x01(\x08\x12\x14\n\x0cneeds_action\x18\x04 \x01(\x08\x32\xc6\x01\n\x08Workshop\x12\x8c\x01\n\rGetEULAStatus\x12 .CWorkshop_GetEULAStatus_Request\x1a!.CWorkshop_GetEULAStatus_Response\"6\x82\xb5\x18\x32Retrieve the status of the user\'s EULA acceptance.\x1a+\x82\xb5\x18\'A service to access published file dataB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CWORKSHOP_GETEULASTATUS_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_GetEULAStatus_Request',
  full_name='CWorkshop_GetEULAStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CWorkshop_GetEULAStatus_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=140,
)


_CWORKSHOP_GETEULASTATUS_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_GetEULAStatus_Response',
  full_name='CWorkshop_GetEULAStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CWorkshop_GetEULAStatus_Response.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_action', full_name='CWorkshop_GetEULAStatus_Response.timestamp_action', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted', full_name='CWorkshop_GetEULAStatus_Response.accepted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='needs_action', full_name='CWorkshop_GetEULAStatus_Response.needs_action', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=259,
)

DESCRIPTOR.message_types_by_name['CWorkshop_GetEULAStatus_Request'] = _CWORKSHOP_GETEULASTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetEULAStatus_Response'] = _CWORKSHOP_GETEULASTATUS_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CWorkshop_GetEULAStatus_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_GetEULAStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CWORKSHOP_GETEULASTATUS_REQUEST,
  '__module__' : 'steammessages_workshop_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetEULAStatus_Request)
  })
_sym_db.RegisterMessage(CWorkshop_GetEULAStatus_Request)

CWorkshop_GetEULAStatus_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_GetEULAStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CWORKSHOP_GETEULASTATUS_RESPONSE,
  '__module__' : 'steammessages_workshop_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetEULAStatus_Response)
  })
_sym_db.RegisterMessage(CWorkshop_GetEULAStatus_Response)


DESCRIPTOR._options = None

_WORKSHOP = _descriptor.ServiceDescriptor(
  name='Workshop',
  full_name='Workshop',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\'A service to access published file data',
  create_key=_descriptor._internal_create_key,
  serialized_start=262,
  serialized_end=460,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEULAStatus',
    full_name='Workshop.GetEULAStatus',
    index=0,
    containing_service=None,
    input_type=_CWORKSHOP_GETEULASTATUS_REQUEST,
    output_type=_CWORKSHOP_GETEULASTATUS_RESPONSE,
    serialized_options=b'\202\265\0302Retrieve the status of the user\'s EULA acceptance.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKSHOP)

DESCRIPTOR.services_by_name['Workshop'] = _WORKSHOP

Workshop = service_reflection.GeneratedServiceType('Workshop', (_service.Service,), dict(
  DESCRIPTOR = _WORKSHOP,
  __module__ = 'steammessages_workshop_pb2'
  ))

Workshop_Stub = service_reflection.GeneratedServiceStubType('Workshop_Stub', (Workshop,), dict(
  DESCRIPTOR = _WORKSHOP,
  __module__ = 'steammessages_workshop_pb2'
  ))


# @@protoc_insertion_point(module_scope)
