# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_physicalgoods.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_physicalgoods.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_physicalgoods.proto\x1a steammessages_unified_base.proto\"`\n.CPhysicalGoods_RegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"1\n/CPhysicalGoods_RegisterSteamController_Response\"l\n:CPhysicalGoods_CompleteSteamControllerRegistration_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"=\n;CPhysicalGoods_CompleteSteamControllerRegistration_Response\"h\n6CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"k\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15registration_complete\x18\x02 \x01(\x08\"\x85\x01\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\x12J\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\"~\n8CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\"\x88\x02\n/CPhysicalGoods_SteamControllerSetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12Q\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"2\n0CPhysicalGoods_SteamControllerSetConfig_Response\"\xca\x01\n/CPhysicalGoods_SteamControllerGetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12\x13\n\x0b\x61ppidorname\x18\x04 \x01(\t\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x95\x01\n8CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x04 \x01(\t\"\x85\x01\n0CPhysicalGoods_SteamControllerGetConfig_Response\x12Q\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\"u\n0CPhysicalGoods_DeRegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\"3\n1CPhysicalGoods_DeRegisterSteamController_Response\"r\n-CPhysicalGoods_SetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x11\n\taccountid\x18\x03 \x01(\r\"0\n.CPhysicalGoods_SetPersonalizationFile_Response\"Y\n-CPhysicalGoods_GetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x11\n\taccountid\x18\x02 \x01(\r\"I\n.CPhysicalGoods_GetPersonalizationFile_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x32\xd7\x0c\n\rPhysicalGoods\x12\xd4\x01\n\x17RegisterSteamController\x12/.CPhysicalGoods_RegisterSteamController_Request\x1a\x30.CPhysicalGoods_RegisterSteamController_Response\"V\x82\xb5\x18RRecords a serial number and the calling user\'s account info for warranty purposes.\x12\xd3\x01\n#CompleteSteamControllerRegistration\x12;.CPhysicalGoods_CompleteSteamControllerRegistration_Request\x1a<.CPhysicalGoods_CompleteSteamControllerRegistration_Response\"1\x82\xb5\x18-Marks a controller\'s registration as complete\x12\xd7\x01\n#QueryAccountsRegisteredToController\x12\x37.CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x1a\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\"=\x82\xb5\x18\x39Sends back a list of accounts registered to a controller.\x12\xb8\x01\n SetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerSetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerSetConfig_Response\"/\x82\xb5\x18+Sets a desired controller config for an app\x12\xb8\x01\n GetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerGetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerGetConfig_Response\"/\x82\xb5\x18+Gets a desired controller config for an app\x12\xa1\x01\n\x19\x44\x65RegisterSteamController\x12\x31.CPhysicalGoods_DeRegisterSteamController_Request\x1a\x32.CPhysicalGoods_DeRegisterSteamController_Response\"\x1d\x82\xb5\x18\x19\x44\x65 registers a controller\x12\xb7\x01\n SetControllerPersonalizationFile\x12..CPhysicalGoods_SetPersonalizationFile_Request\x1a/.CPhysicalGoods_SetPersonalizationFile_Response\"2\x82\xb5\x18.Stores the file ID of the personalization file\x12\xb5\x01\n GetControllerPersonalizationFile\x12..CPhysicalGoods_GetPersonalizationFile_Request\x1a/.CPhysicalGoods_GetPersonalizationFile_Response\"0\x82\xb5\x18,Gets the file ID of the personalization file\x1a\x33\x82\xb5\x18/A service to use physical goods related methodsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])




_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_RegisterSteamController_Request',
  full_name='CPhysicalGoods_RegisterSteamController_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_RegisterSteamController_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_RegisterSteamController_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=167,
)


_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_RegisterSteamController_Response',
  full_name='CPhysicalGoods_RegisterSteamController_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=218,
)


_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_CompleteSteamControllerRegistration_Request',
  full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=328,
)


_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_CompleteSteamControllerRegistration_Response',
  full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=391,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=497,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registration_complete', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts.registration_complete', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=606,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=742,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig',
  full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.appidorname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='templatename', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.templatename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=870,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_Request',
  full_name='CPhysicalGoods_SteamControllerSetConfig_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configurations', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.configurations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.controller_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_for_this_serial', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.only_for_this_serial', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=1137,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_Response',
  full_name='CPhysicalGoods_SteamControllerSetConfig_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1139,
  serialized_end=1189,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_Request',
  full_name='CPhysicalGoods_SteamControllerGetConfig_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.appidorname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.controller_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_for_this_serial', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.only_for_this_serial', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1394,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig',
  full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.appidorname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='templatename', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.templatename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.serial_number', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1546,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_Response',
  full_name='CPhysicalGoods_SteamControllerGetConfig_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configurations', full_name='CPhysicalGoods_SteamControllerGetConfig_Response.configurations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1682,
)


_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_DeRegisterSteamController_Request',
  full_name='CPhysicalGoods_DeRegisterSteamController_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_DeRegisterSteamController_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_DeRegisterSteamController_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_DeRegisterSteamController_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1684,
  serialized_end=1801,
)


_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_DeRegisterSteamController_Response',
  full_name='CPhysicalGoods_DeRegisterSteamController_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1854,
)


_CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SetPersonalizationFile_Request',
  full_name='CPhysicalGoods_SetPersonalizationFile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SetPersonalizationFile_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SetPersonalizationFile_Request.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SetPersonalizationFile_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=1970,
)


_CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SetPersonalizationFile_Response',
  full_name='CPhysicalGoods_SetPersonalizationFile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2020,
)


_CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_GetPersonalizationFile_Request',
  full_name='CPhysicalGoods_GetPersonalizationFile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_GetPersonalizationFile_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_GetPersonalizationFile_Request.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2111,
)


_CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_GetPersonalizationFile_Response',
  full_name='CPhysicalGoods_GetPersonalizationFile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_GetPersonalizationFile_Response.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2113,
  serialized_end=2186,
)

_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE.fields_by_name['accounts'].message_type = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS
_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST.fields_by_name['configurations'].message_type = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG
_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE.fields_by_name['configurations'].message_type = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_RegisterSteamController_Request'] = _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_RegisterSteamController_Response'] = _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_CompleteSteamControllerRegistration_Request'] = _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_CompleteSteamControllerRegistration_Response'] = _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Request'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Response'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_ControllerConfig'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_Request'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_Response'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_Request'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_ControllerConfig'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_Response'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_DeRegisterSteamController_Request'] = _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_DeRegisterSteamController_Response'] = _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SetPersonalizationFile_Request'] = _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SetPersonalizationFile_Response'] = _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_GetPersonalizationFile_Request'] = _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_GetPersonalizationFile_Response'] = _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPhysicalGoods_RegisterSteamController_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_RegisterSteamController_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_RegisterSteamController_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_RegisterSteamController_Request)

CPhysicalGoods_RegisterSteamController_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_RegisterSteamController_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_RegisterSteamController_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_RegisterSteamController_Response)

CPhysicalGoods_CompleteSteamControllerRegistration_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_CompleteSteamControllerRegistration_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_CompleteSteamControllerRegistration_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_CompleteSteamControllerRegistration_Request)

CPhysicalGoods_CompleteSteamControllerRegistration_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_CompleteSteamControllerRegistration_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_CompleteSteamControllerRegistration_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_CompleteSteamControllerRegistration_Response)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Request)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Response)

CPhysicalGoods_SteamControllerSetConfig_ControllerConfig = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_ControllerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_ControllerConfig)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_ControllerConfig)

CPhysicalGoods_SteamControllerSetConfig_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_Request)

CPhysicalGoods_SteamControllerSetConfig_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_Response)

CPhysicalGoods_SteamControllerGetConfig_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_Request)

CPhysicalGoods_SteamControllerGetConfig_ControllerConfig = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_ControllerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_ControllerConfig)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_ControllerConfig)

CPhysicalGoods_SteamControllerGetConfig_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_Response)

CPhysicalGoods_DeRegisterSteamController_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_DeRegisterSteamController_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_DeRegisterSteamController_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_DeRegisterSteamController_Request)

CPhysicalGoods_DeRegisterSteamController_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_DeRegisterSteamController_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_DeRegisterSteamController_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_DeRegisterSteamController_Response)

CPhysicalGoods_SetPersonalizationFile_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SetPersonalizationFile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SetPersonalizationFile_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SetPersonalizationFile_Request)

CPhysicalGoods_SetPersonalizationFile_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SetPersonalizationFile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SetPersonalizationFile_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SetPersonalizationFile_Response)

CPhysicalGoods_GetPersonalizationFile_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_GetPersonalizationFile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_GetPersonalizationFile_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_GetPersonalizationFile_Request)

CPhysicalGoods_GetPersonalizationFile_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_GetPersonalizationFile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_GetPersonalizationFile_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_GetPersonalizationFile_Response)


DESCRIPTOR._options = None

_PHYSICALGOODS = _descriptor.ServiceDescriptor(
  name='PhysicalGoods',
  full_name='PhysicalGoods',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030/A service to use physical goods related methods',
  create_key=_descriptor._internal_create_key,
  serialized_start=2189,
  serialized_end=3812,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterSteamController',
    full_name='PhysicalGoods.RegisterSteamController',
    index=0,
    containing_service=None,
    input_type=_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST,
    output_type=_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE,
    serialized_options=b'\202\265\030RRecords a serial number and the calling user\'s account info for warranty purposes.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteSteamControllerRegistration',
    full_name='PhysicalGoods.CompleteSteamControllerRegistration',
    index=1,
    containing_service=None,
    input_type=_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST,
    output_type=_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE,
    serialized_options=b'\202\265\030-Marks a controller\'s registration as complete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryAccountsRegisteredToController',
    full_name='PhysicalGoods.QueryAccountsRegisteredToController',
    index=2,
    containing_service=None,
    input_type=_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST,
    output_type=_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE,
    serialized_options=b'\202\265\0309Sends back a list of accounts registered to a controller.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDesiredControllerConfigForApp',
    full_name='PhysicalGoods.SetDesiredControllerConfigForApp',
    index=3,
    containing_service=None,
    input_type=_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST,
    output_type=_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE,
    serialized_options=b'\202\265\030+Sets a desired controller config for an app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDesiredControllerConfigForApp',
    full_name='PhysicalGoods.GetDesiredControllerConfigForApp',
    index=4,
    containing_service=None,
    input_type=_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST,
    output_type=_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE,
    serialized_options=b'\202\265\030+Gets a desired controller config for an app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeRegisterSteamController',
    full_name='PhysicalGoods.DeRegisterSteamController',
    index=5,
    containing_service=None,
    input_type=_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST,
    output_type=_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE,
    serialized_options=b'\202\265\030\031De registers a controller',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetControllerPersonalizationFile',
    full_name='PhysicalGoods.SetControllerPersonalizationFile',
    index=6,
    containing_service=None,
    input_type=_CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST,
    output_type=_CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE,
    serialized_options=b'\202\265\030.Stores the file ID of the personalization file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControllerPersonalizationFile',
    full_name='PhysicalGoods.GetControllerPersonalizationFile',
    index=7,
    containing_service=None,
    input_type=_CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST,
    output_type=_CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE,
    serialized_options=b'\202\265\030,Gets the file ID of the personalization file',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PHYSICALGOODS)

DESCRIPTOR.services_by_name['PhysicalGoods'] = _PHYSICALGOODS

PhysicalGoods = service_reflection.GeneratedServiceType('PhysicalGoods', (_service.Service,), dict(
  DESCRIPTOR = _PHYSICALGOODS,
  __module__ = 'steammessages_physicalgoods_pb2'
  ))

PhysicalGoods_Stub = service_reflection.GeneratedServiceStubType('PhysicalGoods_Stub', (PhysicalGoods,), dict(
  DESCRIPTOR = _PHYSICALGOODS,
  __module__ = 'steammessages_physicalgoods_pb2'
  ))


# @@protoc_insertion_point(module_scope)
