# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_credentials.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_credentials.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"q\n*CCredentials_TestAvailablePassword_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x1b\n\x13sha_digest_password\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\"?\n+CCredentials_TestAvailablePassword_Response\x12\x10\n\x08is_valid\x18\x03 \x01(\x08\"\x9e\x03\n)CCredentials_GetSteamGuardDetails_Request\x12u\n\x1binclude_new_authentications\x18\x01 \x01(\x08:\x04trueBJ\x82\xb5\x18\x46Whether or not to populate the newauthentication field in the response\x12\x95\x01\n\twebcookie\x18\x02 \x01(\tB\x81\x01\x82\xb5\x18}The user\'s Steam Guard machine auth cookie. If present, it\'ll be used to get the user\'s machine ID instead of the AM session.\x12 \n\x18timestamp_minimum_wanted\x18\x03 \x01(\x07\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x04 \x01(\x05\x12\"\n\nip_address\x18\x05 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xb3\t\n*CCredentials_GetSteamGuardDetails_Response\x12\x1d\n\x15is_steamguard_enabled\x18\x01 \x01(\x08\x12$\n\x1ctimestamp_steamguard_enabled\x18\x02 \x01(\x07\x12\x63\n\x1c\x64\x65precated_newauthentication\x18\x03 \x03(\x0b\x32=.CCredentials_GetSteamGuardDetails_Response.NewAuthentication\x12*\n\"deprecated_machine_name_userchosen\x18\x04 \x01(\t\x12\x37\n/deprecated_timestamp_machine_steamguard_enabled\x18\x05 \x01(\x07\x12\x43\n;deprecated_authentication_exists_from_geoloc_before_mintime\x18\x06 \x01(\x08\x12\x1d\n\x15\x64\x65precated_machine_id\x18\x07 \x01(\x04\x12M\n\x0csession_data\x18\x08 \x03(\x0b\x32\x37.CCredentials_GetSteamGuardDetails_Response.SessionData\x12\x1c\n\x14is_twofactor_enabled\x18\t \x01(\x08\x12#\n\x1btimestamp_twofactor_enabled\x18\n \x01(\x07\x12\x19\n\x11is_phone_verified\x18\x0b \x01(\x08\x1a\xf2\x01\n\x11NewAuthentication\x12$\n\x1ctimestamp_steamguard_enabled\x18\x01 \x01(\x07\x12\x15\n\ris_web_cookie\x18\x02 \x01(\x08\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x03 \x01(\x05\x12\x13\n\x0bgeoloc_info\x18\x04 \x01(\t\x12\x15\n\ris_remembered\x18\x05 \x01(\x08\x12\"\n\x1amachine_name_user_supplied\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\"\n\nip_address\x18\x08 \x01(\x0b\x32\x0e.CMsgIPAddress\x1a\xef\x02\n\x0bSessionData\x12\x12\n\nmachine_id\x18\x01 \x01(\x04\x12\x1f\n\x17machine_name_userchosen\x18\x02 \x01(\t\x12,\n$timestamp_machine_steamguard_enabled\x18\x03 \x01(\x07\x12\x38\n0authentication_exists_from_geoloc_before_mintime\x18\x04 \x01(\x08\x12X\n\x11newauthentication\x18\x05 \x03(\x0b\x32=.CCredentials_GetSteamGuardDetails_Response.NewAuthentication\x12\x39\n1authentication_exists_from_same_ip_before_mintime\x18\x06 \x01(\x08\x12\x13\n\x0bpublic_ipv4\x18\x07 \x01(\r\x12\x19\n\x11public_ip_address\x18\x08 \x01(\t\"d\n1CCredentials_NewMachineNotificationDialog_Request\x12\x13\n\x0bis_approved\x18\x01 \x01(\x08\x12\x1a\n\x12is_wizard_complete\x18\x02 \x01(\x08\"4\n2CCredentials_NewMachineNotificationDialog_Response\";\n)CCredentials_ValidateEmailAddress_Request\x12\x0e\n\x06stoken\x18\x01 \x01(\t\"C\n*CCredentials_ValidateEmailAddress_Response\x12\x15\n\rwas_validated\x18\x01 \x01(\x08\"_\n-CCredentials_SteamGuardPhishingReport_Request\x12\x14\n\x0cparam_string\x18\x01 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x02 \x01(\t\"\xb3\x02\n.CCredentials_SteamGuardPhishingReport_Response\x12\x1e\n\x16ipaddress_loginattempt\x18\x01 \x01(\t\x12 \n\x18\x63ountryname_loginattempt\x18\x02 \x01(\t\x12\x1e\n\x16statename_loginattempt\x18\x03 \x01(\t\x12\x1d\n\x15\x63ityname_loginattempt\x18\x04 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x05 \x01(\t\x12\x1a\n\x12\x63ountryname_actual\x18\x06 \x01(\t\x12\x18\n\x10statename_actual\x18\x07 \x01(\t\x12\x17\n\x0f\x63ityname_actual\x18\x08 \x01(\t\x12\x17\n\x0fsteamguard_code\x18\t \x01(\t\"J\n-CCredentials_LastCredentialChangeTime_Request\x12\x19\n\x11user_changes_only\x18\x01 \x01(\x08\"\xa4\x01\n.CCredentials_LastCredentialChangeTime_Response\x12&\n\x1etimestamp_last_password_change\x18\x01 \x01(\x07\x12#\n\x1btimestamp_last_email_change\x18\x02 \x01(\x07\x12%\n\x1dtimestamp_last_password_reset\x18\x03 \x01(\x07\"+\n)CCredentials_GetAccountAuthSecret_Request\"O\n*CCredentials_GetAccountAuthSecret_Response\x12\x11\n\tsecret_id\x18\x01 \x01(\x05\x12\x0e\n\x06secret\x18\x02 \x01(\x0c\x32\xed\x08\n\x0b\x43redentials\x12\x8e\x01\n\x15TestAvailablePassword\x12+.CCredentials_TestAvailablePassword_Request\x1a,.CCredentials_TestAvailablePassword_Response\"\x1a\x82\xb5\x18\x16TestAvailablePassword.\x12\x8a\x01\n\x14GetSteamGuardDetails\x12*.CCredentials_GetSteamGuardDetails_Request\x1a+.CCredentials_GetSteamGuardDetails_Response\"\x19\x82\xb5\x18\x15GetSteamGuardDetails.\x12\xb6\x01\n\"NewMachineNotificationDialogResult\x12\x32.CCredentials_NewMachineNotificationDialog_Request\x1a\x33.CCredentials_NewMachineNotificationDialog_Response\"\'\x82\xb5\x18#NewMachineNotificationDialogResult.\x12\x9c\x01\n\x14ValidateEmailAddress\x12*.CCredentials_ValidateEmailAddress_Request\x1a+.CCredentials_ValidateEmailAddress_Response\"+\x82\xb5\x18\'Validate an email address given a token\x12\x99\x01\n\x18SteamGuardPhishingReport\x12..CCredentials_SteamGuardPhishingReport_Request\x1a/.CCredentials_SteamGuardPhishingReport_Response\"\x1c\x82\xb5\x18\x18SteamGuardPhishingReport\x12\xa6\x01\n\x1eGetCredentialChangeTimeDetails\x12..CCredentials_LastCredentialChangeTime_Request\x1a/.CCredentials_LastCredentialChangeTime_Response\"#\x82\xb5\x18\x1fGetCredentialChangeTimeDetails.\x12\x89\x01\n\x14GetAccountAuthSecret\x12*.CCredentials_GetAccountAuthSecret_Request\x1a+.CCredentials_GetAccountAuthSecret_Response\"\x18\x82\xb5\x18\x14GetAccountAuthSecret\x1a\x17\x82\xb5\x18\x13\x43redentials serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST = _descriptor.Descriptor(
  name='CCredentials_TestAvailablePassword_Request',
  full_name='CCredentials_TestAvailablePassword_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CCredentials_TestAvailablePassword_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_digest_password', full_name='CCredentials_TestAvailablePassword_Request.sha_digest_password', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CCredentials_TestAvailablePassword_Request.account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=208,
)


_CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_TestAvailablePassword_Response',
  full_name='CCredentials_TestAvailablePassword_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_valid', full_name='CCredentials_TestAvailablePassword_Response.is_valid', index=0,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=273,
)


_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST = _descriptor.Descriptor(
  name='CCredentials_GetSteamGuardDetails_Request',
  full_name='CCredentials_GetSteamGuardDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_new_authentications', full_name='CCredentials_GetSteamGuardDetails_Request.include_new_authentications', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FWhether or not to populate the newauthentication field in the response', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webcookie', full_name='CCredentials_GetSteamGuardDetails_Request.webcookie', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030}The user\'s Steam Guard machine auth cookie. If present, it\'ll be used to get the user\'s machine ID instead of the AM session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_minimum_wanted', full_name='CCredentials_GetSteamGuardDetails_Request.timestamp_minimum_wanted', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_ipaddress', full_name='CCredentials_GetSteamGuardDetails_Request.deprecated_ipaddress', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='CCredentials_GetSteamGuardDetails_Request.ip_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=690,
)


_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION = _descriptor.Descriptor(
  name='NewAuthentication',
  full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.timestamp_steamguard_enabled', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_web_cookie', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.is_web_cookie', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_ipaddress', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.deprecated_ipaddress', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geoloc_info', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.geoloc_info', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_remembered', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.is_remembered', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name_user_supplied', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.machine_name_user_supplied', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.status', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.ip_address', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1526,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA = _descriptor.Descriptor(
  name='SessionData',
  full_name='CCredentials_GetSteamGuardDetails_Response.SessionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.machine_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name_userchosen', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.machine_name_userchosen', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_machine_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.timestamp_machine_steamguard_enabled', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication_exists_from_geoloc_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.authentication_exists_from_geoloc_before_mintime', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newauthentication', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.newauthentication', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication_exists_from_same_ip_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.authentication_exists_from_same_ip_before_mintime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ipv4', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.public_ipv4', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip_address', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.public_ip_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1896,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_GetSteamGuardDetails_Response',
  full_name='CCredentials_GetSteamGuardDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.is_steamguard_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.timestamp_steamguard_enabled', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_newauthentication', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_newauthentication', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_machine_name_userchosen', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_machine_name_userchosen', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_timestamp_machine_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_timestamp_machine_steamguard_enabled', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_authentication_exists_from_geoloc_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_authentication_exists_from_geoloc_before_mintime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_machine_id', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_machine_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_data', full_name='CCredentials_GetSteamGuardDetails_Response.session_data', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_twofactor_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.is_twofactor_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_twofactor_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.timestamp_twofactor_enabled', index=9,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_phone_verified', full_name='CCredentials_GetSteamGuardDetails_Response.is_phone_verified', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION, _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=1896,
)


_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST = _descriptor.Descriptor(
  name='CCredentials_NewMachineNotificationDialog_Request',
  full_name='CCredentials_NewMachineNotificationDialog_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_approved', full_name='CCredentials_NewMachineNotificationDialog_Request.is_approved', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wizard_complete', full_name='CCredentials_NewMachineNotificationDialog_Request.is_wizard_complete', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1898,
  serialized_end=1998,
)


_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_NewMachineNotificationDialog_Response',
  full_name='CCredentials_NewMachineNotificationDialog_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2000,
  serialized_end=2052,
)


_CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST = _descriptor.Descriptor(
  name='CCredentials_ValidateEmailAddress_Request',
  full_name='CCredentials_ValidateEmailAddress_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stoken', full_name='CCredentials_ValidateEmailAddress_Request.stoken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2054,
  serialized_end=2113,
)


_CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_ValidateEmailAddress_Response',
  full_name='CCredentials_ValidateEmailAddress_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='was_validated', full_name='CCredentials_ValidateEmailAddress_Response.was_validated', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2182,
)


_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST = _descriptor.Descriptor(
  name='CCredentials_SteamGuardPhishingReport_Request',
  full_name='CCredentials_SteamGuardPhishingReport_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='param_string', full_name='CCredentials_SteamGuardPhishingReport_Request.param_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress_actual', full_name='CCredentials_SteamGuardPhishingReport_Request.ipaddress_actual', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2184,
  serialized_end=2279,
)


_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_SteamGuardPhishingReport_Response',
  full_name='CCredentials_SteamGuardPhishingReport_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipaddress_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.ipaddress_loginattempt', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countryname_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.countryname_loginattempt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statename_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.statename_loginattempt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cityname_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.cityname_loginattempt', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.ipaddress_actual', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countryname_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.countryname_actual', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statename_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.statename_actual', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cityname_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.cityname_actual', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_code', full_name='CCredentials_SteamGuardPhishingReport_Response.steamguard_code', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2589,
)


_CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST = _descriptor.Descriptor(
  name='CCredentials_LastCredentialChangeTime_Request',
  full_name='CCredentials_LastCredentialChangeTime_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_changes_only', full_name='CCredentials_LastCredentialChangeTime_Request.user_changes_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=2665,
)


_CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_LastCredentialChangeTime_Response',
  full_name='CCredentials_LastCredentialChangeTime_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_last_password_change', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_password_change', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_last_email_change', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_email_change', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_last_password_reset', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_password_reset', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2668,
  serialized_end=2832,
)


_CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST = _descriptor.Descriptor(
  name='CCredentials_GetAccountAuthSecret_Request',
  full_name='CCredentials_GetAccountAuthSecret_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2834,
  serialized_end=2877,
)


_CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_GetAccountAuthSecret_Response',
  full_name='CCredentials_GetAccountAuthSecret_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret_id', full_name='CCredentials_GetAccountAuthSecret_Response.secret_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='CCredentials_GetAccountAuthSecret_Response.secret', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2879,
  serialized_end=2958,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION.fields_by_name['ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION.containing_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA.fields_by_name['newauthentication'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA.containing_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE.fields_by_name['deprecated_newauthentication'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE.fields_by_name['session_data'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA
DESCRIPTOR.message_types_by_name['CCredentials_TestAvailablePassword_Request'] = _CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_TestAvailablePassword_Response'] = _CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_GetSteamGuardDetails_Request'] = _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_GetSteamGuardDetails_Response'] = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_NewMachineNotificationDialog_Request'] = _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_NewMachineNotificationDialog_Response'] = _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_ValidateEmailAddress_Request'] = _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_ValidateEmailAddress_Response'] = _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_SteamGuardPhishingReport_Request'] = _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_SteamGuardPhishingReport_Response'] = _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_LastCredentialChangeTime_Request'] = _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_LastCredentialChangeTime_Response'] = _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_GetAccountAuthSecret_Request'] = _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_GetAccountAuthSecret_Response'] = _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CCredentials_TestAvailablePassword_Request = _reflection.GeneratedProtocolMessageType('CCredentials_TestAvailablePassword_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_TestAvailablePassword_Request)
  })
_sym_db.RegisterMessage(CCredentials_TestAvailablePassword_Request)

CCredentials_TestAvailablePassword_Response = _reflection.GeneratedProtocolMessageType('CCredentials_TestAvailablePassword_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_TestAvailablePassword_Response)
  })
_sym_db.RegisterMessage(CCredentials_TestAvailablePassword_Response)

CCredentials_GetSteamGuardDetails_Request = _reflection.GeneratedProtocolMessageType('CCredentials_GetSteamGuardDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Request)
  })
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Request)

CCredentials_GetSteamGuardDetails_Response = _reflection.GeneratedProtocolMessageType('CCredentials_GetSteamGuardDetails_Response', (_message.Message,), {

  'NewAuthentication' : _reflection.GeneratedProtocolMessageType('NewAuthentication', (_message.Message,), {
    'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION,
    '__module__' : 'steammessages_credentials_pb2'
    # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response.NewAuthentication)
    })
  ,

  'SessionData' : _reflection.GeneratedProtocolMessageType('SessionData', (_message.Message,), {
    'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA,
    '__module__' : 'steammessages_credentials_pb2'
    # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response.SessionData)
    })
  ,
  'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response)
  })
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response)
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response.NewAuthentication)
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response.SessionData)

CCredentials_NewMachineNotificationDialog_Request = _reflection.GeneratedProtocolMessageType('CCredentials_NewMachineNotificationDialog_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_NewMachineNotificationDialog_Request)
  })
_sym_db.RegisterMessage(CCredentials_NewMachineNotificationDialog_Request)

CCredentials_NewMachineNotificationDialog_Response = _reflection.GeneratedProtocolMessageType('CCredentials_NewMachineNotificationDialog_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_NewMachineNotificationDialog_Response)
  })
_sym_db.RegisterMessage(CCredentials_NewMachineNotificationDialog_Response)

CCredentials_ValidateEmailAddress_Request = _reflection.GeneratedProtocolMessageType('CCredentials_ValidateEmailAddress_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_ValidateEmailAddress_Request)
  })
_sym_db.RegisterMessage(CCredentials_ValidateEmailAddress_Request)

CCredentials_ValidateEmailAddress_Response = _reflection.GeneratedProtocolMessageType('CCredentials_ValidateEmailAddress_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_ValidateEmailAddress_Response)
  })
_sym_db.RegisterMessage(CCredentials_ValidateEmailAddress_Response)

CCredentials_SteamGuardPhishingReport_Request = _reflection.GeneratedProtocolMessageType('CCredentials_SteamGuardPhishingReport_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_SteamGuardPhishingReport_Request)
  })
_sym_db.RegisterMessage(CCredentials_SteamGuardPhishingReport_Request)

CCredentials_SteamGuardPhishingReport_Response = _reflection.GeneratedProtocolMessageType('CCredentials_SteamGuardPhishingReport_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_SteamGuardPhishingReport_Response)
  })
_sym_db.RegisterMessage(CCredentials_SteamGuardPhishingReport_Response)

CCredentials_LastCredentialChangeTime_Request = _reflection.GeneratedProtocolMessageType('CCredentials_LastCredentialChangeTime_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_LastCredentialChangeTime_Request)
  })
_sym_db.RegisterMessage(CCredentials_LastCredentialChangeTime_Request)

CCredentials_LastCredentialChangeTime_Response = _reflection.GeneratedProtocolMessageType('CCredentials_LastCredentialChangeTime_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_LastCredentialChangeTime_Response)
  })
_sym_db.RegisterMessage(CCredentials_LastCredentialChangeTime_Response)

CCredentials_GetAccountAuthSecret_Request = _reflection.GeneratedProtocolMessageType('CCredentials_GetAccountAuthSecret_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetAccountAuthSecret_Request)
  })
_sym_db.RegisterMessage(CCredentials_GetAccountAuthSecret_Request)

CCredentials_GetAccountAuthSecret_Response = _reflection.GeneratedProtocolMessageType('CCredentials_GetAccountAuthSecret_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetAccountAuthSecret_Response)
  })
_sym_db.RegisterMessage(CCredentials_GetAccountAuthSecret_Response)


DESCRIPTOR._options = None
_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['include_new_authentications']._options = None
_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['webcookie']._options = None

_CREDENTIALS = _descriptor.ServiceDescriptor(
  name='Credentials',
  full_name='Credentials',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\023Credentials service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2961,
  serialized_end=4094,
  methods=[
  _descriptor.MethodDescriptor(
    name='TestAvailablePassword',
    full_name='Credentials.TestAvailablePassword',
    index=0,
    containing_service=None,
    input_type=_CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST,
    output_type=_CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE,
    serialized_options=b'\202\265\030\026TestAvailablePassword.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSteamGuardDetails',
    full_name='Credentials.GetSteamGuardDetails',
    index=1,
    containing_service=None,
    input_type=_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST,
    output_type=_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE,
    serialized_options=b'\202\265\030\025GetSteamGuardDetails.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewMachineNotificationDialogResult',
    full_name='Credentials.NewMachineNotificationDialogResult',
    index=2,
    containing_service=None,
    input_type=_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST,
    output_type=_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE,
    serialized_options=b'\202\265\030#NewMachineNotificationDialogResult.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateEmailAddress',
    full_name='Credentials.ValidateEmailAddress',
    index=3,
    containing_service=None,
    input_type=_CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST,
    output_type=_CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE,
    serialized_options=b'\202\265\030\'Validate an email address given a token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SteamGuardPhishingReport',
    full_name='Credentials.SteamGuardPhishingReport',
    index=4,
    containing_service=None,
    input_type=_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST,
    output_type=_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE,
    serialized_options=b'\202\265\030\030SteamGuardPhishingReport',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCredentialChangeTimeDetails',
    full_name='Credentials.GetCredentialChangeTimeDetails',
    index=5,
    containing_service=None,
    input_type=_CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST,
    output_type=_CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE,
    serialized_options=b'\202\265\030\037GetCredentialChangeTimeDetails.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountAuthSecret',
    full_name='Credentials.GetAccountAuthSecret',
    index=6,
    containing_service=None,
    input_type=_CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST,
    output_type=_CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE,
    serialized_options=b'\202\265\030\024GetAccountAuthSecret',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CREDENTIALS)

DESCRIPTOR.services_by_name['Credentials'] = _CREDENTIALS

Credentials = service_reflection.GeneratedServiceType('Credentials', (_service.Service,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'steammessages_credentials_pb2'
  ))

Credentials_Stub = service_reflection.GeneratedServiceStubType('Credentials_Stub', (Credentials,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'steammessages_credentials_pb2'
  ))


# @@protoc_insertion_point(module_scope)
