# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parental.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_parental.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1csteammessages_parental.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"0\n\x0bParentalApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nis_allowed\x18\x02 \x01(\x08\"\xca\x02\n\x10ParentalSettings\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x61pplist_base_id\x18\x02 \x01(\r\x12 \n\x18\x61pplist_base_description\x18\x03 \x01(\t\x12\"\n\x0c\x61pplist_base\x18\x04 \x03(\x0b\x32\x0c.ParentalApp\x12$\n\x0e\x61pplist_custom\x18\x05 \x03(\x0b\x32\x0c.ParentalApp\x12\x18\n\x10passwordhashtype\x18\x06 \x01(\r\x12\x0c\n\x04salt\x18\x07 \x01(\x0c\x12\x14\n\x0cpasswordhash\x18\x08 \x01(\x0c\x12\x12\n\nis_enabled\x18\t \x01(\x08\x12\x18\n\x10\x65nabled_features\x18\n \x01(\r\x12\x16\n\x0erecovery_email\x18\x0b \x01(\t\x12\x1c\n\x14is_site_license_lock\x18\x0c \x01(\x08\"\x99\x01\n(CParental_EnableParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12#\n\x08settings\x18\x02 \x01(\x0b\x32\x11.ParentalSettings\x12\x11\n\tsessionid\x18\x03 \x01(\t\x12\x12\n\nenablecode\x18\x04 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\"+\n)CParental_EnableParentalSettings_Response\"N\n)CParental_DisableParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\n \x01(\x06\",\n*CParental_DisableParentalSettings_Response\"8\n%CParental_GetParentalSettings_Request\x12\x0f\n\x07steamid\x18\n \x01(\x06\"M\n&CParental_GetParentalSettings_Response\x12#\n\x08settings\x18\x01 \x01(\x0b\x32\x11.ParentalSettings\"?\n+CParental_GetSignedParentalSettings_Request\x12\x10\n\x08priority\x18\x01 \x01(\r\"^\n,CParental_GetSignedParentalSettings_Response\x12\x1b\n\x13serialized_settings\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"\x98\x01\n%CParental_SetParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12#\n\x08settings\x18\x02 \x01(\x0b\x32\x11.ParentalSettings\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12\x11\n\tsessionid\x18\x04 \x01(\t\x12\x0f\n\x07steamid\x18\n \x01(\x06\"(\n&CParental_SetParentalSettings_Response\"7\n\x1f\x43Parental_ValidateToken_Request\x12\x14\n\x0cunlock_token\x18\x01 \x01(\t\"\"\n CParental_ValidateToken_Response\"g\n\"CParental_ValidatePassword_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x0f\n\x07session\x18\x02 \x01(\t\x12\x1e\n\x16send_unlock_on_success\x18\x03 \x01(\x08\"4\n#CParental_ValidatePassword_Response\x12\r\n\x05token\x18\x01 \x01(\t\"/\n\x1c\x43Parental_LockClient_Request\x12\x0f\n\x07session\x18\x01 \x01(\t\"\x1f\n\x1d\x43Parental_LockClient_Response\"\'\n%CParental_RequestRecoveryCode_Request\"(\n&CParental_RequestRecoveryCode_Response\"S\n)CParental_DisableWithRecoveryCode_Request\x12\x15\n\rrecovery_code\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\",\n*CParental_DisableWithRecoveryCode_Response\"\x84\x01\n-CParental_ParentalSettingsChange_Notification\x12\x1b\n\x13serialized_settings\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tsessionid\x18\x04 \x01(\t\"L\n%CParental_ParentalUnlock_Notification\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x11\n\tsessionid\x18\x02 \x01(\t\"8\n#CParental_ParentalLock_Notification\x12\x11\n\tsessionid\x18\x01 \x01(\t2\xd2\x0e\n\x08Parental\x12\xd0\x01\n\x16\x45nableParentalSettings\x12).CParental_EnableParentalSettings_Request\x1a*.CParental_EnableParentalSettings_Response\"_\x82\xb5\x18[Enable parental settings for the logged in account, optionally setting the current settings\x12\xab\x01\n\x17\x44isableParentalSettings\x12*.CParental_DisableParentalSettings_Request\x1a+.CParental_DisableParentalSettings_Response\"7\x82\xb5\x18\x33\x44isable parental settings for the logged in account\x12\xa7\x01\n\x13GetParentalSettings\x12&.CParental_GetParentalSettings_Request\x1a\'.CParental_GetParentalSettings_Response\"?\x82\xb5\x18;Get the current parental settings for the logged in account\x12\xe8\x01\n\x19GetSignedParentalSettings\x12,.CParental_GetSignedParentalSettings_Request\x1a-.CParental_GetSignedParentalSettings_Response\"n\x82\xb5\x18jGet the current parental settings for the logged in account in a form that can by verified by the receiver\x12\xa7\x01\n\x13SetParentalSettings\x12&.CParental_SetParentalSettings_Request\x1a\'.CParental_SetParentalSettings_Response\"?\x82\xb5\x18;Set the current parental settings for the logged in account\x12\xa7\x01\n\rValidateToken\x12 .CParental_ValidateToken_Request\x1a!.CParental_ValidateToken_Response\"Q\x82\xb5\x18MCheck if the given parental unlock token is correct for the logged in account\x12\xb7\x01\n\x10ValidatePassword\x12#.CParental_ValidatePassword_Request\x1a$.CParental_ValidatePassword_Response\"X\x82\xb5\x18TValidate the plaintext password for the logged in account and return an unlock token\x12\x8f\x01\n\nLockClient\x12\x1d.CParental_LockClient_Request\x1a\x1e.CParental_LockClient_Response\"B\x82\xb5\x18>Notify connected clients that a lock has occurred in a browser\x12\xc3\x01\n\x13RequestRecoveryCode\x12&.CParental_RequestRecoveryCode_Request\x1a\'.CParental_RequestRecoveryCode_Response\"[\x82\xb5\x18WRequest a recovery code be sent to the recovery email address for the specified account\x12\xaa\x01\n\x17\x44isableWithRecoveryCode\x12*.CParental_DisableWithRecoveryCode_Request\x1a+.CParental_DisableWithRecoveryCode_Response\"6\x82\xb5\x18\x32\x41ttempt a recovery unlock on the specified account\x1a\x1d\x82\xb5\x18\x19Parental settings service2\x86\x04\n\x0eParentalClient\x12\x9c\x01\n\x14NotifySettingsChange\x12..CParental_ParentalSettingsChange_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43Notification from server to client of a change in parental settings\x12\x94\x01\n\x0cNotifyUnlock\x12&.CParental_ParentalUnlock_Notification\x1a\x0b.NoResponse\"O\x82\xb5\x18KNotification from server to client that an unlock has occurred in a browser\x12\x8d\x01\n\nNotifyLock\x12$.CParental_ParentalLock_Notification\x1a\x0b.NoResponse\"L\x82\xb5\x18HNotification from server to client that a lock has occurred in a browser\x1a.\x82\xb5\x18&Parental settings client notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_PARENTALAPP = _descriptor.Descriptor(
  name='ParentalApp',
  full_name='ParentalApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='ParentalApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_allowed', full_name='ParentalApp.is_allowed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=140,
)


_PARENTALSETTINGS = _descriptor.Descriptor(
  name='ParentalSettings',
  full_name='ParentalSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='ParentalSettings.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applist_base_id', full_name='ParentalSettings.applist_base_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applist_base_description', full_name='ParentalSettings.applist_base_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applist_base', full_name='ParentalSettings.applist_base', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applist_custom', full_name='ParentalSettings.applist_custom', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordhashtype', full_name='ParentalSettings.passwordhashtype', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='salt', full_name='ParentalSettings.salt', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordhash', full_name='ParentalSettings.passwordhash', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='ParentalSettings.is_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled_features', full_name='ParentalSettings.enabled_features', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recovery_email', full_name='ParentalSettings.recovery_email', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_site_license_lock', full_name='ParentalSettings.is_site_license_lock', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=473,
)


_CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CParental_EnableParentalSettings_Request',
  full_name='CParental_EnableParentalSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_EnableParentalSettings_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CParental_EnableParentalSettings_Request.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CParental_EnableParentalSettings_Request.sessionid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enablecode', full_name='CParental_EnableParentalSettings_Request.enablecode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParental_EnableParentalSettings_Request.steamid', index=4,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=629,
)


_CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CParental_EnableParentalSettings_Response',
  full_name='CParental_EnableParentalSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=674,
)


_CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CParental_DisableParentalSettings_Request',
  full_name='CParental_DisableParentalSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_DisableParentalSettings_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParental_DisableParentalSettings_Request.steamid', index=1,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=754,
)


_CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CParental_DisableParentalSettings_Response',
  full_name='CParental_DisableParentalSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=800,
)


_CPARENTAL_GETPARENTALSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CParental_GetParentalSettings_Request',
  full_name='CParental_GetParentalSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParental_GetParentalSettings_Request.steamid', index=0,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=858,
)


_CPARENTAL_GETPARENTALSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CParental_GetParentalSettings_Response',
  full_name='CParental_GetParentalSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='CParental_GetParentalSettings_Response.settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=937,
)


_CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CParental_GetSignedParentalSettings_Request',
  full_name='CParental_GetSignedParentalSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='CParental_GetSignedParentalSettings_Request.priority', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1002,
)


_CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CParental_GetSignedParentalSettings_Response',
  full_name='CParental_GetSignedParentalSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialized_settings', full_name='CParental_GetSignedParentalSettings_Response.serialized_settings', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='CParental_GetSignedParentalSettings_Response.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1098,
)


_CPARENTAL_SETPARENTALSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CParental_SetParentalSettings_Request',
  full_name='CParental_SetParentalSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_SetParentalSettings_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CParental_SetParentalSettings_Request.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='CParental_SetParentalSettings_Request.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CParental_SetParentalSettings_Request.sessionid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParental_SetParentalSettings_Request.steamid', index=4,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1253,
)


_CPARENTAL_SETPARENTALSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CParental_SetParentalSettings_Response',
  full_name='CParental_SetParentalSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1295,
)


_CPARENTAL_VALIDATETOKEN_REQUEST = _descriptor.Descriptor(
  name='CParental_ValidateToken_Request',
  full_name='CParental_ValidateToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unlock_token', full_name='CParental_ValidateToken_Request.unlock_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1352,
)


_CPARENTAL_VALIDATETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CParental_ValidateToken_Response',
  full_name='CParental_ValidateToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1388,
)


_CPARENTAL_VALIDATEPASSWORD_REQUEST = _descriptor.Descriptor(
  name='CParental_ValidatePassword_Request',
  full_name='CParental_ValidatePassword_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_ValidatePassword_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='CParental_ValidatePassword_Request.session', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_unlock_on_success', full_name='CParental_ValidatePassword_Request.send_unlock_on_success', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1493,
)


_CPARENTAL_VALIDATEPASSWORD_RESPONSE = _descriptor.Descriptor(
  name='CParental_ValidatePassword_Response',
  full_name='CParental_ValidatePassword_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CParental_ValidatePassword_Response.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1547,
)


_CPARENTAL_LOCKCLIENT_REQUEST = _descriptor.Descriptor(
  name='CParental_LockClient_Request',
  full_name='CParental_LockClient_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='CParental_LockClient_Request.session', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1596,
)


_CPARENTAL_LOCKCLIENT_RESPONSE = _descriptor.Descriptor(
  name='CParental_LockClient_Response',
  full_name='CParental_LockClient_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1629,
)


_CPARENTAL_REQUESTRECOVERYCODE_REQUEST = _descriptor.Descriptor(
  name='CParental_RequestRecoveryCode_Request',
  full_name='CParental_RequestRecoveryCode_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1670,
)


_CPARENTAL_REQUESTRECOVERYCODE_RESPONSE = _descriptor.Descriptor(
  name='CParental_RequestRecoveryCode_Response',
  full_name='CParental_RequestRecoveryCode_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1712,
)


_CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST = _descriptor.Descriptor(
  name='CParental_DisableWithRecoveryCode_Request',
  full_name='CParental_DisableWithRecoveryCode_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='recovery_code', full_name='CParental_DisableWithRecoveryCode_Request.recovery_code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CParental_DisableWithRecoveryCode_Request.steamid', index=1,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1797,
)


_CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE = _descriptor.Descriptor(
  name='CParental_DisableWithRecoveryCode_Response',
  full_name='CParental_DisableWithRecoveryCode_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1799,
  serialized_end=1843,
)


_CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION = _descriptor.Descriptor(
  name='CParental_ParentalSettingsChange_Notification',
  full_name='CParental_ParentalSettingsChange_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialized_settings', full_name='CParental_ParentalSettingsChange_Notification.serialized_settings', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='CParental_ParentalSettingsChange_Notification.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_ParentalSettingsChange_Notification.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CParental_ParentalSettingsChange_Notification.sessionid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=1978,
)


_CPARENTAL_PARENTALUNLOCK_NOTIFICATION = _descriptor.Descriptor(
  name='CParental_ParentalUnlock_Notification',
  full_name='CParental_ParentalUnlock_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CParental_ParentalUnlock_Notification.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CParental_ParentalUnlock_Notification.sessionid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1980,
  serialized_end=2056,
)


_CPARENTAL_PARENTALLOCK_NOTIFICATION = _descriptor.Descriptor(
  name='CParental_ParentalLock_Notification',
  full_name='CParental_ParentalLock_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CParental_ParentalLock_Notification.sessionid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2058,
  serialized_end=2114,
)

_PARENTALSETTINGS.fields_by_name['applist_base'].message_type = _PARENTALAPP
_PARENTALSETTINGS.fields_by_name['applist_custom'].message_type = _PARENTALAPP
_CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST.fields_by_name['settings'].message_type = _PARENTALSETTINGS
_CPARENTAL_GETPARENTALSETTINGS_RESPONSE.fields_by_name['settings'].message_type = _PARENTALSETTINGS
_CPARENTAL_SETPARENTALSETTINGS_REQUEST.fields_by_name['settings'].message_type = _PARENTALSETTINGS
DESCRIPTOR.message_types_by_name['ParentalApp'] = _PARENTALAPP
DESCRIPTOR.message_types_by_name['ParentalSettings'] = _PARENTALSETTINGS
DESCRIPTOR.message_types_by_name['CParental_EnableParentalSettings_Request'] = _CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CParental_EnableParentalSettings_Response'] = _CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_DisableParentalSettings_Request'] = _CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CParental_DisableParentalSettings_Response'] = _CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_GetParentalSettings_Request'] = _CPARENTAL_GETPARENTALSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CParental_GetParentalSettings_Response'] = _CPARENTAL_GETPARENTALSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_GetSignedParentalSettings_Request'] = _CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CParental_GetSignedParentalSettings_Response'] = _CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_SetParentalSettings_Request'] = _CPARENTAL_SETPARENTALSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CParental_SetParentalSettings_Response'] = _CPARENTAL_SETPARENTALSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_ValidateToken_Request'] = _CPARENTAL_VALIDATETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CParental_ValidateToken_Response'] = _CPARENTAL_VALIDATETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_ValidatePassword_Request'] = _CPARENTAL_VALIDATEPASSWORD_REQUEST
DESCRIPTOR.message_types_by_name['CParental_ValidatePassword_Response'] = _CPARENTAL_VALIDATEPASSWORD_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_LockClient_Request'] = _CPARENTAL_LOCKCLIENT_REQUEST
DESCRIPTOR.message_types_by_name['CParental_LockClient_Response'] = _CPARENTAL_LOCKCLIENT_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_RequestRecoveryCode_Request'] = _CPARENTAL_REQUESTRECOVERYCODE_REQUEST
DESCRIPTOR.message_types_by_name['CParental_RequestRecoveryCode_Response'] = _CPARENTAL_REQUESTRECOVERYCODE_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_DisableWithRecoveryCode_Request'] = _CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST
DESCRIPTOR.message_types_by_name['CParental_DisableWithRecoveryCode_Response'] = _CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE
DESCRIPTOR.message_types_by_name['CParental_ParentalSettingsChange_Notification'] = _CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CParental_ParentalUnlock_Notification'] = _CPARENTAL_PARENTALUNLOCK_NOTIFICATION
DESCRIPTOR.message_types_by_name['CParental_ParentalLock_Notification'] = _CPARENTAL_PARENTALLOCK_NOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParentalApp = _reflection.GeneratedProtocolMessageType('ParentalApp', (_message.Message,), {
  'DESCRIPTOR' : _PARENTALAPP,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:ParentalApp)
  })
_sym_db.RegisterMessage(ParentalApp)

ParentalSettings = _reflection.GeneratedProtocolMessageType('ParentalSettings', (_message.Message,), {
  'DESCRIPTOR' : _PARENTALSETTINGS,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:ParentalSettings)
  })
_sym_db.RegisterMessage(ParentalSettings)

CParental_EnableParentalSettings_Request = _reflection.GeneratedProtocolMessageType('CParental_EnableParentalSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_EnableParentalSettings_Request)
  })
_sym_db.RegisterMessage(CParental_EnableParentalSettings_Request)

CParental_EnableParentalSettings_Response = _reflection.GeneratedProtocolMessageType('CParental_EnableParentalSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_EnableParentalSettings_Response)
  })
_sym_db.RegisterMessage(CParental_EnableParentalSettings_Response)

CParental_DisableParentalSettings_Request = _reflection.GeneratedProtocolMessageType('CParental_DisableParentalSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_DisableParentalSettings_Request)
  })
_sym_db.RegisterMessage(CParental_DisableParentalSettings_Request)

CParental_DisableParentalSettings_Response = _reflection.GeneratedProtocolMessageType('CParental_DisableParentalSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_DisableParentalSettings_Response)
  })
_sym_db.RegisterMessage(CParental_DisableParentalSettings_Response)

CParental_GetParentalSettings_Request = _reflection.GeneratedProtocolMessageType('CParental_GetParentalSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_GETPARENTALSETTINGS_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_GetParentalSettings_Request)
  })
_sym_db.RegisterMessage(CParental_GetParentalSettings_Request)

CParental_GetParentalSettings_Response = _reflection.GeneratedProtocolMessageType('CParental_GetParentalSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_GETPARENTALSETTINGS_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_GetParentalSettings_Response)
  })
_sym_db.RegisterMessage(CParental_GetParentalSettings_Response)

CParental_GetSignedParentalSettings_Request = _reflection.GeneratedProtocolMessageType('CParental_GetSignedParentalSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_GetSignedParentalSettings_Request)
  })
_sym_db.RegisterMessage(CParental_GetSignedParentalSettings_Request)

CParental_GetSignedParentalSettings_Response = _reflection.GeneratedProtocolMessageType('CParental_GetSignedParentalSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_GetSignedParentalSettings_Response)
  })
_sym_db.RegisterMessage(CParental_GetSignedParentalSettings_Response)

CParental_SetParentalSettings_Request = _reflection.GeneratedProtocolMessageType('CParental_SetParentalSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_SETPARENTALSETTINGS_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_SetParentalSettings_Request)
  })
_sym_db.RegisterMessage(CParental_SetParentalSettings_Request)

CParental_SetParentalSettings_Response = _reflection.GeneratedProtocolMessageType('CParental_SetParentalSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_SETPARENTALSETTINGS_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_SetParentalSettings_Response)
  })
_sym_db.RegisterMessage(CParental_SetParentalSettings_Response)

CParental_ValidateToken_Request = _reflection.GeneratedProtocolMessageType('CParental_ValidateToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_VALIDATETOKEN_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ValidateToken_Request)
  })
_sym_db.RegisterMessage(CParental_ValidateToken_Request)

CParental_ValidateToken_Response = _reflection.GeneratedProtocolMessageType('CParental_ValidateToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_VALIDATETOKEN_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ValidateToken_Response)
  })
_sym_db.RegisterMessage(CParental_ValidateToken_Response)

CParental_ValidatePassword_Request = _reflection.GeneratedProtocolMessageType('CParental_ValidatePassword_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_VALIDATEPASSWORD_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ValidatePassword_Request)
  })
_sym_db.RegisterMessage(CParental_ValidatePassword_Request)

CParental_ValidatePassword_Response = _reflection.GeneratedProtocolMessageType('CParental_ValidatePassword_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_VALIDATEPASSWORD_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ValidatePassword_Response)
  })
_sym_db.RegisterMessage(CParental_ValidatePassword_Response)

CParental_LockClient_Request = _reflection.GeneratedProtocolMessageType('CParental_LockClient_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_LOCKCLIENT_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_LockClient_Request)
  })
_sym_db.RegisterMessage(CParental_LockClient_Request)

CParental_LockClient_Response = _reflection.GeneratedProtocolMessageType('CParental_LockClient_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_LOCKCLIENT_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_LockClient_Response)
  })
_sym_db.RegisterMessage(CParental_LockClient_Response)

CParental_RequestRecoveryCode_Request = _reflection.GeneratedProtocolMessageType('CParental_RequestRecoveryCode_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_REQUESTRECOVERYCODE_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_RequestRecoveryCode_Request)
  })
_sym_db.RegisterMessage(CParental_RequestRecoveryCode_Request)

CParental_RequestRecoveryCode_Response = _reflection.GeneratedProtocolMessageType('CParental_RequestRecoveryCode_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_REQUESTRECOVERYCODE_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_RequestRecoveryCode_Response)
  })
_sym_db.RegisterMessage(CParental_RequestRecoveryCode_Response)

CParental_DisableWithRecoveryCode_Request = _reflection.GeneratedProtocolMessageType('CParental_DisableWithRecoveryCode_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_DisableWithRecoveryCode_Request)
  })
_sym_db.RegisterMessage(CParental_DisableWithRecoveryCode_Request)

CParental_DisableWithRecoveryCode_Response = _reflection.GeneratedProtocolMessageType('CParental_DisableWithRecoveryCode_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_DisableWithRecoveryCode_Response)
  })
_sym_db.RegisterMessage(CParental_DisableWithRecoveryCode_Response)

CParental_ParentalSettingsChange_Notification = _reflection.GeneratedProtocolMessageType('CParental_ParentalSettingsChange_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ParentalSettingsChange_Notification)
  })
_sym_db.RegisterMessage(CParental_ParentalSettingsChange_Notification)

CParental_ParentalUnlock_Notification = _reflection.GeneratedProtocolMessageType('CParental_ParentalUnlock_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_PARENTALUNLOCK_NOTIFICATION,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ParentalUnlock_Notification)
  })
_sym_db.RegisterMessage(CParental_ParentalUnlock_Notification)

CParental_ParentalLock_Notification = _reflection.GeneratedProtocolMessageType('CParental_ParentalLock_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPARENTAL_PARENTALLOCK_NOTIFICATION,
  '__module__' : 'steammessages_parental_pb2'
  # @@protoc_insertion_point(class_scope:CParental_ParentalLock_Notification)
  })
_sym_db.RegisterMessage(CParental_ParentalLock_Notification)


DESCRIPTOR._options = None

_PARENTAL = _descriptor.ServiceDescriptor(
  name='Parental',
  full_name='Parental',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\031Parental settings service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2117,
  serialized_end=3991,
  methods=[
  _descriptor.MethodDescriptor(
    name='EnableParentalSettings',
    full_name='Parental.EnableParentalSettings',
    index=0,
    containing_service=None,
    input_type=_CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST,
    output_type=_CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030[Enable parental settings for the logged in account, optionally setting the current settings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableParentalSettings',
    full_name='Parental.DisableParentalSettings',
    index=1,
    containing_service=None,
    input_type=_CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST,
    output_type=_CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE,
    serialized_options=b'\202\265\0303Disable parental settings for the logged in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetParentalSettings',
    full_name='Parental.GetParentalSettings',
    index=2,
    containing_service=None,
    input_type=_CPARENTAL_GETPARENTALSETTINGS_REQUEST,
    output_type=_CPARENTAL_GETPARENTALSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030;Get the current parental settings for the logged in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignedParentalSettings',
    full_name='Parental.GetSignedParentalSettings',
    index=3,
    containing_service=None,
    input_type=_CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST,
    output_type=_CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030jGet the current parental settings for the logged in account in a form that can by verified by the receiver',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetParentalSettings',
    full_name='Parental.SetParentalSettings',
    index=4,
    containing_service=None,
    input_type=_CPARENTAL_SETPARENTALSETTINGS_REQUEST,
    output_type=_CPARENTAL_SETPARENTALSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030;Set the current parental settings for the logged in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateToken',
    full_name='Parental.ValidateToken',
    index=5,
    containing_service=None,
    input_type=_CPARENTAL_VALIDATETOKEN_REQUEST,
    output_type=_CPARENTAL_VALIDATETOKEN_RESPONSE,
    serialized_options=b'\202\265\030MCheck if the given parental unlock token is correct for the logged in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidatePassword',
    full_name='Parental.ValidatePassword',
    index=6,
    containing_service=None,
    input_type=_CPARENTAL_VALIDATEPASSWORD_REQUEST,
    output_type=_CPARENTAL_VALIDATEPASSWORD_RESPONSE,
    serialized_options=b'\202\265\030TValidate the plaintext password for the logged in account and return an unlock token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LockClient',
    full_name='Parental.LockClient',
    index=7,
    containing_service=None,
    input_type=_CPARENTAL_LOCKCLIENT_REQUEST,
    output_type=_CPARENTAL_LOCKCLIENT_RESPONSE,
    serialized_options=b'\202\265\030>Notify connected clients that a lock has occurred in a browser',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestRecoveryCode',
    full_name='Parental.RequestRecoveryCode',
    index=8,
    containing_service=None,
    input_type=_CPARENTAL_REQUESTRECOVERYCODE_REQUEST,
    output_type=_CPARENTAL_REQUESTRECOVERYCODE_RESPONSE,
    serialized_options=b'\202\265\030WRequest a recovery code be sent to the recovery email address for the specified account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableWithRecoveryCode',
    full_name='Parental.DisableWithRecoveryCode',
    index=9,
    containing_service=None,
    input_type=_CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST,
    output_type=_CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE,
    serialized_options=b'\202\265\0302Attempt a recovery unlock on the specified account',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARENTAL)

DESCRIPTOR.services_by_name['Parental'] = _PARENTAL


_PARENTALCLIENT = _descriptor.ServiceDescriptor(
  name='ParentalClient',
  full_name='ParentalClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030&Parental settings client notifications\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=3994,
  serialized_end=4512,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifySettingsChange',
    full_name='ParentalClient.NotifySettingsChange',
    index=0,
    containing_service=None,
    input_type=_CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030CNotification from server to client of a change in parental settings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUnlock',
    full_name='ParentalClient.NotifyUnlock',
    index=1,
    containing_service=None,
    input_type=_CPARENTAL_PARENTALUNLOCK_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030KNotification from server to client that an unlock has occurred in a browser',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyLock',
    full_name='ParentalClient.NotifyLock',
    index=2,
    containing_service=None,
    input_type=_CPARENTAL_PARENTALLOCK_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030HNotification from server to client that a lock has occurred in a browser',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARENTALCLIENT)

DESCRIPTOR.services_by_name['ParentalClient'] = _PARENTALCLIENT

Parental = service_reflection.GeneratedServiceType('Parental', (_service.Service,), dict(
  DESCRIPTOR = _PARENTAL,
  __module__ = 'steammessages_parental_pb2'
  ))

Parental_Stub = service_reflection.GeneratedServiceStubType('Parental_Stub', (Parental,), dict(
  DESCRIPTOR = _PARENTAL,
  __module__ = 'steammessages_parental_pb2'
  ))


ParentalClient = service_reflection.GeneratedServiceType('ParentalClient', (_service.Service,), dict(
  DESCRIPTOR = _PARENTALCLIENT,
  __module__ = 'steammessages_parental_pb2'
  ))

ParentalClient_Stub = service_reflection.GeneratedServiceStubType('ParentalClient_Stub', (ParentalClient,), dict(
  DESCRIPTOR = _PARENTALCLIENT,
  __module__ = 'steammessages_parental_pb2'
  ))


# @@protoc_insertion_point(module_scope)
