# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_qms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_qms.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17steammessages_qms.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"2\n\x0fGameSearchParam\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"\xe9\x01\n(CQueuedMatchmaking_SearchForGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x14\n\x0csteamidlobby\x18\x06 \x01(\x06\x12\x10\n\x08searchid\x18\x07 \x01(\x04\"\x87\x03\n)CQueuedMatchmaking_SearchForGame_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x1d\n\x15seconds_time_estimate\x18\x03 \x01(\r\x12\x16\n\x0epoll_frequency\x18\x04 \x01(\r\x12\x17\n\x0f\x63ount_searching\x18\x05 \x01(\r\x12\x18\n\x10players_in_match\x18\x06 \x01(\r\x12\x18\n\x10players_accepted\x18\x07 \x01(\r\x12\x16\n\x0e\x63onnect_string\x18\t \x01(\t\x12\x13\n\x0bsteamidhost\x18\n \x01(\x06\x12\x18\n\x10rtime_match_made\x18\x0b \x01(\r\x12\x11\n\trtime_now\x18\x0c \x01(\r\x12\x1f\n\x17steamid_canceled_search\x18\r \x01(\x06\"\x97\x02\n3CQueuedMatchmakingGameHost_SearchForPlayers_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x1c\n\x14player_max_team_size\x18\x06 \x01(\r\x12\x19\n\x11\x63onnection_string\x18\x07 \x01(\t\x12\x10\n\x08searchid\x18\x08 \x01(\x04\"\x93\x01\n\x0bPlayerFound\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x13\n\x0bteam_number\x18\x04 \x01(\r\"\x88\x02\n4CQueuedMatchmakingGameHost_SearchForPlayers_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x16\n\x0epoll_frequency\x18\x03 \x01(\r\x12\x0f\n\x07matchid\x18\x04 \x01(\x04\x12\x1d\n\x07players\x18\x05 \x03(\x0b\x32\x0c.PlayerFound\x12\x18\n\x10rtime_match_made\x18\x06 \x01(\r\x12\x11\n\trtime_now\x18\x07 \x01(\r\".\n\x0cPlayerResult\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05value\x18\x02 \x01(\r\"~\n5CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\x12%\n\x0eplayer_results\x18\x03 \x03(\x0b\x32\r.PlayerResult\"8\n6CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\"L\n*CQueuedMatchmakingGameHost_EndGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\"-\n+CQueuedMatchmakingGameHost_EndGame_Response*\x92\x01\n\x11\x45GameSearchAction\x12\x1c\n\x18k_EGameSearchAction_None\x10\x00\x12\x1e\n\x1ak_EGameSearchAction_Accept\x10\x01\x12\x1f\n\x1bk_EGameSearchAction_Decline\x10\x02\x12\x1e\n\x1ak_EGameSearchAction_Cancel\x10\x03*\xbc\x02\n\x11\x45GameSearchResult\x12\x1f\n\x1bk_EGameSearchResult_Invalid\x10\x00\x12(\n$k_EGameSearchResult_SearchInProgress\x10\x01\x12+\n\'k_EGameSearchResult_SearchFailedNoHosts\x10\x02\x12\'\n#k_EGameSearchResult_SearchGameFound\x10\x03\x12.\n*k_EGameSearchResult_SearchCompleteAccepted\x10\x04\x12.\n*k_EGameSearchResult_SearchCompleteDeclined\x10\x05\x12&\n\"k_EGameSearchResult_SearchCanceled\x10\x06\x32\xb2\x01\n\x11QueuedMatchmaking\x12}\n\rSearchForGame\x12).CQueuedMatchmaking_SearchForGame_Request\x1a*.CQueuedMatchmaking_SearchForGame_Response\"\x15\x82\xb5\x18\x11Search for a game\x1a\x1e\x82\xb5\x18\x1aQueued matchmaking service2\xeb\x03\n\x19QueuedMatchmakingGameHost\x12\x95\x01\n\x10SearchForPlayers\x12\x34.CQueuedMatchmakingGameHost_SearchForPlayers_Request\x1a\x35.CQueuedMatchmakingGameHost_SearchForPlayers_Response\"\x14\x82\xb5\x18\x10SearchForPlayers\x12\x9d\x01\n\x12SubmitPlayerResult\x12\x36.CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x1a\x37.CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\"\x16\x82\xb5\x18\x12SubmitPlayerResult\x12q\n\x07\x45ndGame\x12+.CQueuedMatchmakingGameHost_EndGame_Request\x1a,.CQueuedMatchmakingGameHost_EndGame_Response\"\x0b\x82\xb5\x18\x07\x45ndGame\x1a#\x82\xb5\x18\x1fQueued matchmaking host serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EGAMESEARCHACTION = _descriptor.EnumDescriptor(
  name='EGameSearchAction',
  full_name='EGameSearchAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Accept', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Decline', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Cancel', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1828,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_EGAMESEARCHACTION)

EGameSearchAction = enum_type_wrapper.EnumTypeWrapper(_EGAMESEARCHACTION)
_EGAMESEARCHRESULT = _descriptor.EnumDescriptor(
  name='EGameSearchResult',
  full_name='EGameSearchResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchInProgress', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchFailedNoHosts', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchGameFound', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCompleteAccepted', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCompleteDeclined', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCanceled', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1977,
  serialized_end=2293,
)
_sym_db.RegisterEnumDescriptor(_EGAMESEARCHRESULT)

EGameSearchResult = enum_type_wrapper.EnumTypeWrapper(_EGAMESEARCHRESULT)
k_EGameSearchAction_None = 0
k_EGameSearchAction_Accept = 1
k_EGameSearchAction_Decline = 2
k_EGameSearchAction_Cancel = 3
k_EGameSearchResult_Invalid = 0
k_EGameSearchResult_SearchInProgress = 1
k_EGameSearchResult_SearchFailedNoHosts = 2
k_EGameSearchResult_SearchGameFound = 3
k_EGameSearchResult_SearchCompleteAccepted = 4
k_EGameSearchResult_SearchCompleteDeclined = 5
k_EGameSearchResult_SearchCanceled = 6



_GAMESEARCHPARAM = _descriptor.Descriptor(
  name='GameSearchParam',
  full_name='GameSearchParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_name', full_name='GameSearchParam.key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='GameSearchParam.value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=137,
)


_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmaking_SearchForGame_Request',
  full_name='CQueuedMatchmaking_SearchForGame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmaking_SearchForGame_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='CQueuedMatchmaking_SearchForGame_Request.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='CQueuedMatchmaking_SearchForGame_Request.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_min', full_name='CQueuedMatchmaking_SearchForGame_Request.player_min', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max', full_name='CQueuedMatchmaking_SearchForGame_Request.player_max', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamidlobby', full_name='CQueuedMatchmaking_SearchForGame_Request.steamidlobby', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmaking_SearchForGame_Request.searchid', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=373,
)


_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmaking_SearchForGame_Response',
  full_name='CQueuedMatchmaking_SearchForGame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gamesearchresult', full_name='CQueuedMatchmaking_SearchForGame_Response.gamesearchresult', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmaking_SearchForGame_Response.searchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_time_estimate', full_name='CQueuedMatchmaking_SearchForGame_Response.seconds_time_estimate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_frequency', full_name='CQueuedMatchmaking_SearchForGame_Response.poll_frequency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_searching', full_name='CQueuedMatchmaking_SearchForGame_Response.count_searching', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_in_match', full_name='CQueuedMatchmaking_SearchForGame_Response.players_in_match', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_accepted', full_name='CQueuedMatchmaking_SearchForGame_Response.players_accepted', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CQueuedMatchmaking_SearchForGame_Response.connect_string', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamidhost', full_name='CQueuedMatchmaking_SearchForGame_Response.steamidhost', index=8,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_match_made', full_name='CQueuedMatchmaking_SearchForGame_Response.rtime_match_made', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_now', full_name='CQueuedMatchmaking_SearchForGame_Response.rtime_now', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_canceled_search', full_name='CQueuedMatchmaking_SearchForGame_Response.steamid_canceled_search', index=11,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=767,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SearchForPlayers_Request',
  full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_min', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_min', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_max', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max_team_size', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_max_team_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_string', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.connection_string', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.searchid', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=1049,
)


_PLAYERFOUND = _descriptor.Descriptor(
  name='PlayerFound',
  full_name='PlayerFound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='PlayerFound.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='PlayerFound.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='PlayerFound.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_number', full_name='PlayerFound.team_number', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1199,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SearchForPlayers_Response',
  full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gamesearchresult', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.gamesearchresult', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.searchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_frequency', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.poll_frequency', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.matchid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.players', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_match_made', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.rtime_match_made', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_now', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.rtime_now', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1466,
)


_PLAYERRESULT = _descriptor.Descriptor(
  name='PlayerResult',
  full_name='PlayerResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='PlayerResult.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PlayerResult.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1468,
  serialized_end=1514,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request',
  full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_results', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.player_results', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1516,
  serialized_end=1642,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Response',
  full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1700,
)


_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_EndGame_Request',
  full_name='CQueuedMatchmakingGameHost_EndGame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_EndGame_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_EndGame_Request.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1778,
)


_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_EndGame_Response',
  full_name='CQueuedMatchmakingGameHost_EndGame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=1825,
)

_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE.fields_by_name['gamesearchresult'].enum_type = _EGAMESEARCHRESULT
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_PLAYERFOUND.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_PLAYERFOUND.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE.fields_by_name['gamesearchresult'].enum_type = _EGAMESEARCHRESULT
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE.fields_by_name['players'].message_type = _PLAYERFOUND
_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST.fields_by_name['player_results'].message_type = _PLAYERRESULT
DESCRIPTOR.message_types_by_name['GameSearchParam'] = _GAMESEARCHPARAM
DESCRIPTOR.message_types_by_name['CQueuedMatchmaking_SearchForGame_Request'] = _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmaking_SearchForGame_Response'] = _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SearchForPlayers_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST
DESCRIPTOR.message_types_by_name['PlayerFound'] = _PLAYERFOUND
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SearchForPlayers_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE
DESCRIPTOR.message_types_by_name['PlayerResult'] = _PLAYERRESULT
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SubmitPlayerResult_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SubmitPlayerResult_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_EndGame_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_EndGame_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE
DESCRIPTOR.enum_types_by_name['EGameSearchAction'] = _EGAMESEARCHACTION
DESCRIPTOR.enum_types_by_name['EGameSearchResult'] = _EGAMESEARCHRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GameSearchParam = _reflection.GeneratedProtocolMessageType('GameSearchParam', (_message.Message,), {
  'DESCRIPTOR' : _GAMESEARCHPARAM,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:GameSearchParam)
  })
_sym_db.RegisterMessage(GameSearchParam)

CQueuedMatchmaking_SearchForGame_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmaking_SearchForGame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmaking_SearchForGame_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmaking_SearchForGame_Request)

CQueuedMatchmaking_SearchForGame_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmaking_SearchForGame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmaking_SearchForGame_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmaking_SearchForGame_Response)

CQueuedMatchmakingGameHost_SearchForPlayers_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SearchForPlayers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SearchForPlayers_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SearchForPlayers_Request)

PlayerFound = _reflection.GeneratedProtocolMessageType('PlayerFound', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERFOUND,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:PlayerFound)
  })
_sym_db.RegisterMessage(PlayerFound)

CQueuedMatchmakingGameHost_SearchForPlayers_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SearchForPlayers_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SearchForPlayers_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SearchForPlayers_Response)

PlayerResult = _reflection.GeneratedProtocolMessageType('PlayerResult', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESULT,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:PlayerResult)
  })
_sym_db.RegisterMessage(PlayerResult)

CQueuedMatchmakingGameHost_SubmitPlayerResult_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SubmitPlayerResult_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SubmitPlayerResult_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SubmitPlayerResult_Request)

CQueuedMatchmakingGameHost_SubmitPlayerResult_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SubmitPlayerResult_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SubmitPlayerResult_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SubmitPlayerResult_Response)

CQueuedMatchmakingGameHost_EndGame_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_EndGame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_EndGame_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_EndGame_Request)

CQueuedMatchmakingGameHost_EndGame_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_EndGame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_EndGame_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_EndGame_Response)


DESCRIPTOR._options = None

_QUEUEDMATCHMAKING = _descriptor.ServiceDescriptor(
  name='QueuedMatchmaking',
  full_name='QueuedMatchmaking',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\032Queued matchmaking service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2296,
  serialized_end=2474,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchForGame',
    full_name='QueuedMatchmaking.SearchForGame',
    index=0,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST,
    output_type=_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE,
    serialized_options=b'\202\265\030\021Search for a game',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEDMATCHMAKING)

DESCRIPTOR.services_by_name['QueuedMatchmaking'] = _QUEUEDMATCHMAKING


_QUEUEDMATCHMAKINGGAMEHOST = _descriptor.ServiceDescriptor(
  name='QueuedMatchmakingGameHost',
  full_name='QueuedMatchmakingGameHost',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030\037Queued matchmaking host service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2477,
  serialized_end=2968,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchForPlayers',
    full_name='QueuedMatchmakingGameHost.SearchForPlayers',
    index=0,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE,
    serialized_options=b'\202\265\030\020SearchForPlayers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitPlayerResult',
    full_name='QueuedMatchmakingGameHost.SubmitPlayerResult',
    index=1,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE,
    serialized_options=b'\202\265\030\022SubmitPlayerResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndGame',
    full_name='QueuedMatchmakingGameHost.EndGame',
    index=2,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE,
    serialized_options=b'\202\265\030\007EndGame',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEDMATCHMAKINGGAMEHOST)

DESCRIPTOR.services_by_name['QueuedMatchmakingGameHost'] = _QUEUEDMATCHMAKINGGAMEHOST

QueuedMatchmaking = service_reflection.GeneratedServiceType('QueuedMatchmaking', (_service.Service,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKING,
  __module__ = 'steammessages_qms_pb2'
  ))

QueuedMatchmaking_Stub = service_reflection.GeneratedServiceStubType('QueuedMatchmaking_Stub', (QueuedMatchmaking,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKING,
  __module__ = 'steammessages_qms_pb2'
  ))


QueuedMatchmakingGameHost = service_reflection.GeneratedServiceType('QueuedMatchmakingGameHost', (_service.Service,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKINGGAMEHOST,
  __module__ = 'steammessages_qms_pb2'
  ))

QueuedMatchmakingGameHost_Stub = service_reflection.GeneratedServiceStubType('QueuedMatchmakingGameHost_Stub', (QueuedMatchmakingGameHost,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKINGGAMEHOST,
  __module__ = 'steammessages_qms_pb2'
  ))


# @@protoc_insertion_point(module_scope)
