# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_market.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_market.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asteammessages_market.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"n\n(CEconMarket_IsMarketplaceAllowed_Request\x12\x42\n\twebcookie\x18\x01 \x01(\tB/\x82\xb5\x18+The user\'s Steam Guard machine auth cookie.\"\xf5\x05\n)CEconMarket_IsMarketplaceAllowed_Response\x12I\n\x07\x61llowed\x18\x01 \x01(\x08\x42\x38\x82\xb5\x18\x34Whether or not the user is allowed to use the market\x12K\n\x06reason\x18\x02 \x01(\rB;\x82\xb5\x18\x37The reason the user can\'t use the market, if applicable\x12P\n\x0f\x61llowed_at_time\x18\x03 \x01(\rB7\x82\xb5\x18\x33The time the user will be allowed to use the market\x12\x84\x01\n\x18steamguard_required_days\x18\x04 \x01(\rBb\x82\xb5\x18^The number of days any user is required to have had Steam Guard before they can use the market\x12W\n\x0f\x66orms_requested\x18\x07 \x01(\x08\x42>\x82\xb5\x18:Whether or not we\'ve requested the user fill out tax forms\x12h\n\x1a\x66orms_require_verification\x18\x08 \x01(\x08\x42\x44\x82\xb5\x18@True if we\'ve received forms but they require verification first\x12\x93\x01\n\x18new_device_cooldown_days\x18\t \x01(\rBq\x82\xb5\x18mThe number of days after initial device authorization a user must wait before using the market on that device2\xee\x01\n\nEconMarket\x12\xb8\x01\n\x14IsMarketplaceAllowed\x12).CEconMarket_IsMarketplaceAllowed_Request\x1a*.CEconMarket_IsMarketplaceAllowed_Response\"I\x82\xb5\x18\x45\x43hecks whether or not the authed account is allowed to use the market\x1a%\x82\xb5\x18!A service to use market functionsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CECONMARKET_ISMARKETPLACEALLOWED_REQUEST = _descriptor.Descriptor(
  name='CEconMarket_IsMarketplaceAllowed_Request',
  full_name='CEconMarket_IsMarketplaceAllowed_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='webcookie', full_name='CEconMarket_IsMarketplaceAllowed_Request.webcookie', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+The user\'s Steam Guard machine auth cookie.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=200,
)


_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE = _descriptor.Descriptor(
  name='CEconMarket_IsMarketplaceAllowed_Response',
  full_name='CEconMarket_IsMarketplaceAllowed_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed', full_name='CEconMarket_IsMarketplaceAllowed_Response.allowed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304Whether or not the user is allowed to use the market', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CEconMarket_IsMarketplaceAllowed_Response.reason', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307The reason the user can\'t use the market, if applicable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_at_time', full_name='CEconMarket_IsMarketplaceAllowed_Response.allowed_at_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303The time the user will be allowed to use the market', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_required_days', full_name='CEconMarket_IsMarketplaceAllowed_Response.steamguard_required_days', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030^The number of days any user is required to have had Steam Guard before they can use the market', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forms_requested', full_name='CEconMarket_IsMarketplaceAllowed_Response.forms_requested', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030:Whether or not we\'ve requested the user fill out tax forms', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forms_require_verification', full_name='CEconMarket_IsMarketplaceAllowed_Response.forms_require_verification', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@True if we\'ve received forms but they require verification first', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_device_cooldown_days', full_name='CEconMarket_IsMarketplaceAllowed_Response.new_device_cooldown_days', index=6,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030mThe number of days after initial device authorization a user must wait before using the market on that device', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=960,
)

DESCRIPTOR.message_types_by_name['CEconMarket_IsMarketplaceAllowed_Request'] = _CECONMARKET_ISMARKETPLACEALLOWED_REQUEST
DESCRIPTOR.message_types_by_name['CEconMarket_IsMarketplaceAllowed_Response'] = _CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CEconMarket_IsMarketplaceAllowed_Request = _reflection.GeneratedProtocolMessageType('CEconMarket_IsMarketplaceAllowed_Request', (_message.Message,), {
  'DESCRIPTOR' : _CECONMARKET_ISMARKETPLACEALLOWED_REQUEST,
  '__module__' : 'steammessages_market_pb2'
  # @@protoc_insertion_point(class_scope:CEconMarket_IsMarketplaceAllowed_Request)
  })
_sym_db.RegisterMessage(CEconMarket_IsMarketplaceAllowed_Request)

CEconMarket_IsMarketplaceAllowed_Response = _reflection.GeneratedProtocolMessageType('CEconMarket_IsMarketplaceAllowed_Response', (_message.Message,), {
  'DESCRIPTOR' : _CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE,
  '__module__' : 'steammessages_market_pb2'
  # @@protoc_insertion_point(class_scope:CEconMarket_IsMarketplaceAllowed_Response)
  })
_sym_db.RegisterMessage(CEconMarket_IsMarketplaceAllowed_Response)


DESCRIPTOR._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_REQUEST.fields_by_name['webcookie']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['allowed']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['reason']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['allowed_at_time']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['steamguard_required_days']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['forms_requested']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['forms_require_verification']._options = None
_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE.fields_by_name['new_device_cooldown_days']._options = None

_ECONMARKET = _descriptor.ServiceDescriptor(
  name='EconMarket',
  full_name='EconMarket',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030!A service to use market functions',
  create_key=_descriptor._internal_create_key,
  serialized_start=963,
  serialized_end=1201,
  methods=[
  _descriptor.MethodDescriptor(
    name='IsMarketplaceAllowed',
    full_name='EconMarket.IsMarketplaceAllowed',
    index=0,
    containing_service=None,
    input_type=_CECONMARKET_ISMARKETPLACEALLOWED_REQUEST,
    output_type=_CECONMARKET_ISMARKETPLACEALLOWED_RESPONSE,
    serialized_options=b'\202\265\030EChecks whether or not the authed account is allowed to use the market',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ECONMARKET)

DESCRIPTOR.services_by_name['EconMarket'] = _ECONMARKET

EconMarket = service_reflection.GeneratedServiceType('EconMarket', (_service.Service,), dict(
  DESCRIPTOR = _ECONMARKET,
  __module__ = 'steammessages_market_pb2'
  ))

EconMarket_Stub = service_reflection.GeneratedServiceStubType('EconMarket_Stub', (EconMarket,), dict(
  DESCRIPTOR = _ECONMARKET,
  __module__ = 'steammessages_market_pb2'
  ))


# @@protoc_insertion_point(module_scope)
