# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_site_license.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_site_license.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n steammessages_site_license.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x8d\x01\n)CSiteManagerClient_IncomingClient_Request\x12\x17\n\x0fsite_instanceid\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_steamid\x18\x02 \x01(\x06\x12\x17\n\x0f\x63lient_local_ip\x18\x03 \x01(\x07\x12\x16\n\x0e\x63onnection_key\x18\x04 \x01(\x0c\",\n*CSiteManagerClient_IncomingClient_Response\"N\n,CSiteLicense_ClientSeatCheckout_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"\xe3\x02\n/CSiteManagerClient_TrackedPayments_Notification\x12\x0f\n\x07site_id\x18\x01 \x01(\x06\x12J\n\x08payments\x18\x02 \x03(\x0b\x32\x38.CSiteManagerClient_TrackedPayments_Notification.Payment\x1a\xd2\x01\n\x07Payment\x12\x0f\n\x07transid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x11\n\tecurrency\x18\x04 \x01(\r\x12\x14\n\x0ctime_created\x18\x05 \x01(\x05\x12\x17\n\x0fpurchase_status\x18\x06 \x01(\x05\x12\x14\n\x0cmachine_name\x18\x07 \x01(\t\x12\x14\n\x0cpersona_name\x18\x08 \x01(\t\x12\x13\n\x0bprofile_url\x18\t \x01(\t\x12\x12\n\navatar_url\x18\n \x01(\t\"r\n(CSiteLicense_InitiateAssociation_Request\x12\x14\n\x0csite_steamid\x18\x01 \x01(\x06\x12\x17\n\x0fsite_instanceid\x18\x02 \x01(\x06\x12\x17\n\x0f\x63lient_local_ip\x18\x03 \x01(\x07\"C\n)CSiteLicense_InitiateAssociation_Response\x12\x16\n\x0e\x63onnection_key\x18\x01 \x01(\x0c\":\n$CSiteLicense_LCSAuthenticate_Request\x12\x12\n\ninstanceid\x18\x01 \x01(\x06\"z\n%CSiteLicense_LCSAuthenticate_Response\x12\x0f\n\x07site_id\x18\x01 \x01(\x04\x12\x11\n\tsite_name\x18\x02 \x01(\t\x12\x13\n\x0bnew_session\x18\x03 \x01(\x08\x12\x18\n\x10no_site_licenses\x18\x04 \x01(\x08\"t\n%CSiteLicense_LCSAssociateUser_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08local_ip\x18\x02 \x01(\x07\x12\x12\n\ninstanceid\x18\x03 \x01(\x06\x12\x14\n\x0cmachine_name\x18\x04 \x01(\t\"(\n&CSiteLicense_LCSAssociateUser_Response\"]\n\'CSiteLicense_ClientSeatCheckout_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x12\n\ninstanceid\x18\x02 \x01(\x06\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"*\n(CSiteLicense_ClientSeatCheckout_Response\"b\n,CSiteLicense_ClientGetAvailableSeats_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x12\n\ninstanceid\x18\x02 \x01(\x06\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"H\n-CSiteLicense_ClientGetAvailableSeats_Response\x12\x17\n\x0f\x61vailable_seats\x18\x01 \x01(\r2\xa3\x04\n\x11SiteManagerClient\x12\xaf\x01\n\x0eIncomingClient\x12*.CSiteManagerClient_IncomingClient_Request\x1a+.CSiteManagerClient_IncomingClient_Response\"D\x82\xb5\x18@Rack informing site manager of new inbound client PSK connection\x12\x93\x01\n\x1e\x43lientSeatCheckoutNotification\x12-.CSiteLicense_ClientSeatCheckout_Notification\x1a\x0b.NoResponse\"5\x82\xb5\x18\x31Notify client directly about seat checkout result\x12\x9a\x01\n\x1bTrackedPaymentsNotification\x12\x30.CSiteManagerClient_TrackedPayments_Notification\x1a\x0b.NoResponse\"<\x82\xb5\x18\x38Rack informing site manager of existing tracked payments\x1a)\x82\xb5\x18!Local site manager client service\xc0\xb5\x18\x02\x32\xd5\x06\n\x0bSiteLicense\x12\xa4\x01\n\x13InitiateAssociation\x12).CSiteLicense_InitiateAssociation_Request\x1a*.CSiteLicense_InitiateAssociation_Response\"6\x82\xb5\x18\x32\x43lient is requesting connetion info for local site\x12\x86\x01\n\x0fLCSAuthenticate\x12%.CSiteLicense_LCSAuthenticate_Request\x1a&.CSiteLicense_LCSAuthenticate_Response\"$\x82\xb5\x18 Local cafe server authentication\x12\x9d\x01\n\x10LCSAssociateUser\x12&.CSiteLicense_LCSAssociateUser_Request\x1a\'.CSiteLicense_LCSAssociateUser_Response\"8\x82\xb5\x18\x34Local cafe server wants to grant user access to site\x12\x9e\x01\n\x12\x43lientSeatCheckout\x12(.CSiteLicense_ClientSeatCheckout_Request\x1a).CSiteLicense_ClientSeatCheckout_Response\"3\x82\xb5\x18/Client is requesting use of a site license seat\x12\xba\x01\n\x17\x43lientGetAvailableSeats\x12-.CSiteLicense_ClientGetAvailableSeats_Request\x1a..CSiteLicense_ClientGetAvailableSeats_Response\"@\x82\xb5\x18<Client is requesting the number of currently available seats\x1a\x18\x82\xb5\x18\x14Site License serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST = _descriptor.Descriptor(
  name='CSiteManagerClient_IncomingClient_Request',
  full_name='CSiteManagerClient_IncomingClient_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='site_instanceid', full_name='CSiteManagerClient_IncomingClient_Request.site_instanceid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_steamid', full_name='CSiteManagerClient_IncomingClient_Request.client_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_local_ip', full_name='CSiteManagerClient_IncomingClient_Request.client_local_ip', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_key', full_name='CSiteManagerClient_IncomingClient_Request.connection_key', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=238,
)


_CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE = _descriptor.Descriptor(
  name='CSiteManagerClient_IncomingClient_Response',
  full_name='CSiteManagerClient_IncomingClient_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=284,
)


_CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION = _descriptor.Descriptor(
  name='CSiteLicense_ClientSeatCheckout_Notification',
  full_name='CSiteLicense_ClientSeatCheckout_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSiteLicense_ClientSeatCheckout_Notification.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CSiteLicense_ClientSeatCheckout_Notification.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=364,
)


_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT = _descriptor.Descriptor(
  name='Payment',
  full_name='CSiteManagerClient_TrackedPayments_Notification.Payment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transid', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.transid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecurrency', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.ecurrency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.time_created', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_status', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.purchase_status', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.machine_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.persona_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_url', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.profile_url', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_url', full_name='CSiteManagerClient_TrackedPayments_Notification.Payment.avatar_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=722,
)

_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION = _descriptor.Descriptor(
  name='CSiteManagerClient_TrackedPayments_Notification',
  full_name='CSiteManagerClient_TrackedPayments_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='site_id', full_name='CSiteManagerClient_TrackedPayments_Notification.site_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payments', full_name='CSiteManagerClient_TrackedPayments_Notification.payments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=722,
)


_CSITELICENSE_INITIATEASSOCIATION_REQUEST = _descriptor.Descriptor(
  name='CSiteLicense_InitiateAssociation_Request',
  full_name='CSiteLicense_InitiateAssociation_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='site_steamid', full_name='CSiteLicense_InitiateAssociation_Request.site_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_instanceid', full_name='CSiteLicense_InitiateAssociation_Request.site_instanceid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_local_ip', full_name='CSiteLicense_InitiateAssociation_Request.client_local_ip', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=838,
)


_CSITELICENSE_INITIATEASSOCIATION_RESPONSE = _descriptor.Descriptor(
  name='CSiteLicense_InitiateAssociation_Response',
  full_name='CSiteLicense_InitiateAssociation_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_key', full_name='CSiteLicense_InitiateAssociation_Response.connection_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=907,
)


_CSITELICENSE_LCSAUTHENTICATE_REQUEST = _descriptor.Descriptor(
  name='CSiteLicense_LCSAuthenticate_Request',
  full_name='CSiteLicense_LCSAuthenticate_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CSiteLicense_LCSAuthenticate_Request.instanceid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=967,
)


_CSITELICENSE_LCSAUTHENTICATE_RESPONSE = _descriptor.Descriptor(
  name='CSiteLicense_LCSAuthenticate_Response',
  full_name='CSiteLicense_LCSAuthenticate_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='site_id', full_name='CSiteLicense_LCSAuthenticate_Response.site_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_name', full_name='CSiteLicense_LCSAuthenticate_Response.site_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_session', full_name='CSiteLicense_LCSAuthenticate_Response.new_session', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_site_licenses', full_name='CSiteLicense_LCSAuthenticate_Response.no_site_licenses', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1091,
)


_CSITELICENSE_LCSASSOCIATEUSER_REQUEST = _descriptor.Descriptor(
  name='CSiteLicense_LCSAssociateUser_Request',
  full_name='CSiteLicense_LCSAssociateUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSiteLicense_LCSAssociateUser_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ip', full_name='CSiteLicense_LCSAssociateUser_Request.local_ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CSiteLicense_LCSAssociateUser_Request.instanceid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CSiteLicense_LCSAssociateUser_Request.machine_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1209,
)


_CSITELICENSE_LCSASSOCIATEUSER_RESPONSE = _descriptor.Descriptor(
  name='CSiteLicense_LCSAssociateUser_Response',
  full_name='CSiteLicense_LCSAssociateUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1251,
)


_CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST = _descriptor.Descriptor(
  name='CSiteLicense_ClientSeatCheckout_Request',
  full_name='CSiteLicense_ClientSeatCheckout_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSiteLicense_ClientSeatCheckout_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CSiteLicense_ClientSeatCheckout_Request.instanceid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSiteLicense_ClientSeatCheckout_Request.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1346,
)


_CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE = _descriptor.Descriptor(
  name='CSiteLicense_ClientSeatCheckout_Response',
  full_name='CSiteLicense_ClientSeatCheckout_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1390,
)


_CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST = _descriptor.Descriptor(
  name='CSiteLicense_ClientGetAvailableSeats_Request',
  full_name='CSiteLicense_ClientGetAvailableSeats_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSiteLicense_ClientGetAvailableSeats_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CSiteLicense_ClientGetAvailableSeats_Request.instanceid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSiteLicense_ClientGetAvailableSeats_Request.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1490,
)


_CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE = _descriptor.Descriptor(
  name='CSiteLicense_ClientGetAvailableSeats_Response',
  full_name='CSiteLicense_ClientGetAvailableSeats_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available_seats', full_name='CSiteLicense_ClientGetAvailableSeats_Response.available_seats', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1492,
  serialized_end=1564,
)

_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT.containing_type = _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION
_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION.fields_by_name['payments'].message_type = _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT
DESCRIPTOR.message_types_by_name['CSiteManagerClient_IncomingClient_Request'] = _CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST
DESCRIPTOR.message_types_by_name['CSiteManagerClient_IncomingClient_Response'] = _CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE
DESCRIPTOR.message_types_by_name['CSiteLicense_ClientSeatCheckout_Notification'] = _CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CSiteManagerClient_TrackedPayments_Notification'] = _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CSiteLicense_InitiateAssociation_Request'] = _CSITELICENSE_INITIATEASSOCIATION_REQUEST
DESCRIPTOR.message_types_by_name['CSiteLicense_InitiateAssociation_Response'] = _CSITELICENSE_INITIATEASSOCIATION_RESPONSE
DESCRIPTOR.message_types_by_name['CSiteLicense_LCSAuthenticate_Request'] = _CSITELICENSE_LCSAUTHENTICATE_REQUEST
DESCRIPTOR.message_types_by_name['CSiteLicense_LCSAuthenticate_Response'] = _CSITELICENSE_LCSAUTHENTICATE_RESPONSE
DESCRIPTOR.message_types_by_name['CSiteLicense_LCSAssociateUser_Request'] = _CSITELICENSE_LCSASSOCIATEUSER_REQUEST
DESCRIPTOR.message_types_by_name['CSiteLicense_LCSAssociateUser_Response'] = _CSITELICENSE_LCSASSOCIATEUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CSiteLicense_ClientSeatCheckout_Request'] = _CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST
DESCRIPTOR.message_types_by_name['CSiteLicense_ClientSeatCheckout_Response'] = _CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE
DESCRIPTOR.message_types_by_name['CSiteLicense_ClientGetAvailableSeats_Request'] = _CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST
DESCRIPTOR.message_types_by_name['CSiteLicense_ClientGetAvailableSeats_Response'] = _CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CSiteManagerClient_IncomingClient_Request = _reflection.GeneratedProtocolMessageType('CSiteManagerClient_IncomingClient_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteManagerClient_IncomingClient_Request)
  })
_sym_db.RegisterMessage(CSiteManagerClient_IncomingClient_Request)

CSiteManagerClient_IncomingClient_Response = _reflection.GeneratedProtocolMessageType('CSiteManagerClient_IncomingClient_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteManagerClient_IncomingClient_Response)
  })
_sym_db.RegisterMessage(CSiteManagerClient_IncomingClient_Response)

CSiteLicense_ClientSeatCheckout_Notification = _reflection.GeneratedProtocolMessageType('CSiteLicense_ClientSeatCheckout_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_ClientSeatCheckout_Notification)
  })
_sym_db.RegisterMessage(CSiteLicense_ClientSeatCheckout_Notification)

CSiteManagerClient_TrackedPayments_Notification = _reflection.GeneratedProtocolMessageType('CSiteManagerClient_TrackedPayments_Notification', (_message.Message,), {

  'Payment' : _reflection.GeneratedProtocolMessageType('Payment', (_message.Message,), {
    'DESCRIPTOR' : _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION_PAYMENT,
    '__module__' : 'steammessages_site_license_pb2'
    # @@protoc_insertion_point(class_scope:CSiteManagerClient_TrackedPayments_Notification.Payment)
    })
  ,
  'DESCRIPTOR' : _CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteManagerClient_TrackedPayments_Notification)
  })
_sym_db.RegisterMessage(CSiteManagerClient_TrackedPayments_Notification)
_sym_db.RegisterMessage(CSiteManagerClient_TrackedPayments_Notification.Payment)

CSiteLicense_InitiateAssociation_Request = _reflection.GeneratedProtocolMessageType('CSiteLicense_InitiateAssociation_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_INITIATEASSOCIATION_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_InitiateAssociation_Request)
  })
_sym_db.RegisterMessage(CSiteLicense_InitiateAssociation_Request)

CSiteLicense_InitiateAssociation_Response = _reflection.GeneratedProtocolMessageType('CSiteLicense_InitiateAssociation_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_INITIATEASSOCIATION_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_InitiateAssociation_Response)
  })
_sym_db.RegisterMessage(CSiteLicense_InitiateAssociation_Response)

CSiteLicense_LCSAuthenticate_Request = _reflection.GeneratedProtocolMessageType('CSiteLicense_LCSAuthenticate_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_LCSAUTHENTICATE_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_LCSAuthenticate_Request)
  })
_sym_db.RegisterMessage(CSiteLicense_LCSAuthenticate_Request)

CSiteLicense_LCSAuthenticate_Response = _reflection.GeneratedProtocolMessageType('CSiteLicense_LCSAuthenticate_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_LCSAUTHENTICATE_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_LCSAuthenticate_Response)
  })
_sym_db.RegisterMessage(CSiteLicense_LCSAuthenticate_Response)

CSiteLicense_LCSAssociateUser_Request = _reflection.GeneratedProtocolMessageType('CSiteLicense_LCSAssociateUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_LCSASSOCIATEUSER_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_LCSAssociateUser_Request)
  })
_sym_db.RegisterMessage(CSiteLicense_LCSAssociateUser_Request)

CSiteLicense_LCSAssociateUser_Response = _reflection.GeneratedProtocolMessageType('CSiteLicense_LCSAssociateUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_LCSASSOCIATEUSER_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_LCSAssociateUser_Response)
  })
_sym_db.RegisterMessage(CSiteLicense_LCSAssociateUser_Response)

CSiteLicense_ClientSeatCheckout_Request = _reflection.GeneratedProtocolMessageType('CSiteLicense_ClientSeatCheckout_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_ClientSeatCheckout_Request)
  })
_sym_db.RegisterMessage(CSiteLicense_ClientSeatCheckout_Request)

CSiteLicense_ClientSeatCheckout_Response = _reflection.GeneratedProtocolMessageType('CSiteLicense_ClientSeatCheckout_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_ClientSeatCheckout_Response)
  })
_sym_db.RegisterMessage(CSiteLicense_ClientSeatCheckout_Response)

CSiteLicense_ClientGetAvailableSeats_Request = _reflection.GeneratedProtocolMessageType('CSiteLicense_ClientGetAvailableSeats_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_ClientGetAvailableSeats_Request)
  })
_sym_db.RegisterMessage(CSiteLicense_ClientGetAvailableSeats_Request)

CSiteLicense_ClientGetAvailableSeats_Response = _reflection.GeneratedProtocolMessageType('CSiteLicense_ClientGetAvailableSeats_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE,
  '__module__' : 'steammessages_site_license_pb2'
  # @@protoc_insertion_point(class_scope:CSiteLicense_ClientGetAvailableSeats_Response)
  })
_sym_db.RegisterMessage(CSiteLicense_ClientGetAvailableSeats_Response)


DESCRIPTOR._options = None

_SITEMANAGERCLIENT = _descriptor.ServiceDescriptor(
  name='SiteManagerClient',
  full_name='SiteManagerClient',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030!Local site manager client service\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=1567,
  serialized_end=2114,
  methods=[
  _descriptor.MethodDescriptor(
    name='IncomingClient',
    full_name='SiteManagerClient.IncomingClient',
    index=0,
    containing_service=None,
    input_type=_CSITEMANAGERCLIENT_INCOMINGCLIENT_REQUEST,
    output_type=_CSITEMANAGERCLIENT_INCOMINGCLIENT_RESPONSE,
    serialized_options=b'\202\265\030@Rack informing site manager of new inbound client PSK connection',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientSeatCheckoutNotification',
    full_name='SiteManagerClient.ClientSeatCheckoutNotification',
    index=1,
    containing_service=None,
    input_type=_CSITELICENSE_CLIENTSEATCHECKOUT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0301Notify client directly about seat checkout result',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TrackedPaymentsNotification',
    full_name='SiteManagerClient.TrackedPaymentsNotification',
    index=2,
    containing_service=None,
    input_type=_CSITEMANAGERCLIENT_TRACKEDPAYMENTS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0308Rack informing site manager of existing tracked payments',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SITEMANAGERCLIENT)

DESCRIPTOR.services_by_name['SiteManagerClient'] = _SITEMANAGERCLIENT


_SITELICENSE = _descriptor.ServiceDescriptor(
  name='SiteLicense',
  full_name='SiteLicense',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030\024Site License service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2117,
  serialized_end=2970,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitiateAssociation',
    full_name='SiteLicense.InitiateAssociation',
    index=0,
    containing_service=None,
    input_type=_CSITELICENSE_INITIATEASSOCIATION_REQUEST,
    output_type=_CSITELICENSE_INITIATEASSOCIATION_RESPONSE,
    serialized_options=b'\202\265\0302Client is requesting connetion info for local site',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LCSAuthenticate',
    full_name='SiteLicense.LCSAuthenticate',
    index=1,
    containing_service=None,
    input_type=_CSITELICENSE_LCSAUTHENTICATE_REQUEST,
    output_type=_CSITELICENSE_LCSAUTHENTICATE_RESPONSE,
    serialized_options=b'\202\265\030 Local cafe server authentication',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LCSAssociateUser',
    full_name='SiteLicense.LCSAssociateUser',
    index=2,
    containing_service=None,
    input_type=_CSITELICENSE_LCSASSOCIATEUSER_REQUEST,
    output_type=_CSITELICENSE_LCSASSOCIATEUSER_RESPONSE,
    serialized_options=b'\202\265\0304Local cafe server wants to grant user access to site',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientSeatCheckout',
    full_name='SiteLicense.ClientSeatCheckout',
    index=3,
    containing_service=None,
    input_type=_CSITELICENSE_CLIENTSEATCHECKOUT_REQUEST,
    output_type=_CSITELICENSE_CLIENTSEATCHECKOUT_RESPONSE,
    serialized_options=b'\202\265\030/Client is requesting use of a site license seat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientGetAvailableSeats',
    full_name='SiteLicense.ClientGetAvailableSeats',
    index=4,
    containing_service=None,
    input_type=_CSITELICENSE_CLIENTGETAVAILABLESEATS_REQUEST,
    output_type=_CSITELICENSE_CLIENTGETAVAILABLESEATS_RESPONSE,
    serialized_options=b'\202\265\030<Client is requesting the number of currently available seats',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SITELICENSE)

DESCRIPTOR.services_by_name['SiteLicense'] = _SITELICENSE

SiteManagerClient = service_reflection.GeneratedServiceType('SiteManagerClient', (_service.Service,), dict(
  DESCRIPTOR = _SITEMANAGERCLIENT,
  __module__ = 'steammessages_site_license_pb2'
  ))

SiteManagerClient_Stub = service_reflection.GeneratedServiceStubType('SiteManagerClient_Stub', (SiteManagerClient,), dict(
  DESCRIPTOR = _SITEMANAGERCLIENT,
  __module__ = 'steammessages_site_license_pb2'
  ))


SiteLicense = service_reflection.GeneratedServiceType('SiteLicense', (_service.Service,), dict(
  DESCRIPTOR = _SITELICENSE,
  __module__ = 'steammessages_site_license_pb2'
  ))

SiteLicense_Stub = service_reflection.GeneratedServiceStubType('SiteLicense_Stub', (SiteLicense,), dict(
  DESCRIPTOR = _SITELICENSE,
  __module__ = 'steammessages_site_license_pb2'
  ))


# @@protoc_insertion_point(module_scope)
