# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_contentsystem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_contentsystem.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_contentsystem.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xb5\x02\n6CContentServerDirectory_GetServersForSteamPipe_Request\x12#\n\x07\x63\x65ll_id\x18\x01 \x01(\rB\x12\x82\xb5\x18\x0e\x63lient Cell ID\x12\x39\n\x0bmax_servers\x18\x02 \x01(\r:\x02\x32\x30\x42 \x82\xb5\x18\x1cmax servers in response list\x12*\n\x0bip_override\x18\x03 \x01(\tB\x15\x82\xb5\x18\x11\x63lient IP address\x12+\n\rlauncher_type\x18\x04 \x01(\x05:\x01\x30\x42\x11\x82\xb5\x18\rlauncher type\x12\x42\n\x0bipv6_public\x18\x05 \x01(\tB-\x82\xb5\x18)client public ipv6 address if it knows it\"\xdb\x02\n\"CContentServerDirectory_ServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x03 \x01(\x05\x12\x0c\n\x04load\x18\x04 \x01(\x05\x12\x15\n\rweighted_load\x18\x05 \x01(\x02\x12\"\n\x1anum_entries_in_client_list\x18\x06 \x01(\x05\x12\x18\n\x10steam_china_only\x18\x07 \x01(\x08\x12\x0c\n\x04host\x18\x08 \x01(\t\x12\r\n\x05vhost\x18\t \x01(\t\x12\x14\n\x0cuse_as_proxy\x18\n \x01(\x08\x12#\n\x1bproxy_request_path_template\x18\x0b \x01(\t\x12\x15\n\rhttps_support\x18\x0c \x01(\t\x12\x17\n\x0f\x61llowed_app_ids\x18\r \x03(\r\x12\x18\n\x10preferred_server\x18\x0e \x01(\x08\"o\n7CContentServerDirectory_GetServersForSteamPipe_Response\x12\x34\n\x07servers\x18\x01 \x03(\x0b\x32#.CContentServerDirectory_ServerInfo\"\x89\x01\n1CContentServerDirectory_GetDepotPatchInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x19\n\x11source_manifestid\x18\x03 \x01(\x04\x12\x19\n\x11target_manifestid\x18\x04 \x01(\x04\"{\n2CContentServerDirectory_GetDepotPatchInfo_Response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\npatch_size\x18\x02 \x01(\x04\x12\x1b\n\x13patched_chunks_size\x18\x03 \x01(\x04\"P\n4CContentServerDirectory_GetClientUpdateHosts_Request\x12\x18\n\x10\x63\x61\x63hed_signature\x18\x01 \x01(\t\"w\n5CContentServerDirectory_GetClientUpdateHosts_Response\x12\x10\n\x08hosts_kv\x18\x01 \x01(\t\x12\x18\n\x10valid_until_time\x18\x02 \x01(\x04\x12\x12\n\nip_country\x18\x03 \x01(\t\"\xa1\x01\n6CContentServerDirectory_GetManifestRequestCode_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x04\x12\x12\n\napp_branch\x18\x04 \x01(\t\x12\x1c\n\x14\x62ranch_password_hash\x18\x05 \x01(\t\"X\n7CContentServerDirectory_GetManifestRequestCode_Response\x12\x1d\n\x15manifest_request_code\x18\x01 \x01(\x04\x32\xe0\x04\n\x16\x43ontentServerDirectory\x12\x8b\x01\n\x16GetServersForSteamPipe\x12\x37.CContentServerDirectory_GetServersForSteamPipe_Request\x1a\x38.CContentServerDirectory_GetServersForSteamPipe_Response\x12|\n\x11GetDepotPatchInfo\x12\x32.CContentServerDirectory_GetDepotPatchInfo_Request\x1a\x33.CContentServerDirectory_GetDepotPatchInfo_Response\x12\x85\x01\n\x14GetClientUpdateHosts\x12\x35.CContentServerDirectory_GetClientUpdateHosts_Request\x1a\x36.CContentServerDirectory_GetClientUpdateHosts_Response\x12\x8b\x01\n\x16GetManifestRequestCode\x12\x37.CContentServerDirectory_GetManifestRequestCode_Request\x1a\x38.CContentServerDirectory_GetManifestRequestCode_Response\x1a$\x82\xb5\x18 Content Server and CDN directoryB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetServersForSteamPipe_Request',
  full_name='CContentServerDirectory_GetServersForSteamPipe_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.cell_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016client Cell ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_servers', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.max_servers', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034max servers in response list', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_override', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.ip_override', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021client IP address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launcher_type', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.launcher_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\rlauncher type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_public', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.ipv6_public', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)client public ipv6 address if it knows it', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=407,
)


_CCONTENTSERVERDIRECTORY_SERVERINFO = _descriptor.Descriptor(
  name='CContentServerDirectory_ServerInfo',
  full_name='CContentServerDirectory_ServerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CContentServerDirectory_ServerInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='CContentServerDirectory_ServerInfo.source_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CContentServerDirectory_ServerInfo.cell_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='CContentServerDirectory_ServerInfo.load', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_load', full_name='CContentServerDirectory_ServerInfo.weighted_load', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_entries_in_client_list', full_name='CContentServerDirectory_ServerInfo.num_entries_in_client_list', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_china_only', full_name='CContentServerDirectory_ServerInfo.steam_china_only', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='CContentServerDirectory_ServerInfo.host', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vhost', full_name='CContentServerDirectory_ServerInfo.vhost', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_as_proxy', full_name='CContentServerDirectory_ServerInfo.use_as_proxy', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_request_path_template', full_name='CContentServerDirectory_ServerInfo.proxy_request_path_template', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='https_support', full_name='CContentServerDirectory_ServerInfo.https_support', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_app_ids', full_name='CContentServerDirectory_ServerInfo.allowed_app_ids', index=12,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_server', full_name='CContentServerDirectory_ServerInfo.preferred_server', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=757,
)


_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetServersForSteamPipe_Response',
  full_name='CContentServerDirectory_GetServersForSteamPipe_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='CContentServerDirectory_GetServersForSteamPipe_Response.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=870,
)


_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetDepotPatchInfo_Request',
  full_name='CContentServerDirectory_GetDepotPatchInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depotid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.depotid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_manifestid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.source_manifestid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_manifestid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.target_manifestid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=1010,
)


_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetDepotPatchInfo_Response',
  full_name='CContentServerDirectory_GetDepotPatchInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_available', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.is_available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch_size', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.patch_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patched_chunks_size', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.patched_chunks_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1135,
)


_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetClientUpdateHosts_Request',
  full_name='CContentServerDirectory_GetClientUpdateHosts_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cached_signature', full_name='CContentServerDirectory_GetClientUpdateHosts_Request.cached_signature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1137,
  serialized_end=1217,
)


_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetClientUpdateHosts_Response',
  full_name='CContentServerDirectory_GetClientUpdateHosts_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts_kv', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.hosts_kv', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_until_time', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.valid_until_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_country', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.ip_country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1338,
)


_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetManifestRequestCode_Request',
  full_name='CContentServerDirectory_GetManifestRequestCode_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.depot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.manifest_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_branch', full_name='CContentServerDirectory_GetManifestRequestCode_Request.app_branch', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_password_hash', full_name='CContentServerDirectory_GetManifestRequestCode_Request.branch_password_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1341,
  serialized_end=1502,
)


_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetManifestRequestCode_Response',
  full_name='CContentServerDirectory_GetManifestRequestCode_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifest_request_code', full_name='CContentServerDirectory_GetManifestRequestCode_Response.manifest_request_code', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1592,
)

_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE.fields_by_name['servers'].message_type = _CCONTENTSERVERDIRECTORY_SERVERINFO
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetServersForSteamPipe_Request'] = _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_ServerInfo'] = _CCONTENTSERVERDIRECTORY_SERVERINFO
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetServersForSteamPipe_Response'] = _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetDepotPatchInfo_Request'] = _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetDepotPatchInfo_Response'] = _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetClientUpdateHosts_Request'] = _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetClientUpdateHosts_Response'] = _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetManifestRequestCode_Request'] = _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetManifestRequestCode_Response'] = _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CContentServerDirectory_GetServersForSteamPipe_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetServersForSteamPipe_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetServersForSteamPipe_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetServersForSteamPipe_Request)

CContentServerDirectory_ServerInfo = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_ServerInfo', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_SERVERINFO,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_ServerInfo)
  })
_sym_db.RegisterMessage(CContentServerDirectory_ServerInfo)

CContentServerDirectory_GetServersForSteamPipe_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetServersForSteamPipe_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetServersForSteamPipe_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetServersForSteamPipe_Response)

CContentServerDirectory_GetDepotPatchInfo_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetDepotPatchInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetDepotPatchInfo_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetDepotPatchInfo_Request)

CContentServerDirectory_GetDepotPatchInfo_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetDepotPatchInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetDepotPatchInfo_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetDepotPatchInfo_Response)

CContentServerDirectory_GetClientUpdateHosts_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetClientUpdateHosts_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetClientUpdateHosts_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetClientUpdateHosts_Request)

CContentServerDirectory_GetClientUpdateHosts_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetClientUpdateHosts_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetClientUpdateHosts_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetClientUpdateHosts_Response)

CContentServerDirectory_GetManifestRequestCode_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetManifestRequestCode_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetManifestRequestCode_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetManifestRequestCode_Request)

CContentServerDirectory_GetManifestRequestCode_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetManifestRequestCode_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetManifestRequestCode_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetManifestRequestCode_Response)


DESCRIPTOR._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['cell_id']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['max_servers']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['ip_override']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['launcher_type']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['ipv6_public']._options = None

_CONTENTSERVERDIRECTORY = _descriptor.ServiceDescriptor(
  name='ContentServerDirectory',
  full_name='ContentServerDirectory',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030 Content Server and CDN directory',
  create_key=_descriptor._internal_create_key,
  serialized_start=1595,
  serialized_end=2203,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetServersForSteamPipe',
    full_name='ContentServerDirectory.GetServersForSteamPipe',
    index=0,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDepotPatchInfo',
    full_name='ContentServerDirectory.GetDepotPatchInfo',
    index=1,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClientUpdateHosts',
    full_name='ContentServerDirectory.GetClientUpdateHosts',
    index=2,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetManifestRequestCode',
    full_name='ContentServerDirectory.GetManifestRequestCode',
    index=3,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTENTSERVERDIRECTORY)

DESCRIPTOR.services_by_name['ContentServerDirectory'] = _CONTENTSERVERDIRECTORY

ContentServerDirectory = service_reflection.GeneratedServiceType('ContentServerDirectory', (_service.Service,), dict(
  DESCRIPTOR = _CONTENTSERVERDIRECTORY,
  __module__ = 'steammessages_contentsystem_pb2'
  ))

ContentServerDirectory_Stub = service_reflection.GeneratedServiceStubType('ContentServerDirectory_Stub', (ContentServerDirectory,), dict(
  DESCRIPTOR = _CONTENTSERVERDIRECTORY,
  __module__ = 'steammessages_contentsystem_pb2'
  ))


# @@protoc_insertion_point(module_scope)
