# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_publishedfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_publishedfile.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_publishedfile.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"G\n\x1b\x43PublishedFile_Vote_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"\x1e\n\x1c\x43PublishedFile_Vote_Response\"t\n CPublishedFile_Subscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\"#\n!CPublishedFile_Subscribe_Response\"v\n\"CPublishedFile_Unsubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\"%\n#CPublishedFile_Unsubscribe_Response\">\n#CPublishedFile_CanSubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"=\n$CPublishedFile_CanSubscribe_Response\x12\x15\n\rcan_subscribe\x18\x01 \x01(\x08\"\x85\x02\n(CPublishedFile_GetSubSectionData_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x66or_table_of_contents\x18\x02 \x01(\x08\x12\x1a\n\x12specific_sectionid\x18\x03 \x01(\x04\x12\x84\x01\n\x10\x64\x65sired_revision\x18\x04 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB/\x82\xb5\x18+Return the data for the specified revision.\"i\n\x17PublishedFileSubSection\x12\x11\n\tsectionid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65scription_text\x18\x03 \x01(\t\x12\x12\n\nsort_order\x18\x04 \x01(\r\"[\n)CPublishedFile_GetSubSectionData_Response\x12.\n\x0csub_sections\x18\x01 \x03(\x0b\x32\x18.PublishedFileSubSection\"\xcc\n\n\x1e\x43PublishedFile_Publish_Request\x12<\n\x05\x61ppid\x18\x01 \x01(\rB-\x82\xb5\x18)App Id this file is being published FROM.\x12\x43\n\x0e\x63onsumer_appid\x18\x02 \x01(\rB+\x82\xb5\x18\'App Id this file is being published TO.\x12K\n\rcloudfilename\x18\x03 \x01(\tB4\x82\xb5\x18\x30Name of the file to publish in the user\'s cloud.\x12[\n\x15preview_cloudfilename\x18\x04 \x01(\tB<\x82\xb5\x18\x38Name of the file to use as the published file\'s preview.\x12\x35\n\x05title\x18\x05 \x01(\tB&\x82\xb5\x18\"Text title for the published file.\x12\x46\n\x10\x66ile_description\x18\x06 \x01(\tB,\x82\xb5\x18(Text description for the published file.\x12L\n\tfile_type\x18\x07 \x01(\rB9\x82\xb5\x18\x35(EWorkshopFileType) Type of Workshop file to publish.\x12I\n\x16\x63onsumer_shortcut_name\x18\x08 \x01(\tB)\x82\xb5\x18%Shortcut name for the published file.\x12I\n\x10youtube_username\x18\t \x01(\tB/\x82\xb5\x18+(Optional) User\'s YouTube account username.\x12\\\n\x0fyoutube_videoid\x18\n \x01(\tBC\x82\xb5\x18?(Optional) Video Id of a YouTube video for this published file.\x12\x81\x01\n\nvisibility\x18\x0b \x01(\rBm\x82\xb5\x18i(ERemoteStoragePublishedFileVisibility) Visibility of the published file (private, friends, public, etc.)\x12k\n\x0credirect_uri\x18\x0c \x01(\tBU\x82\xb5\x18Q(Optional) If supplied, the resulting published file\'s Id is appended to the URI.\x12\x44\n\x04tags\x18\r \x03(\tB6\x82\xb5\x18\x32\x41rray of text tags to apply to the published file.\x12Y\n\x0f\x63ollection_type\x18\x0e \x01(\tB@\x82\xb5\x18<(Optional) Type of collection the published file represents.\x12M\n\tgame_type\x18\x0f \x01(\tB:\x82\xb5\x18\x36(Optional) Type of game the published file represents.\x12[\n\x03url\x18\x10 \x01(\tBN\x82\xb5\x18J(Optional) If this represents a game, this is the URL to that game\'s page.\"P\n\x1f\x43PublishedFile_Publish_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x8d\n\n!CPublishedFile_GetDetails_Request\x12P\n\x10publishedfileids\x18\x01 \x03(\x06\x42\x36\x82\xb5\x18\x32Set of published file Ids to retrieve details for.\x12Q\n\x0bincludetags\x18\x02 \x01(\x08\x42<\x82\xb5\x18\x38If true, return tag information in the returned details.\x12\x63\n\x19includeadditionalpreviews\x18\x03 \x01(\x08\x42@\x82\xb5\x18<If true, return preview information in the returned details.\x12N\n\x0fincludechildren\x18\x04 \x01(\x08\x42\x35\x82\xb5\x18\x31If true, return children in the returned details.\x12R\n\rincludekvtags\x18\x05 \x01(\x08\x42;\x82\xb5\x18\x37If true, return key value tags in the returned details.\x12L\n\x0cincludevotes\x18\x06 \x01(\x08\x42\x36\x82\xb5\x18\x32If true, return vote data in the returned details.\x12\x63\n\x11short_description\x18\x08 \x01(\x08\x42H\x82\xb5\x18\x44If true, return a short description instead of the full description.\x12L\n\x12includeforsaledata\x18\n \x01(\x08\x42\x30\x82\xb5\x18,If true, return pricing data, if applicable.\x12\x42\n\x0fincludemetadata\x18\x0b \x01(\x08\x42)\x82\xb5\x18%If true, populate the metadata field.\x12U\n\x08language\x18\x0c \x01(\x05:\x01\x30\x42@\x82\xb5\x18<Specifies the localized text to return. Defaults to English.\x12g\n\x15return_playtime_stats\x18\r \x01(\rBH\x82\xb5\x18\x44Return playtime stats for the specified number of days before today.\x12\r\n\x05\x61ppid\x18\x0e \x01(\r\x12\x46\n\x18strip_description_bbcode\x18\x0f \x01(\x08\x42$\x82\xb5\x18 Strips BBCode from descriptions.\x12\x84\x01\n\x10\x64\x65sired_revision\x18\x10 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB/\x82\xb5\x18+Return the data for the specified revision.\x12W\n\x10includereactions\x18\x11 \x01(\x08:\x05\x66\x61lseB6\x82\xb5\x18\x32If true, then reactions to items will be returned.\"\xf2\x18\n\x14PublishedFileDetails\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x06\x12\x15\n\rcreator_appid\x18\x04 \x01(\r\x12\x16\n\x0e\x63onsumer_appid\x18\x05 \x01(\r\x12\x1b\n\x13\x63onsumer_shortcutid\x18\x06 \x01(\r\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x11\n\tfile_size\x18\x08 \x01(\x04\x12\x19\n\x11preview_file_size\x18\t \x01(\x04\x12\x10\n\x08\x66ile_url\x18\n \x01(\t\x12\x13\n\x0bpreview_url\x18\x0b \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x0c \x01(\t\x12\x0b\n\x03url\x18\r \x01(\t\x12\x15\n\rhcontent_file\x18\x0e \x01(\x06\x12\x18\n\x10hcontent_preview\x18\x0f \x01(\x06\x12\r\n\x05title\x18\x10 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x11 \x01(\t\x12\x19\n\x11short_description\x18\x12 \x01(\t\x12\x14\n\x0ctime_created\x18\x13 \x01(\r\x12\x14\n\x0ctime_updated\x18\x14 \x01(\r\x12\x12\n\nvisibility\x18\x15 \x01(\r\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x15\n\rworkshop_file\x18\x17 \x01(\x08\x12\x19\n\x11workshop_accepted\x18\x18 \x01(\x08\x12\x1a\n\x12show_subscribe_all\x18\x19 \x01(\x08\x12\x1e\n\x16num_comments_developer\x18\x1a \x01(\x05\x12\x1b\n\x13num_comments_public\x18\x1b \x01(\x05\x12\x0e\n\x06\x62\x61nned\x18\x1c \x01(\x08\x12\x12\n\nban_reason\x18\x1d \x01(\t\x12\x0e\n\x06\x62\x61nner\x18\x1e \x01(\x06\x12\x16\n\x0e\x63\x61n_be_deleted\x18\x1f \x01(\x08\x12\x14\n\x0cincompatible\x18  \x01(\x08\x12\x10\n\x08\x61pp_name\x18! \x01(\t\x12\x11\n\tfile_type\x18\" \x01(\r\x12\x15\n\rcan_subscribe\x18# \x01(\x08\x12\x15\n\rsubscriptions\x18$ \x01(\r\x12\x11\n\tfavorited\x18% \x01(\r\x12\x11\n\tfollowers\x18& \x01(\r\x12\x1e\n\x16lifetime_subscriptions\x18\' \x01(\r\x12\x1a\n\x12lifetime_favorited\x18( \x01(\r\x12\x1a\n\x12lifetime_followers\x18) \x01(\r\x12\x19\n\x11lifetime_playtime\x18> \x01(\x04\x12\"\n\x1alifetime_playtime_sessions\x18? \x01(\x04\x12\r\n\x05views\x18* \x01(\r\x12\x13\n\x0bimage_width\x18+ \x01(\r\x12\x14\n\x0cimage_height\x18, \x01(\r\x12\x11\n\timage_url\x18- \x01(\t\x12\x13\n\x0bspoiler_tag\x18. \x01(\x08\x12\x12\n\nshortcutid\x18/ \x01(\r\x12\x14\n\x0cshortcutname\x18\x30 \x01(\t\x12\x14\n\x0cnum_children\x18\x31 \x01(\r\x12\x13\n\x0bnum_reports\x18\x32 \x01(\r\x12/\n\x08previews\x18\x33 \x03(\x0b\x32\x1d.PublishedFileDetails.Preview\x12\'\n\x04tags\x18\x34 \x03(\x0b\x32\x19.PublishedFileDetails.Tag\x12-\n\x08\x63hildren\x18\x35 \x03(\x0b\x32\x1b.PublishedFileDetails.Child\x12+\n\x06kvtags\x18\x36 \x03(\x0b\x32\x1b.PublishedFileDetails.KVTag\x12\x31\n\tvote_data\x18\x37 \x01(\x0b\x32\x1e.PublishedFileDetails.VoteData\x12;\n\x0eplaytime_stats\x18@ \x01(\x0b\x32#.PublishedFileDetails.PlaytimeStats\x12r\n\x0ftime_subscribed\x18\x38 \x01(\rBY\x82\xb5\x18UOnly valid in PublishedFile.GetUserFiles and not normal PublishedFile.GetDetail calls\x12\x61\n\rfor_sale_data\x18\x39 \x01(\x0b\x32!.PublishedFileDetails.ForSaleDataB\'\x82\xb5\x18#Pricing information, if applicable.\x12\x37\n\x08metadata\x18: \x01(\tB%\x82\xb5\x18!Metadata associated with the item\x12\x43\n\x08language\x18= \x01(\x05:\x01\x30\x42.\x82\xb5\x18*The language of the title and description.\x12\x1f\n\x17maybe_inappropriate_sex\x18\x41 \x01(\x08\x12$\n\x1cmaybe_inappropriate_violence\x18\x42 \x01(\x08\x12Q\n\x16revision_change_number\x18\x43 \x01(\x04\x42\x31\x82\xb5\x18-The change number for the specified revision.\x12\xdc\x01\n\x08revision\x18\x44 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB\x8e\x01\x82\xb5\x18\x89\x01The revision of the data returned, usually k_EPublishedFileRevision_Latest, but can be another revision/snapshot depending on the caller.\x12M\n\x13\x61vailable_revisions\x18\x45 \x03(\x0e\x32\x17.EPublishedFileRevisionB\x17\x82\xb5\x18\x13\x41vailable revisions\x12M\n\treactions\x18\x46 \x03(\x0b\x32\x1e.PublishedFileDetails.ReactionB\x1a\x82\xb5\x18\x16Reactions to this item\x12[\n\x15\x62\x61n_text_check_result\x18G \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\x1a;\n\x03Tag\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x11\n\tadminonly\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x1a\xa6\x01\n\x07Preview\x12\x11\n\tpreviewid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x06 \x01(\t\x12\x14\n\x0cpreview_type\x18\x07 \x01(\r\x12\x1a\n\x12\x65xternal_reference\x18\x08 \x01(\t\x1a\x46\n\x05\x43hild\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x11\n\tfile_type\x18\x03 \x01(\r\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a?\n\x08VoteData\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08votes_up\x18\x02 \x01(\r\x12\x12\n\nvotes_down\x18\x03 \x01(\r\x1a\xdc\x01\n\x0b\x46orSaleData\x12\x13\n\x0bis_for_sale\x18\x01 \x01(\x08\x12\x16\n\x0eprice_category\x18\x02 \x01(\r\x12\x41\n\x07\x65status\x18\x03 \x01(\x0e\x32\x1c.EPublishedFileForSaleStatus:\x12k_PFFSS_NotForSale\x12\x1c\n\x14price_category_floor\x18\x04 \x01(\r\x12\"\n\x1aprice_is_pay_what_you_want\x18\x05 \x01(\x08\x12\x1b\n\x13\x64iscount_percentage\x18\x06 \x01(\r\x1a?\n\rPlaytimeStats\x12\x18\n\x10playtime_seconds\x18\x01 \x01(\x04\x12\x14\n\x0cnum_sessions\x18\x02 \x01(\x04\x1a-\n\x08Reaction\x12\x12\n\nreactionid\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"Y\n\"CPublishedFile_GetDetails_Response\x12\x33\n\x14publishedfiledetails\x18\x01 \x03(\x0b\x32\x15.PublishedFileDetails\"\xe1\x02\n\"CPublishedFile_GetItemInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12H\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32\x30.CPublishedFile_GetItemInfo_Request.WorkshopItem\x1a\xc6\x01\n\x0cWorkshopItem\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x84\x01\n\x10\x64\x65sired_revision\x18\x03 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB/\x82\xb5\x18+Return the data for the specified revision.\"\x89\x02\n#CPublishedFile_GetItemInfo_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12M\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x35.CPublishedFile_GetItemInfo_Response.WorkshopItemInfo\x12\x15\n\rprivate_items\x18\x03 \x03(\x06\x1ag\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\r\n\x05\x66lags\x18\x04 \x01(\r\"\xd0\x16\n#CPublishedFile_GetUserFiles_Request\x12J\n\x07steamid\x18\x01 \x01(\x06\x42\x39\x82\xb5\x18\x35Steam ID of the user whose files are being requested.\x12\x46\n\x05\x61ppid\x18\x02 \x01(\rB7\x82\xb5\x18\x33\x41pp Id of the app that the files were published to.\x12:\n\x04page\x18\x04 \x01(\r:\x01\x31\x42)\x82\xb5\x18%(Optional) Starting page for results.\x12P\n\nnumperpage\x18\x05 \x01(\r:\x01\x31\x42\x39\x82\xb5\x18\x35(Optional) The number of results, per page to return.\x12\x43\n\x04type\x18\x06 \x01(\t:\x07myfilesB,\x82\xb5\x18((Optional) Type of files to be returned.\x12Y\n\nsortmethod\x18\x07 \x01(\t:\x0blastupdatedB8\x82\xb5\x18\x34(Optional) Sorting method to use on returned values.\x12;\n\x07privacy\x18\t \x01(\rB*\x82\xb5\x18&(optional) Filter by privacy settings.\x12h\n\x0crequiredtags\x18\n \x03(\tBR\x82\xb5\x18N(Optional) Tags that must be present on a published file to satisfy the query.\x12l\n\x0c\x65xcludedtags\x18\x0b \x03(\tBV\x82\xb5\x18R(Optional) Tags that must NOT be present on a published file to satisfy the query.\x12n\n\x10required_kv_tags\x18\x1e \x03(\x0b\x32*.CPublishedFile_GetUserFiles_Request.KVTagB(\x82\xb5\x18$Required key-value tags to match on.\x12=\n\x08\x66iletype\x18\x0e \x01(\rB+\x82\xb5\x18\'(Optional) File type to match files to.\x12\x61\n\rcreator_appid\x18\x0f \x01(\rBJ\x82\xb5\x18\x46\x41pp Id of the app that published the files, only matched if specified.\x12I\n\x14match_cloud_filename\x18\x10 \x01(\tB+\x82\xb5\x18\'Match this cloud filename if specified.\x12j\n\x15\x63\x61\x63he_max_age_seconds\x18\x1b \x01(\r:\x01\x30\x42H\x82\xb5\x18\x44\x41llow stale data to be returned for the specified number of seconds.\x12U\n\x08language\x18\x1d \x01(\x05:\x01\x30\x42@\x82\xb5\x18<Specifies the localized text to return. Defaults to English.\x12\xa3\x01\n\ttaggroups\x18\" \x03(\x0b\x32-.CPublishedFile_GetUserFiles_Request.TagGroupBa\x82\xb5\x18](Optional) At least one of the tags must be present on a published file to satisfy the query.\x12i\n\ttotalonly\x18\x11 \x01(\x08\x42V\x82\xb5\x18R(Optional) If true, only return the total number of files that satisfy this query.\x12n\n\x08ids_only\x18\x12 \x01(\x08\x42\\\x82\xb5\x18X(Optional) If true, only return the published file ids of files that satisfy this query.\x12\x34\n\x10return_vote_data\x18\x13 \x01(\x08:\x04trueB\x14\x82\xb5\x18\x10Return vote data\x12\x38\n\x0breturn_tags\x18\x14 \x01(\x08\x42#\x82\xb5\x18\x1fReturn tags in the file details\x12K\n\x0ereturn_kv_tags\x18\x15 \x01(\x08:\x04trueB-\x82\xb5\x18)Return key-value tags in the file details\x12W\n\x0freturn_previews\x18\x16 \x01(\x08\x42>\x82\xb5\x18:Return preview image and video details in the file details\x12\x46\n\x0freturn_children\x18\x17 \x01(\x08\x42-\x82\xb5\x18)Return child item ids in the file details\x12l\n\x18return_short_description\x18\x18 \x01(\x08:\x04trueBD\x82\xb5\x18@Populate the short_description field instead of file_description\x12K\n\x14return_for_sale_data\x18\x1a \x01(\x08\x42-\x82\xb5\x18)Return pricing information, if applicable\x12?\n\x0freturn_metadata\x18\x1c \x01(\x08:\x05\x66\x61lseB\x1f\x82\xb5\x18\x1bPopulate the metadata field\x12g\n\x15return_playtime_stats\x18\x1f \x01(\rBH\x82\xb5\x18\x44Return playtime stats for the specified number of days before today.\x12\x46\n\x18strip_description_bbcode\x18  \x01(\x08\x42$\x82\xb5\x18 Strips BBCode from descriptions.\x12W\n\x10return_reactions\x18# \x01(\x08:\x05\x66\x61lseB6\x82\xb5\x18\x32If true, then reactions to items will be returned.\x12\x45\n\x13startindex_override\x18\x19 \x01(\rB(\x82\xb5\x18$Backwards compatible for the client.\x12\x84\x01\n\x10\x64\x65sired_revision\x18! \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB/\x82\xb5\x18+Return the data for the specified revision.\x12@\n\x0breturn_apps\x18$ \x01(\x08\x42+\x82\xb5\x18\'Return list of apps the items belong to\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\"\x80\x02\n$CPublishedFile_GetUserFiles_Response\x12\r\n\x05total\x18\x01 \x01(\r\x12\x12\n\nstartindex\x18\x02 \x01(\r\x12\x33\n\x14publishedfiledetails\x18\x03 \x03(\x0b\x32\x15.PublishedFileDetails\x12\x37\n\x04\x61pps\x18\x04 \x03(\x0b\x32).CPublishedFile_GetUserFiles_Response.App\x1aG\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nshortcutid\x18\x03 \x01(\r\x12\x0f\n\x07private\x18\x04 \x01(\x08\"\x9a\x02\n1CPublishedFile_AreFilesInSubscriptionList_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x06\x12&\n\x08listtype\x18\x03 \x01(\rB\x14\x82\xb5\x18\x10See EUCMListType\x12<\n\x08\x66iletype\x18\x04 \x01(\rB*\x82\xb5\x18&See EPublishedFileInfoMatchingFileType\x12V\n\x10workshopfiletype\x18\x05 \x01(\rB<\x82\xb5\x18\x38See EWorkshopFileType.  If specified, overrides filetype\"\xb2\x01\n2CPublishedFile_AreFilesInSubscriptionList_Response\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.CPublishedFile_AreFilesInSubscriptionList_Response.InList\x1a\x31\n\x06InList\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x0e\n\x06inlist\x18\x02 \x01(\x08\"\xff\x06\n\x1d\x43PublishedFile_Update_Request\x12\x39\n\x05\x61ppid\x18\x01 \x01(\rB*\x82\xb5\x18&App Id this published file belongs to.\x12O\n\x0fpublishedfileid\x18\x02 \x01(\x06\x42\x36\x82\xb5\x18\x32Published file id of the file we\'d like to update.\x12:\n\x05title\x18\x03 \x01(\tB+\x82\xb5\x18\'(Optional) Title of the published file.\x12K\n\x10\x66ile_description\x18\x04 \x01(\tB1\x82\xb5\x18-(Optional) Description of the published file.\x12\x44\n\nvisibility\x18\x05 \x01(\rB0\x82\xb5\x18,(Optional) Visibility of the published file.\x12@\n\x04tags\x18\x06 \x03(\tB2\x82\xb5\x18.(Optional) Set of tags for the published file.\x12\x41\n\x08\x66ilename\x18\x07 \x01(\tB/\x82\xb5\x18+(Optional) Filename for the published file.\x12Q\n\x10preview_filename\x18\x08 \x01(\tB7\x82\xb5\x18\x33(Optional) Preview filename for the published file.\x12i\n\x0bspoiler_tag\x18\n \x01(\x08\x42T\x82\xb5\x18P(Optional) Whether this published file should have a spoiler tag attached to it.\x12^\n\x0bimage_width\x18\x0f \x01(\rBI\x82\xb5\x18\x45(Optional) If this is an image file, you can specify the image width.\x12`\n\x0cimage_height\x18\x10 \x01(\rBJ\x82\xb5\x18\x46(Optional) If this is an image file, you can specify the image height.\" \n\x1e\x43PublishedFile_Update_Response\"p\n\x1d\x43PublishedFile_Delete_Request\x12O\n\x0fpublishedfileid\x18\x01 \x01(\x06\x42\x36\x82\xb5\x18\x32Published file id of the file we\'d like to delete.\" \n\x1e\x43PublishedFile_Delete_Response\"\xb8\x01\n,CPublishedFile_GetChangeHistoryEntry_Request\x12\x63\n\x0fpublishedfileid\x18\x01 \x01(\x06\x42J\x82\xb5\x18\x46Published file id of the file we\'d like to get the change history for.\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08language\x18\x03 \x01(\x05\"]\n-CPublishedFile_GetChangeHistoryEntry_Response\x12\x1a\n\x12\x63hange_description\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\"\x9e\x02\n\'CPublishedFile_GetChangeHistory_Request\x12\x63\n\x0fpublishedfileid\x18\x01 \x01(\x06\x42J\x82\xb5\x18\x46Published file id of the file we\'d like to get the change history for.\x12@\n\ntotal_only\x18\x02 \x01(\x08\x42,\x82\xb5\x18(Return the total number of changes only.\x12\x12\n\nstartindex\x18\x03 \x01(\r\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12)\n\x08language\x18\x05 \x01(\x05:\x01\x30\x42\x14\x82\xb5\x18\x10\x44\x65sired language\"\xcd\x01\n(CPublishedFile_GetChangeHistory_Response\x12\x44\n\x07\x63hanges\x18\x01 \x03(\x0b\x32\x33.CPublishedFile_GetChangeHistory_Response.ChangeLog\x12\r\n\x05total\x18\x02 \x01(\r\x1aL\n\tChangeLog\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x1a\n\x12\x63hange_description\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\x05\"\xd1\x05\n)CPublishedFile_RefreshVotingQueue_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x42\n\x12matching_file_type\x18\x02 \x01(\rB&\x82\xb5\x18\"EPublishedFileInfoMatchingFileType\x12l\n\x04tags\x18\x03 \x03(\tB^\x82\xb5\x18ZInclude files that have all the tags or any of the tags if match_all_tags is set to false.\x12\x95\x01\n\x0ematch_all_tags\x18\x04 \x01(\x08:\x04trueBw\x82\xb5\x18sIf true, then files must have all the tags specified.  If false, then must have at least one of the tags specified.\x12I\n\rexcluded_tags\x18\x05 \x03(\tB2\x82\xb5\x18.Exclude any files that have any of these tags.\x12j\n\x12\x64\x65sired_queue_size\x18\x06 \x01(\rBN\x82\xb5\x18JDesired number of items in the voting queue.  May be clamped by the server\x12\x93\x01\n\x10\x64\x65sired_revision\x18\x08 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB>\x82\xb5\x18:Filter to items that have data for the specified revision.\",\n*CPublishedFile_RefreshVotingQueue_Response\"\x9b\x1f\n!CPublishedFile_QueryFiles_Request\x12L\n\nquery_type\x18\x01 \x01(\rB8\x82\xb5\x18\x34\x65numeration EPublishedFileQueryType in clientenums.h\x12\x1e\n\x04page\x18\x02 \x01(\rB\x10\x82\xb5\x18\x0c\x43urrent page\x12\xe8\x01\n\x06\x63ursor\x18\' \x01(\tB\xd7\x01\x82\xb5\x18\xd2\x01\x43ursor to paginate through the results (set to \'*\' for the first request).  Prefer this over using the page parameter, as it will allow you to do deep pagination.  When used, the page parameter will be ignored.\x12P\n\nnumperpage\x18\x03 \x01(\r:\x01\x31\x42\x39\x82\xb5\x18\x35(Optional) The number of results, per page to return.\x12\x35\n\rcreator_appid\x18\x04 \x01(\rB\x1e\x82\xb5\x18\x1a\x41pp that created the files\x12.\n\x05\x61ppid\x18\x05 \x01(\rB\x1f\x82\xb5\x18\x1b\x41pp that consumes the files\x12N\n\x0crequiredtags\x18\x06 \x03(\tB8\x82\xb5\x18\x34Tags to match on. See match_all_tags parameter below\x12l\n\x0c\x65xcludedtags\x18\x07 \x03(\tBV\x82\xb5\x18R(Optional) Tags that must NOT be present on a published file to satisfy the query.\x12\x8a\x01\n\x0ematch_all_tags\x18\x08 \x01(\x08:\x04trueBl\x82\xb5\x18hIf true, then items must have all the tags specified, otherwise they must have at least one of the tags.\x12Q\n\x0erequired_flags\x18\t \x03(\tB9\x82\xb5\x18\x35Required flags that must be set on any returned items\x12K\n\romitted_flags\x18\n \x03(\tB4\x82\xb5\x18\x30\x46lags that must not be set on any returned items\x12I\n\x0bsearch_text\x18\x0b \x01(\tB4\x82\xb5\x18\x30Text to match in the item\'s title or description\x12\x38\n\x08\x66iletype\x18\x0c \x01(\rB&\x82\xb5\x18\"EPublishedFileInfoMatchingFileType\x12P\n\x15\x63hild_publishedfileid\x18\r \x01(\x06\x42\x31\x82\xb5\x18-Find all items that reference the given item.\x12\x82\x01\n\x04\x64\x61ys\x18\x0e \x01(\rBt\x82\xb5\x18pIf query_type is k_PublishedFileQueryType_RankedByTrend, then this is the number of days to get votes for [1,7].\x12\xb0\x01\n\x19include_recent_votes_only\x18\x0f \x01(\x08\x42\x8c\x01\x82\xb5\x18\x87\x01If query_type is k_PublishedFileQueryType_RankedByTrend, then limit result set just to items that have votes within the day range given\x12j\n\x15\x63\x61\x63he_max_age_seconds\x18\x1f \x01(\r:\x01\x30\x42H\x82\xb5\x18\x44\x41llow stale data to be returned for the specified number of seconds.\x12`\n\x08language\x18! \x01(\x05:\x01\x30\x42K\x82\xb5\x18GLanguage to search in and also what gets returned. Defaults to English.\x12l\n\x10required_kv_tags\x18\" \x03(\x0b\x32(.CPublishedFile_QueryFiles_Request.KVTagB(\x82\xb5\x18$Required key-value tags to match on.\x12\xa1\x01\n\ttaggroups\x18* \x03(\x0b\x32+.CPublishedFile_QueryFiles_Request.TagGroupBa\x82\xb5\x18](Optional) At least one of the tags must be present on a published file to satisfy the query.\x12\x83\x01\n\x12\x64\x61te_range_created\x18, \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRangeB9\x82\xb5\x18\x35(Optional) Filter to items created within this range.\x12\x83\x01\n\x12\x64\x61te_range_updated\x18- \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRangeB9\x82\xb5\x18\x35(Optional) Filter to items updated within this range.\x12i\n\ttotalonly\x18\x10 \x01(\x08\x42V\x82\xb5\x18R(Optional) If true, only return the total number of files that satisfy this query.\x12n\n\x08ids_only\x18# \x01(\x08\x42\\\x82\xb5\x18X(Optional) If true, only return the published file ids of files that satisfy this query.\x12.\n\x10return_vote_data\x18\x11 \x01(\x08\x42\x14\x82\xb5\x18\x10Return vote data\x12\x38\n\x0breturn_tags\x18\x12 \x01(\x08\x42#\x82\xb5\x18\x1fReturn tags in the file details\x12\x45\n\x0ereturn_kv_tags\x18\x13 \x01(\x08\x42-\x82\xb5\x18)Return key-value tags in the file details\x12W\n\x0freturn_previews\x18\x14 \x01(\x08\x42>\x82\xb5\x18:Return preview image and video details in the file details\x12\x46\n\x0freturn_children\x18\x15 \x01(\x08\x42-\x82\xb5\x18)Return child item ids in the file details\x12\x66\n\x18return_short_description\x18\x16 \x01(\x08\x42\x44\x82\xb5\x18@Populate the short_description field instead of file_description\x12K\n\x14return_for_sale_data\x18\x1e \x01(\x08\x42-\x82\xb5\x18)Return pricing information, if applicable\x12\x39\n\x0freturn_metadata\x18  \x01(\x08:\x05\x66\x61lseB\x19\x82\xb5\x18\x15Populate the metadata\x12g\n\x15return_playtime_stats\x18$ \x01(\rBH\x82\xb5\x18\x44Return playtime stats for the specified number of days before today.\x12\xb7\x01\n\x0ereturn_details\x18% \x01(\x08\x42\x9e\x01\x82\xb5\x18\x99\x01\x42y default, if none of the other \'return_*\' fields are set, only some voting details are returned. Set this to true to return the default set of details.\x12\x46\n\x18strip_description_bbcode\x18& \x01(\x08\x42$\x82\xb5\x18 Strips BBCode from descriptions.\x12\x84\x01\n\x10\x64\x65sired_revision\x18( \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_DefaultB/\x82\xb5\x18+Return the data for the specified revision.\x12W\n\x10return_reactions\x18+ \x01(\x08:\x05\x66\x61lseB6\x82\xb5\x18\x32If true, then reactions to items will be returned.\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\x1a\xd6\x01\n\tDateRange\x12\x64\n\x0ftimestamp_start\x18\x01 \x01(\rBK\x82\xb5\x18G(Optional) Include items with the relevant date field after this value.\x12\x63\n\rtimestamp_end\x18\x02 \x01(\rBL\x82\xb5\x18H(Optional) Include items with the relevant date field before this value.\"\x85\x03\n\"CPublishedFile_QueryFiles_Response\x12T\n\x05total\x18\x01 \x01(\rBE\x82\xb5\x18\x41Number of matches found, not necessarily number of items returned\x12\x8d\x01\n\x14publishedfiledetails\x18\x02 \x03(\x0b\x32\x15.PublishedFileDetailsBX\x82\xb5\x18TEach file details will be populated, depending on what return values were requested.\x12y\n\x0bnext_cursor\x18\x03 \x01(\tBd\x82\xb5\x18`If a paging cursor was used, then this will be the next cursor to use for paging through results\"i\n)CPublishedFile_AddAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\",\n*CPublishedFile_AddAppRelationship_Response\"l\n,CPublishedFile_RemoveAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\"/\n-CPublishedFile_RemoveAppRelationship_Response\"E\n*CPublishedFile_GetAppRelationships_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"\xbe\x01\n+CPublishedFile_GetAppRelationships_Response\x12W\n\x11\x61pp_relationships\x18\x03 \x03(\x0b\x32<.CPublishedFile_GetAppRelationships_Response.AppRelationship\x1a\x36\n\x0f\x41ppRelationship\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0crelationship\x18\x02 \x01(\r\"W\n,CPublishedFile_StartPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\"/\n-CPublishedFile_StartPlaytimeTracking_Response\"V\n+CPublishedFile_StopPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\".\n,CPublishedFile_StopPlaytimeTracking_Response\"J\n9CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"<\n:CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\"\x81\x02\n6CPublishedFile_SetPlaytimeForControllerConfigs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12n\n\x17\x63ontroller_config_usage\x18\x02 \x03(\x0b\x32M.CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage\x1aH\n\x15\x43ontrollerConfigUsage\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x16\n\x0eseconds_active\x18\x02 \x01(\x02\"9\n7CPublishedFile_SetPlaytimeForControllerConfigs_Response\"Y\n\x1f\x43PublishedFile_AddChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"\"\n CPublishedFile_AddChild_Response\"\\\n\"CPublishedFile_RemoveChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"%\n#CPublishedFile_RemoveChild_Response\"E\n)CPublishedFile_GetUserVoteSummary_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x06\"\xda\x01\n*CPublishedFile_GetUserVoteSummary_Response\x12J\n\tsummaries\x18\x01 \x03(\x0b\x32\x37.CPublishedFile_GetUserVoteSummary_Response.VoteSummary\x1a`\n\x0bVoteSummary\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x10\n\x08vote_for\x18\x02 \x01(\x08\x12\x14\n\x0cvote_against\x18\x03 \x01(\x08\x12\x10\n\x08reported\x18\x04 \x01(\x08\"h\n%CPublishedFile_GetItemChanges_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12\x15\n\rnum_items_max\x18\x03 \x01(\r\"\xe9\x01\n&CPublishedFile_GetItemChanges_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12P\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x38.CPublishedFile_GetItemChanges_Response.WorkshopItemInfo\x1aX\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\"\xaf\x05\n*CPublishedFile_FileSubscribed_Notification\x12@\n\x11published_file_id\x18\x01 \x01(\x06\x42%\x82\xb5\x18!PublishedFileID_t for the content\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12:\n\rfile_hcontent\x18\x03 \x01(\x06\x42#\x82\xb5\x18\x1fUGC file handle or manifest GID\x12\x11\n\tfile_size\x18\x04 \x01(\r\x12\x18\n\x10rtime_subscribed\x18\x05 \x01(\r\x12N\n\x10is_depot_content\x18\x06 \x01(\x08\x42\x34\x82\xb5\x18\x30True if workshop item is delivered via Steampipe\x12\x34\n\rrtime_updated\x18\x07 \x01(\rB\x1d\x82\xb5\x18\x19Last time content updated\x12\x82\x01\n\trevisions\x18\x08 \x03(\x0b\x32\x38.CPublishedFile_FileSubscribed_Notification.RevisionDataB5\x82\xb5\x18\x31\x44\x61ta for each of the revisions that this item has\x1a\xba\x01\n\x0cRevisionData\x12K\n\x08revision\x18\x01 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\'\n\rfile_hcontent\x18\x02 \x01(\x06\x42\x10\x82\xb5\x18\x0cManifest GID\x12\x34\n\rrtime_updated\x18\x03 \x01(\rB\x1d\x82\xb5\x18\x19Last time content updated\"\x80\x01\n,CPublishedFile_FileUnsubscribed_Notification\x12@\n\x11published_file_id\x18\x01 \x01(\x06\x42%\x82\xb5\x18!PublishedFileID_t for the content\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\x82\x01\n.CPublishedFile_FileDeleted_Client_Notification\x12@\n\x11published_file_id\x18\x01 \x01(\x06\x42%\x82\xb5\x18!PublishedFileID_t for the content\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r*\xab\x02\n\x16\x45PublishedFileRevision\x12$\n k_EPublishedFileRevision_Default\x10\x00\x12#\n\x1fk_EPublishedFileRevision_Latest\x10\x01\x12-\n)k_EPublishedFileRevision_ApprovedSnapshot\x10\x02\x12\x33\n/k_EPublishedFileRevision_ApprovedSnapshot_China\x10\x03\x12-\n)k_EPublishedFileRevision_RejectedSnapshot\x10\x04\x12\x33\n/k_EPublishedFileRevision_RejectedSnapshot_China\x10\x05*\xc8\x01\n\x1b\x45PublishedFileForSaleStatus\x12\x16\n\x12k_PFFSS_NotForSale\x10\x00\x12\x1b\n\x17k_PFFSS_PendingApproval\x10\x01\x12\x1b\n\x17k_PFFSS_ApprovedForSale\x10\x02\x12\x1b\n\x17k_PFFSS_RejectedForSale\x10\x03\x12\x1b\n\x17k_PFFSS_NoLongerForSale\x10\x04\x12\x1d\n\x19k_PFFSS_TentativeApproval\x10\x05\x32\xd3$\n\rPublishedFile\x12g\n\x04Vote\x12\x1c.CPublishedFile_Vote_Request\x1a\x1d.CPublishedFile_Vote_Response\"\"\x82\xb5\x18\x1eUser wants to vote on the item\x12\x81\x01\n\tSubscribe\x12!.CPublishedFile_Subscribe_Request\x1a\".CPublishedFile_Subscribe_Response\"-\x82\xb5\x18)Subscribes the user to the published file\x12\x8b\x01\n\x0bUnsubscribe\x12#.CPublishedFile_Unsubscribe_Request\x1a$.CPublishedFile_Unsubscribe_Response\"1\x82\xb5\x18-Unsubscribes the user from the published file\x12\x96\x01\n\x0c\x43\x61nSubscribe\x12$.CPublishedFile_CanSubscribe_Request\x1a%.CPublishedFile_CanSubscribe_Response\"9\x82\xb5\x18\x35\x43heck if the user can subscribe to the published file\x12\xb8\x01\n\x11GetSubSectionData\x12).CPublishedFile_GetSubSectionData_Request\x1a*.CPublishedFile_GetSubSectionData_Response\"L\x82\xb5\x18HGet sub section data (for table of contents, a specific section, or all)\x12\x80\x01\n\x07Publish\x12\x1f.CPublishedFile_Publish_Request\x1a .CPublishedFile_Publish_Response\"2\x82\xb5\x18.Publishes a clouded user file to the Workshop.\x12\x90\x01\n\nGetDetails\x12\".CPublishedFile_GetDetails_Request\x1a#.CPublishedFile_GetDetails_Response\"9\x82\xb5\x18\x35Retrieves information about a set of published files.\x12\x93\x01\n\x0bGetItemInfo\x12#.CPublishedFile_GetItemInfo_Request\x1a$.CPublishedFile_GetItemInfo_Response\"9\x82\xb5\x18\x35Retrieves information about a set of published files.\x12\x85\x01\n\x0cGetUserFiles\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\"(\x82\xb5\x18$Retrieves files published by a user.\x12\xd7\x01\n\x10GetUserFileCount\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\"v\x82\xb5\x18rRetrieves a count of files published by a user. Uses the same messages as GetUserFiles but totalonly must be true.\x12\xd5\x01\n\x1a\x41reFilesInSubscriptionList\x12\x32.CPublishedFile_AreFilesInSubscriptionList_Request\x1a\x33.CPublishedFile_AreFilesInSubscriptionList_Response\"N\x82\xb5\x18JDetermines which files in the given list are in a user\'s subscription list\x12z\n\x06Update\x12\x1e.CPublishedFile_Update_Request\x1a\x1f.CPublishedFile_Update_Response\"/\x82\xb5\x18+Updates information about a published file.\x12h\n\x06\x44\x65lete\x12\x1e.CPublishedFile_Delete_Request\x1a\x1f.CPublishedFile_Delete_Response\"\x1d\x82\xb5\x18\x19\x44\x65letes a published file.\x12\xc0\x01\n\x15GetChangeHistoryEntry\x12-.CPublishedFile_GetChangeHistoryEntry_Request\x1a..CPublishedFile_GetChangeHistoryEntry_Response\"H\x82\xb5\x18\x44Returns data on a specific change history entry for a published file\x12\xa4\x01\n\x10GetChangeHistory\x12(.CPublishedFile_GetChangeHistory_Request\x1a).CPublishedFile_GetChangeHistory_Response\";\x82\xb5\x18\x37Returns data on the change history for a published file\x12\x98\x01\n\x12RefreshVotingQueue\x12*.CPublishedFile_RefreshVotingQueue_Request\x1a+.CPublishedFile_RefreshVotingQueue_Response\")\x82\xb5\x18%Refresh the voting queue for the user\x12\x86\x01\n\nQueryFiles\x12\".CPublishedFile_QueryFiles_Request\x1a#.CPublishedFile_QueryFiles_Response\"/\x82\xb5\x18+Performs a search query for published files\x12\xb3\x01\n\x12\x41\x64\x64\x41ppRelationship\x12*.CPublishedFile_AddAppRelationship_Request\x1a+.CPublishedFile_AddAppRelationship_Response\"D\x82\xb5\x18@Adds a relationship between the published file and the given app\x12\xbe\x01\n\x15RemoveAppRelationship\x12-.CPublishedFile_RemoveAppRelationship_Request\x1a..CPublishedFile_RemoveAppRelationship_Response\"F\x82\xb5\x18\x42Remove a relationship between the published file and the given app\x12\xb3\x01\n\x13GetAppRelationships\x12+.CPublishedFile_GetAppRelationships_Request\x1a,.CPublishedFile_GetAppRelationships_Response\"A\x82\xb5\x18=Returns the list of app relationships for this published file\x12\xb3\x01\n\x15StartPlaytimeTracking\x12-.CPublishedFile_StartPlaytimeTracking_Request\x1a..CPublishedFile_StartPlaytimeTracking_Response\";\x82\xb5\x18\x37Start usage tracking for a given set of published files\x12\xb0\x01\n\x14StopPlaytimeTracking\x12,.CPublishedFile_StopPlaytimeTracking_Request\x1a-.CPublishedFile_StopPlaytimeTracking_Response\";\x82\xb5\x18\x37Stops usage tracking for a given set of published files\x12\xed\x01\n\"StopPlaytimeTrackingForAllAppItems\x12:.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x1a;.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\"N\x82\xb5\x18JStops usage tracking for all items currently tracked for the specified app\x12\x98\x02\n\x1fSetPlaytimeForControllerConfigs\x12\x37.CPublishedFile_SetPlaytimeForControllerConfigs_Request\x1a\x38.CPublishedFile_SetPlaytimeForControllerConfigs_Response\"\x81\x01\x82\xb5\x18}Stops usage tracking all controller configs for the given app and set the usage time for the for the given controller configs\x12\x8f\x01\n\x08\x41\x64\x64\x43hild\x12 .CPublishedFile_AddChild_Request\x1a!.CPublishedFile_AddChild_Response\">\x82\xb5\x18:Adds a parent->child relationship between the given items.\x12\x99\x01\n\x0bRemoveChild\x12#.CPublishedFile_RemoveChild_Request\x1a$.CPublishedFile_RemoveChild_Response\"?\x82\xb5\x18;Removes parent->child relationship between the given items.\x12\x88\x01\n\x12GetUserVoteSummary\x12*.CPublishedFile_GetUserVoteSummary_Request\x1a+.CPublishedFile_GetUserVoteSummary_Response\"\x19\x82\xb5\x18\x15Get user vote summary\x12\x91\x01\n\x0eGetItemChanges\x12&.CPublishedFile_GetItemChanges_Request\x1a\'.CPublishedFile_GetItemChanges_Response\".\x82\xb5\x18*Get list of updated items since given date\x1a+\x82\xb5\x18\'A service to access published file data2\x8d\x04\n\x13PublishedFileClient\x12\x93\x01\n\x14NotifyFileSubscribed\x12+.CPublishedFile_FileSubscribed_Notification\x1a\x0b.NoResponse\"A\x82\xb5\x18=Notification from the server when a user subscribes to a file\x12\x9b\x01\n\x16NotifyFileUnsubscribed\x12-.CPublishedFile_FileUnsubscribed_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Notification from the server when a user unsubscribes from a file\x12\x94\x01\n\x11NotifyFileDeleted\x12/.CPublishedFile_FileDeleted_Client_Notification\x1a\x0b.NoResponse\"A\x82\xb5\x18=Notification from the server when a published file is deleted\x1a+\x82\xb5\x18#Published file client notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EPUBLISHEDFILEREVISION = _descriptor.EnumDescriptor(
  name='EPublishedFileRevision',
  full_name='EPublishedFileRevision',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_Default', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_Latest', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_ApprovedSnapshot', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_ApprovedSnapshot_China', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_RejectedSnapshot', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EPublishedFileRevision_RejectedSnapshot_China', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21547,
  serialized_end=21846,
)
_sym_db.RegisterEnumDescriptor(_EPUBLISHEDFILEREVISION)

EPublishedFileRevision = enum_type_wrapper.EnumTypeWrapper(_EPUBLISHEDFILEREVISION)
_EPUBLISHEDFILEFORSALESTATUS = _descriptor.EnumDescriptor(
  name='EPublishedFileForSaleStatus',
  full_name='EPublishedFileForSaleStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_NotForSale', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_PendingApproval', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_ApprovedForSale', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_RejectedForSale', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_NoLongerForSale', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_PFFSS_TentativeApproval', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21849,
  serialized_end=22049,
)
_sym_db.RegisterEnumDescriptor(_EPUBLISHEDFILEFORSALESTATUS)

EPublishedFileForSaleStatus = enum_type_wrapper.EnumTypeWrapper(_EPUBLISHEDFILEFORSALESTATUS)
k_EPublishedFileRevision_Default = 0
k_EPublishedFileRevision_Latest = 1
k_EPublishedFileRevision_ApprovedSnapshot = 2
k_EPublishedFileRevision_ApprovedSnapshot_China = 3
k_EPublishedFileRevision_RejectedSnapshot = 4
k_EPublishedFileRevision_RejectedSnapshot_China = 5
k_PFFSS_NotForSale = 0
k_PFFSS_PendingApproval = 1
k_PFFSS_ApprovedForSale = 2
k_PFFSS_RejectedForSale = 3
k_PFFSS_NoLongerForSale = 4
k_PFFSS_TentativeApproval = 5



_CPUBLISHEDFILE_VOTE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Vote_Request',
  full_name='CPublishedFile_Vote_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Vote_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_up', full_name='CPublishedFile_Vote_Request.vote_up', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=168,
)


_CPUBLISHEDFILE_VOTE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Vote_Response',
  full_name='CPublishedFile_Vote_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=200,
)


_CPUBLISHEDFILE_SUBSCRIBE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Subscribe_Request',
  full_name='CPublishedFile_Subscribe_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Subscribe_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='CPublishedFile_Subscribe_Request.list_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_Subscribe_Request.appid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_client', full_name='CPublishedFile_Subscribe_Request.notify_client', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=318,
)


_CPUBLISHEDFILE_SUBSCRIBE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Subscribe_Response',
  full_name='CPublishedFile_Subscribe_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=355,
)


_CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Unsubscribe_Request',
  full_name='CPublishedFile_Unsubscribe_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Unsubscribe_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='CPublishedFile_Unsubscribe_Request.list_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_Unsubscribe_Request.appid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_client', full_name='CPublishedFile_Unsubscribe_Request.notify_client', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=475,
)


_CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Unsubscribe_Response',
  full_name='CPublishedFile_Unsubscribe_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=514,
)


_CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_CanSubscribe_Request',
  full_name='CPublishedFile_CanSubscribe_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_CanSubscribe_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=578,
)


_CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_CanSubscribe_Response',
  full_name='CPublishedFile_CanSubscribe_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_subscribe', full_name='CPublishedFile_CanSubscribe_Response.can_subscribe', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=641,
)


_CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetSubSectionData_Request',
  full_name='CPublishedFile_GetSubSectionData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_GetSubSectionData_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for_table_of_contents', full_name='CPublishedFile_GetSubSectionData_Request.for_table_of_contents', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='specific_sectionid', full_name='CPublishedFile_GetSubSectionData_Request.specific_sectionid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_GetSubSectionData_Request.desired_revision', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Return the data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=905,
)


_PUBLISHEDFILESUBSECTION = _descriptor.Descriptor(
  name='PublishedFileSubSection',
  full_name='PublishedFileSubSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sectionid', full_name='PublishedFileSubSection.sectionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='PublishedFileSubSection.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description_text', full_name='PublishedFileSubSection.description_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='PublishedFileSubSection.sort_order', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1012,
)


_CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetSubSectionData_Response',
  full_name='CPublishedFile_GetSubSectionData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_sections', full_name='CPublishedFile_GetSubSectionData_Response.sub_sections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1105,
)


_CPUBLISHEDFILE_PUBLISH_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Publish_Request',
  full_name='CPublishedFile_Publish_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_Publish_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)App Id this file is being published FROM.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_appid', full_name='CPublishedFile_Publish_Request.consumer_appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'App Id this file is being published TO.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloudfilename', full_name='CPublishedFile_Publish_Request.cloudfilename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Name of the file to publish in the user\'s cloud.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_cloudfilename', full_name='CPublishedFile_Publish_Request.preview_cloudfilename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308Name of the file to use as the published file\'s preview.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CPublishedFile_Publish_Request.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Text title for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_description', full_name='CPublishedFile_Publish_Request.file_description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030(Text description for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='CPublishedFile_Publish_Request.file_type', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305(EWorkshopFileType) Type of Workshop file to publish.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_shortcut_name', full_name='CPublishedFile_Publish_Request.consumer_shortcut_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Shortcut name for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='youtube_username', full_name='CPublishedFile_Publish_Request.youtube_username', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+(Optional) User\'s YouTube account username.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='youtube_videoid', full_name='CPublishedFile_Publish_Request.youtube_videoid', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?(Optional) Video Id of a YouTube video for this published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='CPublishedFile_Publish_Request.visibility', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030i(ERemoteStoragePublishedFileVisibility) Visibility of the published file (private, friends, public, etc.)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='CPublishedFile_Publish_Request.redirect_uri', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Q(Optional) If supplied, the resulting published file\'s Id is appended to the URI.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CPublishedFile_Publish_Request.tags', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Array of text tags to apply to the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_type', full_name='CPublishedFile_Publish_Request.collection_type', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<(Optional) Type of collection the published file represents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='CPublishedFile_Publish_Request.game_type', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306(Optional) Type of game the published file represents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='CPublishedFile_Publish_Request.url', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030J(Optional) If this represents a game, this is the URL to that game\'s page.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1108,
  serialized_end=2464,
)


_CPUBLISHEDFILE_PUBLISH_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Publish_Response',
  full_name='CPublishedFile_Publish_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Publish_Response.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='CPublishedFile_Publish_Response.redirect_uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2466,
  serialized_end=2546,
)


_CPUBLISHEDFILE_GETDETAILS_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetDetails_Request',
  full_name='CPublishedFile_GetDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileids', full_name='CPublishedFile_GetDetails_Request.publishedfileids', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Set of published file Ids to retrieve details for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includetags', full_name='CPublishedFile_GetDetails_Request.includetags', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308If true, return tag information in the returned details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeadditionalpreviews', full_name='CPublishedFile_GetDetails_Request.includeadditionalpreviews', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<If true, return preview information in the returned details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includechildren', full_name='CPublishedFile_GetDetails_Request.includechildren', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301If true, return children in the returned details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includekvtags', full_name='CPublishedFile_GetDetails_Request.includekvtags', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307If true, return key value tags in the returned details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includevotes', full_name='CPublishedFile_GetDetails_Request.includevotes', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302If true, return vote data in the returned details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_description', full_name='CPublishedFile_GetDetails_Request.short_description', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DIf true, return a short description instead of the full description.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeforsaledata', full_name='CPublishedFile_GetDetails_Request.includeforsaledata', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030,If true, return pricing data, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includemetadata', full_name='CPublishedFile_GetDetails_Request.includemetadata', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%If true, populate the metadata field.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetDetails_Request.language', index=9,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<Specifies the localized text to return. Defaults to English.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_playtime_stats', full_name='CPublishedFile_GetDetails_Request.return_playtime_stats', index=10,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DReturn playtime stats for the specified number of days before today.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetDetails_Request.appid', index=11,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_description_bbcode', full_name='CPublishedFile_GetDetails_Request.strip_description_bbcode', index=12,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 Strips BBCode from descriptions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_GetDetails_Request.desired_revision', index=13,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Return the data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includereactions', full_name='CPublishedFile_GetDetails_Request.includereactions', index=14,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302If true, then reactions to items will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2549,
  serialized_end=3842,
)


_PUBLISHEDFILEDETAILS_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='PublishedFileDetails.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='PublishedFileDetails.Tag.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adminonly', full_name='PublishedFileDetails.Tag.adminonly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='PublishedFileDetails.Tag.display_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6294,
  serialized_end=6353,
)

_PUBLISHEDFILEDETAILS_PREVIEW = _descriptor.Descriptor(
  name='Preview',
  full_name='PublishedFileDetails.Preview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='previewid', full_name='PublishedFileDetails.Preview.previewid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortorder', full_name='PublishedFileDetails.Preview.sortorder', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='PublishedFileDetails.Preview.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='PublishedFileDetails.Preview.size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='PublishedFileDetails.Preview.filename', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='youtubevideoid', full_name='PublishedFileDetails.Preview.youtubevideoid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_type', full_name='PublishedFileDetails.Preview.preview_type', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_reference', full_name='PublishedFileDetails.Preview.external_reference', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6356,
  serialized_end=6522,
)

_PUBLISHEDFILEDETAILS_CHILD = _descriptor.Descriptor(
  name='Child',
  full_name='PublishedFileDetails.Child',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='PublishedFileDetails.Child.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortorder', full_name='PublishedFileDetails.Child.sortorder', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='PublishedFileDetails.Child.file_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6524,
  serialized_end=6594,
)

_PUBLISHEDFILEDETAILS_KVTAG = _descriptor.Descriptor(
  name='KVTag',
  full_name='PublishedFileDetails.KVTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PublishedFileDetails.KVTag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PublishedFileDetails.KVTag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=6631,
)

_PUBLISHEDFILEDETAILS_VOTEDATA = _descriptor.Descriptor(
  name='VoteData',
  full_name='PublishedFileDetails.VoteData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='PublishedFileDetails.VoteData.score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_up', full_name='PublishedFileDetails.VoteData.votes_up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_down', full_name='PublishedFileDetails.VoteData.votes_down', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6633,
  serialized_end=6696,
)

_PUBLISHEDFILEDETAILS_FORSALEDATA = _descriptor.Descriptor(
  name='ForSaleData',
  full_name='PublishedFileDetails.ForSaleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_for_sale', full_name='PublishedFileDetails.ForSaleData.is_for_sale', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_category', full_name='PublishedFileDetails.ForSaleData.price_category', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estatus', full_name='PublishedFileDetails.ForSaleData.estatus', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_category_floor', full_name='PublishedFileDetails.ForSaleData.price_category_floor', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_is_pay_what_you_want', full_name='PublishedFileDetails.ForSaleData.price_is_pay_what_you_want', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discount_percentage', full_name='PublishedFileDetails.ForSaleData.discount_percentage', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6699,
  serialized_end=6919,
)

_PUBLISHEDFILEDETAILS_PLAYTIMESTATS = _descriptor.Descriptor(
  name='PlaytimeStats',
  full_name='PublishedFileDetails.PlaytimeStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='playtime_seconds', full_name='PublishedFileDetails.PlaytimeStats.playtime_seconds', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sessions', full_name='PublishedFileDetails.PlaytimeStats.num_sessions', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6921,
  serialized_end=6984,
)

_PUBLISHEDFILEDETAILS_REACTION = _descriptor.Descriptor(
  name='Reaction',
  full_name='PublishedFileDetails.Reaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reactionid', full_name='PublishedFileDetails.Reaction.reactionid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='PublishedFileDetails.Reaction.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6986,
  serialized_end=7031,
)

_PUBLISHEDFILEDETAILS = _descriptor.Descriptor(
  name='PublishedFileDetails',
  full_name='PublishedFileDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='PublishedFileDetails.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='PublishedFileDetails.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator', full_name='PublishedFileDetails.creator', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_appid', full_name='PublishedFileDetails.creator_appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_appid', full_name='PublishedFileDetails.consumer_appid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_shortcutid', full_name='PublishedFileDetails.consumer_shortcutid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='PublishedFileDetails.filename', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='PublishedFileDetails.file_size', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_file_size', full_name='PublishedFileDetails.preview_file_size', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_url', full_name='PublishedFileDetails.file_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_url', full_name='PublishedFileDetails.preview_url', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='youtubevideoid', full_name='PublishedFileDetails.youtubevideoid', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='PublishedFileDetails.url', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hcontent_file', full_name='PublishedFileDetails.hcontent_file', index=13,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hcontent_preview', full_name='PublishedFileDetails.hcontent_preview', index=14,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='PublishedFileDetails.title', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_description', full_name='PublishedFileDetails.file_description', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_description', full_name='PublishedFileDetails.short_description', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='PublishedFileDetails.time_created', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='PublishedFileDetails.time_updated', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='PublishedFileDetails.visibility', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='PublishedFileDetails.flags', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_file', full_name='PublishedFileDetails.workshop_file', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_accepted', full_name='PublishedFileDetails.workshop_accepted', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_subscribe_all', full_name='PublishedFileDetails.show_subscribe_all', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_comments_developer', full_name='PublishedFileDetails.num_comments_developer', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_comments_public', full_name='PublishedFileDetails.num_comments_public', index=26,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banned', full_name='PublishedFileDetails.banned', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ban_reason', full_name='PublishedFileDetails.ban_reason', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banner', full_name='PublishedFileDetails.banner', index=29,
      number=30, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_be_deleted', full_name='PublishedFileDetails.can_be_deleted', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incompatible', full_name='PublishedFileDetails.incompatible', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='PublishedFileDetails.app_name', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='PublishedFileDetails.file_type', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_subscribe', full_name='PublishedFileDetails.can_subscribe', index=34,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscriptions', full_name='PublishedFileDetails.subscriptions', index=35,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorited', full_name='PublishedFileDetails.favorited', index=36,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='followers', full_name='PublishedFileDetails.followers', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime_subscriptions', full_name='PublishedFileDetails.lifetime_subscriptions', index=38,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime_favorited', full_name='PublishedFileDetails.lifetime_favorited', index=39,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime_followers', full_name='PublishedFileDetails.lifetime_followers', index=40,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime_playtime', full_name='PublishedFileDetails.lifetime_playtime', index=41,
      number=62, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime_playtime_sessions', full_name='PublishedFileDetails.lifetime_playtime_sessions', index=42,
      number=63, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='views', full_name='PublishedFileDetails.views', index=43,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_width', full_name='PublishedFileDetails.image_width', index=44,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_height', full_name='PublishedFileDetails.image_height', index=45,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='PublishedFileDetails.image_url', index=46,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spoiler_tag', full_name='PublishedFileDetails.spoiler_tag', index=47,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortcutid', full_name='PublishedFileDetails.shortcutid', index=48,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortcutname', full_name='PublishedFileDetails.shortcutname', index=49,
      number=48, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_children', full_name='PublishedFileDetails.num_children', index=50,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_reports', full_name='PublishedFileDetails.num_reports', index=51,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previews', full_name='PublishedFileDetails.previews', index=52,
      number=51, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='PublishedFileDetails.tags', index=53,
      number=52, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='children', full_name='PublishedFileDetails.children', index=54,
      number=53, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kvtags', full_name='PublishedFileDetails.kvtags', index=55,
      number=54, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_data', full_name='PublishedFileDetails.vote_data', index=56,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_stats', full_name='PublishedFileDetails.playtime_stats', index=57,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_subscribed', full_name='PublishedFileDetails.time_subscribed', index=58,
      number=56, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030UOnly valid in PublishedFile.GetUserFiles and not normal PublishedFile.GetDetail calls', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for_sale_data', full_name='PublishedFileDetails.for_sale_data', index=59,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#Pricing information, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='PublishedFileDetails.metadata', index=60,
      number=58, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Metadata associated with the item', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='PublishedFileDetails.language', index=61,
      number=61, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*The language of the title and description.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maybe_inappropriate_sex', full_name='PublishedFileDetails.maybe_inappropriate_sex', index=62,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maybe_inappropriate_violence', full_name='PublishedFileDetails.maybe_inappropriate_violence', index=63,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision_change_number', full_name='PublishedFileDetails.revision_change_number', index=64,
      number=67, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030-The change number for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='PublishedFileDetails.revision', index=65,
      number=68, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\211\001The revision of the data returned, usually k_EPublishedFileRevision_Latest, but can be another revision/snapshot depending on the caller.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_revisions', full_name='PublishedFileDetails.available_revisions', index=66,
      number=69, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Available revisions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='PublishedFileDetails.reactions', index=67,
      number=70, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026Reactions to this item', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ban_text_check_result', full_name='PublishedFileDetails.ban_text_check_result', index=68,
      number=71, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PUBLISHEDFILEDETAILS_TAG, _PUBLISHEDFILEDETAILS_PREVIEW, _PUBLISHEDFILEDETAILS_CHILD, _PUBLISHEDFILEDETAILS_KVTAG, _PUBLISHEDFILEDETAILS_VOTEDATA, _PUBLISHEDFILEDETAILS_FORSALEDATA, _PUBLISHEDFILEDETAILS_PLAYTIMESTATS, _PUBLISHEDFILEDETAILS_REACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3845,
  serialized_end=7031,
)


_CPUBLISHEDFILE_GETDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetDetails_Response',
  full_name='CPublishedFile_GetDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfiledetails', full_name='CPublishedFile_GetDetails_Response.publishedfiledetails', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7033,
  serialized_end=7122,
)


_CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM = _descriptor.Descriptor(
  name='WorkshopItem',
  full_name='CPublishedFile_GetItemInfo_Request.WorkshopItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_GetItemInfo_Request.WorkshopItem.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CPublishedFile_GetItemInfo_Request.WorkshopItem.time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_GetItemInfo_Request.WorkshopItem.desired_revision', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Return the data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7280,
  serialized_end=7478,
)

_CPUBLISHEDFILE_GETITEMINFO_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetItemInfo_Request',
  full_name='CPublishedFile_GetItemInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetItemInfo_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time_updated', full_name='CPublishedFile_GetItemInfo_Request.last_time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_items', full_name='CPublishedFile_GetItemInfo_Request.workshop_items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7125,
  serialized_end=7478,
)


_CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO = _descriptor.Descriptor(
  name='WorkshopItemInfo',
  full_name='CPublishedFile_GetItemInfo_Response.WorkshopItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_GetItemInfo_Response.WorkshopItemInfo.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CPublishedFile_GetItemInfo_Response.WorkshopItemInfo.time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CPublishedFile_GetItemInfo_Response.WorkshopItemInfo.manifest_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPublishedFile_GetItemInfo_Response.WorkshopItemInfo.flags', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7643,
  serialized_end=7746,
)

_CPUBLISHEDFILE_GETITEMINFO_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetItemInfo_Response',
  full_name='CPublishedFile_GetItemInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_time', full_name='CPublishedFile_GetItemInfo_Response.update_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_items', full_name='CPublishedFile_GetItemInfo_Response.workshop_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_items', full_name='CPublishedFile_GetItemInfo_Response.private_items', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7481,
  serialized_end=7746,
)


_CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG = _descriptor.Descriptor(
  name='KVTag',
  full_name='CPublishedFile_GetUserFiles_Request.KVTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CPublishedFile_GetUserFiles_Request.KVTag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CPublishedFile_GetUserFiles_Request.KVTag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=6631,
)

_CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP = _descriptor.Descriptor(
  name='TagGroup',
  full_name='CPublishedFile_GetUserFiles_Request.TagGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='CPublishedFile_GetUserFiles_Request.TagGroup.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10621,
  serialized_end=10645,
)

_CPUBLISHEDFILE_GETUSERFILES_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetUserFiles_Request',
  full_name='CPublishedFile_GetUserFiles_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPublishedFile_GetUserFiles_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305Steam ID of the user whose files are being requested.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetUserFiles_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303App Id of the app that the files were published to.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page', full_name='CPublishedFile_GetUserFiles_Request.page', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%(Optional) Starting page for results.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numperpage', full_name='CPublishedFile_GetUserFiles_Request.numperpage', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305(Optional) The number of results, per page to return.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='CPublishedFile_GetUserFiles_Request.type', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"myfiles".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030((Optional) Type of files to be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortmethod', full_name='CPublishedFile_GetUserFiles_Request.sortmethod', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lastupdated".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304(Optional) Sorting method to use on returned values.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy', full_name='CPublishedFile_GetUserFiles_Request.privacy', index=6,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&(optional) Filter by privacy settings.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requiredtags', full_name='CPublishedFile_GetUserFiles_Request.requiredtags', index=7,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030N(Optional) Tags that must be present on a published file to satisfy the query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludedtags', full_name='CPublishedFile_GetUserFiles_Request.excludedtags', index=8,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030R(Optional) Tags that must NOT be present on a published file to satisfy the query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_kv_tags', full_name='CPublishedFile_GetUserFiles_Request.required_kv_tags', index=9,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Required key-value tags to match on.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filetype', full_name='CPublishedFile_GetUserFiles_Request.filetype', index=10,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'(Optional) File type to match files to.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_appid', full_name='CPublishedFile_GetUserFiles_Request.creator_appid', index=11,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FApp Id of the app that published the files, only matched if specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_cloud_filename', full_name='CPublishedFile_GetUserFiles_Request.match_cloud_filename', index=12,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Match this cloud filename if specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_max_age_seconds', full_name='CPublishedFile_GetUserFiles_Request.cache_max_age_seconds', index=13,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DAllow stale data to be returned for the specified number of seconds.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetUserFiles_Request.language', index=14,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030<Specifies the localized text to return. Defaults to English.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taggroups', full_name='CPublishedFile_GetUserFiles_Request.taggroups', index=15,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030](Optional) At least one of the tags must be present on a published file to satisfy the query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalonly', full_name='CPublishedFile_GetUserFiles_Request.totalonly', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030R(Optional) If true, only return the total number of files that satisfy this query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids_only', full_name='CPublishedFile_GetUserFiles_Request.ids_only', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030X(Optional) If true, only return the published file ids of files that satisfy this query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_vote_data', full_name='CPublishedFile_GetUserFiles_Request.return_vote_data', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020Return vote data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_tags', full_name='CPublishedFile_GetUserFiles_Request.return_tags', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Return tags in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_kv_tags', full_name='CPublishedFile_GetUserFiles_Request.return_kv_tags', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return key-value tags in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_previews', full_name='CPublishedFile_GetUserFiles_Request.return_previews', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030:Return preview image and video details in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_children', full_name='CPublishedFile_GetUserFiles_Request.return_children', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return child item ids in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_short_description', full_name='CPublishedFile_GetUserFiles_Request.return_short_description', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@Populate the short_description field instead of file_description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_for_sale_data', full_name='CPublishedFile_GetUserFiles_Request.return_for_sale_data', index=24,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return pricing information, if applicable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_metadata', full_name='CPublishedFile_GetUserFiles_Request.return_metadata', index=25,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033Populate the metadata field', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_playtime_stats', full_name='CPublishedFile_GetUserFiles_Request.return_playtime_stats', index=26,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DReturn playtime stats for the specified number of days before today.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_description_bbcode', full_name='CPublishedFile_GetUserFiles_Request.strip_description_bbcode', index=27,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 Strips BBCode from descriptions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_reactions', full_name='CPublishedFile_GetUserFiles_Request.return_reactions', index=28,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302If true, then reactions to items will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startindex_override', full_name='CPublishedFile_GetUserFiles_Request.startindex_override', index=29,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Backwards compatible for the client.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_GetUserFiles_Request.desired_revision', index=30,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Return the data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_apps', full_name='CPublishedFile_GetUserFiles_Request.return_apps', index=31,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Return list of apps the items belong to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG, _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7749,
  serialized_end=10645,
)


_CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP = _descriptor.Descriptor(
  name='App',
  full_name='CPublishedFile_GetUserFiles_Response.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetUserFiles_Response.App.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CPublishedFile_GetUserFiles_Response.App.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortcutid', full_name='CPublishedFile_GetUserFiles_Response.App.shortcutid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='CPublishedFile_GetUserFiles_Response.App.private', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10833,
  serialized_end=10904,
)

_CPUBLISHEDFILE_GETUSERFILES_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetUserFiles_Response',
  full_name='CPublishedFile_GetUserFiles_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='CPublishedFile_GetUserFiles_Response.total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startindex', full_name='CPublishedFile_GetUserFiles_Response.startindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfiledetails', full_name='CPublishedFile_GetUserFiles_Response.publishedfiledetails', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apps', full_name='CPublishedFile_GetUserFiles_Response.apps', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10648,
  serialized_end=10904,
)


_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_AreFilesInSubscriptionList_Request',
  full_name='CPublishedFile_AreFilesInSubscriptionList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_AreFilesInSubscriptionList_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileids', full_name='CPublishedFile_AreFilesInSubscriptionList_Request.publishedfileids', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listtype', full_name='CPublishedFile_AreFilesInSubscriptionList_Request.listtype', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020See EUCMListType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filetype', full_name='CPublishedFile_AreFilesInSubscriptionList_Request.filetype', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&See EPublishedFileInfoMatchingFileType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshopfiletype', full_name='CPublishedFile_AreFilesInSubscriptionList_Request.workshopfiletype', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308See EWorkshopFileType.  If specified, overrides filetype', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10907,
  serialized_end=11189,
)


_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST = _descriptor.Descriptor(
  name='InList',
  full_name='CPublishedFile_AreFilesInSubscriptionList_Response.InList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_AreFilesInSubscriptionList_Response.InList.publishedfileid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inlist', full_name='CPublishedFile_AreFilesInSubscriptionList_Response.InList.inlist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11321,
  serialized_end=11370,
)

_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_AreFilesInSubscriptionList_Response',
  full_name='CPublishedFile_AreFilesInSubscriptionList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CPublishedFile_AreFilesInSubscriptionList_Response.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11192,
  serialized_end=11370,
)


_CPUBLISHEDFILE_UPDATE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Update_Request',
  full_name='CPublishedFile_Update_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_Update_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&App Id this published file belongs to.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Update_Request.publishedfileid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Published file id of the file we\'d like to update.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CPublishedFile_Update_Request.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'(Optional) Title of the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_description', full_name='CPublishedFile_Update_Request.file_description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030-(Optional) Description of the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='CPublishedFile_Update_Request.visibility', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030,(Optional) Visibility of the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CPublishedFile_Update_Request.tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.(Optional) Set of tags for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CPublishedFile_Update_Request.filename', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+(Optional) Filename for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_filename', full_name='CPublishedFile_Update_Request.preview_filename', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303(Optional) Preview filename for the published file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spoiler_tag', full_name='CPublishedFile_Update_Request.spoiler_tag', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030P(Optional) Whether this published file should have a spoiler tag attached to it.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_width', full_name='CPublishedFile_Update_Request.image_width', index=9,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030E(Optional) If this is an image file, you can specify the image width.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_height', full_name='CPublishedFile_Update_Request.image_height', index=10,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030F(Optional) If this is an image file, you can specify the image height.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11373,
  serialized_end=12268,
)


_CPUBLISHEDFILE_UPDATE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Update_Response',
  full_name='CPublishedFile_Update_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12270,
  serialized_end=12302,
)


_CPUBLISHEDFILE_DELETE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_Delete_Request',
  full_name='CPublishedFile_Delete_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_Delete_Request.publishedfileid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Published file id of the file we\'d like to delete.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12304,
  serialized_end=12416,
)


_CPUBLISHEDFILE_DELETE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_Delete_Response',
  full_name='CPublishedFile_Delete_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12418,
  serialized_end=12450,
)


_CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetChangeHistoryEntry_Request',
  full_name='CPublishedFile_GetChangeHistoryEntry_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_GetChangeHistoryEntry_Request.publishedfileid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FPublished file id of the file we\'d like to get the change history for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CPublishedFile_GetChangeHistoryEntry_Request.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetChangeHistoryEntry_Request.language', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12453,
  serialized_end=12637,
)


_CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetChangeHistoryEntry_Response',
  full_name='CPublishedFile_GetChangeHistoryEntry_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_description', full_name='CPublishedFile_GetChangeHistoryEntry_Response.change_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetChangeHistoryEntry_Response.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12639,
  serialized_end=12732,
)


_CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetChangeHistory_Request',
  full_name='CPublishedFile_GetChangeHistory_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_GetChangeHistory_Request.publishedfileid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FPublished file id of the file we\'d like to get the change history for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_only', full_name='CPublishedFile_GetChangeHistory_Request.total_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030(Return the total number of changes only.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startindex', full_name='CPublishedFile_GetChangeHistory_Request.startindex', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CPublishedFile_GetChangeHistory_Request.count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetChangeHistory_Request.language', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020Desired language', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12735,
  serialized_end=13021,
)


_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG = _descriptor.Descriptor(
  name='ChangeLog',
  full_name='CPublishedFile_GetChangeHistory_Response.ChangeLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CPublishedFile_GetChangeHistory_Response.ChangeLog.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_description', full_name='CPublishedFile_GetChangeHistory_Response.ChangeLog.change_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_GetChangeHistory_Response.ChangeLog.language', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13153,
  serialized_end=13229,
)

_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetChangeHistory_Response',
  full_name='CPublishedFile_GetChangeHistory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='CPublishedFile_GetChangeHistory_Response.changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='CPublishedFile_GetChangeHistory_Response.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13024,
  serialized_end=13229,
)


_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_RefreshVotingQueue_Request',
  full_name='CPublishedFile_RefreshVotingQueue_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_RefreshVotingQueue_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matching_file_type', full_name='CPublishedFile_RefreshVotingQueue_Request.matching_file_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"EPublishedFileInfoMatchingFileType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CPublishedFile_RefreshVotingQueue_Request.tags', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ZInclude files that have all the tags or any of the tags if match_all_tags is set to false.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_all_tags', full_name='CPublishedFile_RefreshVotingQueue_Request.match_all_tags', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030sIf true, then files must have all the tags specified.  If false, then must have at least one of the tags specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_tags', full_name='CPublishedFile_RefreshVotingQueue_Request.excluded_tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Exclude any files that have any of these tags.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_queue_size', full_name='CPublishedFile_RefreshVotingQueue_Request.desired_queue_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030JDesired number of items in the voting queue.  May be clamped by the server', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_RefreshVotingQueue_Request.desired_revision', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030:Filter to items that have data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13232,
  serialized_end=13953,
)


_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_RefreshVotingQueue_Response',
  full_name='CPublishedFile_RefreshVotingQueue_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13955,
  serialized_end=13999,
)


_CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG = _descriptor.Descriptor(
  name='KVTag',
  full_name='CPublishedFile_QueryFiles_Request.KVTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CPublishedFile_QueryFiles_Request.KVTag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CPublishedFile_QueryFiles_Request.KVTag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=6631,
)

_CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP = _descriptor.Descriptor(
  name='TagGroup',
  full_name='CPublishedFile_QueryFiles_Request.TagGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='CPublishedFile_QueryFiles_Request.TagGroup.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10621,
  serialized_end=10645,
)

_CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE = _descriptor.Descriptor(
  name='DateRange',
  full_name='CPublishedFile_QueryFiles_Request.DateRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_start', full_name='CPublishedFile_QueryFiles_Request.DateRange.timestamp_start', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030G(Optional) Include items with the relevant date field after this value.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_end', full_name='CPublishedFile_QueryFiles_Request.DateRange.timestamp_end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030H(Optional) Include items with the relevant date field before this value.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17783,
  serialized_end=17997,
)

_CPUBLISHEDFILE_QUERYFILES_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_QueryFiles_Request',
  full_name='CPublishedFile_QueryFiles_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_type', full_name='CPublishedFile_QueryFiles_Request.query_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304enumeration EPublishedFileQueryType in clientenums.h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page', full_name='CPublishedFile_QueryFiles_Request.page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Current page', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cursor', full_name='CPublishedFile_QueryFiles_Request.cursor', index=2,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\322\001Cursor to paginate through the results (set to \'*\' for the first request).  Prefer this over using the page parameter, as it will allow you to do deep pagination.  When used, the page parameter will be ignored.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numperpage', full_name='CPublishedFile_QueryFiles_Request.numperpage', index=3,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305(Optional) The number of results, per page to return.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_appid', full_name='CPublishedFile_QueryFiles_Request.creator_appid', index=4,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032App that created the files', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_QueryFiles_Request.appid', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033App that consumes the files', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requiredtags', full_name='CPublishedFile_QueryFiles_Request.requiredtags', index=6,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304Tags to match on. See match_all_tags parameter below', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludedtags', full_name='CPublishedFile_QueryFiles_Request.excludedtags', index=7,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030R(Optional) Tags that must NOT be present on a published file to satisfy the query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_all_tags', full_name='CPublishedFile_QueryFiles_Request.match_all_tags', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030hIf true, then items must have all the tags specified, otherwise they must have at least one of the tags.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_flags', full_name='CPublishedFile_QueryFiles_Request.required_flags', index=9,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305Required flags that must be set on any returned items', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omitted_flags', full_name='CPublishedFile_QueryFiles_Request.omitted_flags', index=10,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Flags that must not be set on any returned items', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='CPublishedFile_QueryFiles_Request.search_text', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Text to match in the item\'s title or description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filetype', full_name='CPublishedFile_QueryFiles_Request.filetype', index=12,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"EPublishedFileInfoMatchingFileType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_publishedfileid', full_name='CPublishedFile_QueryFiles_Request.child_publishedfileid', index=13,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030-Find all items that reference the given item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days', full_name='CPublishedFile_QueryFiles_Request.days', index=14,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030pIf query_type is k_PublishedFileQueryType_RankedByTrend, then this is the number of days to get votes for [1,7].', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_recent_votes_only', full_name='CPublishedFile_QueryFiles_Request.include_recent_votes_only', index=15,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\207\001If query_type is k_PublishedFileQueryType_RankedByTrend, then limit result set just to items that have votes within the day range given', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_max_age_seconds', full_name='CPublishedFile_QueryFiles_Request.cache_max_age_seconds', index=16,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DAllow stale data to be returned for the specified number of seconds.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPublishedFile_QueryFiles_Request.language', index=17,
      number=33, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030GLanguage to search in and also what gets returned. Defaults to English.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_kv_tags', full_name='CPublishedFile_QueryFiles_Request.required_kv_tags', index=18,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Required key-value tags to match on.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taggroups', full_name='CPublishedFile_QueryFiles_Request.taggroups', index=19,
      number=42, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030](Optional) At least one of the tags must be present on a published file to satisfy the query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_range_created', full_name='CPublishedFile_QueryFiles_Request.date_range_created', index=20,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305(Optional) Filter to items created within this range.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_range_updated', full_name='CPublishedFile_QueryFiles_Request.date_range_updated', index=21,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305(Optional) Filter to items updated within this range.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalonly', full_name='CPublishedFile_QueryFiles_Request.totalonly', index=22,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030R(Optional) If true, only return the total number of files that satisfy this query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ids_only', full_name='CPublishedFile_QueryFiles_Request.ids_only', index=23,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030X(Optional) If true, only return the published file ids of files that satisfy this query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_vote_data', full_name='CPublishedFile_QueryFiles_Request.return_vote_data', index=24,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020Return vote data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_tags', full_name='CPublishedFile_QueryFiles_Request.return_tags', index=25,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Return tags in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_kv_tags', full_name='CPublishedFile_QueryFiles_Request.return_kv_tags', index=26,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return key-value tags in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_previews', full_name='CPublishedFile_QueryFiles_Request.return_previews', index=27,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030:Return preview image and video details in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_children', full_name='CPublishedFile_QueryFiles_Request.return_children', index=28,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return child item ids in the file details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_short_description', full_name='CPublishedFile_QueryFiles_Request.return_short_description', index=29,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@Populate the short_description field instead of file_description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_for_sale_data', full_name='CPublishedFile_QueryFiles_Request.return_for_sale_data', index=30,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Return pricing information, if applicable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_metadata', full_name='CPublishedFile_QueryFiles_Request.return_metadata', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025Populate the metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_playtime_stats', full_name='CPublishedFile_QueryFiles_Request.return_playtime_stats', index=32,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DReturn playtime stats for the specified number of days before today.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_details', full_name='CPublishedFile_QueryFiles_Request.return_details', index=33,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\231\001By default, if none of the other \'return_*\' fields are set, only some voting details are returned. Set this to true to return the default set of details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_description_bbcode', full_name='CPublishedFile_QueryFiles_Request.strip_description_bbcode', index=34,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 Strips BBCode from descriptions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_revision', full_name='CPublishedFile_QueryFiles_Request.desired_revision', index=35,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Return the data for the specified revision.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_reactions', full_name='CPublishedFile_QueryFiles_Request.return_reactions', index=36,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302If true, then reactions to items will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG, _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP, _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14002,
  serialized_end=17997,
)


_CPUBLISHEDFILE_QUERYFILES_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_QueryFiles_Response',
  full_name='CPublishedFile_QueryFiles_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='CPublishedFile_QueryFiles_Response.total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ANumber of matches found, not necessarily number of items returned', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfiledetails', full_name='CPublishedFile_QueryFiles_Response.publishedfiledetails', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030TEach file details will be populated, depending on what return values were requested.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_cursor', full_name='CPublishedFile_QueryFiles_Response.next_cursor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030`If a paging cursor was used, then this will be the next cursor to use for paging through results', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18000,
  serialized_end=18389,
)


_CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_AddAppRelationship_Request',
  full_name='CPublishedFile_AddAppRelationship_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_AddAppRelationship_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_AddAppRelationship_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relationship', full_name='CPublishedFile_AddAppRelationship_Request.relationship', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18391,
  serialized_end=18496,
)


_CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_AddAppRelationship_Response',
  full_name='CPublishedFile_AddAppRelationship_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18498,
  serialized_end=18542,
)


_CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_RemoveAppRelationship_Request',
  full_name='CPublishedFile_RemoveAppRelationship_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_RemoveAppRelationship_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_RemoveAppRelationship_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relationship', full_name='CPublishedFile_RemoveAppRelationship_Request.relationship', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18544,
  serialized_end=18652,
)


_CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_RemoveAppRelationship_Response',
  full_name='CPublishedFile_RemoveAppRelationship_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18654,
  serialized_end=18701,
)


_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetAppRelationships_Request',
  full_name='CPublishedFile_GetAppRelationships_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_GetAppRelationships_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18703,
  serialized_end=18772,
)


_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP = _descriptor.Descriptor(
  name='AppRelationship',
  full_name='CPublishedFile_GetAppRelationships_Response.AppRelationship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetAppRelationships_Response.AppRelationship.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relationship', full_name='CPublishedFile_GetAppRelationships_Response.AppRelationship.relationship', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18911,
  serialized_end=18965,
)

_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetAppRelationships_Response',
  full_name='CPublishedFile_GetAppRelationships_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_relationships', full_name='CPublishedFile_GetAppRelationships_Response.app_relationships', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18775,
  serialized_end=18965,
)


_CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_StartPlaytimeTracking_Request',
  full_name='CPublishedFile_StartPlaytimeTracking_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_StartPlaytimeTracking_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileids', full_name='CPublishedFile_StartPlaytimeTracking_Request.publishedfileids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18967,
  serialized_end=19054,
)


_CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_StartPlaytimeTracking_Response',
  full_name='CPublishedFile_StartPlaytimeTracking_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19056,
  serialized_end=19103,
)


_CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_StopPlaytimeTracking_Request',
  full_name='CPublishedFile_StopPlaytimeTracking_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_StopPlaytimeTracking_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileids', full_name='CPublishedFile_StopPlaytimeTracking_Request.publishedfileids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19105,
  serialized_end=19191,
)


_CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_StopPlaytimeTracking_Response',
  full_name='CPublishedFile_StopPlaytimeTracking_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19193,
  serialized_end=19239,
)


_CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request',
  full_name='CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19241,
  serialized_end=19315,
)


_CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response',
  full_name='CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19317,
  serialized_end=19377,
)


_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE = _descriptor.Descriptor(
  name='ControllerConfigUsage',
  full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_active', full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage.seconds_active', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19565,
  serialized_end=19637,
)

_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_SetPlaytimeForControllerConfigs_Request',
  full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_config_usage', full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Request.controller_config_usage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19380,
  serialized_end=19637,
)


_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_SetPlaytimeForControllerConfigs_Response',
  full_name='CPublishedFile_SetPlaytimeForControllerConfigs_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19639,
  serialized_end=19696,
)


_CPUBLISHEDFILE_ADDCHILD_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_AddChild_Request',
  full_name='CPublishedFile_AddChild_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_AddChild_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_publishedfileid', full_name='CPublishedFile_AddChild_Request.child_publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19698,
  serialized_end=19787,
)


_CPUBLISHEDFILE_ADDCHILD_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_AddChild_Response',
  full_name='CPublishedFile_AddChild_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19789,
  serialized_end=19823,
)


_CPUBLISHEDFILE_REMOVECHILD_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_RemoveChild_Request',
  full_name='CPublishedFile_RemoveChild_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_RemoveChild_Request.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_publishedfileid', full_name='CPublishedFile_RemoveChild_Request.child_publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19825,
  serialized_end=19917,
)


_CPUBLISHEDFILE_REMOVECHILD_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_RemoveChild_Response',
  full_name='CPublishedFile_RemoveChild_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19919,
  serialized_end=19956,
)


_CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetUserVoteSummary_Request',
  full_name='CPublishedFile_GetUserVoteSummary_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileids', full_name='CPublishedFile_GetUserVoteSummary_Request.publishedfileids', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19958,
  serialized_end=20027,
)


_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY = _descriptor.Descriptor(
  name='VoteSummary',
  full_name='CPublishedFile_GetUserVoteSummary_Response.VoteSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPublishedFile_GetUserVoteSummary_Response.VoteSummary.publishedfileid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_for', full_name='CPublishedFile_GetUserVoteSummary_Response.VoteSummary.vote_for', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_against', full_name='CPublishedFile_GetUserVoteSummary_Response.VoteSummary.vote_against', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reported', full_name='CPublishedFile_GetUserVoteSummary_Response.VoteSummary.reported', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20152,
  serialized_end=20248,
)

_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetUserVoteSummary_Response',
  full_name='CPublishedFile_GetUserVoteSummary_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summaries', full_name='CPublishedFile_GetUserVoteSummary_Response.summaries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20030,
  serialized_end=20248,
)


_CPUBLISHEDFILE_GETITEMCHANGES_REQUEST = _descriptor.Descriptor(
  name='CPublishedFile_GetItemChanges_Request',
  full_name='CPublishedFile_GetItemChanges_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPublishedFile_GetItemChanges_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time_updated', full_name='CPublishedFile_GetItemChanges_Request.last_time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_items_max', full_name='CPublishedFile_GetItemChanges_Request.num_items_max', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20250,
  serialized_end=20354,
)


_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO = _descriptor.Descriptor(
  name='WorkshopItemInfo',
  full_name='CPublishedFile_GetItemChanges_Response.WorkshopItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_GetItemChanges_Response.WorkshopItemInfo.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CPublishedFile_GetItemChanges_Response.WorkshopItemInfo.time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CPublishedFile_GetItemChanges_Response.WorkshopItemInfo.manifest_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7643,
  serialized_end=7731,
)

_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE = _descriptor.Descriptor(
  name='CPublishedFile_GetItemChanges_Response',
  full_name='CPublishedFile_GetItemChanges_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_time', full_name='CPublishedFile_GetItemChanges_Response.update_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_items', full_name='CPublishedFile_GetItemChanges_Response.workshop_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20357,
  serialized_end=20590,
)


_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA = _descriptor.Descriptor(
  name='RevisionData',
  full_name='CPublishedFile_FileSubscribed_Notification.RevisionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='revision', full_name='CPublishedFile_FileSubscribed_Notification.RevisionData.revision', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_hcontent', full_name='CPublishedFile_FileSubscribed_Notification.RevisionData.file_hcontent', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Manifest GID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_updated', full_name='CPublishedFile_FileSubscribed_Notification.RevisionData.rtime_updated', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Last time content updated', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21094,
  serialized_end=21280,
)

_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION = _descriptor.Descriptor(
  name='CPublishedFile_FileSubscribed_Notification',
  full_name='CPublishedFile_FileSubscribed_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_FileSubscribed_Notification.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!PublishedFileID_t for the content', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPublishedFile_FileSubscribed_Notification.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_hcontent', full_name='CPublishedFile_FileSubscribed_Notification.file_hcontent', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037UGC file handle or manifest GID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CPublishedFile_FileSubscribed_Notification.file_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_subscribed', full_name='CPublishedFile_FileSubscribed_Notification.rtime_subscribed', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_depot_content', full_name='CPublishedFile_FileSubscribed_Notification.is_depot_content', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300True if workshop item is delivered via Steampipe', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_updated', full_name='CPublishedFile_FileSubscribed_Notification.rtime_updated', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Last time content updated', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revisions', full_name='CPublishedFile_FileSubscribed_Notification.revisions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301Data for each of the revisions that this item has', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20593,
  serialized_end=21280,
)


_CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION = _descriptor.Descriptor(
  name='CPublishedFile_FileUnsubscribed_Notification',
  full_name='CPublishedFile_FileUnsubscribed_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_FileUnsubscribed_Notification.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!PublishedFileID_t for the content', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPublishedFile_FileUnsubscribed_Notification.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21283,
  serialized_end=21411,
)


_CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION = _descriptor.Descriptor(
  name='CPublishedFile_FileDeleted_Client_Notification',
  full_name='CPublishedFile_FileDeleted_Client_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CPublishedFile_FileDeleted_Client_Notification.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!PublishedFileID_t for the content', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPublishedFile_FileDeleted_Client_Notification.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21414,
  serialized_end=21544,
)

_CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE.fields_by_name['sub_sections'].message_type = _PUBLISHEDFILESUBSECTION
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_PUBLISHEDFILEDETAILS_TAG.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_PREVIEW.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_CHILD.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_KVTAG.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_VOTEDATA.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_FORSALEDATA.fields_by_name['estatus'].enum_type = _EPUBLISHEDFILEFORSALESTATUS
_PUBLISHEDFILEDETAILS_FORSALEDATA.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_PLAYTIMESTATS.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS_REACTION.containing_type = _PUBLISHEDFILEDETAILS
_PUBLISHEDFILEDETAILS.fields_by_name['previews'].message_type = _PUBLISHEDFILEDETAILS_PREVIEW
_PUBLISHEDFILEDETAILS.fields_by_name['tags'].message_type = _PUBLISHEDFILEDETAILS_TAG
_PUBLISHEDFILEDETAILS.fields_by_name['children'].message_type = _PUBLISHEDFILEDETAILS_CHILD
_PUBLISHEDFILEDETAILS.fields_by_name['kvtags'].message_type = _PUBLISHEDFILEDETAILS_KVTAG
_PUBLISHEDFILEDETAILS.fields_by_name['vote_data'].message_type = _PUBLISHEDFILEDETAILS_VOTEDATA
_PUBLISHEDFILEDETAILS.fields_by_name['playtime_stats'].message_type = _PUBLISHEDFILEDETAILS_PLAYTIMESTATS
_PUBLISHEDFILEDETAILS.fields_by_name['for_sale_data'].message_type = _PUBLISHEDFILEDETAILS_FORSALEDATA
_PUBLISHEDFILEDETAILS.fields_by_name['revision'].enum_type = _EPUBLISHEDFILEREVISION
_PUBLISHEDFILEDETAILS.fields_by_name['available_revisions'].enum_type = _EPUBLISHEDFILEREVISION
_PUBLISHEDFILEDETAILS.fields_by_name['reactions'].message_type = _PUBLISHEDFILEDETAILS_REACTION
_PUBLISHEDFILEDETAILS.fields_by_name['ban_text_check_result'].enum_type = steammessages__base__pb2._EBANCONTENTCHECKRESULT
_CPUBLISHEDFILE_GETDETAILS_RESPONSE.fields_by_name['publishedfiledetails'].message_type = _PUBLISHEDFILEDETAILS
_CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM.containing_type = _CPUBLISHEDFILE_GETITEMINFO_REQUEST
_CPUBLISHEDFILE_GETITEMINFO_REQUEST.fields_by_name['workshop_items'].message_type = _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM
_CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO.containing_type = _CPUBLISHEDFILE_GETITEMINFO_RESPONSE
_CPUBLISHEDFILE_GETITEMINFO_RESPONSE.fields_by_name['workshop_items'].message_type = _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO
_CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG.containing_type = _CPUBLISHEDFILE_GETUSERFILES_REQUEST
_CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP.containing_type = _CPUBLISHEDFILE_GETUSERFILES_REQUEST
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['required_kv_tags'].message_type = _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['taggroups'].message_type = _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP.containing_type = _CPUBLISHEDFILE_GETUSERFILES_RESPONSE
_CPUBLISHEDFILE_GETUSERFILES_RESPONSE.fields_by_name['publishedfiledetails'].message_type = _PUBLISHEDFILEDETAILS
_CPUBLISHEDFILE_GETUSERFILES_RESPONSE.fields_by_name['apps'].message_type = _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP
_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST.containing_type = _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE
_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE.fields_by_name['files'].message_type = _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST
_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG.containing_type = _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE
_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE.fields_by_name['changes'].message_type = _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG.containing_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST
_CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP.containing_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST
_CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE.containing_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['required_kv_tags'].message_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['taggroups'].message_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['date_range_created'].message_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['date_range_updated'].message_type = _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['desired_revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_QUERYFILES_RESPONSE.fields_by_name['publishedfiledetails'].message_type = _PUBLISHEDFILEDETAILS
_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP.containing_type = _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE
_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE.fields_by_name['app_relationships'].message_type = _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP
_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE.containing_type = _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST
_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST.fields_by_name['controller_config_usage'].message_type = _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE
_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY.containing_type = _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE
_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE.fields_by_name['summaries'].message_type = _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY
_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO.containing_type = _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE
_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE.fields_by_name['workshop_items'].message_type = _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA.fields_by_name['revision'].enum_type = _EPUBLISHEDFILEREVISION
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA.containing_type = _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['revisions'].message_type = _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA
DESCRIPTOR.message_types_by_name['CPublishedFile_Vote_Request'] = _CPUBLISHEDFILE_VOTE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Vote_Response'] = _CPUBLISHEDFILE_VOTE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_Subscribe_Request'] = _CPUBLISHEDFILE_SUBSCRIBE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Subscribe_Response'] = _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_Unsubscribe_Request'] = _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Unsubscribe_Response'] = _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_CanSubscribe_Request'] = _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_CanSubscribe_Response'] = _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetSubSectionData_Request'] = _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST
DESCRIPTOR.message_types_by_name['PublishedFileSubSection'] = _PUBLISHEDFILESUBSECTION
DESCRIPTOR.message_types_by_name['CPublishedFile_GetSubSectionData_Response'] = _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_Publish_Request'] = _CPUBLISHEDFILE_PUBLISH_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Publish_Response'] = _CPUBLISHEDFILE_PUBLISH_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetDetails_Request'] = _CPUBLISHEDFILE_GETDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['PublishedFileDetails'] = _PUBLISHEDFILEDETAILS
DESCRIPTOR.message_types_by_name['CPublishedFile_GetDetails_Response'] = _CPUBLISHEDFILE_GETDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetItemInfo_Request'] = _CPUBLISHEDFILE_GETITEMINFO_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetItemInfo_Response'] = _CPUBLISHEDFILE_GETITEMINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetUserFiles_Request'] = _CPUBLISHEDFILE_GETUSERFILES_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetUserFiles_Response'] = _CPUBLISHEDFILE_GETUSERFILES_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_AreFilesInSubscriptionList_Request'] = _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_AreFilesInSubscriptionList_Response'] = _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_Update_Request'] = _CPUBLISHEDFILE_UPDATE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Update_Response'] = _CPUBLISHEDFILE_UPDATE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_Delete_Request'] = _CPUBLISHEDFILE_DELETE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_Delete_Response'] = _CPUBLISHEDFILE_DELETE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetChangeHistoryEntry_Request'] = _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetChangeHistoryEntry_Response'] = _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetChangeHistory_Request'] = _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetChangeHistory_Response'] = _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_RefreshVotingQueue_Request'] = _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_RefreshVotingQueue_Response'] = _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_QueryFiles_Request'] = _CPUBLISHEDFILE_QUERYFILES_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_QueryFiles_Response'] = _CPUBLISHEDFILE_QUERYFILES_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_AddAppRelationship_Request'] = _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_AddAppRelationship_Response'] = _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_RemoveAppRelationship_Request'] = _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_RemoveAppRelationship_Response'] = _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetAppRelationships_Request'] = _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetAppRelationships_Response'] = _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_StartPlaytimeTracking_Request'] = _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_StartPlaytimeTracking_Response'] = _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_StopPlaytimeTracking_Request'] = _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_StopPlaytimeTracking_Response'] = _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request'] = _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response'] = _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_SetPlaytimeForControllerConfigs_Request'] = _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_SetPlaytimeForControllerConfigs_Response'] = _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_AddChild_Request'] = _CPUBLISHEDFILE_ADDCHILD_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_AddChild_Response'] = _CPUBLISHEDFILE_ADDCHILD_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_RemoveChild_Request'] = _CPUBLISHEDFILE_REMOVECHILD_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_RemoveChild_Response'] = _CPUBLISHEDFILE_REMOVECHILD_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetUserVoteSummary_Request'] = _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetUserVoteSummary_Response'] = _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_GetItemChanges_Request'] = _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST
DESCRIPTOR.message_types_by_name['CPublishedFile_GetItemChanges_Response'] = _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE
DESCRIPTOR.message_types_by_name['CPublishedFile_FileSubscribed_Notification'] = _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPublishedFile_FileUnsubscribed_Notification'] = _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPublishedFile_FileDeleted_Client_Notification'] = _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EPublishedFileRevision'] = _EPUBLISHEDFILEREVISION
DESCRIPTOR.enum_types_by_name['EPublishedFileForSaleStatus'] = _EPUBLISHEDFILEFORSALESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPublishedFile_Vote_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Vote_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_VOTE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Vote_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Vote_Request)

CPublishedFile_Vote_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Vote_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_VOTE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Vote_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Vote_Response)

CPublishedFile_Subscribe_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Subscribe_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_SUBSCRIBE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Subscribe_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Subscribe_Request)

CPublishedFile_Subscribe_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Subscribe_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Subscribe_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Subscribe_Response)

CPublishedFile_Unsubscribe_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Unsubscribe_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Unsubscribe_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Unsubscribe_Request)

CPublishedFile_Unsubscribe_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Unsubscribe_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Unsubscribe_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Unsubscribe_Response)

CPublishedFile_CanSubscribe_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_CanSubscribe_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_CanSubscribe_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_CanSubscribe_Request)

CPublishedFile_CanSubscribe_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_CanSubscribe_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_CanSubscribe_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_CanSubscribe_Response)

CPublishedFile_GetSubSectionData_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetSubSectionData_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetSubSectionData_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetSubSectionData_Request)

PublishedFileSubSection = _reflection.GeneratedProtocolMessageType('PublishedFileSubSection', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDFILESUBSECTION,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:PublishedFileSubSection)
  })
_sym_db.RegisterMessage(PublishedFileSubSection)

CPublishedFile_GetSubSectionData_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetSubSectionData_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetSubSectionData_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetSubSectionData_Response)

CPublishedFile_Publish_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Publish_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_PUBLISH_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Publish_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Publish_Request)

CPublishedFile_Publish_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Publish_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_PUBLISH_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Publish_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Publish_Response)

CPublishedFile_GetDetails_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETDETAILS_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetDetails_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetDetails_Request)

PublishedFileDetails = _reflection.GeneratedProtocolMessageType('PublishedFileDetails', (_message.Message,), {

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_TAG,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.Tag)
    })
  ,

  'Preview' : _reflection.GeneratedProtocolMessageType('Preview', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_PREVIEW,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.Preview)
    })
  ,

  'Child' : _reflection.GeneratedProtocolMessageType('Child', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_CHILD,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.Child)
    })
  ,

  'KVTag' : _reflection.GeneratedProtocolMessageType('KVTag', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_KVTAG,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.KVTag)
    })
  ,

  'VoteData' : _reflection.GeneratedProtocolMessageType('VoteData', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_VOTEDATA,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.VoteData)
    })
  ,

  'ForSaleData' : _reflection.GeneratedProtocolMessageType('ForSaleData', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_FORSALEDATA,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.ForSaleData)
    })
  ,

  'PlaytimeStats' : _reflection.GeneratedProtocolMessageType('PlaytimeStats', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_PLAYTIMESTATS,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.PlaytimeStats)
    })
  ,

  'Reaction' : _reflection.GeneratedProtocolMessageType('Reaction', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHEDFILEDETAILS_REACTION,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:PublishedFileDetails.Reaction)
    })
  ,
  'DESCRIPTOR' : _PUBLISHEDFILEDETAILS,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:PublishedFileDetails)
  })
_sym_db.RegisterMessage(PublishedFileDetails)
_sym_db.RegisterMessage(PublishedFileDetails.Tag)
_sym_db.RegisterMessage(PublishedFileDetails.Preview)
_sym_db.RegisterMessage(PublishedFileDetails.Child)
_sym_db.RegisterMessage(PublishedFileDetails.KVTag)
_sym_db.RegisterMessage(PublishedFileDetails.VoteData)
_sym_db.RegisterMessage(PublishedFileDetails.ForSaleData)
_sym_db.RegisterMessage(PublishedFileDetails.PlaytimeStats)
_sym_db.RegisterMessage(PublishedFileDetails.Reaction)

CPublishedFile_GetDetails_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetDetails_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETDETAILS_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetDetails_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetDetails_Response)

CPublishedFile_GetItemInfo_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetItemInfo_Request', (_message.Message,), {

  'WorkshopItem' : _reflection.GeneratedProtocolMessageType('WorkshopItem', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemInfo_Request.WorkshopItem)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMINFO_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemInfo_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetItemInfo_Request)
_sym_db.RegisterMessage(CPublishedFile_GetItemInfo_Request.WorkshopItem)

CPublishedFile_GetItemInfo_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetItemInfo_Response', (_message.Message,), {

  'WorkshopItemInfo' : _reflection.GeneratedProtocolMessageType('WorkshopItemInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemInfo_Response.WorkshopItemInfo)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMINFO_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemInfo_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetItemInfo_Response)
_sym_db.RegisterMessage(CPublishedFile_GetItemInfo_Response.WorkshopItemInfo)

CPublishedFile_GetUserFiles_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetUserFiles_Request', (_message.Message,), {

  'KVTag' : _reflection.GeneratedProtocolMessageType('KVTag', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserFiles_Request.KVTag)
    })
  ,

  'TagGroup' : _reflection.GeneratedProtocolMessageType('TagGroup', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserFiles_Request.TagGroup)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERFILES_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserFiles_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetUserFiles_Request)
_sym_db.RegisterMessage(CPublishedFile_GetUserFiles_Request.KVTag)
_sym_db.RegisterMessage(CPublishedFile_GetUserFiles_Request.TagGroup)

CPublishedFile_GetUserFiles_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetUserFiles_Response', (_message.Message,), {

  'App' : _reflection.GeneratedProtocolMessageType('App', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserFiles_Response.App)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERFILES_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserFiles_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetUserFiles_Response)
_sym_db.RegisterMessage(CPublishedFile_GetUserFiles_Response.App)

CPublishedFile_AreFilesInSubscriptionList_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_AreFilesInSubscriptionList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AreFilesInSubscriptionList_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_AreFilesInSubscriptionList_Request)

CPublishedFile_AreFilesInSubscriptionList_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_AreFilesInSubscriptionList_Response', (_message.Message,), {

  'InList' : _reflection.GeneratedProtocolMessageType('InList', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_AreFilesInSubscriptionList_Response.InList)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AreFilesInSubscriptionList_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_AreFilesInSubscriptionList_Response)
_sym_db.RegisterMessage(CPublishedFile_AreFilesInSubscriptionList_Response.InList)

CPublishedFile_Update_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Update_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_UPDATE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Update_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Update_Request)

CPublishedFile_Update_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Update_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_UPDATE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Update_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Update_Response)

CPublishedFile_Delete_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_Delete_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_DELETE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Delete_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_Delete_Request)

CPublishedFile_Delete_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_Delete_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_DELETE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_Delete_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_Delete_Response)

CPublishedFile_GetChangeHistoryEntry_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetChangeHistoryEntry_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetChangeHistoryEntry_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetChangeHistoryEntry_Request)

CPublishedFile_GetChangeHistoryEntry_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetChangeHistoryEntry_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetChangeHistoryEntry_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetChangeHistoryEntry_Response)

CPublishedFile_GetChangeHistory_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetChangeHistory_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetChangeHistory_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetChangeHistory_Request)

CPublishedFile_GetChangeHistory_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetChangeHistory_Response', (_message.Message,), {

  'ChangeLog' : _reflection.GeneratedProtocolMessageType('ChangeLog', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetChangeHistory_Response.ChangeLog)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetChangeHistory_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetChangeHistory_Response)
_sym_db.RegisterMessage(CPublishedFile_GetChangeHistory_Response.ChangeLog)

CPublishedFile_RefreshVotingQueue_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_RefreshVotingQueue_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RefreshVotingQueue_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_RefreshVotingQueue_Request)

CPublishedFile_RefreshVotingQueue_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_RefreshVotingQueue_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RefreshVotingQueue_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_RefreshVotingQueue_Response)

CPublishedFile_QueryFiles_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_QueryFiles_Request', (_message.Message,), {

  'KVTag' : _reflection.GeneratedProtocolMessageType('KVTag', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_QueryFiles_Request.KVTag)
    })
  ,

  'TagGroup' : _reflection.GeneratedProtocolMessageType('TagGroup', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_QueryFiles_Request.TagGroup)
    })
  ,

  'DateRange' : _reflection.GeneratedProtocolMessageType('DateRange', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_QueryFiles_Request.DateRange)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_QUERYFILES_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_QueryFiles_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_QueryFiles_Request)
_sym_db.RegisterMessage(CPublishedFile_QueryFiles_Request.KVTag)
_sym_db.RegisterMessage(CPublishedFile_QueryFiles_Request.TagGroup)
_sym_db.RegisterMessage(CPublishedFile_QueryFiles_Request.DateRange)

CPublishedFile_QueryFiles_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_QueryFiles_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_QUERYFILES_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_QueryFiles_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_QueryFiles_Response)

CPublishedFile_AddAppRelationship_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_AddAppRelationship_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AddAppRelationship_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_AddAppRelationship_Request)

CPublishedFile_AddAppRelationship_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_AddAppRelationship_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AddAppRelationship_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_AddAppRelationship_Response)

CPublishedFile_RemoveAppRelationship_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_RemoveAppRelationship_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RemoveAppRelationship_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_RemoveAppRelationship_Request)

CPublishedFile_RemoveAppRelationship_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_RemoveAppRelationship_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RemoveAppRelationship_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_RemoveAppRelationship_Response)

CPublishedFile_GetAppRelationships_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetAppRelationships_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetAppRelationships_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetAppRelationships_Request)

CPublishedFile_GetAppRelationships_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetAppRelationships_Response', (_message.Message,), {

  'AppRelationship' : _reflection.GeneratedProtocolMessageType('AppRelationship', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetAppRelationships_Response.AppRelationship)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetAppRelationships_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetAppRelationships_Response)
_sym_db.RegisterMessage(CPublishedFile_GetAppRelationships_Response.AppRelationship)

CPublishedFile_StartPlaytimeTracking_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_StartPlaytimeTracking_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StartPlaytimeTracking_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_StartPlaytimeTracking_Request)

CPublishedFile_StartPlaytimeTracking_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_StartPlaytimeTracking_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StartPlaytimeTracking_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_StartPlaytimeTracking_Response)

CPublishedFile_StopPlaytimeTracking_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_StopPlaytimeTracking_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StopPlaytimeTracking_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_StopPlaytimeTracking_Request)

CPublishedFile_StopPlaytimeTracking_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_StopPlaytimeTracking_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StopPlaytimeTracking_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_StopPlaytimeTracking_Response)

CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request)

CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response)

CPublishedFile_SetPlaytimeForControllerConfigs_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_SetPlaytimeForControllerConfigs_Request', (_message.Message,), {

  'ControllerConfigUsage' : _reflection.GeneratedProtocolMessageType('ControllerConfigUsage', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_SetPlaytimeForControllerConfigs_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_SetPlaytimeForControllerConfigs_Request)
_sym_db.RegisterMessage(CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage)

CPublishedFile_SetPlaytimeForControllerConfigs_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_SetPlaytimeForControllerConfigs_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_SetPlaytimeForControllerConfigs_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_SetPlaytimeForControllerConfigs_Response)

CPublishedFile_AddChild_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_AddChild_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_ADDCHILD_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AddChild_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_AddChild_Request)

CPublishedFile_AddChild_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_AddChild_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_ADDCHILD_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_AddChild_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_AddChild_Response)

CPublishedFile_RemoveChild_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_RemoveChild_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REMOVECHILD_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RemoveChild_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_RemoveChild_Request)

CPublishedFile_RemoveChild_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_RemoveChild_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_REMOVECHILD_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_RemoveChild_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_RemoveChild_Response)

CPublishedFile_GetUserVoteSummary_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetUserVoteSummary_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserVoteSummary_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetUserVoteSummary_Request)

CPublishedFile_GetUserVoteSummary_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetUserVoteSummary_Response', (_message.Message,), {

  'VoteSummary' : _reflection.GeneratedProtocolMessageType('VoteSummary', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserVoteSummary_Response.VoteSummary)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetUserVoteSummary_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetUserVoteSummary_Response)
_sym_db.RegisterMessage(CPublishedFile_GetUserVoteSummary_Response.VoteSummary)

CPublishedFile_GetItemChanges_Request = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetItemChanges_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemChanges_Request)
  })
_sym_db.RegisterMessage(CPublishedFile_GetItemChanges_Request)

CPublishedFile_GetItemChanges_Response = _reflection.GeneratedProtocolMessageType('CPublishedFile_GetItemChanges_Response', (_message.Message,), {

  'WorkshopItemInfo' : _reflection.GeneratedProtocolMessageType('WorkshopItemInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemChanges_Response.WorkshopItemInfo)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_GetItemChanges_Response)
  })
_sym_db.RegisterMessage(CPublishedFile_GetItemChanges_Response)
_sym_db.RegisterMessage(CPublishedFile_GetItemChanges_Response.WorkshopItemInfo)

CPublishedFile_FileSubscribed_Notification = _reflection.GeneratedProtocolMessageType('CPublishedFile_FileSubscribed_Notification', (_message.Message,), {

  'RevisionData' : _reflection.GeneratedProtocolMessageType('RevisionData', (_message.Message,), {
    'DESCRIPTOR' : _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA,
    '__module__' : 'steammessages_publishedfile_pb2'
    # @@protoc_insertion_point(class_scope:CPublishedFile_FileSubscribed_Notification.RevisionData)
    })
  ,
  'DESCRIPTOR' : _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_FileSubscribed_Notification)
  })
_sym_db.RegisterMessage(CPublishedFile_FileSubscribed_Notification)
_sym_db.RegisterMessage(CPublishedFile_FileSubscribed_Notification.RevisionData)

CPublishedFile_FileUnsubscribed_Notification = _reflection.GeneratedProtocolMessageType('CPublishedFile_FileUnsubscribed_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_FileUnsubscribed_Notification)
  })
_sym_db.RegisterMessage(CPublishedFile_FileUnsubscribed_Notification)

CPublishedFile_FileDeleted_Client_Notification = _reflection.GeneratedProtocolMessageType('CPublishedFile_FileDeleted_Client_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION,
  '__module__' : 'steammessages_publishedfile_pb2'
  # @@protoc_insertion_point(class_scope:CPublishedFile_FileDeleted_Client_Notification)
  })
_sym_db.RegisterMessage(CPublishedFile_FileDeleted_Client_Notification)


DESCRIPTOR._options = None
_CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['appid']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['consumer_appid']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['cloudfilename']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['preview_cloudfilename']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['title']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['file_description']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['file_type']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['consumer_shortcut_name']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['youtube_username']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['youtube_videoid']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['visibility']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['redirect_uri']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['tags']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['collection_type']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['game_type']._options = None
_CPUBLISHEDFILE_PUBLISH_REQUEST.fields_by_name['url']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['publishedfileids']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includetags']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includeadditionalpreviews']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includechildren']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includekvtags']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includevotes']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['short_description']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includeforsaledata']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includemetadata']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['language']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['return_playtime_stats']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['strip_description_bbcode']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_GETDETAILS_REQUEST.fields_by_name['includereactions']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['time_subscribed']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['for_sale_data']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['metadata']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['language']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['revision_change_number']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['revision']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['available_revisions']._options = None
_PUBLISHEDFILEDETAILS.fields_by_name['reactions']._options = None
_CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['steamid']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['appid']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['page']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['numperpage']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['type']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['sortmethod']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['privacy']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['requiredtags']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['excludedtags']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['required_kv_tags']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['filetype']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['creator_appid']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['match_cloud_filename']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['cache_max_age_seconds']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['language']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['taggroups']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['totalonly']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['ids_only']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_vote_data']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_tags']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_kv_tags']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_previews']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_children']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_short_description']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_for_sale_data']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_metadata']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_playtime_stats']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['strip_description_bbcode']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_reactions']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['startindex_override']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_GETUSERFILES_REQUEST.fields_by_name['return_apps']._options = None
_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST.fields_by_name['listtype']._options = None
_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST.fields_by_name['filetype']._options = None
_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST.fields_by_name['workshopfiletype']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['appid']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['publishedfileid']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['title']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['file_description']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['visibility']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['tags']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['filename']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['preview_filename']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['spoiler_tag']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['image_width']._options = None
_CPUBLISHEDFILE_UPDATE_REQUEST.fields_by_name['image_height']._options = None
_CPUBLISHEDFILE_DELETE_REQUEST.fields_by_name['publishedfileid']._options = None
_CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST.fields_by_name['publishedfileid']._options = None
_CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST.fields_by_name['publishedfileid']._options = None
_CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST.fields_by_name['total_only']._options = None
_CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST.fields_by_name['language']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['matching_file_type']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['tags']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['match_all_tags']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['excluded_tags']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['desired_queue_size']._options = None
_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE.fields_by_name['timestamp_start']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE.fields_by_name['timestamp_end']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['query_type']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['page']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['cursor']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['numperpage']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['creator_appid']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['appid']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['requiredtags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['excludedtags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['match_all_tags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['required_flags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['omitted_flags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['search_text']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['filetype']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['child_publishedfileid']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['days']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['include_recent_votes_only']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['cache_max_age_seconds']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['language']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['required_kv_tags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['taggroups']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['date_range_created']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['date_range_updated']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['totalonly']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['ids_only']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_vote_data']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_tags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_kv_tags']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_previews']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_children']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_short_description']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_for_sale_data']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_metadata']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_playtime_stats']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_details']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['strip_description_bbcode']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['desired_revision']._options = None
_CPUBLISHEDFILE_QUERYFILES_REQUEST.fields_by_name['return_reactions']._options = None
_CPUBLISHEDFILE_QUERYFILES_RESPONSE.fields_by_name['total']._options = None
_CPUBLISHEDFILE_QUERYFILES_RESPONSE.fields_by_name['publishedfiledetails']._options = None
_CPUBLISHEDFILE_QUERYFILES_RESPONSE.fields_by_name['next_cursor']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA.fields_by_name['file_hcontent']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA.fields_by_name['rtime_updated']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['published_file_id']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['file_hcontent']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['is_depot_content']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['rtime_updated']._options = None
_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION.fields_by_name['revisions']._options = None
_CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION.fields_by_name['published_file_id']._options = None
_CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION.fields_by_name['published_file_id']._options = None

_PUBLISHEDFILE = _descriptor.ServiceDescriptor(
  name='PublishedFile',
  full_name='PublishedFile',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\'A service to access published file data',
  create_key=_descriptor._internal_create_key,
  serialized_start=22052,
  serialized_end=26743,
  methods=[
  _descriptor.MethodDescriptor(
    name='Vote',
    full_name='PublishedFile.Vote',
    index=0,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_VOTE_REQUEST,
    output_type=_CPUBLISHEDFILE_VOTE_RESPONSE,
    serialized_options=b'\202\265\030\036User wants to vote on the item',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='PublishedFile.Subscribe',
    index=1,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_SUBSCRIBE_REQUEST,
    output_type=_CPUBLISHEDFILE_SUBSCRIBE_RESPONSE,
    serialized_options=b'\202\265\030)Subscribes the user to the published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Unsubscribe',
    full_name='PublishedFile.Unsubscribe',
    index=2,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST,
    output_type=_CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE,
    serialized_options=b'\202\265\030-Unsubscribes the user from the published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CanSubscribe',
    full_name='PublishedFile.CanSubscribe',
    index=3,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST,
    output_type=_CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE,
    serialized_options=b'\202\265\0305Check if the user can subscribe to the published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSubSectionData',
    full_name='PublishedFile.GetSubSectionData',
    index=4,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST,
    output_type=_CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE,
    serialized_options=b'\202\265\030HGet sub section data (for table of contents, a specific section, or all)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Publish',
    full_name='PublishedFile.Publish',
    index=5,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_PUBLISH_REQUEST,
    output_type=_CPUBLISHEDFILE_PUBLISH_RESPONSE,
    serialized_options=b'\202\265\030.Publishes a clouded user file to the Workshop.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetails',
    full_name='PublishedFile.GetDetails',
    index=6,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETDETAILS_REQUEST,
    output_type=_CPUBLISHEDFILE_GETDETAILS_RESPONSE,
    serialized_options=b'\202\265\0305Retrieves information about a set of published files.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetItemInfo',
    full_name='PublishedFile.GetItemInfo',
    index=7,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETITEMINFO_REQUEST,
    output_type=_CPUBLISHEDFILE_GETITEMINFO_RESPONSE,
    serialized_options=b'\202\265\0305Retrieves information about a set of published files.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserFiles',
    full_name='PublishedFile.GetUserFiles',
    index=8,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETUSERFILES_REQUEST,
    output_type=_CPUBLISHEDFILE_GETUSERFILES_RESPONSE,
    serialized_options=b'\202\265\030$Retrieves files published by a user.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserFileCount',
    full_name='PublishedFile.GetUserFileCount',
    index=9,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETUSERFILES_REQUEST,
    output_type=_CPUBLISHEDFILE_GETUSERFILES_RESPONSE,
    serialized_options=b'\202\265\030rRetrieves a count of files published by a user. Uses the same messages as GetUserFiles but totalonly must be true.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AreFilesInSubscriptionList',
    full_name='PublishedFile.AreFilesInSubscriptionList',
    index=10,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST,
    output_type=_CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE,
    serialized_options=b'\202\265\030JDetermines which files in the given list are in a user\'s subscription list',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='PublishedFile.Update',
    index=11,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_UPDATE_REQUEST,
    output_type=_CPUBLISHEDFILE_UPDATE_RESPONSE,
    serialized_options=b'\202\265\030+Updates information about a published file.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='PublishedFile.Delete',
    index=12,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_DELETE_REQUEST,
    output_type=_CPUBLISHEDFILE_DELETE_RESPONSE,
    serialized_options=b'\202\265\030\031Deletes a published file.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChangeHistoryEntry',
    full_name='PublishedFile.GetChangeHistoryEntry',
    index=13,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST,
    output_type=_CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE,
    serialized_options=b'\202\265\030DReturns data on a specific change history entry for a published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChangeHistory',
    full_name='PublishedFile.GetChangeHistory',
    index=14,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST,
    output_type=_CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE,
    serialized_options=b'\202\265\0307Returns data on the change history for a published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RefreshVotingQueue',
    full_name='PublishedFile.RefreshVotingQueue',
    index=15,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST,
    output_type=_CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE,
    serialized_options=b'\202\265\030%Refresh the voting queue for the user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryFiles',
    full_name='PublishedFile.QueryFiles',
    index=16,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_QUERYFILES_REQUEST,
    output_type=_CPUBLISHEDFILE_QUERYFILES_RESPONSE,
    serialized_options=b'\202\265\030+Performs a search query for published files',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddAppRelationship',
    full_name='PublishedFile.AddAppRelationship',
    index=17,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST,
    output_type=_CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE,
    serialized_options=b'\202\265\030@Adds a relationship between the published file and the given app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAppRelationship',
    full_name='PublishedFile.RemoveAppRelationship',
    index=18,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST,
    output_type=_CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE,
    serialized_options=b'\202\265\030BRemove a relationship between the published file and the given app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAppRelationships',
    full_name='PublishedFile.GetAppRelationships',
    index=19,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST,
    output_type=_CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE,
    serialized_options=b'\202\265\030=Returns the list of app relationships for this published file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartPlaytimeTracking',
    full_name='PublishedFile.StartPlaytimeTracking',
    index=20,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST,
    output_type=_CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE,
    serialized_options=b'\202\265\0307Start usage tracking for a given set of published files',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopPlaytimeTracking',
    full_name='PublishedFile.StopPlaytimeTracking',
    index=21,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST,
    output_type=_CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE,
    serialized_options=b'\202\265\0307Stops usage tracking for a given set of published files',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopPlaytimeTrackingForAllAppItems',
    full_name='PublishedFile.StopPlaytimeTrackingForAllAppItems',
    index=22,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST,
    output_type=_CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE,
    serialized_options=b'\202\265\030JStops usage tracking for all items currently tracked for the specified app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPlaytimeForControllerConfigs',
    full_name='PublishedFile.SetPlaytimeForControllerConfigs',
    index=23,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST,
    output_type=_CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE,
    serialized_options=b'\202\265\030}Stops usage tracking all controller configs for the given app and set the usage time for the for the given controller configs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddChild',
    full_name='PublishedFile.AddChild',
    index=24,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_ADDCHILD_REQUEST,
    output_type=_CPUBLISHEDFILE_ADDCHILD_RESPONSE,
    serialized_options=b'\202\265\030:Adds a parent->child relationship between the given items.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveChild',
    full_name='PublishedFile.RemoveChild',
    index=25,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_REMOVECHILD_REQUEST,
    output_type=_CPUBLISHEDFILE_REMOVECHILD_RESPONSE,
    serialized_options=b'\202\265\030;Removes parent->child relationship between the given items.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserVoteSummary',
    full_name='PublishedFile.GetUserVoteSummary',
    index=26,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST,
    output_type=_CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE,
    serialized_options=b'\202\265\030\025Get user vote summary',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetItemChanges',
    full_name='PublishedFile.GetItemChanges',
    index=27,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_GETITEMCHANGES_REQUEST,
    output_type=_CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE,
    serialized_options=b'\202\265\030*Get list of updated items since given date',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PUBLISHEDFILE)

DESCRIPTOR.services_by_name['PublishedFile'] = _PUBLISHEDFILE


_PUBLISHEDFILECLIENT = _descriptor.ServiceDescriptor(
  name='PublishedFileClient',
  full_name='PublishedFileClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030#Published file client notifications\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=26746,
  serialized_end=27271,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyFileSubscribed',
    full_name='PublishedFileClient.NotifyFileSubscribed',
    index=0,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030=Notification from the server when a user subscribes to a file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyFileUnsubscribed',
    full_name='PublishedFileClient.NotifyFileUnsubscribed',
    index=1,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ANotification from the server when a user unsubscribes from a file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyFileDeleted',
    full_name='PublishedFileClient.NotifyFileDeleted',
    index=2,
    containing_service=None,
    input_type=_CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030=Notification from the server when a published file is deleted',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PUBLISHEDFILECLIENT)

DESCRIPTOR.services_by_name['PublishedFileClient'] = _PUBLISHEDFILECLIENT

PublishedFile = service_reflection.GeneratedServiceType('PublishedFile', (_service.Service,), dict(
  DESCRIPTOR = _PUBLISHEDFILE,
  __module__ = 'steammessages_publishedfile_pb2'
  ))

PublishedFile_Stub = service_reflection.GeneratedServiceStubType('PublishedFile_Stub', (PublishedFile,), dict(
  DESCRIPTOR = _PUBLISHEDFILE,
  __module__ = 'steammessages_publishedfile_pb2'
  ))


PublishedFileClient = service_reflection.GeneratedServiceType('PublishedFileClient', (_service.Service,), dict(
  DESCRIPTOR = _PUBLISHEDFILECLIENT,
  __module__ = 'steammessages_publishedfile_pb2'
  ))

PublishedFileClient_Stub = service_reflection.GeneratedServiceStubType('PublishedFileClient_Stub', (PublishedFileClient,), dict(
  DESCRIPTOR = _PUBLISHEDFILECLIENT,
  __module__ = 'steammessages_publishedfile_pb2'
  ))


# @@protoc_insertion_point(module_scope)
