# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteplay.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_remoteplay.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1esteammessages_remoteplay.proto\"H\n\x15\x43\x44iscoveryPingRequest\x12\x10\n\x08sequence\x18\x01 \x01(\r\x12\x1d\n\x15packet_size_requested\x18\x02 \x01(\r\"H\n\x16\x43\x44iscoveryPingResponse\x12\x10\n\x08sequence\x18\x01 \x01(\r\x12\x1c\n\x14packet_size_received\x18\x02 \x01(\r\"5\n\x1d\x43StreamingClientHandshakeInfo\x12\x14\n\x0cnetwork_test\x18\x02 \x01(\x05\"C\n\x13\x43\x43lientHandshakeMsg\x12,\n\x04info\x18\x01 \x02(\x0b\x32\x1e.CStreamingClientHandshakeInfo\",\n\x1d\x43StreamingServerHandshakeInfo\x12\x0b\n\x03mtu\x18\x01 \x01(\x05\"C\n\x13\x43ServerHandshakeMsg\x12,\n\x04info\x18\x01 \x02(\x0b\x32\x1e.CStreamingServerHandshakeInfo\"s\n\x19\x43\x41uthenticationRequestMsg\x12\r\n\x05token\x18\x01 \x01(\x0c\x12\x36\n\x07version\x18\x02 \x01(\x0e\x32\x0f.EStreamVersion:\x14k_EStreamVersionNone\x12\x0f\n\x07steamid\x18\x03 \x01(\x04\"\xd4\x01\n\x1a\x43\x41uthenticationResponseMsg\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x30.CAuthenticationResponseMsg.AuthenticationResult:\tSUCCEEDED\x12\x36\n\x07version\x18\x02 \x01(\x0e\x32\x0f.EStreamVersion:\x14k_EStreamVersionNone\"1\n\x14\x41uthenticationResult\x12\r\n\tSUCCEEDED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\"\x0f\n\rCKeepAliveMsg\"\x83\x01\n\x14\x43StartNetworkTestMsg\x12\x0e\n\x06\x66rames\x18\x01 \x01(\r\x12\x11\n\tframerate\x18\x02 \x01(\r\x12\x14\n\x0c\x62itrate_kbps\x18\x03 \x01(\r\x12\x1a\n\x12\x62urst_bitrate_kbps\x18\x04 \x01(\r\x12\x16\n\x0e\x62\x61ndwidth_test\x18\x05 \x01(\x08\"\x89\x01\n\x10\x43StreamVideoMode\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\x14\n\x0crefresh_rate\x18\x03 \x01(\r\x12\x1e\n\x16refresh_rate_numerator\x18\x04 \x01(\r\x12 \n\x18refresh_rate_denominator\x18\x05 \x01(\r\"\xcb\x03\n\x14\x43StreamingClientCaps\x12\x13\n\x0bsystem_info\x18\x01 \x01(\t\x12\x1a\n\x12system_can_suspend\x18\x02 \x01(\x08\x12#\n\x1bmaximum_decode_bitrate_kbps\x18\x03 \x01(\x05\x12\"\n\x1amaximum_burst_bitrate_kbps\x18\x04 \x01(\x05\x12\x1b\n\x13supports_video_hevc\x18\x05 \x01(\x08\x12\x1b\n\x13\x64isable_steam_store\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isable_client_cursor\x18\x07 \x01(\x08\x12\'\n\x1f\x64isable_intel_hardware_encoding\x18\x08 \x01(\x08\x12%\n\x1d\x64isable_amd_hardware_encoding\x18\t \x01(\x08\x12(\n disable_nvidia_hardware_encoding\x18\n \x01(\x08\x12\x13\n\x0b\x66orm_factor\x18\x0b \x01(\x05\x12\x1e\n\x16has_on_screen_keyboard\x18\x0c \x01(\x08\x12\x31\n\x15supported_colorspaces\x18\r \x03(\x0e\x32\x12.EStreamColorspace\"\xea\x05\n\x16\x43StreamingClientConfig\x12\x44\n\x07quality\x18\x01 \x01(\x0e\x32\x19.EStreamQualityPreference:\x18k_EStreamQualityBalanced\x12\x1c\n\x14maximum_resolution_x\x18\x02 \x01(\r\x12\x1c\n\x14maximum_resolution_y\x18\x03 \x01(\r\x12#\n\x1bmaximum_framerate_numerator\x18\x04 \x01(\r\x12%\n\x1dmaximum_framerate_denominator\x18\x05 \x01(\r\x12 \n\x14maximum_bitrate_kbps\x18\x06 \x01(\x05:\x02-1\x12&\n\x18\x65nable_hardware_decoding\x18\x07 \x01(\x08:\x04true\x12)\n\x1a\x65nable_performance_overlay\x18\x08 \x01(\x08:\x05\x66\x61lse\x12$\n\x16\x65nable_video_streaming\x18\t \x01(\x08:\x04true\x12$\n\x16\x65nable_audio_streaming\x18\n \x01(\x08:\x04true\x12$\n\x16\x65nable_input_streaming\x18\x0b \x01(\x08:\x04true\x12\x19\n\x0e\x61udio_channels\x18\x0c \x01(\x05:\x01\x32\x12 \n\x11\x65nable_video_hevc\x18\r \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x65nable_performance_icons\x18\x0e \x01(\x08:\x04true\x12*\n\x1b\x65nable_microphone_streaming\x18\x0f \x01(\x08:\x05\x66\x61lse\x12!\n\x19\x63ontroller_overlay_hotkey\x18\x10 \x01(\t\x12&\n\x17\x65nable_touch_controller\x18\x11 \x01(\x08:\x05\x66\x61lse\x12?\n\tp2p_scope\x18\x13 \x01(\x0e\x32\x10.EStreamP2PScope:\x1ak_EStreamP2PScopeAutomatic\"\x94\x03\n\x16\x43StreamingServerConfig\x12!\n\x19\x63hange_desktop_resolution\x18\x01 \x01(\x08\x12%\n\x1d\x64ynamically_adjust_resolution\x18\x02 \x01(\x08\x12\x1c\n\x14\x65nable_capture_nvfbc\x18\x03 \x01(\x08\x12\'\n\x1f\x65nable_hardware_encoding_nvidia\x18\x04 \x01(\x08\x12$\n\x1c\x65nable_hardware_encoding_amd\x18\x05 \x01(\x08\x12&\n\x1e\x65nable_hardware_encoding_intel\x18\x06 \x01(\x08\x12!\n\x19software_encoding_threads\x18\x07 \x01(\x05\x12\x1f\n\x17\x65nable_traffic_priority\x18\x08 \x01(\x08\x12W\n\x0fhost_play_audio\x18\t \x01(\x0e\x32\x1f.EStreamHostPlayAudioPreference:\x1dk_EStreamHostPlayAudioDefault\"\xc8\x02\n\x11\x43NegotiatedConfig\x12\x15\n\rreliable_data\x18\x01 \x01(\x08\x12I\n\x14selected_audio_codec\x18\x02 \x01(\x0e\x32\x12.EStreamAudioCodec:\x17k_EStreamAudioCodecNone\x12I\n\x14selected_video_codec\x18\x03 \x01(\x0e\x32\x12.EStreamVideoCodec:\x17k_EStreamVideoCodecNone\x12\x30\n\x15\x61vailable_video_modes\x18\x04 \x03(\x0b\x32\x11.CStreamVideoMode\x12\x19\n\x11\x65nable_remote_hid\x18\x05 \x01(\x08\x12\x1a\n\x12\x65nable_touch_input\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isable_client_cursor\x18\x07 \x01(\x08\"\xcf\x01\n\x13\x43NegotiationInitMsg\x12\x15\n\rreliable_data\x18\x01 \x01(\x08\x12\x32\n\x16supported_audio_codecs\x18\x02 \x03(\x0e\x32\x12.EStreamAudioCodec\x12\x32\n\x16supported_video_codecs\x18\x03 \x03(\x0e\x32\x12.EStreamVideoCodec\x12\x1b\n\x13supports_remote_hid\x18\x04 \x01(\x08\x12\x1c\n\x14supports_touch_input\x18\x05 \x01(\x08\"\xae\x01\n\x18\x43NegotiationSetConfigMsg\x12\"\n\x06\x63onfig\x18\x01 \x02(\x0b\x32\x12.CNegotiatedConfig\x12\x38\n\x17streaming_client_config\x18\x02 \x01(\x0b\x32\x17.CStreamingClientConfig\x12\x34\n\x15streaming_client_caps\x18\x03 \x01(\x0b\x32\x15.CStreamingClientCaps\"\x19\n\x17\x43NegotiationCompleteMsg\"\x9a\x01\n\x12\x43StartAudioDataMsg\x12\x0f\n\x07\x63hannel\x18\x02 \x02(\r\x12:\n\x05\x63odec\x18\x03 \x01(\x0e\x32\x12.EStreamAudioCodec:\x17k_EStreamAudioCodecNone\x12\x12\n\ncodec_data\x18\x04 \x01(\x0c\x12\x11\n\tfrequency\x18\x05 \x01(\r\x12\x10\n\x08\x63hannels\x18\x06 \x01(\r\"\x13\n\x11\x43StopAudioDataMsg\"\x94\x01\n\x12\x43StartVideoDataMsg\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\r\x12:\n\x05\x63odec\x18\x02 \x01(\x0e\x32\x12.EStreamVideoCodec:\x17k_EStreamVideoCodecNone\x12\x12\n\ncodec_data\x18\x03 \x01(\x0c\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\"\x13\n\x11\x43StopVideoDataMsg\"\xc5\x04\n\x0e\x43RecordedInput\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x16.EStreamControlMessage:%k_EStreamControlAuthenticationRequest\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x30\n\x0b\x66inger_down\x18\x03 \x01(\x0b\x32\x19.CInputTouchFingerDownMsgH\x00\x12\x34\n\rfinger_motion\x18\x04 \x01(\x0b\x32\x1b.CInputTouchFingerMotionMsgH\x00\x12,\n\tfinger_up\x18\x05 \x01(\x0b\x32\x17.CInputTouchFingerUpMsgH\x00\x12-\n\x0cmouse_motion\x18\x06 \x01(\x0b\x32\x15.CInputMouseMotionMsgH\x00\x12+\n\x0bmouse_wheel\x18\x07 \x01(\x0b\x32\x14.CInputMouseWheelMsgH\x00\x12)\n\nmouse_down\x18\x08 \x01(\x0b\x32\x13.CInputMouseDownMsgH\x00\x12%\n\x08mouse_up\x18\t \x01(\x0b\x32\x11.CInputMouseUpMsgH\x00\x12%\n\x08key_down\x18\n \x01(\x0b\x32\x11.CInputKeyDownMsgH\x00\x12!\n\x06key_up\x18\x0b \x01(\x0b\x32\x0f.CInputKeyUpMsgH\x00\x12\x1e\n\x04text\x18\x0c \x01(\x0b\x32\x0e.CInputTextMsgH\x00\x12\x1d\n\x03hid\x18\r \x01(\x0b\x32\x0e.CRemoteHIDMsgH\x00\x42\x06\n\x04\x64\x61ta\"8\n\x14\x43RecordedInputStream\x12 \n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0f.CRecordedInput\"9\n\x14\x43InputLatencyTestMsg\x12\x12\n\ninput_mark\x18\x01 \x02(\r\x12\r\n\x05\x63olor\x18\x02 \x01(\r\"l\n\x18\x43InputTouchFingerDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\"n\n\x1a\x43InputTouchFingerMotionMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\"j\n\x16\x43InputTouchFingerUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08\x66ingerid\x18\x02 \x01(\x04\x12\x14\n\x0cx_normalized\x18\x03 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x04 \x01(\x02\"n\n\x14\x43InputMouseMotionMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x14\n\x0cx_normalized\x18\x02 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x03 \x01(\x02\x12\n\n\x02\x64x\x18\x04 \x01(\x05\x12\n\n\x02\x64y\x18\x05 \x01(\x05\"p\n\x13\x43InputMouseWheelMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x45\n\tdirection\x18\x02 \x02(\x0e\x32\x1b.EStreamMouseWheelDirection:\x15k_EStreamMouseWheelUp\"g\n\x12\x43InputMouseDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12=\n\x06\x62utton\x18\x02 \x02(\x0e\x32\x13.EStreamMouseButton:\x18k_EStreamMouseButtonLeft\"e\n\x10\x43InputMouseUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12=\n\x06\x62utton\x18\x02 \x02(\x0e\x32\x13.EStreamMouseButton:\x18k_EStreamMouseButtonLeft\"8\n\x10\x43InputKeyDownMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08scancode\x18\x02 \x02(\r\"6\n\x0e\x43InputKeyUpMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x10\n\x08scancode\x18\x02 \x02(\r\"6\n\rCInputTextMsg\x12\x12\n\ninput_mark\x18\x01 \x01(\r\x12\x11\n\ttext_utf8\x18\x02 \x02(\t\"\x1c\n\x0c\x43SetTitleMsg\x12\x0c\n\x04text\x18\x01 \x01(\t\"3\n\x12\x43SetCaptureSizeMsg\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\";\n\x0b\x43SetIconMsg\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05image\x18\x03 \x01(\x0c\"E\n\x11\x43SetFlashStateMsg\x12\r\n\x05\x66lags\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x12\n\ntimeout_ms\x18\x03 \x01(\r\"<\n\x0e\x43ShowCursorMsg\x12\x14\n\x0cx_normalized\x18\x01 \x01(\x02\x12\x14\n\x0cy_normalized\x18\x02 \x01(\x02\"\x10\n\x0e\x43HideCursorMsg\"\"\n\rCSetCursorMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"\'\n\x12\x43GetCursorImageMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"s\n\x12\x43SetCursorImageMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\r\n\x05hot_x\x18\x04 \x01(\x05\x12\r\n\x05hot_y\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x01(\x0c\"5\n\x14\x43VideoDecoderInfoMsg\x12\x0c\n\x04info\x18\x01 \x01(\t\x12\x0f\n\x07threads\x18\x02 \x01(\x05\"$\n\x14\x43VideoEncoderInfoMsg\x12\x0c\n\x04info\x18\x01 \x01(\t\"\x0b\n\tCPauseMsg\"\x0c\n\nCResumeMsg\"\x1a\n\x18\x43\x45nableHighResCaptureMsg\"\x1b\n\x19\x43\x44isableHighResCaptureMsg\"\x19\n\x17\x43ToggleMagnificationMsg\"\"\n\x0f\x43SetCapslockMsg\x12\x0f\n\x07pressed\x18\x01 \x01(\x08\"\x8c\x02\n\x15\x43StreamingKeymapEntry\x12\x10\n\x08scancode\x18\x01 \x01(\x05\x12\x16\n\x0enormal_keycode\x18\x02 \x01(\x05\x12\x15\n\rshift_keycode\x18\x03 \x01(\x05\x12\x18\n\x10\x63\x61pslock_keycode\x18\x04 \x01(\x05\x12\x1e\n\x16shift_capslock_keycode\x18\x05 \x01(\x05\x12\x15\n\raltgr_keycode\x18\x06 \x01(\x05\x12\x1b\n\x13\x61ltgr_shift_keycode\x18\x07 \x01(\x05\x12\x1e\n\x16\x61ltgr_capslock_keycode\x18\x08 \x01(\x05\x12$\n\x1c\x61ltgr_shift_capslock_keycode\x18\t \x01(\x05\";\n\x10\x43StreamingKeymap\x12\'\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x16.CStreamingKeymapEntry\"2\n\rCSetKeymapMsg\x12!\n\x06keymap\x18\x01 \x01(\x0b\x32\x11.CStreamingKeymap\"\x0e\n\x0c\x43StopRequest\"\x0e\n\x0c\x43QuitRequest\"%\n\x10\x43\x44\x65leteCursorMsg\x12\x11\n\tcursor_id\x18\x01 \x02(\x04\"D\n\x19\x43SetStreamingClientConfig\x12\'\n\x06\x63onfig\x18\x01 \x02(\x0b\x32\x17.CStreamingClientConfig\"\x1d\n\nCSetQoSMsg\x12\x0f\n\x07use_qos\x18\x01 \x02(\x08\"x\n\x16\x43SetTargetFramerateMsg\x12\x11\n\tframerate\x18\x01 \x02(\r\x12\x0f\n\x07reasons\x18\x02 \x01(\r\x12\x1b\n\x13\x66ramerate_numerator\x18\x03 \x01(\r\x12\x1d\n\x15\x66ramerate_denominator\x18\x04 \x01(\r\"\'\n\x14\x43SetTargetBitrateMsg\x12\x0f\n\x07\x62itrate\x18\x01 \x02(\x05\"%\n\x12\x43OverlayEnabledMsg\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"&\n\x10\x43SetGammaRampMsg\x12\x12\n\ngamma_ramp\x18\x01 \x01(\x0c\"~\n\x0f\x43SetActivityMsg\x12\x39\n\x08\x61\x63tivity\x18\x01 \x01(\x0e\x32\x10.EStreamActivity:\x15k_EStreamActivityIdle\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0e\n\x06gameid\x18\x03 \x01(\x04\x12\x11\n\tgame_name\x18\x04 \x01(\t\"\x13\n\x11\x43SystemSuspendMsg\"*\n\x16\x43VirtualHereRequestMsg\x12\x10\n\x08hostname\x18\x01 \x01(\t\"5\n\x14\x43VirtualHereReadyMsg\x12\x1d\n\x15licensed_device_count\x18\x01 \x01(\r\"4\n\x1a\x43VirtualHereShareDeviceMsg\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\t\"\'\n\x14\x43SetSpectatorModeMsg\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"3\n\rCRemoteHIDMsg\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x14\n\x0c\x61\x63tive_input\x18\x02 \x01(\x08\"I\n\x15\x43TouchConfigActiveMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08revision\x18\x02 \x01(\r\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x04\"\'\n\x16\x43GetTouchConfigDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"h\n\x16\x43SetTouchConfigDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08revision\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x0e\n\x06layout\x18\x04 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x05 \x01(\x04\":\n\x19\x43SaveTouchConfigLayoutMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06layout\x18\x04 \x01(\x0c\"?\n\x18\x43TouchActionSetActiveMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"C\n\x1c\x43TouchActionSetLayerAddedMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"E\n\x1e\x43TouchActionSetLayerRemovedMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\"3\n\x14\x43GetTouchIconDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\"A\n\x14\x43SetTouchIconDataMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xea\x02\n!CRemotePlayTogetherGroupUpdateMsg\x12:\n\x07players\x18\x01 \x03(\x0b\x32).CRemotePlayTogetherGroupUpdateMsg.Player\x12\x14\n\x0cplayer_index\x18\x02 \x01(\x05\x12\x1c\n\x14miniprofile_location\x18\x03 \x01(\t\x12\x11\n\tgame_name\x18\x04 \x01(\t\x12\x17\n\x0f\x61vatar_location\x18\x05 \x01(\t\x1a\xa8\x01\n\x06Player\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0f\n\x07guestid\x18\x02 \x01(\r\x12\x18\n\x10keyboard_enabled\x18\x03 \x01(\x08\x12\x15\n\rmouse_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x63ontroller_enabled\x18\x05 \x01(\x08\x12\x18\n\x10\x63ontroller_slots\x18\x06 \x03(\r\x12\x13\n\x0b\x61vatar_hash\x18\x07 \x01(\x0c\"3\n\x1f\x43SetInputTemporarilyDisabledMsg\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\"\'\n\x16\x43SetQualityOverrideMsg\x12\r\n\x05value\x18\x01 \x01(\x05\"\'\n\x16\x43SetBitrateOverrideMsg\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1a\n\x18\x43ShowOnScreenKeyboardMsg\"%\n\x12\x43StreamDataLostMsg\x12\x0f\n\x07packets\x18\x01 \x03(\r\"f\n\x0c\x43\x41udioFormat\x12\x31\n\x06\x66ormat\x18\x01 \x02(\x0e\x32\r.EAudioFormat:\x12k_EAudioFormatNone\x12\x11\n\tfrequency\x18\x02 \x01(\r\x12\x10\n\x08\x63hannels\x18\x03 \x01(\r\"`\n\x0c\x43VideoFormat\x12\x31\n\x06\x66ormat\x18\x01 \x02(\x0e\x32\r.EVideoFormat:\x12k_EVideoFormatNone\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\"`\n\x0b\x43\x46rameEvent\x12>\n\x08\x65vent_id\x18\x01 \x02(\x0e\x32\x12.EStreamFrameEvent:\x18k_EStreamInputEventStart\x12\x11\n\ttimestamp\x18\x02 \x02(\r\"\xcf\x02\n\x0b\x43\x46rameStats\x12\x10\n\x08\x66rame_id\x18\x01 \x02(\r\x12\x12\n\ninput_mark\x18\x02 \x01(\r\x12\x1c\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x0c.CFrameEvent\x12@\n\x06result\x18\x04 \x02(\x0e\x32\x13.EStreamFrameResult:\x1bk_EStreamFrameResultPending\x12\x19\n\x11\x66rame_start_delta\x18\x05 \x01(\x02\x12\x1b\n\x13\x66rame_display_delta\x18\x06 \x01(\x02\x12\x11\n\tping_time\x18\x07 \x01(\x02\x12\x16\n\x0eserver_bitrate\x18\x08 \x01(\x02\x12\x16\n\x0e\x63lient_bitrate\x18\t \x01(\x02\x12\x16\n\x0elink_bandwidth\x18\n \x01(\x02\x12\x13\n\x0bpacket_loss\x18\x0b \x01(\x02\x12\x12\n\nframe_size\x18\x0c \x01(\r\"\x88\x01\n\x1a\x43\x46rameStatAccumulatedValue\x12:\n\tstat_type\x18\x01 \x02(\x0e\x32\x16.EFrameAccumulatedStat:\x0fk_EFrameStatFPS\x12\r\n\x05\x63ount\x18\x02 \x02(\x05\x12\x0f\n\x07\x61verage\x18\x03 \x02(\x02\x12\x0e\n\x06stddev\x18\x04 \x01(\x02\"\xc1\x01\n\x12\x43\x46rameStatsListMsg\x12=\n\tdata_type\x18\x01 \x02(\x0e\x32\x13.EStreamingDataType:\x15k_EStreamingAudioData\x12\x1b\n\x05stats\x18\x02 \x03(\x0b\x32\x0c.CFrameStats\x12\x36\n\x11\x61\x63\x63umulated_stats\x18\x03 \x03(\x0b\x32\x1b.CFrameStatAccumulatedValue\x12\x17\n\x0flatest_frame_id\x18\x04 \x02(\x05\"x\n\x16\x43StreamingSessionStats\x12\x1d\n\x15\x66rame_loss_percentage\x18\x01 \x01(\x02\x12\x1f\n\x17\x61verage_network_time_ms\x18\x02 \x01(\x02\x12\x1e\n\x16stddev_network_time_ms\x18\x03 \x01(\x02\"#\n\rCDebugDumpMsg\x12\x12\n\nscreenshot\x18\x01 \x01(\x0c\"(\n\x07\x43LogMsg\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"P\n\rCLogUploadMsg\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\r.ELogFileType:\x14k_ELogFileSystemBoot\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xb3\x02\n\x13\x43TransportSignalMsg\x12\x32\n\x06webrtc\x18\x01 \x01(\x0b\x32\".CTransportSignalMsg.WebRTCMessage\x12\x0b\n\x03sdr\x18\x02 \x03(\x0c\x1a\xda\x01\n\rWebRTCMessage\x12\x12\n\x08greeting\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05offer\x18\x02 \x01(\tH\x00\x12\x10\n\x06\x61nswer\x18\x03 \x01(\tH\x00\x12\x41\n\tcandidate\x18\x04 \x01(\x0b\x32,.CTransportSignalMsg.WebRTCMessage.CandidateH\x00\x1aH\n\tCandidate\x12\x0f\n\x07sdp_mid\x18\x01 \x01(\t\x12\x17\n\x0fsdp_mline_index\x18\x02 \x01(\x05\x12\x11\n\tcandidate\x18\x03 \x01(\tB\x05\n\x03msg\"\xde\x06\n\x14\x43\x43ontrollerConfigMsg\x12\\\n\x04type\x18\x01 \x02(\x0e\x32\x1b.EStreamControllerConfigMsg:1k_EStreamControllerConfigMsg_RequestConfigsForApp\x12\x16\n\x0e\x63ontrollerPath\x18\x02 \x01(\t\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12X\n\x17personalizationResponse\x18\x04 \x01(\x0b\x32\x37.CControllerConfigMsg.ControllerPersonalizationResponse\x12\x46\n\x0e\x63onfigResponse\x18\x06 \x03(\x0b\x32..CControllerConfigMsg.ControllerConfigResponse\x12N\n\x15\x61\x63tiveConfigChangeMsg\x18\x07 \x01(\x0b\x32/.CControllerConfigMsg.ControllerActiveConfigMsg\x1a\x99\x01\n\x18\x43ontrollerConfigResponse\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t\x12\x16\n\x0eselectionOrder\x18\x05 \x01(\r\x12\x13\n\x0b\x61\x63tionBlock\x18\x06 \x01(\x08\x1a@\n!ControllerPersonalizationResponse\x12\x1b\n\x13personalizationData\x18\x01 \x01(\t\x1a\x81\x01\n$ControllerActiveConfigChangeResponse\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t\x12\x16\n\x0eselectionOrder\x18\x05 \x01(\r\x1am\n\x19\x43ontrollerActiveConfigMsg\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tconfigURL\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontrollerType\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerData\x18\x04 \x01(\t*\xb3\x01\n\x0e\x45StreamChannel\x12$\n\x17k_EStreamChannelInvalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x19k_EStreamChannelDiscovery\x10\x00\x12\x1b\n\x17k_EStreamChannelControl\x10\x01\x12\x19\n\x15k_EStreamChannelStats\x10\x02\x12$\n k_EStreamChannelDataChannelStart\x10\x03*`\n\x17\x45StreamDiscoveryMessage\x12!\n\x1dk_EStreamDiscoveryPingRequest\x10\x01\x12\"\n\x1ek_EStreamDiscoveryPingResponse\x10\x02*\xb0\x1c\n\x15\x45StreamControlMessage\x12)\n%k_EStreamControlAuthenticationRequest\x10\x01\x12*\n&k_EStreamControlAuthenticationResponse\x10\x02\x12#\n\x1fk_EStreamControlNegotiationInit\x10\x03\x12(\n$k_EStreamControlNegotiationSetConfig\x10\x04\x12\'\n#k_EStreamControlNegotiationComplete\x10\x05\x12#\n\x1fk_EStreamControlClientHandshake\x10\x06\x12#\n\x1fk_EStreamControlServerHandshake\x10\x07\x12$\n k_EStreamControlStartNetworkTest\x10\x08\x12\x1d\n\x19k_EStreamControlKeepAlive\x10\t\x12\'\n#k_EStreamControl_LAST_SETUP_MESSAGE\x10\x0f\x12\"\n\x1ek_EStreamControlStartAudioData\x10\x32\x12!\n\x1dk_EStreamControlStopAudioData\x10\x33\x12\"\n\x1ek_EStreamControlStartVideoData\x10\x34\x12!\n\x1dk_EStreamControlStopVideoData\x10\x35\x12$\n k_EStreamControlInputMouseMotion\x10\x36\x12#\n\x1fk_EStreamControlInputMouseWheel\x10\x37\x12\"\n\x1ek_EStreamControlInputMouseDown\x10\x38\x12 \n\x1ck_EStreamControlInputMouseUp\x10\x39\x12 \n\x1ck_EStreamControlInputKeyDown\x10:\x12\x1e\n\x1ak_EStreamControlInputKeyUp\x10;\x12\x31\n-k_EStreamControlInputGamepadAttached_OBSOLETE\x10<\x12.\n*k_EStreamControlInputGamepadEvent_OBSOLETE\x10=\x12\x31\n-k_EStreamControlInputGamepadDetached_OBSOLETE\x10>\x12\x1e\n\x1ak_EStreamControlShowCursor\x10?\x12\x1e\n\x1ak_EStreamControlHideCursor\x10@\x12\x1d\n\x19k_EStreamControlSetCursor\x10\x41\x12\"\n\x1ek_EStreamControlGetCursorImage\x10\x42\x12\"\n\x1ek_EStreamControlSetCursorImage\x10\x43\x12 \n\x1ck_EStreamControlDeleteCursor\x10\x44\x12&\n\"k_EStreamControlSetTargetFramerate\x10\x45\x12$\n k_EStreamControlInputLatencyTest\x10\x46\x12*\n&k_EStreamControlGamepadRumble_OBSOLETE\x10G\x12\"\n\x1ek_EStreamControlOverlayEnabled\x10J\x12\x34\n0k_EStreamControlInputControllerAttached_OBSOLETE\x10K\x12\x31\n-k_EStreamControlInputControllerState_OBSOLETE\x10L\x12/\n+k_EStreamControlTriggerHapticPulse_OBSOLETE\x10M\x12\x34\n0k_EStreamControlInputControllerDetached_OBSOLETE\x10N\x12$\n k_EStreamControlVideoDecoderInfo\x10P\x12\x1c\n\x18k_EStreamControlSetTitle\x10Q\x12\x1b\n\x17k_EStreamControlSetIcon\x10R\x12\x1f\n\x1bk_EStreamControlQuitRequest\x10S\x12\x1a\n\x16k_EStreamControlSetQoS\x10W\x12<\n8k_EStreamControlInputControllerWirelessPresence_OBSOLETE\x10X\x12 \n\x1ck_EStreamControlSetGammaRamp\x10Y\x12$\n k_EStreamControlVideoEncoderInfo\x10Z\x12\x34\n0k_EStreamControlInputControllerStateHID_OBSOLETE\x10]\x12$\n k_EStreamControlSetTargetBitrate\x10^\x12\x38\n4k_EStreamControlSetControllerPairingEnabled_OBSOLETE\x10_\x12\x37\n3k_EStreamControlSetControllerPairingResult_OBSOLETE\x10`\x12\x38\n4k_EStreamControlTriggerControllerDisconnect_OBSOLETE\x10\x61\x12\x1f\n\x1bk_EStreamControlSetActivity\x10\x62\x12,\n(k_EStreamControlSetStreamingClientConfig\x10\x63\x12!\n\x1dk_EStreamControlSystemSuspend\x10\x64\x12\x32\n.k_EStreamControlSetControllerSettings_OBSOLETE\x10\x65\x12&\n\"k_EStreamControlVirtualHereRequest\x10\x66\x12$\n k_EStreamControlVirtualHereReady\x10g\x12*\n&k_EStreamControlVirtualHereShareDevice\x10h\x12$\n k_EStreamControlSetSpectatorMode\x10i\x12\x1d\n\x19k_EStreamControlRemoteHID\x10j\x12\'\n#k_EStreamControlStartMicrophoneData\x10k\x12&\n\"k_EStreamControlStopMicrophoneData\x10l\x12\x1d\n\x19k_EStreamControlInputText\x10m\x12%\n!k_EStreamControlTouchConfigActive\x10n\x12&\n\"k_EStreamControlGetTouchConfigData\x10o\x12&\n\"k_EStreamControlSetTouchConfigData\x10p\x12)\n%k_EStreamControlSaveTouchConfigLayout\x10q\x12(\n$k_EStreamControlTouchActionSetActive\x10r\x12$\n k_EStreamControlGetTouchIconData\x10s\x12$\n k_EStreamControlSetTouchIconData\x10t\x12(\n$k_EStreamControlInputTouchFingerDown\x10u\x12*\n&k_EStreamControlInputTouchFingerMotion\x10v\x12&\n\"k_EStreamControlInputTouchFingerUp\x10w\x12\"\n\x1ek_EStreamControlSetCaptureSize\x10x\x12!\n\x1dk_EStreamControlSetFlashState\x10y\x12\x19\n\x15k_EStreamControlPause\x10z\x12\x1a\n\x16k_EStreamControlResume\x10{\x12(\n$k_EStreamControlEnableHighResCapture\x10|\x12)\n%k_EStreamControlDisableHighResCapture\x10}\x12\'\n#k_EStreamControlToggleMagnification\x10~\x12\x1f\n\x1bk_EStreamControlSetCapslock\x10\x7f\x12\x1e\n\x19k_EStreamControlSetKeymap\x10\x80\x01\x12 \n\x1bk_EStreamControlStopRequest\x10\x81\x01\x12-\n(k_EStreamControlTouchActionSetLayerAdded\x10\x82\x01\x12/\n*k_EStreamControlTouchActionSetLayerRemoved\x10\x83\x01\x12\x32\n-k_EStreamControlRemotePlayTogetherGroupUpdate\x10\x84\x01\x12\x30\n+k_EStreamControlSetInputTemporarilyDisabled\x10\x85\x01\x12\'\n\"k_EStreamControlSetQualityOverride\x10\x86\x01\x12\'\n\"k_EStreamControlSetBitrateOverride\x10\x87\x01\x12)\n$k_EStreamControlShowOnScreenKeyboard\x10\x88\x01\x12(\n#k_EStreamControlControllerConfigMsg\x10\x89\x01*G\n\x0e\x45StreamVersion\x12\x18\n\x14k_EStreamVersionNone\x10\x00\x12\x1b\n\x17k_EStreamVersionCurrent\x10\x01*\xc0\x01\n\x11\x45StreamAudioCodec\x12\x1b\n\x17k_EStreamAudioCodecNone\x10\x00\x12\x1a\n\x16k_EStreamAudioCodecRaw\x10\x01\x12\x1d\n\x19k_EStreamAudioCodecVorbis\x10\x02\x12\x1b\n\x17k_EStreamAudioCodecOpus\x10\x03\x12\x1a\n\x16k_EStreamAudioCodecMP3\x10\x04\x12\x1a\n\x16k_EStreamAudioCodecAAC\x10\x05*\xfa\x01\n\x11\x45StreamVideoCodec\x12\x1b\n\x17k_EStreamVideoCodecNone\x10\x00\x12\x1a\n\x16k_EStreamVideoCodecRaw\x10\x01\x12\x1a\n\x16k_EStreamVideoCodecVP8\x10\x02\x12\x1a\n\x16k_EStreamVideoCodecVP9\x10\x03\x12\x1b\n\x17k_EStreamVideoCodecH264\x10\x04\x12\x1b\n\x17k_EStreamVideoCodecHEVC\x10\x05\x12\x1c\n\x18k_EStreamVideoCodecORBX1\x10\x06\x12\x1c\n\x18k_EStreamVideoCodecORBX2\x10\x07*\x99\x01\n\x18\x45StreamQualityPreference\x12&\n\x19k_EStreamQualityAutomatic\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x14k_EStreamQualityFast\x10\x01\x12\x1c\n\x18k_EStreamQualityBalanced\x10\x02\x12\x1d\n\x19k_EStreamQualityBeautiful\x10\x03*X\n\x0e\x45StreamBitrate\x12\'\n\x1ak_EStreamBitrateAutodetect\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x19k_EStreamBitrateUnlimited\x10\x00*\xba\x01\n\x11\x45StreamColorspace\x12\x1f\n\x1bk_EStreamColorspace_Unknown\x10\x00\x12\x1d\n\x19k_EStreamColorspace_BT601\x10\x01\x12\"\n\x1ek_EStreamColorspace_BT601_Full\x10\x02\x12\x1d\n\x19k_EStreamColorspace_BT709\x10\x03\x12\"\n\x1ek_EStreamColorspace_BT709_Full\x10\x04*\xaa\x01\n\x0f\x45StreamP2PScope\x12\x1e\n\x1ak_EStreamP2PScopeAutomatic\x10\x00\x12\x1d\n\x19k_EStreamP2PScopeDisabled\x10\x01\x12\x1b\n\x17k_EStreamP2PScopeOnlyMe\x10\x02\x12\x1c\n\x18k_EStreamP2PScopeFriends\x10\x03\x12\x1d\n\x19k_EStreamP2PScopeEveryone\x10\x04*e\n\x1e\x45StreamHostPlayAudioPreference\x12!\n\x1dk_EStreamHostPlayAudioDefault\x10\x00\x12 \n\x1ck_EStreamHostPlayAudioAlways\x10\x01*j\n\x12\x45StreamingDataType\x12\x19\n\x15k_EStreamingAudioData\x10\x00\x12\x19\n\x15k_EStreamingVideoData\x10\x01\x12\x1e\n\x1ak_EStreamingMicrophoneData\x10\x02*\xcb\x01\n\x12\x45StreamMouseButton\x12\x1c\n\x18k_EStreamMouseButtonLeft\x10\x01\x12\x1d\n\x19k_EStreamMouseButtonRight\x10\x02\x12\x1e\n\x1ak_EStreamMouseButtonMiddle\x10\x10\x12\x1a\n\x16k_EStreamMouseButtonX1\x10 \x12\x1a\n\x16k_EStreamMouseButtonX2\x10@\x12 \n\x1bk_EStreamMouseButtonUnknown\x10\x80 *\x98\x01\n\x1a\x45StreamMouseWheelDirection\x12\x19\n\x15k_EStreamMouseWheelUp\x10x\x12$\n\x17k_EStreamMouseWheelDown\x10\x88\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1b\n\x17k_EStreamMouseWheelLeft\x10\x03\x12\x1c\n\x18k_EStreamMouseWheelRight\x10\x04*\x89\x02\n\x17\x45StreamFramerateLimiter\x12!\n\x1dk_EStreamFramerateSlowCapture\x10\x01\x12!\n\x1dk_EStreamFramerateSlowConvert\x10\x02\x12 \n\x1ck_EStreamFramerateSlowEncode\x10\x04\x12!\n\x1dk_EStreamFramerateSlowNetwork\x10\x08\x12 \n\x1ck_EStreamFramerateSlowDecode\x10\x10\x12\x1e\n\x1ak_EStreamFramerateSlowGame\x10 \x12!\n\x1dk_EStreamFramerateSlowDisplay\x10@*\xa5\x01\n\x0f\x45StreamActivity\x12\x19\n\x15k_EStreamActivityIdle\x10\x01\x12\x19\n\x15k_EStreamActivityGame\x10\x02\x12\x1c\n\x18k_EStreamActivityDesktop\x10\x03\x12\"\n\x1ek_EStreamActivitySecureDesktop\x10\x04\x12\x1a\n\x16k_EStreamActivityMusic\x10\x05*D\n\x12\x45StreamDataMessage\x12\x17\n\x13k_EStreamDataPacket\x10\x01\x12\x15\n\x11k_EStreamDataLost\x10\x02*d\n\x0c\x45\x41udioFormat\x12\x16\n\x12k_EAudioFormatNone\x10\x00\x12#\n\x1fk_EAudioFormat16BitLittleEndian\x10\x01\x12\x17\n\x13k_EAudioFormatFloat\x10\x02*W\n\x0c\x45VideoFormat\x12\x16\n\x12k_EVideoFormatNone\x10\x00\x12\x16\n\x12k_EVideoFormatYV12\x10\x01\x12\x17\n\x13k_EVideoFormatAccel\x10\x02*\xd7\x01\n\x13\x45StreamStatsMessage\x12\x1d\n\x19k_EStreamStatsFrameEvents\x10\x01\x12\x1b\n\x17k_EStreamStatsDebugDump\x10\x02\x12\x1c\n\x18k_EStreamStatsLogMessage\x10\x03\x12 \n\x1ck_EStreamStatsLogUploadBegin\x10\x04\x12\x1f\n\x1bk_EStreamStatsLogUploadData\x10\x05\x12#\n\x1fk_EStreamStatsLogUploadComplete\x10\x06*\x85\x05\n\x11\x45StreamFrameEvent\x12\x1c\n\x18k_EStreamInputEventStart\x10\x00\x12\x1b\n\x17k_EStreamInputEventSend\x10\x01\x12\x1b\n\x17k_EStreamInputEventRecv\x10\x02\x12\x1d\n\x19k_EStreamInputEventQueued\x10\x03\x12\x1e\n\x1ak_EStreamInputEventHandled\x10\x04\x12\x1c\n\x18k_EStreamFrameEventStart\x10\x05\x12#\n\x1fk_EStreamFrameEventCaptureBegin\x10\x06\x12!\n\x1dk_EStreamFrameEventCaptureEnd\x10\x07\x12#\n\x1fk_EStreamFrameEventConvertBegin\x10\x08\x12!\n\x1dk_EStreamFrameEventConvertEnd\x10\t\x12\"\n\x1ek_EStreamFrameEventEncodeBegin\x10\n\x12 \n\x1ck_EStreamFrameEventEncodeEnd\x10\x0b\x12\x1b\n\x17k_EStreamFrameEventSend\x10\x0c\x12\x1b\n\x17k_EStreamFrameEventRecv\x10\r\x12\"\n\x1ek_EStreamFrameEventDecodeBegin\x10\x0e\x12 \n\x1ck_EStreamFrameEventDecodeEnd\x10\x0f\x12\"\n\x1ek_EStreamFrameEventUploadBegin\x10\x10\x12 \n\x1ck_EStreamFrameEventUploadEnd\x10\x11\x12\x1f\n\x1bk_EStreamFrameEventComplete\x10\x12*\xd4\x02\n\x12\x45StreamFrameResult\x12\x1f\n\x1bk_EStreamFrameResultPending\x10\x00\x12!\n\x1dk_EStreamFrameResultDisplayed\x10\x01\x12*\n&k_EStreamFrameResultDroppedNetworkSlow\x10\x02\x12*\n&k_EStreamFrameResultDroppedNetworkLost\x10\x03\x12)\n%k_EStreamFrameResultDroppedDecodeSlow\x10\x04\x12,\n(k_EStreamFrameResultDroppedDecodeCorrupt\x10\x05\x12#\n\x1fk_EStreamFrameResultDroppedLate\x10\x06\x12$\n k_EStreamFrameResultDroppedReset\x10\x07*\xa2\x05\n\x15\x45\x46rameAccumulatedStat\x12\x13\n\x0fk_EFrameStatFPS\x10\x00\x12!\n\x1dk_EFrameStatCaptureDurationMS\x10\x01\x12!\n\x1dk_EFrameStatConvertDurationMS\x10\x02\x12 \n\x1ck_EFrameStatEncodeDurationMS\x10\x03\x12\x1f\n\x1bk_EFrameStatSteamDurationMS\x10\x04\x12 \n\x1ck_EFrameStatServerDurationMS\x10\x05\x12!\n\x1dk_EFrameStatNetworkDurationMS\x10\x06\x12 \n\x1ck_EFrameStatDecodeDurationMS\x10\x07\x12!\n\x1dk_EFrameStatDisplayDurationMS\x10\x08\x12 \n\x1ck_EFrameStatClientDurationMS\x10\t\x12\x1f\n\x1bk_EFrameStatFrameDurationMS\x10\n\x12\x1e\n\x1ak_EFrameStatInputLatencyMS\x10\x0b\x12\x1d\n\x19k_EFrameStatGameLatencyMS\x10\x0c\x12\"\n\x1ek_EFrameStatRoundTripLatencyMS\x10\r\x12\x1a\n\x16k_EFrameStatPingTimeMS\x10\x0e\x12\'\n#k_EFrameStatServerBitrateKbitPerSec\x10\x0f\x12\'\n#k_EFrameStatClientBitrateKbitPerSec\x10\x10\x12\'\n#k_EFrameStatLinkBandwidthKbitPerSec\x10\x11\x12$\n k_EFrameStatPacketLossPercentage\x10\x12*^\n\x0c\x45LogFileType\x12\x18\n\x14k_ELogFileSystemBoot\x10\x00\x12\x19\n\x15k_ELogFileSystemReset\x10\x01\x12\x19\n\x15k_ELogFileSystemDebug\x10\x02*\xa9\x02\n\x1a\x45StreamControllerConfigMsg\x12\x35\n1k_EStreamControllerConfigMsg_RequestConfigsForApp\x10\x00\x12/\n+k_EStreamControllerConfigMsg_ConfigResponse\x10\x01\x12\x38\n4k_EStreamControllerConfigMsg_PersonalizationResponse\x10\x02\x12\x33\n/k_EStreamControllerConfigMsg_ActiveConfigChange\x10\x03\x12\x34\n0k_EStreamControllerConfigMsg_RequestActiveConfig\x10\x04\x42\x05H\x01\x90\x01\x00'
)

_ESTREAMCHANNEL = _descriptor.EnumDescriptor(
  name='EStreamChannel',
  full_name='EStreamChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamChannelInvalid', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamChannelDiscovery', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamChannelControl', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamChannelStats', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamChannelDataChannelStart', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10921,
  serialized_end=11100,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMCHANNEL)

EStreamChannel = enum_type_wrapper.EnumTypeWrapper(_ESTREAMCHANNEL)
_ESTREAMDISCOVERYMESSAGE = _descriptor.EnumDescriptor(
  name='EStreamDiscoveryMessage',
  full_name='EStreamDiscoveryMessage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamDiscoveryPingRequest', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamDiscoveryPingResponse', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11102,
  serialized_end=11198,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMDISCOVERYMESSAGE)

EStreamDiscoveryMessage = enum_type_wrapper.EnumTypeWrapper(_ESTREAMDISCOVERYMESSAGE)
_ESTREAMCONTROLMESSAGE = _descriptor.EnumDescriptor(
  name='EStreamControlMessage',
  full_name='EStreamControlMessage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlAuthenticationRequest', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlAuthenticationResponse', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlNegotiationInit', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlNegotiationSetConfig', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlNegotiationComplete', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlClientHandshake', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlServerHandshake', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStartNetworkTest', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlKeepAlive', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControl_LAST_SETUP_MESSAGE', index=9, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStartAudioData', index=10, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStopAudioData', index=11, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStartVideoData', index=12, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStopVideoData', index=13, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputMouseMotion', index=14, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputMouseWheel', index=15, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputMouseDown', index=16, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputMouseUp', index=17, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputKeyDown', index=18, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputKeyUp', index=19, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputGamepadAttached_OBSOLETE', index=20, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputGamepadEvent_OBSOLETE', index=21, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputGamepadDetached_OBSOLETE', index=22, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlShowCursor', index=23, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlHideCursor', index=24, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetCursor', index=25, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlGetCursorImage', index=26, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetCursorImage', index=27, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlDeleteCursor', index=28, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetTargetFramerate', index=29, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputLatencyTest', index=30, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlGamepadRumble_OBSOLETE', index=31, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlOverlayEnabled', index=32, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputControllerAttached_OBSOLETE', index=33, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputControllerState_OBSOLETE', index=34, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTriggerHapticPulse_OBSOLETE', index=35, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputControllerDetached_OBSOLETE', index=36, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlVideoDecoderInfo', index=37, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetTitle', index=38, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetIcon', index=39, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlQuitRequest', index=40, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetQoS', index=41, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputControllerWirelessPresence_OBSOLETE', index=42, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetGammaRamp', index=43, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlVideoEncoderInfo', index=44, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputControllerStateHID_OBSOLETE', index=45, number=93,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetTargetBitrate', index=46, number=94,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetControllerPairingEnabled_OBSOLETE', index=47, number=95,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetControllerPairingResult_OBSOLETE', index=48, number=96,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTriggerControllerDisconnect_OBSOLETE', index=49, number=97,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetActivity', index=50, number=98,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetStreamingClientConfig', index=51, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSystemSuspend', index=52, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetControllerSettings_OBSOLETE', index=53, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlVirtualHereRequest', index=54, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlVirtualHereReady', index=55, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlVirtualHereShareDevice', index=56, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetSpectatorMode', index=57, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlRemoteHID', index=58, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStartMicrophoneData', index=59, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStopMicrophoneData', index=60, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputText', index=61, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTouchConfigActive', index=62, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlGetTouchConfigData', index=63, number=111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetTouchConfigData', index=64, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSaveTouchConfigLayout', index=65, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTouchActionSetActive', index=66, number=114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlGetTouchIconData', index=67, number=115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetTouchIconData', index=68, number=116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputTouchFingerDown', index=69, number=117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputTouchFingerMotion', index=70, number=118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlInputTouchFingerUp', index=71, number=119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetCaptureSize', index=72, number=120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetFlashState', index=73, number=121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlPause', index=74, number=122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlResume', index=75, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlEnableHighResCapture', index=76, number=124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlDisableHighResCapture', index=77, number=125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlToggleMagnification', index=78, number=126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetCapslock', index=79, number=127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetKeymap', index=80, number=128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlStopRequest', index=81, number=129,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTouchActionSetLayerAdded', index=82, number=130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlTouchActionSetLayerRemoved', index=83, number=131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlRemotePlayTogetherGroupUpdate', index=84, number=132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetInputTemporarilyDisabled', index=85, number=133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetQualityOverride', index=86, number=134,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlSetBitrateOverride', index=87, number=135,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlShowOnScreenKeyboard', index=88, number=136,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControlControllerConfigMsg', index=89, number=137,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11201,
  serialized_end=14833,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMCONTROLMESSAGE)

EStreamControlMessage = enum_type_wrapper.EnumTypeWrapper(_ESTREAMCONTROLMESSAGE)
_ESTREAMVERSION = _descriptor.EnumDescriptor(
  name='EStreamVersion',
  full_name='EStreamVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVersionNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVersionCurrent', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14835,
  serialized_end=14906,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMVERSION)

EStreamVersion = enum_type_wrapper.EnumTypeWrapper(_ESTREAMVERSION)
_ESTREAMAUDIOCODEC = _descriptor.EnumDescriptor(
  name='EStreamAudioCodec',
  full_name='EStreamAudioCodec',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecRaw', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecVorbis', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecOpus', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecMP3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamAudioCodecAAC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14909,
  serialized_end=15101,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMAUDIOCODEC)

EStreamAudioCodec = enum_type_wrapper.EnumTypeWrapper(_ESTREAMAUDIOCODEC)
_ESTREAMVIDEOCODEC = _descriptor.EnumDescriptor(
  name='EStreamVideoCodec',
  full_name='EStreamVideoCodec',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecRaw', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecVP8', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecVP9', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecH264', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecHEVC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecORBX1', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamVideoCodecORBX2', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15104,
  serialized_end=15354,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMVIDEOCODEC)

EStreamVideoCodec = enum_type_wrapper.EnumTypeWrapper(_ESTREAMVIDEOCODEC)
_ESTREAMQUALITYPREFERENCE = _descriptor.EnumDescriptor(
  name='EStreamQualityPreference',
  full_name='EStreamQualityPreference',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamQualityAutomatic', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamQualityFast', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamQualityBalanced', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamQualityBeautiful', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15357,
  serialized_end=15510,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMQUALITYPREFERENCE)

EStreamQualityPreference = enum_type_wrapper.EnumTypeWrapper(_ESTREAMQUALITYPREFERENCE)
_ESTREAMBITRATE = _descriptor.EnumDescriptor(
  name='EStreamBitrate',
  full_name='EStreamBitrate',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamBitrateAutodetect', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamBitrateUnlimited', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15512,
  serialized_end=15600,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMBITRATE)

EStreamBitrate = enum_type_wrapper.EnumTypeWrapper(_ESTREAMBITRATE)
_ESTREAMCOLORSPACE = _descriptor.EnumDescriptor(
  name='EStreamColorspace',
  full_name='EStreamColorspace',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamColorspace_Unknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamColorspace_BT601', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamColorspace_BT601_Full', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamColorspace_BT709', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamColorspace_BT709_Full', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15603,
  serialized_end=15789,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMCOLORSPACE)

EStreamColorspace = enum_type_wrapper.EnumTypeWrapper(_ESTREAMCOLORSPACE)
_ESTREAMP2PSCOPE = _descriptor.EnumDescriptor(
  name='EStreamP2PScope',
  full_name='EStreamP2PScope',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamP2PScopeAutomatic', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamP2PScopeDisabled', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamP2PScopeOnlyMe', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamP2PScopeFriends', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamP2PScopeEveryone', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15792,
  serialized_end=15962,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMP2PSCOPE)

EStreamP2PScope = enum_type_wrapper.EnumTypeWrapper(_ESTREAMP2PSCOPE)
_ESTREAMHOSTPLAYAUDIOPREFERENCE = _descriptor.EnumDescriptor(
  name='EStreamHostPlayAudioPreference',
  full_name='EStreamHostPlayAudioPreference',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamHostPlayAudioDefault', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamHostPlayAudioAlways', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15964,
  serialized_end=16065,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMHOSTPLAYAUDIOPREFERENCE)

EStreamHostPlayAudioPreference = enum_type_wrapper.EnumTypeWrapper(_ESTREAMHOSTPLAYAUDIOPREFERENCE)
_ESTREAMINGDATATYPE = _descriptor.EnumDescriptor(
  name='EStreamingDataType',
  full_name='EStreamingDataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamingAudioData', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamingVideoData', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamingMicrophoneData', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16067,
  serialized_end=16173,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMINGDATATYPE)

EStreamingDataType = enum_type_wrapper.EnumTypeWrapper(_ESTREAMINGDATATYPE)
_ESTREAMMOUSEBUTTON = _descriptor.EnumDescriptor(
  name='EStreamMouseButton',
  full_name='EStreamMouseButton',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonLeft', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonRight', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonMiddle', index=2, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonX1', index=3, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonX2', index=4, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseButtonUnknown', index=5, number=4096,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16176,
  serialized_end=16379,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMMOUSEBUTTON)

EStreamMouseButton = enum_type_wrapper.EnumTypeWrapper(_ESTREAMMOUSEBUTTON)
_ESTREAMMOUSEWHEELDIRECTION = _descriptor.EnumDescriptor(
  name='EStreamMouseWheelDirection',
  full_name='EStreamMouseWheelDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseWheelUp', index=0, number=120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseWheelDown', index=1, number=-120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseWheelLeft', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamMouseWheelRight', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16382,
  serialized_end=16534,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMMOUSEWHEELDIRECTION)

EStreamMouseWheelDirection = enum_type_wrapper.EnumTypeWrapper(_ESTREAMMOUSEWHEELDIRECTION)
_ESTREAMFRAMERATELIMITER = _descriptor.EnumDescriptor(
  name='EStreamFramerateLimiter',
  full_name='EStreamFramerateLimiter',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowCapture', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowConvert', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowEncode', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowNetwork', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowDecode', index=4, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowGame', index=5, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFramerateSlowDisplay', index=6, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16537,
  serialized_end=16802,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMFRAMERATELIMITER)

EStreamFramerateLimiter = enum_type_wrapper.EnumTypeWrapper(_ESTREAMFRAMERATELIMITER)
_ESTREAMACTIVITY = _descriptor.EnumDescriptor(
  name='EStreamActivity',
  full_name='EStreamActivity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamActivityIdle', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamActivityGame', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamActivityDesktop', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamActivitySecureDesktop', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamActivityMusic', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16805,
  serialized_end=16970,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMACTIVITY)

EStreamActivity = enum_type_wrapper.EnumTypeWrapper(_ESTREAMACTIVITY)
_ESTREAMDATAMESSAGE = _descriptor.EnumDescriptor(
  name='EStreamDataMessage',
  full_name='EStreamDataMessage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamDataPacket', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamDataLost', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16972,
  serialized_end=17040,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMDATAMESSAGE)

EStreamDataMessage = enum_type_wrapper.EnumTypeWrapper(_ESTREAMDATAMESSAGE)
_EAUDIOFORMAT = _descriptor.EnumDescriptor(
  name='EAudioFormat',
  full_name='EAudioFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EAudioFormatNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EAudioFormat16BitLittleEndian', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EAudioFormatFloat', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17042,
  serialized_end=17142,
)
_sym_db.RegisterEnumDescriptor(_EAUDIOFORMAT)

EAudioFormat = enum_type_wrapper.EnumTypeWrapper(_EAUDIOFORMAT)
_EVIDEOFORMAT = _descriptor.EnumDescriptor(
  name='EVideoFormat',
  full_name='EVideoFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EVideoFormatNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EVideoFormatYV12', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EVideoFormatAccel', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17144,
  serialized_end=17231,
)
_sym_db.RegisterEnumDescriptor(_EVIDEOFORMAT)

EVideoFormat = enum_type_wrapper.EnumTypeWrapper(_EVIDEOFORMAT)
_ESTREAMSTATSMESSAGE = _descriptor.EnumDescriptor(
  name='EStreamStatsMessage',
  full_name='EStreamStatsMessage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsFrameEvents', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsDebugDump', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsLogMessage', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsLogUploadBegin', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsLogUploadData', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamStatsLogUploadComplete', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17234,
  serialized_end=17449,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMSTATSMESSAGE)

EStreamStatsMessage = enum_type_wrapper.EnumTypeWrapper(_ESTREAMSTATSMESSAGE)
_ESTREAMFRAMEEVENT = _descriptor.EnumDescriptor(
  name='EStreamFrameEvent',
  full_name='EStreamFrameEvent',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamInputEventStart', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamInputEventSend', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamInputEventRecv', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamInputEventQueued', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamInputEventHandled', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventStart', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventCaptureBegin', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventCaptureEnd', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventConvertBegin', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventConvertEnd', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventEncodeBegin', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventEncodeEnd', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventSend', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventRecv', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventDecodeBegin', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventDecodeEnd', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventUploadBegin', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventUploadEnd', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameEventComplete', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17452,
  serialized_end=18097,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMFRAMEEVENT)

EStreamFrameEvent = enum_type_wrapper.EnumTypeWrapper(_ESTREAMFRAMEEVENT)
_ESTREAMFRAMERESULT = _descriptor.EnumDescriptor(
  name='EStreamFrameResult',
  full_name='EStreamFrameResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultPending', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDisplayed', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedNetworkSlow', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedNetworkLost', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedDecodeSlow', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedDecodeCorrupt', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedLate', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamFrameResultDroppedReset', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18100,
  serialized_end=18440,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMFRAMERESULT)

EStreamFrameResult = enum_type_wrapper.EnumTypeWrapper(_ESTREAMFRAMERESULT)
_EFRAMEACCUMULATEDSTAT = _descriptor.EnumDescriptor(
  name='EFrameAccumulatedStat',
  full_name='EFrameAccumulatedStat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatFPS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatCaptureDurationMS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatConvertDurationMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatEncodeDurationMS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatSteamDurationMS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatServerDurationMS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatNetworkDurationMS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatDecodeDurationMS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatDisplayDurationMS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatClientDurationMS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatFrameDurationMS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatInputLatencyMS', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatGameLatencyMS', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatRoundTripLatencyMS', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatPingTimeMS', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatServerBitrateKbitPerSec', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatClientBitrateKbitPerSec', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatLinkBandwidthKbitPerSec', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EFrameStatPacketLossPercentage', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18443,
  serialized_end=19117,
)
_sym_db.RegisterEnumDescriptor(_EFRAMEACCUMULATEDSTAT)

EFrameAccumulatedStat = enum_type_wrapper.EnumTypeWrapper(_EFRAMEACCUMULATEDSTAT)
_ELOGFILETYPE = _descriptor.EnumDescriptor(
  name='ELogFileType',
  full_name='ELogFileType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ELogFileSystemBoot', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ELogFileSystemReset', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ELogFileSystemDebug', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19119,
  serialized_end=19213,
)
_sym_db.RegisterEnumDescriptor(_ELOGFILETYPE)

ELogFileType = enum_type_wrapper.EnumTypeWrapper(_ELOGFILETYPE)
_ESTREAMCONTROLLERCONFIGMSG = _descriptor.EnumDescriptor(
  name='EStreamControllerConfigMsg',
  full_name='EStreamControllerConfigMsg',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControllerConfigMsg_RequestConfigsForApp', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControllerConfigMsg_ConfigResponse', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControllerConfigMsg_PersonalizationResponse', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControllerConfigMsg_ActiveConfigChange', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EStreamControllerConfigMsg_RequestActiveConfig', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19216,
  serialized_end=19513,
)
_sym_db.RegisterEnumDescriptor(_ESTREAMCONTROLLERCONFIGMSG)

EStreamControllerConfigMsg = enum_type_wrapper.EnumTypeWrapper(_ESTREAMCONTROLLERCONFIGMSG)
k_EStreamChannelInvalid = -1
k_EStreamChannelDiscovery = 0
k_EStreamChannelControl = 1
k_EStreamChannelStats = 2
k_EStreamChannelDataChannelStart = 3
k_EStreamDiscoveryPingRequest = 1
k_EStreamDiscoveryPingResponse = 2
k_EStreamControlAuthenticationRequest = 1
k_EStreamControlAuthenticationResponse = 2
k_EStreamControlNegotiationInit = 3
k_EStreamControlNegotiationSetConfig = 4
k_EStreamControlNegotiationComplete = 5
k_EStreamControlClientHandshake = 6
k_EStreamControlServerHandshake = 7
k_EStreamControlStartNetworkTest = 8
k_EStreamControlKeepAlive = 9
k_EStreamControl_LAST_SETUP_MESSAGE = 15
k_EStreamControlStartAudioData = 50
k_EStreamControlStopAudioData = 51
k_EStreamControlStartVideoData = 52
k_EStreamControlStopVideoData = 53
k_EStreamControlInputMouseMotion = 54
k_EStreamControlInputMouseWheel = 55
k_EStreamControlInputMouseDown = 56
k_EStreamControlInputMouseUp = 57
k_EStreamControlInputKeyDown = 58
k_EStreamControlInputKeyUp = 59
k_EStreamControlInputGamepadAttached_OBSOLETE = 60
k_EStreamControlInputGamepadEvent_OBSOLETE = 61
k_EStreamControlInputGamepadDetached_OBSOLETE = 62
k_EStreamControlShowCursor = 63
k_EStreamControlHideCursor = 64
k_EStreamControlSetCursor = 65
k_EStreamControlGetCursorImage = 66
k_EStreamControlSetCursorImage = 67
k_EStreamControlDeleteCursor = 68
k_EStreamControlSetTargetFramerate = 69
k_EStreamControlInputLatencyTest = 70
k_EStreamControlGamepadRumble_OBSOLETE = 71
k_EStreamControlOverlayEnabled = 74
k_EStreamControlInputControllerAttached_OBSOLETE = 75
k_EStreamControlInputControllerState_OBSOLETE = 76
k_EStreamControlTriggerHapticPulse_OBSOLETE = 77
k_EStreamControlInputControllerDetached_OBSOLETE = 78
k_EStreamControlVideoDecoderInfo = 80
k_EStreamControlSetTitle = 81
k_EStreamControlSetIcon = 82
k_EStreamControlQuitRequest = 83
k_EStreamControlSetQoS = 87
k_EStreamControlInputControllerWirelessPresence_OBSOLETE = 88
k_EStreamControlSetGammaRamp = 89
k_EStreamControlVideoEncoderInfo = 90
k_EStreamControlInputControllerStateHID_OBSOLETE = 93
k_EStreamControlSetTargetBitrate = 94
k_EStreamControlSetControllerPairingEnabled_OBSOLETE = 95
k_EStreamControlSetControllerPairingResult_OBSOLETE = 96
k_EStreamControlTriggerControllerDisconnect_OBSOLETE = 97
k_EStreamControlSetActivity = 98
k_EStreamControlSetStreamingClientConfig = 99
k_EStreamControlSystemSuspend = 100
k_EStreamControlSetControllerSettings_OBSOLETE = 101
k_EStreamControlVirtualHereRequest = 102
k_EStreamControlVirtualHereReady = 103
k_EStreamControlVirtualHereShareDevice = 104
k_EStreamControlSetSpectatorMode = 105
k_EStreamControlRemoteHID = 106
k_EStreamControlStartMicrophoneData = 107
k_EStreamControlStopMicrophoneData = 108
k_EStreamControlInputText = 109
k_EStreamControlTouchConfigActive = 110
k_EStreamControlGetTouchConfigData = 111
k_EStreamControlSetTouchConfigData = 112
k_EStreamControlSaveTouchConfigLayout = 113
k_EStreamControlTouchActionSetActive = 114
k_EStreamControlGetTouchIconData = 115
k_EStreamControlSetTouchIconData = 116
k_EStreamControlInputTouchFingerDown = 117
k_EStreamControlInputTouchFingerMotion = 118
k_EStreamControlInputTouchFingerUp = 119
k_EStreamControlSetCaptureSize = 120
k_EStreamControlSetFlashState = 121
k_EStreamControlPause = 122
k_EStreamControlResume = 123
k_EStreamControlEnableHighResCapture = 124
k_EStreamControlDisableHighResCapture = 125
k_EStreamControlToggleMagnification = 126
k_EStreamControlSetCapslock = 127
k_EStreamControlSetKeymap = 128
k_EStreamControlStopRequest = 129
k_EStreamControlTouchActionSetLayerAdded = 130
k_EStreamControlTouchActionSetLayerRemoved = 131
k_EStreamControlRemotePlayTogetherGroupUpdate = 132
k_EStreamControlSetInputTemporarilyDisabled = 133
k_EStreamControlSetQualityOverride = 134
k_EStreamControlSetBitrateOverride = 135
k_EStreamControlShowOnScreenKeyboard = 136
k_EStreamControlControllerConfigMsg = 137
k_EStreamVersionNone = 0
k_EStreamVersionCurrent = 1
k_EStreamAudioCodecNone = 0
k_EStreamAudioCodecRaw = 1
k_EStreamAudioCodecVorbis = 2
k_EStreamAudioCodecOpus = 3
k_EStreamAudioCodecMP3 = 4
k_EStreamAudioCodecAAC = 5
k_EStreamVideoCodecNone = 0
k_EStreamVideoCodecRaw = 1
k_EStreamVideoCodecVP8 = 2
k_EStreamVideoCodecVP9 = 3
k_EStreamVideoCodecH264 = 4
k_EStreamVideoCodecHEVC = 5
k_EStreamVideoCodecORBX1 = 6
k_EStreamVideoCodecORBX2 = 7
k_EStreamQualityAutomatic = -1
k_EStreamQualityFast = 1
k_EStreamQualityBalanced = 2
k_EStreamQualityBeautiful = 3
k_EStreamBitrateAutodetect = -1
k_EStreamBitrateUnlimited = 0
k_EStreamColorspace_Unknown = 0
k_EStreamColorspace_BT601 = 1
k_EStreamColorspace_BT601_Full = 2
k_EStreamColorspace_BT709 = 3
k_EStreamColorspace_BT709_Full = 4
k_EStreamP2PScopeAutomatic = 0
k_EStreamP2PScopeDisabled = 1
k_EStreamP2PScopeOnlyMe = 2
k_EStreamP2PScopeFriends = 3
k_EStreamP2PScopeEveryone = 4
k_EStreamHostPlayAudioDefault = 0
k_EStreamHostPlayAudioAlways = 1
k_EStreamingAudioData = 0
k_EStreamingVideoData = 1
k_EStreamingMicrophoneData = 2
k_EStreamMouseButtonLeft = 1
k_EStreamMouseButtonRight = 2
k_EStreamMouseButtonMiddle = 16
k_EStreamMouseButtonX1 = 32
k_EStreamMouseButtonX2 = 64
k_EStreamMouseButtonUnknown = 4096
k_EStreamMouseWheelUp = 120
k_EStreamMouseWheelDown = -120
k_EStreamMouseWheelLeft = 3
k_EStreamMouseWheelRight = 4
k_EStreamFramerateSlowCapture = 1
k_EStreamFramerateSlowConvert = 2
k_EStreamFramerateSlowEncode = 4
k_EStreamFramerateSlowNetwork = 8
k_EStreamFramerateSlowDecode = 16
k_EStreamFramerateSlowGame = 32
k_EStreamFramerateSlowDisplay = 64
k_EStreamActivityIdle = 1
k_EStreamActivityGame = 2
k_EStreamActivityDesktop = 3
k_EStreamActivitySecureDesktop = 4
k_EStreamActivityMusic = 5
k_EStreamDataPacket = 1
k_EStreamDataLost = 2
k_EAudioFormatNone = 0
k_EAudioFormat16BitLittleEndian = 1
k_EAudioFormatFloat = 2
k_EVideoFormatNone = 0
k_EVideoFormatYV12 = 1
k_EVideoFormatAccel = 2
k_EStreamStatsFrameEvents = 1
k_EStreamStatsDebugDump = 2
k_EStreamStatsLogMessage = 3
k_EStreamStatsLogUploadBegin = 4
k_EStreamStatsLogUploadData = 5
k_EStreamStatsLogUploadComplete = 6
k_EStreamInputEventStart = 0
k_EStreamInputEventSend = 1
k_EStreamInputEventRecv = 2
k_EStreamInputEventQueued = 3
k_EStreamInputEventHandled = 4
k_EStreamFrameEventStart = 5
k_EStreamFrameEventCaptureBegin = 6
k_EStreamFrameEventCaptureEnd = 7
k_EStreamFrameEventConvertBegin = 8
k_EStreamFrameEventConvertEnd = 9
k_EStreamFrameEventEncodeBegin = 10
k_EStreamFrameEventEncodeEnd = 11
k_EStreamFrameEventSend = 12
k_EStreamFrameEventRecv = 13
k_EStreamFrameEventDecodeBegin = 14
k_EStreamFrameEventDecodeEnd = 15
k_EStreamFrameEventUploadBegin = 16
k_EStreamFrameEventUploadEnd = 17
k_EStreamFrameEventComplete = 18
k_EStreamFrameResultPending = 0
k_EStreamFrameResultDisplayed = 1
k_EStreamFrameResultDroppedNetworkSlow = 2
k_EStreamFrameResultDroppedNetworkLost = 3
k_EStreamFrameResultDroppedDecodeSlow = 4
k_EStreamFrameResultDroppedDecodeCorrupt = 5
k_EStreamFrameResultDroppedLate = 6
k_EStreamFrameResultDroppedReset = 7
k_EFrameStatFPS = 0
k_EFrameStatCaptureDurationMS = 1
k_EFrameStatConvertDurationMS = 2
k_EFrameStatEncodeDurationMS = 3
k_EFrameStatSteamDurationMS = 4
k_EFrameStatServerDurationMS = 5
k_EFrameStatNetworkDurationMS = 6
k_EFrameStatDecodeDurationMS = 7
k_EFrameStatDisplayDurationMS = 8
k_EFrameStatClientDurationMS = 9
k_EFrameStatFrameDurationMS = 10
k_EFrameStatInputLatencyMS = 11
k_EFrameStatGameLatencyMS = 12
k_EFrameStatRoundTripLatencyMS = 13
k_EFrameStatPingTimeMS = 14
k_EFrameStatServerBitrateKbitPerSec = 15
k_EFrameStatClientBitrateKbitPerSec = 16
k_EFrameStatLinkBandwidthKbitPerSec = 17
k_EFrameStatPacketLossPercentage = 18
k_ELogFileSystemBoot = 0
k_ELogFileSystemReset = 1
k_ELogFileSystemDebug = 2
k_EStreamControllerConfigMsg_RequestConfigsForApp = 0
k_EStreamControllerConfigMsg_ConfigResponse = 1
k_EStreamControllerConfigMsg_PersonalizationResponse = 2
k_EStreamControllerConfigMsg_ActiveConfigChange = 3
k_EStreamControllerConfigMsg_RequestActiveConfig = 4


_CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT = _descriptor.EnumDescriptor(
  name='AuthenticationResult',
  full_name='CAuthenticationResponseMsg.AuthenticationResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=702,
  serialized_end=751,
)
_sym_db.RegisterEnumDescriptor(_CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT)


_CDISCOVERYPINGREQUEST = _descriptor.Descriptor(
  name='CDiscoveryPingRequest',
  full_name='CDiscoveryPingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='CDiscoveryPingRequest.sequence', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_size_requested', full_name='CDiscoveryPingRequest.packet_size_requested', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=106,
)


_CDISCOVERYPINGRESPONSE = _descriptor.Descriptor(
  name='CDiscoveryPingResponse',
  full_name='CDiscoveryPingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='CDiscoveryPingResponse.sequence', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_size_received', full_name='CDiscoveryPingResponse.packet_size_received', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=180,
)


_CSTREAMINGCLIENTHANDSHAKEINFO = _descriptor.Descriptor(
  name='CStreamingClientHandshakeInfo',
  full_name='CStreamingClientHandshakeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_test', full_name='CStreamingClientHandshakeInfo.network_test', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=235,
)


_CCLIENTHANDSHAKEMSG = _descriptor.Descriptor(
  name='CClientHandshakeMsg',
  full_name='CClientHandshakeMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='CClientHandshakeMsg.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=304,
)


_CSTREAMINGSERVERHANDSHAKEINFO = _descriptor.Descriptor(
  name='CStreamingServerHandshakeInfo',
  full_name='CStreamingServerHandshakeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mtu', full_name='CStreamingServerHandshakeInfo.mtu', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=350,
)


_CSERVERHANDSHAKEMSG = _descriptor.Descriptor(
  name='CServerHandshakeMsg',
  full_name='CServerHandshakeMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='CServerHandshakeMsg.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=419,
)


_CAUTHENTICATIONREQUESTMSG = _descriptor.Descriptor(
  name='CAuthenticationRequestMsg',
  full_name='CAuthenticationRequestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CAuthenticationRequestMsg.token', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CAuthenticationRequestMsg.version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CAuthenticationRequestMsg.steamid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=536,
)


_CAUTHENTICATIONRESPONSEMSG = _descriptor.Descriptor(
  name='CAuthenticationResponseMsg',
  full_name='CAuthenticationResponseMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CAuthenticationResponseMsg.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CAuthenticationResponseMsg.version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=751,
)


_CKEEPALIVEMSG = _descriptor.Descriptor(
  name='CKeepAliveMsg',
  full_name='CKeepAliveMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=768,
)


_CSTARTNETWORKTESTMSG = _descriptor.Descriptor(
  name='CStartNetworkTestMsg',
  full_name='CStartNetworkTestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frames', full_name='CStartNetworkTestMsg.frames', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framerate', full_name='CStartNetworkTestMsg.framerate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate_kbps', full_name='CStartNetworkTestMsg.bitrate_kbps', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='burst_bitrate_kbps', full_name='CStartNetworkTestMsg.burst_bitrate_kbps', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bandwidth_test', full_name='CStartNetworkTestMsg.bandwidth_test', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=902,
)


_CSTREAMVIDEOMODE = _descriptor.Descriptor(
  name='CStreamVideoMode',
  full_name='CStreamVideoMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='CStreamVideoMode.width', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CStreamVideoMode.height', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_rate', full_name='CStreamVideoMode.refresh_rate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_rate_numerator', full_name='CStreamVideoMode.refresh_rate_numerator', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_rate_denominator', full_name='CStreamVideoMode.refresh_rate_denominator', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1042,
)


_CSTREAMINGCLIENTCAPS = _descriptor.Descriptor(
  name='CStreamingClientCaps',
  full_name='CStreamingClientCaps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system_info', full_name='CStreamingClientCaps.system_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_can_suspend', full_name='CStreamingClientCaps.system_can_suspend', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_decode_bitrate_kbps', full_name='CStreamingClientCaps.maximum_decode_bitrate_kbps', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_burst_bitrate_kbps', full_name='CStreamingClientCaps.maximum_burst_bitrate_kbps', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supports_video_hevc', full_name='CStreamingClientCaps.supports_video_hevc', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_steam_store', full_name='CStreamingClientCaps.disable_steam_store', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_client_cursor', full_name='CStreamingClientCaps.disable_client_cursor', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_intel_hardware_encoding', full_name='CStreamingClientCaps.disable_intel_hardware_encoding', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_amd_hardware_encoding', full_name='CStreamingClientCaps.disable_amd_hardware_encoding', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_nvidia_hardware_encoding', full_name='CStreamingClientCaps.disable_nvidia_hardware_encoding', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='form_factor', full_name='CStreamingClientCaps.form_factor', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_on_screen_keyboard', full_name='CStreamingClientCaps.has_on_screen_keyboard', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_colorspaces', full_name='CStreamingClientCaps.supported_colorspaces', index=12,
      number=13, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1504,
)


_CSTREAMINGCLIENTCONFIG = _descriptor.Descriptor(
  name='CStreamingClientConfig',
  full_name='CStreamingClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quality', full_name='CStreamingClientConfig.quality', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_resolution_x', full_name='CStreamingClientConfig.maximum_resolution_x', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_resolution_y', full_name='CStreamingClientConfig.maximum_resolution_y', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_framerate_numerator', full_name='CStreamingClientConfig.maximum_framerate_numerator', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_framerate_denominator', full_name='CStreamingClientConfig.maximum_framerate_denominator', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_bitrate_kbps', full_name='CStreamingClientConfig.maximum_bitrate_kbps', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hardware_decoding', full_name='CStreamingClientConfig.enable_hardware_decoding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_performance_overlay', full_name='CStreamingClientConfig.enable_performance_overlay', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_video_streaming', full_name='CStreamingClientConfig.enable_video_streaming', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_audio_streaming', full_name='CStreamingClientConfig.enable_audio_streaming', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_input_streaming', full_name='CStreamingClientConfig.enable_input_streaming', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_channels', full_name='CStreamingClientConfig.audio_channels', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_video_hevc', full_name='CStreamingClientConfig.enable_video_hevc', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_performance_icons', full_name='CStreamingClientConfig.enable_performance_icons', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_microphone_streaming', full_name='CStreamingClientConfig.enable_microphone_streaming', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_overlay_hotkey', full_name='CStreamingClientConfig.controller_overlay_hotkey', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_touch_controller', full_name='CStreamingClientConfig.enable_touch_controller', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2p_scope', full_name='CStreamingClientConfig.p2p_scope', index=17,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=2253,
)


_CSTREAMINGSERVERCONFIG = _descriptor.Descriptor(
  name='CStreamingServerConfig',
  full_name='CStreamingServerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_desktop_resolution', full_name='CStreamingServerConfig.change_desktop_resolution', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamically_adjust_resolution', full_name='CStreamingServerConfig.dynamically_adjust_resolution', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_capture_nvfbc', full_name='CStreamingServerConfig.enable_capture_nvfbc', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hardware_encoding_nvidia', full_name='CStreamingServerConfig.enable_hardware_encoding_nvidia', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hardware_encoding_amd', full_name='CStreamingServerConfig.enable_hardware_encoding_amd', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hardware_encoding_intel', full_name='CStreamingServerConfig.enable_hardware_encoding_intel', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='software_encoding_threads', full_name='CStreamingServerConfig.software_encoding_threads', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_traffic_priority', full_name='CStreamingServerConfig.enable_traffic_priority', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_play_audio', full_name='CStreamingServerConfig.host_play_audio', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2256,
  serialized_end=2660,
)


_CNEGOTIATEDCONFIG = _descriptor.Descriptor(
  name='CNegotiatedConfig',
  full_name='CNegotiatedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reliable_data', full_name='CNegotiatedConfig.reliable_data', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_audio_codec', full_name='CNegotiatedConfig.selected_audio_codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_video_codec', full_name='CNegotiatedConfig.selected_video_codec', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_video_modes', full_name='CNegotiatedConfig.available_video_modes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_remote_hid', full_name='CNegotiatedConfig.enable_remote_hid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_touch_input', full_name='CNegotiatedConfig.enable_touch_input', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_client_cursor', full_name='CNegotiatedConfig.disable_client_cursor', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2663,
  serialized_end=2991,
)


_CNEGOTIATIONINITMSG = _descriptor.Descriptor(
  name='CNegotiationInitMsg',
  full_name='CNegotiationInitMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reliable_data', full_name='CNegotiationInitMsg.reliable_data', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_audio_codecs', full_name='CNegotiationInitMsg.supported_audio_codecs', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_video_codecs', full_name='CNegotiationInitMsg.supported_video_codecs', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supports_remote_hid', full_name='CNegotiationInitMsg.supports_remote_hid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supports_touch_input', full_name='CNegotiationInitMsg.supports_touch_input', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2994,
  serialized_end=3201,
)


_CNEGOTIATIONSETCONFIGMSG = _descriptor.Descriptor(
  name='CNegotiationSetConfigMsg',
  full_name='CNegotiationSetConfigMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='CNegotiationSetConfigMsg.config', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_client_config', full_name='CNegotiationSetConfigMsg.streaming_client_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_client_caps', full_name='CNegotiationSetConfigMsg.streaming_client_caps', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3204,
  serialized_end=3378,
)


_CNEGOTIATIONCOMPLETEMSG = _descriptor.Descriptor(
  name='CNegotiationCompleteMsg',
  full_name='CNegotiationCompleteMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3380,
  serialized_end=3405,
)


_CSTARTAUDIODATAMSG = _descriptor.Descriptor(
  name='CStartAudioDataMsg',
  full_name='CStartAudioDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='CStartAudioDataMsg.channel', index=0,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='CStartAudioDataMsg.codec', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec_data', full_name='CStartAudioDataMsg.codec_data', index=2,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='CStartAudioDataMsg.frequency', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='CStartAudioDataMsg.channels', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3408,
  serialized_end=3562,
)


_CSTOPAUDIODATAMSG = _descriptor.Descriptor(
  name='CStopAudioDataMsg',
  full_name='CStopAudioDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3564,
  serialized_end=3583,
)


_CSTARTVIDEODATAMSG = _descriptor.Descriptor(
  name='CStartVideoDataMsg',
  full_name='CStartVideoDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='CStartVideoDataMsg.channel', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='CStartVideoDataMsg.codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec_data', full_name='CStartVideoDataMsg.codec_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='CStartVideoDataMsg.width', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CStartVideoDataMsg.height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3586,
  serialized_end=3734,
)


_CSTOPVIDEODATAMSG = _descriptor.Descriptor(
  name='CStopVideoDataMsg',
  full_name='CStopVideoDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3736,
  serialized_end=3755,
)


_CRECORDEDINPUT = _descriptor.Descriptor(
  name='CRecordedInput',
  full_name='CRecordedInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CRecordedInput.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CRecordedInput.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finger_down', full_name='CRecordedInput.finger_down', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finger_motion', full_name='CRecordedInput.finger_motion', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finger_up', full_name='CRecordedInput.finger_up', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_motion', full_name='CRecordedInput.mouse_motion', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_wheel', full_name='CRecordedInput.mouse_wheel', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_down', full_name='CRecordedInput.mouse_down', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_up', full_name='CRecordedInput.mouse_up', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_down', full_name='CRecordedInput.key_down', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_up', full_name='CRecordedInput.key_up', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='CRecordedInput.text', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hid', full_name='CRecordedInput.hid', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='CRecordedInput.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3758,
  serialized_end=4339,
)


_CRECORDEDINPUTSTREAM = _descriptor.Descriptor(
  name='CRecordedInputStream',
  full_name='CRecordedInputStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CRecordedInputStream.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4341,
  serialized_end=4397,
)


_CINPUTLATENCYTESTMSG = _descriptor.Descriptor(
  name='CInputLatencyTestMsg',
  full_name='CInputLatencyTestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputLatencyTestMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='CInputLatencyTestMsg.color', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4399,
  serialized_end=4456,
)


_CINPUTTOUCHFINGERDOWNMSG = _descriptor.Descriptor(
  name='CInputTouchFingerDownMsg',
  full_name='CInputTouchFingerDownMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputTouchFingerDownMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerid', full_name='CInputTouchFingerDownMsg.fingerid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_normalized', full_name='CInputTouchFingerDownMsg.x_normalized', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_normalized', full_name='CInputTouchFingerDownMsg.y_normalized', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4458,
  serialized_end=4566,
)


_CINPUTTOUCHFINGERMOTIONMSG = _descriptor.Descriptor(
  name='CInputTouchFingerMotionMsg',
  full_name='CInputTouchFingerMotionMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputTouchFingerMotionMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerid', full_name='CInputTouchFingerMotionMsg.fingerid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_normalized', full_name='CInputTouchFingerMotionMsg.x_normalized', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_normalized', full_name='CInputTouchFingerMotionMsg.y_normalized', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4568,
  serialized_end=4678,
)


_CINPUTTOUCHFINGERUPMSG = _descriptor.Descriptor(
  name='CInputTouchFingerUpMsg',
  full_name='CInputTouchFingerUpMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputTouchFingerUpMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerid', full_name='CInputTouchFingerUpMsg.fingerid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_normalized', full_name='CInputTouchFingerUpMsg.x_normalized', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_normalized', full_name='CInputTouchFingerUpMsg.y_normalized', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4680,
  serialized_end=4786,
)


_CINPUTMOUSEMOTIONMSG = _descriptor.Descriptor(
  name='CInputMouseMotionMsg',
  full_name='CInputMouseMotionMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputMouseMotionMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_normalized', full_name='CInputMouseMotionMsg.x_normalized', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_normalized', full_name='CInputMouseMotionMsg.y_normalized', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dx', full_name='CInputMouseMotionMsg.dx', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dy', full_name='CInputMouseMotionMsg.dy', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4788,
  serialized_end=4898,
)


_CINPUTMOUSEWHEELMSG = _descriptor.Descriptor(
  name='CInputMouseWheelMsg',
  full_name='CInputMouseWheelMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputMouseWheelMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='CInputMouseWheelMsg.direction', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=120,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4900,
  serialized_end=5012,
)


_CINPUTMOUSEDOWNMSG = _descriptor.Descriptor(
  name='CInputMouseDownMsg',
  full_name='CInputMouseDownMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputMouseDownMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='CInputMouseDownMsg.button', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5014,
  serialized_end=5117,
)


_CINPUTMOUSEUPMSG = _descriptor.Descriptor(
  name='CInputMouseUpMsg',
  full_name='CInputMouseUpMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputMouseUpMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='CInputMouseUpMsg.button', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5119,
  serialized_end=5220,
)


_CINPUTKEYDOWNMSG = _descriptor.Descriptor(
  name='CInputKeyDownMsg',
  full_name='CInputKeyDownMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputKeyDownMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scancode', full_name='CInputKeyDownMsg.scancode', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5222,
  serialized_end=5278,
)


_CINPUTKEYUPMSG = _descriptor.Descriptor(
  name='CInputKeyUpMsg',
  full_name='CInputKeyUpMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputKeyUpMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scancode', full_name='CInputKeyUpMsg.scancode', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5280,
  serialized_end=5334,
)


_CINPUTTEXTMSG = _descriptor.Descriptor(
  name='CInputTextMsg',
  full_name='CInputTextMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CInputTextMsg.input_mark', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_utf8', full_name='CInputTextMsg.text_utf8', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5336,
  serialized_end=5390,
)


_CSETTITLEMSG = _descriptor.Descriptor(
  name='CSetTitleMsg',
  full_name='CSetTitleMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CSetTitleMsg.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5392,
  serialized_end=5420,
)


_CSETCAPTURESIZEMSG = _descriptor.Descriptor(
  name='CSetCaptureSizeMsg',
  full_name='CSetCaptureSizeMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='CSetCaptureSizeMsg.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSetCaptureSizeMsg.height', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5422,
  serialized_end=5473,
)


_CSETICONMSG = _descriptor.Descriptor(
  name='CSetIconMsg',
  full_name='CSetIconMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='CSetIconMsg.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSetIconMsg.height', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='CSetIconMsg.image', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5475,
  serialized_end=5534,
)


_CSETFLASHSTATEMSG = _descriptor.Descriptor(
  name='CSetFlashStateMsg',
  full_name='CSetFlashStateMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSetFlashStateMsg.flags', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CSetFlashStateMsg.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_ms', full_name='CSetFlashStateMsg.timeout_ms', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5536,
  serialized_end=5605,
)


_CSHOWCURSORMSG = _descriptor.Descriptor(
  name='CShowCursorMsg',
  full_name='CShowCursorMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x_normalized', full_name='CShowCursorMsg.x_normalized', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_normalized', full_name='CShowCursorMsg.y_normalized', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5607,
  serialized_end=5667,
)


_CHIDECURSORMSG = _descriptor.Descriptor(
  name='CHideCursorMsg',
  full_name='CHideCursorMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5669,
  serialized_end=5685,
)


_CSETCURSORMSG = _descriptor.Descriptor(
  name='CSetCursorMsg',
  full_name='CSetCursorMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cursor_id', full_name='CSetCursorMsg.cursor_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5687,
  serialized_end=5721,
)


_CGETCURSORIMAGEMSG = _descriptor.Descriptor(
  name='CGetCursorImageMsg',
  full_name='CGetCursorImageMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cursor_id', full_name='CGetCursorImageMsg.cursor_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5723,
  serialized_end=5762,
)


_CSETCURSORIMAGEMSG = _descriptor.Descriptor(
  name='CSetCursorImageMsg',
  full_name='CSetCursorImageMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cursor_id', full_name='CSetCursorImageMsg.cursor_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='CSetCursorImageMsg.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSetCursorImageMsg.height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hot_x', full_name='CSetCursorImageMsg.hot_x', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hot_y', full_name='CSetCursorImageMsg.hot_y', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='CSetCursorImageMsg.image', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5764,
  serialized_end=5879,
)


_CVIDEODECODERINFOMSG = _descriptor.Descriptor(
  name='CVideoDecoderInfoMsg',
  full_name='CVideoDecoderInfoMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='CVideoDecoderInfoMsg.info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threads', full_name='CVideoDecoderInfoMsg.threads', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5881,
  serialized_end=5934,
)


_CVIDEOENCODERINFOMSG = _descriptor.Descriptor(
  name='CVideoEncoderInfoMsg',
  full_name='CVideoEncoderInfoMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='CVideoEncoderInfoMsg.info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5936,
  serialized_end=5972,
)


_CPAUSEMSG = _descriptor.Descriptor(
  name='CPauseMsg',
  full_name='CPauseMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5974,
  serialized_end=5985,
)


_CRESUMEMSG = _descriptor.Descriptor(
  name='CResumeMsg',
  full_name='CResumeMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5987,
  serialized_end=5999,
)


_CENABLEHIGHRESCAPTUREMSG = _descriptor.Descriptor(
  name='CEnableHighResCaptureMsg',
  full_name='CEnableHighResCaptureMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6001,
  serialized_end=6027,
)


_CDISABLEHIGHRESCAPTUREMSG = _descriptor.Descriptor(
  name='CDisableHighResCaptureMsg',
  full_name='CDisableHighResCaptureMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6029,
  serialized_end=6056,
)


_CTOGGLEMAGNIFICATIONMSG = _descriptor.Descriptor(
  name='CToggleMagnificationMsg',
  full_name='CToggleMagnificationMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6058,
  serialized_end=6083,
)


_CSETCAPSLOCKMSG = _descriptor.Descriptor(
  name='CSetCapslockMsg',
  full_name='CSetCapslockMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pressed', full_name='CSetCapslockMsg.pressed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6085,
  serialized_end=6119,
)


_CSTREAMINGKEYMAPENTRY = _descriptor.Descriptor(
  name='CStreamingKeymapEntry',
  full_name='CStreamingKeymapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scancode', full_name='CStreamingKeymapEntry.scancode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normal_keycode', full_name='CStreamingKeymapEntry.normal_keycode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_keycode', full_name='CStreamingKeymapEntry.shift_keycode', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capslock_keycode', full_name='CStreamingKeymapEntry.capslock_keycode', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shift_capslock_keycode', full_name='CStreamingKeymapEntry.shift_capslock_keycode', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altgr_keycode', full_name='CStreamingKeymapEntry.altgr_keycode', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altgr_shift_keycode', full_name='CStreamingKeymapEntry.altgr_shift_keycode', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altgr_capslock_keycode', full_name='CStreamingKeymapEntry.altgr_capslock_keycode', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altgr_shift_capslock_keycode', full_name='CStreamingKeymapEntry.altgr_shift_capslock_keycode', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6122,
  serialized_end=6390,
)


_CSTREAMINGKEYMAP = _descriptor.Descriptor(
  name='CStreamingKeymap',
  full_name='CStreamingKeymap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CStreamingKeymap.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6392,
  serialized_end=6451,
)


_CSETKEYMAPMSG = _descriptor.Descriptor(
  name='CSetKeymapMsg',
  full_name='CSetKeymapMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keymap', full_name='CSetKeymapMsg.keymap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6453,
  serialized_end=6503,
)


_CSTOPREQUEST = _descriptor.Descriptor(
  name='CStopRequest',
  full_name='CStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6505,
  serialized_end=6519,
)


_CQUITREQUEST = _descriptor.Descriptor(
  name='CQuitRequest',
  full_name='CQuitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6521,
  serialized_end=6535,
)


_CDELETECURSORMSG = _descriptor.Descriptor(
  name='CDeleteCursorMsg',
  full_name='CDeleteCursorMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cursor_id', full_name='CDeleteCursorMsg.cursor_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6537,
  serialized_end=6574,
)


_CSETSTREAMINGCLIENTCONFIG = _descriptor.Descriptor(
  name='CSetStreamingClientConfig',
  full_name='CSetStreamingClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='CSetStreamingClientConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6576,
  serialized_end=6644,
)


_CSETQOSMSG = _descriptor.Descriptor(
  name='CSetQoSMsg',
  full_name='CSetQoSMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_qos', full_name='CSetQoSMsg.use_qos', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6646,
  serialized_end=6675,
)


_CSETTARGETFRAMERATEMSG = _descriptor.Descriptor(
  name='CSetTargetFramerateMsg',
  full_name='CSetTargetFramerateMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='framerate', full_name='CSetTargetFramerateMsg.framerate', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='CSetTargetFramerateMsg.reasons', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framerate_numerator', full_name='CSetTargetFramerateMsg.framerate_numerator', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framerate_denominator', full_name='CSetTargetFramerateMsg.framerate_denominator', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6677,
  serialized_end=6797,
)


_CSETTARGETBITRATEMSG = _descriptor.Descriptor(
  name='CSetTargetBitrateMsg',
  full_name='CSetTargetBitrateMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='CSetTargetBitrateMsg.bitrate', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6799,
  serialized_end=6838,
)


_COVERLAYENABLEDMSG = _descriptor.Descriptor(
  name='COverlayEnabledMsg',
  full_name='COverlayEnabledMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='COverlayEnabledMsg.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6840,
  serialized_end=6877,
)


_CSETGAMMARAMPMSG = _descriptor.Descriptor(
  name='CSetGammaRampMsg',
  full_name='CSetGammaRampMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gamma_ramp', full_name='CSetGammaRampMsg.gamma_ramp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6879,
  serialized_end=6917,
)


_CSETACTIVITYMSG = _descriptor.Descriptor(
  name='CSetActivityMsg',
  full_name='CSetActivityMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activity', full_name='CSetActivityMsg.activity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSetActivityMsg.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CSetActivityMsg.gameid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CSetActivityMsg.game_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6919,
  serialized_end=7045,
)


_CSYSTEMSUSPENDMSG = _descriptor.Descriptor(
  name='CSystemSuspendMsg',
  full_name='CSystemSuspendMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7047,
  serialized_end=7066,
)


_CVIRTUALHEREREQUESTMSG = _descriptor.Descriptor(
  name='CVirtualHereRequestMsg',
  full_name='CVirtualHereRequestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='CVirtualHereRequestMsg.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7068,
  serialized_end=7110,
)


_CVIRTUALHEREREADYMSG = _descriptor.Descriptor(
  name='CVirtualHereReadyMsg',
  full_name='CVirtualHereReadyMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='licensed_device_count', full_name='CVirtualHereReadyMsg.licensed_device_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7112,
  serialized_end=7165,
)


_CVIRTUALHERESHAREDEVICEMSG = _descriptor.Descriptor(
  name='CVirtualHereShareDeviceMsg',
  full_name='CVirtualHereShareDeviceMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='CVirtualHereShareDeviceMsg.device_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7167,
  serialized_end=7219,
)


_CSETSPECTATORMODEMSG = _descriptor.Descriptor(
  name='CSetSpectatorModeMsg',
  full_name='CSetSpectatorModeMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='CSetSpectatorModeMsg.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7221,
  serialized_end=7260,
)


_CREMOTEHIDMSG = _descriptor.Descriptor(
  name='CRemoteHIDMsg',
  full_name='CRemoteHIDMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CRemoteHIDMsg.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_input', full_name='CRemoteHIDMsg.active_input', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7262,
  serialized_end=7313,
)


_CTOUCHCONFIGACTIVEMSG = _descriptor.Descriptor(
  name='CTouchConfigActiveMsg',
  full_name='CTouchConfigActiveMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CTouchConfigActiveMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='CTouchConfigActiveMsg.revision', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator', full_name='CTouchConfigActiveMsg.creator', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7315,
  serialized_end=7388,
)


_CGETTOUCHCONFIGDATAMSG = _descriptor.Descriptor(
  name='CGetTouchConfigDataMsg',
  full_name='CGetTouchConfigDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGetTouchConfigDataMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7390,
  serialized_end=7429,
)


_CSETTOUCHCONFIGDATAMSG = _descriptor.Descriptor(
  name='CSetTouchConfigDataMsg',
  full_name='CSetTouchConfigDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSetTouchConfigDataMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='CSetTouchConfigDataMsg.revision', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CSetTouchConfigDataMsg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layout', full_name='CSetTouchConfigDataMsg.layout', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator', full_name='CSetTouchConfigDataMsg.creator', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7431,
  serialized_end=7535,
)


_CSAVETOUCHCONFIGLAYOUTMSG = _descriptor.Descriptor(
  name='CSaveTouchConfigLayoutMsg',
  full_name='CSaveTouchConfigLayoutMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSaveTouchConfigLayoutMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layout', full_name='CSaveTouchConfigLayoutMsg.layout', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7537,
  serialized_end=7595,
)


_CTOUCHACTIONSETACTIVEMSG = _descriptor.Descriptor(
  name='CTouchActionSetActiveMsg',
  full_name='CTouchActionSetActiveMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CTouchActionSetActiveMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionset_id', full_name='CTouchActionSetActiveMsg.actionset_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7597,
  serialized_end=7660,
)


_CTOUCHACTIONSETLAYERADDEDMSG = _descriptor.Descriptor(
  name='CTouchActionSetLayerAddedMsg',
  full_name='CTouchActionSetLayerAddedMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CTouchActionSetLayerAddedMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionset_id', full_name='CTouchActionSetLayerAddedMsg.actionset_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7662,
  serialized_end=7729,
)


_CTOUCHACTIONSETLAYERREMOVEDMSG = _descriptor.Descriptor(
  name='CTouchActionSetLayerRemovedMsg',
  full_name='CTouchActionSetLayerRemovedMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CTouchActionSetLayerRemovedMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionset_id', full_name='CTouchActionSetLayerRemovedMsg.actionset_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7731,
  serialized_end=7800,
)


_CGETTOUCHICONDATAMSG = _descriptor.Descriptor(
  name='CGetTouchIconDataMsg',
  full_name='CGetTouchIconDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGetTouchIconDataMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='CGetTouchIconDataMsg.icon', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7802,
  serialized_end=7853,
)


_CSETTOUCHICONDATAMSG = _descriptor.Descriptor(
  name='CSetTouchIconDataMsg',
  full_name='CSetTouchIconDataMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSetTouchIconDataMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='CSetTouchIconDataMsg.icon', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CSetTouchIconDataMsg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7855,
  serialized_end=7920,
)


_CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CRemotePlayTogetherGroupUpdateMsg.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guestid', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.guestid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyboard_enabled', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.keyboard_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_enabled', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.mouse_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_enabled', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.controller_enabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_slots', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.controller_slots', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_hash', full_name='CRemotePlayTogetherGroupUpdateMsg.Player.avatar_hash', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8117,
  serialized_end=8285,
)

_CREMOTEPLAYTOGETHERGROUPUPDATEMSG = _descriptor.Descriptor(
  name='CRemotePlayTogetherGroupUpdateMsg',
  full_name='CRemotePlayTogetherGroupUpdateMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CRemotePlayTogetherGroupUpdateMsg.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_index', full_name='CRemotePlayTogetherGroupUpdateMsg.player_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miniprofile_location', full_name='CRemotePlayTogetherGroupUpdateMsg.miniprofile_location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CRemotePlayTogetherGroupUpdateMsg.game_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_location', full_name='CRemotePlayTogetherGroupUpdateMsg.avatar_location', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7923,
  serialized_end=8285,
)


_CSETINPUTTEMPORARILYDISABLEDMSG = _descriptor.Descriptor(
  name='CSetInputTemporarilyDisabledMsg',
  full_name='CSetInputTemporarilyDisabledMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='CSetInputTemporarilyDisabledMsg.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8287,
  serialized_end=8338,
)


_CSETQUALITYOVERRIDEMSG = _descriptor.Descriptor(
  name='CSetQualityOverrideMsg',
  full_name='CSetQualityOverrideMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CSetQualityOverrideMsg.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8340,
  serialized_end=8379,
)


_CSETBITRATEOVERRIDEMSG = _descriptor.Descriptor(
  name='CSetBitrateOverrideMsg',
  full_name='CSetBitrateOverrideMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CSetBitrateOverrideMsg.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8381,
  serialized_end=8420,
)


_CSHOWONSCREENKEYBOARDMSG = _descriptor.Descriptor(
  name='CShowOnScreenKeyboardMsg',
  full_name='CShowOnScreenKeyboardMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8422,
  serialized_end=8448,
)


_CSTREAMDATALOSTMSG = _descriptor.Descriptor(
  name='CStreamDataLostMsg',
  full_name='CStreamDataLostMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packets', full_name='CStreamDataLostMsg.packets', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8450,
  serialized_end=8487,
)


_CAUDIOFORMAT = _descriptor.Descriptor(
  name='CAudioFormat',
  full_name='CAudioFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='CAudioFormat.format', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='CAudioFormat.frequency', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='CAudioFormat.channels', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8489,
  serialized_end=8591,
)


_CVIDEOFORMAT = _descriptor.Descriptor(
  name='CVideoFormat',
  full_name='CVideoFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='CVideoFormat.format', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='CVideoFormat.width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CVideoFormat.height', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8593,
  serialized_end=8689,
)


_CFRAMEEVENT = _descriptor.Descriptor(
  name='CFrameEvent',
  full_name='CFrameEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CFrameEvent.event_id', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CFrameEvent.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8691,
  serialized_end=8787,
)


_CFRAMESTATS = _descriptor.Descriptor(
  name='CFrameStats',
  full_name='CFrameStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='CFrameStats.frame_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_mark', full_name='CFrameStats.input_mark', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='CFrameStats.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='CFrameStats.result', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_start_delta', full_name='CFrameStats.frame_start_delta', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_display_delta', full_name='CFrameStats.frame_display_delta', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_time', full_name='CFrameStats.ping_time', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_bitrate', full_name='CFrameStats.server_bitrate', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_bitrate', full_name='CFrameStats.client_bitrate', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_bandwidth', full_name='CFrameStats.link_bandwidth', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_loss', full_name='CFrameStats.packet_loss', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_size', full_name='CFrameStats.frame_size', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8790,
  serialized_end=9125,
)


_CFRAMESTATACCUMULATEDVALUE = _descriptor.Descriptor(
  name='CFrameStatAccumulatedValue',
  full_name='CFrameStatAccumulatedValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_type', full_name='CFrameStatAccumulatedValue.stat_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CFrameStatAccumulatedValue.count', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='CFrameStatAccumulatedValue.average', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='CFrameStatAccumulatedValue.stddev', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9128,
  serialized_end=9264,
)


_CFRAMESTATSLISTMSG = _descriptor.Descriptor(
  name='CFrameStatsListMsg',
  full_name='CFrameStatsListMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_type', full_name='CFrameStatsListMsg.data_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CFrameStatsListMsg.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulated_stats', full_name='CFrameStatsListMsg.accumulated_stats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_frame_id', full_name='CFrameStatsListMsg.latest_frame_id', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9267,
  serialized_end=9460,
)


_CSTREAMINGSESSIONSTATS = _descriptor.Descriptor(
  name='CStreamingSessionStats',
  full_name='CStreamingSessionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_loss_percentage', full_name='CStreamingSessionStats.frame_loss_percentage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_network_time_ms', full_name='CStreamingSessionStats.average_network_time_ms', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_network_time_ms', full_name='CStreamingSessionStats.stddev_network_time_ms', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9462,
  serialized_end=9582,
)


_CDEBUGDUMPMSG = _descriptor.Descriptor(
  name='CDebugDumpMsg',
  full_name='CDebugDumpMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='screenshot', full_name='CDebugDumpMsg.screenshot', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9584,
  serialized_end=9619,
)


_CLOGMSG = _descriptor.Descriptor(
  name='CLogMsg',
  full_name='CLogMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CLogMsg.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CLogMsg.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9621,
  serialized_end=9661,
)


_CLOGUPLOADMSG = _descriptor.Descriptor(
  name='CLogUploadMsg',
  full_name='CLogUploadMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CLogUploadMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CLogUploadMsg.data', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9663,
  serialized_end=9743,
)


_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE = _descriptor.Descriptor(
  name='Candidate',
  full_name='CTransportSignalMsg.WebRTCMessage.Candidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdp_mid', full_name='CTransportSignalMsg.WebRTCMessage.Candidate.sdp_mid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdp_mline_index', full_name='CTransportSignalMsg.WebRTCMessage.Candidate.sdp_mline_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CTransportSignalMsg.WebRTCMessage.Candidate.candidate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9974,
  serialized_end=10046,
)

_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE = _descriptor.Descriptor(
  name='WebRTCMessage',
  full_name='CTransportSignalMsg.WebRTCMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='greeting', full_name='CTransportSignalMsg.WebRTCMessage.greeting', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offer', full_name='CTransportSignalMsg.WebRTCMessage.offer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='CTransportSignalMsg.WebRTCMessage.answer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CTransportSignalMsg.WebRTCMessage.candidate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='msg', full_name='CTransportSignalMsg.WebRTCMessage.msg',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9835,
  serialized_end=10053,
)

_CTRANSPORTSIGNALMSG = _descriptor.Descriptor(
  name='CTransportSignalMsg',
  full_name='CTransportSignalMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='webrtc', full_name='CTransportSignalMsg.webrtc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr', full_name='CTransportSignalMsg.sdr', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9746,
  serialized_end=10053,
)


_CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE = _descriptor.Descriptor(
  name='ControllerConfigResponse',
  full_name='CControllerConfigMsg.ControllerConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CControllerConfigMsg.ControllerConfigResponse.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configURL', full_name='CControllerConfigMsg.ControllerConfigResponse.configURL', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerType', full_name='CControllerConfigMsg.ControllerConfigResponse.controllerType', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerData', full_name='CControllerConfigMsg.ControllerConfigResponse.controllerData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectionOrder', full_name='CControllerConfigMsg.ControllerConfigResponse.selectionOrder', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actionBlock', full_name='CControllerConfigMsg.ControllerConfigResponse.actionBlock', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10456,
  serialized_end=10609,
)

_CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE = _descriptor.Descriptor(
  name='ControllerPersonalizationResponse',
  full_name='CControllerConfigMsg.ControllerPersonalizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='personalizationData', full_name='CControllerConfigMsg.ControllerPersonalizationResponse.personalizationData', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10611,
  serialized_end=10675,
)

_CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE = _descriptor.Descriptor(
  name='ControllerActiveConfigChangeResponse',
  full_name='CControllerConfigMsg.ControllerActiveConfigChangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configURL', full_name='CControllerConfigMsg.ControllerActiveConfigChangeResponse.configURL', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerType', full_name='CControllerConfigMsg.ControllerActiveConfigChangeResponse.controllerType', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerData', full_name='CControllerConfigMsg.ControllerActiveConfigChangeResponse.controllerData', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectionOrder', full_name='CControllerConfigMsg.ControllerActiveConfigChangeResponse.selectionOrder', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10678,
  serialized_end=10807,
)

_CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG = _descriptor.Descriptor(
  name='ControllerActiveConfigMsg',
  full_name='CControllerConfigMsg.ControllerActiveConfigMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CControllerConfigMsg.ControllerActiveConfigMsg.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configURL', full_name='CControllerConfigMsg.ControllerActiveConfigMsg.configURL', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerType', full_name='CControllerConfigMsg.ControllerActiveConfigMsg.controllerType', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerData', full_name='CControllerConfigMsg.ControllerActiveConfigMsg.controllerData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10809,
  serialized_end=10918,
)

_CCONTROLLERCONFIGMSG = _descriptor.Descriptor(
  name='CControllerConfigMsg',
  full_name='CControllerConfigMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CControllerConfigMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerPath', full_name='CControllerConfigMsg.controllerPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CControllerConfigMsg.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='personalizationResponse', full_name='CControllerConfigMsg.personalizationResponse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configResponse', full_name='CControllerConfigMsg.configResponse', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activeConfigChangeMsg', full_name='CControllerConfigMsg.activeConfigChangeMsg', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE, _CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE, _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE, _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10056,
  serialized_end=10918,
)

_CCLIENTHANDSHAKEMSG.fields_by_name['info'].message_type = _CSTREAMINGCLIENTHANDSHAKEINFO
_CSERVERHANDSHAKEMSG.fields_by_name['info'].message_type = _CSTREAMINGSERVERHANDSHAKEINFO
_CAUTHENTICATIONREQUESTMSG.fields_by_name['version'].enum_type = _ESTREAMVERSION
_CAUTHENTICATIONRESPONSEMSG.fields_by_name['result'].enum_type = _CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT
_CAUTHENTICATIONRESPONSEMSG.fields_by_name['version'].enum_type = _ESTREAMVERSION
_CAUTHENTICATIONRESPONSEMSG_AUTHENTICATIONRESULT.containing_type = _CAUTHENTICATIONRESPONSEMSG
_CSTREAMINGCLIENTCAPS.fields_by_name['supported_colorspaces'].enum_type = _ESTREAMCOLORSPACE
_CSTREAMINGCLIENTCONFIG.fields_by_name['quality'].enum_type = _ESTREAMQUALITYPREFERENCE
_CSTREAMINGCLIENTCONFIG.fields_by_name['p2p_scope'].enum_type = _ESTREAMP2PSCOPE
_CSTREAMINGSERVERCONFIG.fields_by_name['host_play_audio'].enum_type = _ESTREAMHOSTPLAYAUDIOPREFERENCE
_CNEGOTIATEDCONFIG.fields_by_name['selected_audio_codec'].enum_type = _ESTREAMAUDIOCODEC
_CNEGOTIATEDCONFIG.fields_by_name['selected_video_codec'].enum_type = _ESTREAMVIDEOCODEC
_CNEGOTIATEDCONFIG.fields_by_name['available_video_modes'].message_type = _CSTREAMVIDEOMODE
_CNEGOTIATIONINITMSG.fields_by_name['supported_audio_codecs'].enum_type = _ESTREAMAUDIOCODEC
_CNEGOTIATIONINITMSG.fields_by_name['supported_video_codecs'].enum_type = _ESTREAMVIDEOCODEC
_CNEGOTIATIONSETCONFIGMSG.fields_by_name['config'].message_type = _CNEGOTIATEDCONFIG
_CNEGOTIATIONSETCONFIGMSG.fields_by_name['streaming_client_config'].message_type = _CSTREAMINGCLIENTCONFIG
_CNEGOTIATIONSETCONFIGMSG.fields_by_name['streaming_client_caps'].message_type = _CSTREAMINGCLIENTCAPS
_CSTARTAUDIODATAMSG.fields_by_name['codec'].enum_type = _ESTREAMAUDIOCODEC
_CSTARTVIDEODATAMSG.fields_by_name['codec'].enum_type = _ESTREAMVIDEOCODEC
_CRECORDEDINPUT.fields_by_name['type'].enum_type = _ESTREAMCONTROLMESSAGE
_CRECORDEDINPUT.fields_by_name['finger_down'].message_type = _CINPUTTOUCHFINGERDOWNMSG
_CRECORDEDINPUT.fields_by_name['finger_motion'].message_type = _CINPUTTOUCHFINGERMOTIONMSG
_CRECORDEDINPUT.fields_by_name['finger_up'].message_type = _CINPUTTOUCHFINGERUPMSG
_CRECORDEDINPUT.fields_by_name['mouse_motion'].message_type = _CINPUTMOUSEMOTIONMSG
_CRECORDEDINPUT.fields_by_name['mouse_wheel'].message_type = _CINPUTMOUSEWHEELMSG
_CRECORDEDINPUT.fields_by_name['mouse_down'].message_type = _CINPUTMOUSEDOWNMSG
_CRECORDEDINPUT.fields_by_name['mouse_up'].message_type = _CINPUTMOUSEUPMSG
_CRECORDEDINPUT.fields_by_name['key_down'].message_type = _CINPUTKEYDOWNMSG
_CRECORDEDINPUT.fields_by_name['key_up'].message_type = _CINPUTKEYUPMSG
_CRECORDEDINPUT.fields_by_name['text'].message_type = _CINPUTTEXTMSG
_CRECORDEDINPUT.fields_by_name['hid'].message_type = _CREMOTEHIDMSG
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['finger_down'])
_CRECORDEDINPUT.fields_by_name['finger_down'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['finger_motion'])
_CRECORDEDINPUT.fields_by_name['finger_motion'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['finger_up'])
_CRECORDEDINPUT.fields_by_name['finger_up'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['mouse_motion'])
_CRECORDEDINPUT.fields_by_name['mouse_motion'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['mouse_wheel'])
_CRECORDEDINPUT.fields_by_name['mouse_wheel'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['mouse_down'])
_CRECORDEDINPUT.fields_by_name['mouse_down'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['mouse_up'])
_CRECORDEDINPUT.fields_by_name['mouse_up'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['key_down'])
_CRECORDEDINPUT.fields_by_name['key_down'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['key_up'])
_CRECORDEDINPUT.fields_by_name['key_up'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['text'])
_CRECORDEDINPUT.fields_by_name['text'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUT.oneofs_by_name['data'].fields.append(
  _CRECORDEDINPUT.fields_by_name['hid'])
_CRECORDEDINPUT.fields_by_name['hid'].containing_oneof = _CRECORDEDINPUT.oneofs_by_name['data']
_CRECORDEDINPUTSTREAM.fields_by_name['entries'].message_type = _CRECORDEDINPUT
_CINPUTMOUSEWHEELMSG.fields_by_name['direction'].enum_type = _ESTREAMMOUSEWHEELDIRECTION
_CINPUTMOUSEDOWNMSG.fields_by_name['button'].enum_type = _ESTREAMMOUSEBUTTON
_CINPUTMOUSEUPMSG.fields_by_name['button'].enum_type = _ESTREAMMOUSEBUTTON
_CSTREAMINGKEYMAP.fields_by_name['entries'].message_type = _CSTREAMINGKEYMAPENTRY
_CSETKEYMAPMSG.fields_by_name['keymap'].message_type = _CSTREAMINGKEYMAP
_CSETSTREAMINGCLIENTCONFIG.fields_by_name['config'].message_type = _CSTREAMINGCLIENTCONFIG
_CSETACTIVITYMSG.fields_by_name['activity'].enum_type = _ESTREAMACTIVITY
_CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER.containing_type = _CREMOTEPLAYTOGETHERGROUPUPDATEMSG
_CREMOTEPLAYTOGETHERGROUPUPDATEMSG.fields_by_name['players'].message_type = _CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER
_CAUDIOFORMAT.fields_by_name['format'].enum_type = _EAUDIOFORMAT
_CVIDEOFORMAT.fields_by_name['format'].enum_type = _EVIDEOFORMAT
_CFRAMEEVENT.fields_by_name['event_id'].enum_type = _ESTREAMFRAMEEVENT
_CFRAMESTATS.fields_by_name['events'].message_type = _CFRAMEEVENT
_CFRAMESTATS.fields_by_name['result'].enum_type = _ESTREAMFRAMERESULT
_CFRAMESTATACCUMULATEDVALUE.fields_by_name['stat_type'].enum_type = _EFRAMEACCUMULATEDSTAT
_CFRAMESTATSLISTMSG.fields_by_name['data_type'].enum_type = _ESTREAMINGDATATYPE
_CFRAMESTATSLISTMSG.fields_by_name['stats'].message_type = _CFRAMESTATS
_CFRAMESTATSLISTMSG.fields_by_name['accumulated_stats'].message_type = _CFRAMESTATACCUMULATEDVALUE
_CLOGUPLOADMSG.fields_by_name['type'].enum_type = _ELOGFILETYPE
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE.containing_type = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['candidate'].message_type = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.containing_type = _CTRANSPORTSIGNALMSG
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg'].fields.append(
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['greeting'])
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['greeting'].containing_oneof = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg']
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg'].fields.append(
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['offer'])
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['offer'].containing_oneof = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg']
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg'].fields.append(
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['answer'])
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['answer'].containing_oneof = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg']
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg'].fields.append(
  _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['candidate'])
_CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.fields_by_name['candidate'].containing_oneof = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE.oneofs_by_name['msg']
_CTRANSPORTSIGNALMSG.fields_by_name['webrtc'].message_type = _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE
_CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE.containing_type = _CCONTROLLERCONFIGMSG
_CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE.containing_type = _CCONTROLLERCONFIGMSG
_CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE.containing_type = _CCONTROLLERCONFIGMSG
_CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG.containing_type = _CCONTROLLERCONFIGMSG
_CCONTROLLERCONFIGMSG.fields_by_name['type'].enum_type = _ESTREAMCONTROLLERCONFIGMSG
_CCONTROLLERCONFIGMSG.fields_by_name['personalizationResponse'].message_type = _CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE
_CCONTROLLERCONFIGMSG.fields_by_name['configResponse'].message_type = _CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE
_CCONTROLLERCONFIGMSG.fields_by_name['activeConfigChangeMsg'].message_type = _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG
DESCRIPTOR.message_types_by_name['CDiscoveryPingRequest'] = _CDISCOVERYPINGREQUEST
DESCRIPTOR.message_types_by_name['CDiscoveryPingResponse'] = _CDISCOVERYPINGRESPONSE
DESCRIPTOR.message_types_by_name['CStreamingClientHandshakeInfo'] = _CSTREAMINGCLIENTHANDSHAKEINFO
DESCRIPTOR.message_types_by_name['CClientHandshakeMsg'] = _CCLIENTHANDSHAKEMSG
DESCRIPTOR.message_types_by_name['CStreamingServerHandshakeInfo'] = _CSTREAMINGSERVERHANDSHAKEINFO
DESCRIPTOR.message_types_by_name['CServerHandshakeMsg'] = _CSERVERHANDSHAKEMSG
DESCRIPTOR.message_types_by_name['CAuthenticationRequestMsg'] = _CAUTHENTICATIONREQUESTMSG
DESCRIPTOR.message_types_by_name['CAuthenticationResponseMsg'] = _CAUTHENTICATIONRESPONSEMSG
DESCRIPTOR.message_types_by_name['CKeepAliveMsg'] = _CKEEPALIVEMSG
DESCRIPTOR.message_types_by_name['CStartNetworkTestMsg'] = _CSTARTNETWORKTESTMSG
DESCRIPTOR.message_types_by_name['CStreamVideoMode'] = _CSTREAMVIDEOMODE
DESCRIPTOR.message_types_by_name['CStreamingClientCaps'] = _CSTREAMINGCLIENTCAPS
DESCRIPTOR.message_types_by_name['CStreamingClientConfig'] = _CSTREAMINGCLIENTCONFIG
DESCRIPTOR.message_types_by_name['CStreamingServerConfig'] = _CSTREAMINGSERVERCONFIG
DESCRIPTOR.message_types_by_name['CNegotiatedConfig'] = _CNEGOTIATEDCONFIG
DESCRIPTOR.message_types_by_name['CNegotiationInitMsg'] = _CNEGOTIATIONINITMSG
DESCRIPTOR.message_types_by_name['CNegotiationSetConfigMsg'] = _CNEGOTIATIONSETCONFIGMSG
DESCRIPTOR.message_types_by_name['CNegotiationCompleteMsg'] = _CNEGOTIATIONCOMPLETEMSG
DESCRIPTOR.message_types_by_name['CStartAudioDataMsg'] = _CSTARTAUDIODATAMSG
DESCRIPTOR.message_types_by_name['CStopAudioDataMsg'] = _CSTOPAUDIODATAMSG
DESCRIPTOR.message_types_by_name['CStartVideoDataMsg'] = _CSTARTVIDEODATAMSG
DESCRIPTOR.message_types_by_name['CStopVideoDataMsg'] = _CSTOPVIDEODATAMSG
DESCRIPTOR.message_types_by_name['CRecordedInput'] = _CRECORDEDINPUT
DESCRIPTOR.message_types_by_name['CRecordedInputStream'] = _CRECORDEDINPUTSTREAM
DESCRIPTOR.message_types_by_name['CInputLatencyTestMsg'] = _CINPUTLATENCYTESTMSG
DESCRIPTOR.message_types_by_name['CInputTouchFingerDownMsg'] = _CINPUTTOUCHFINGERDOWNMSG
DESCRIPTOR.message_types_by_name['CInputTouchFingerMotionMsg'] = _CINPUTTOUCHFINGERMOTIONMSG
DESCRIPTOR.message_types_by_name['CInputTouchFingerUpMsg'] = _CINPUTTOUCHFINGERUPMSG
DESCRIPTOR.message_types_by_name['CInputMouseMotionMsg'] = _CINPUTMOUSEMOTIONMSG
DESCRIPTOR.message_types_by_name['CInputMouseWheelMsg'] = _CINPUTMOUSEWHEELMSG
DESCRIPTOR.message_types_by_name['CInputMouseDownMsg'] = _CINPUTMOUSEDOWNMSG
DESCRIPTOR.message_types_by_name['CInputMouseUpMsg'] = _CINPUTMOUSEUPMSG
DESCRIPTOR.message_types_by_name['CInputKeyDownMsg'] = _CINPUTKEYDOWNMSG
DESCRIPTOR.message_types_by_name['CInputKeyUpMsg'] = _CINPUTKEYUPMSG
DESCRIPTOR.message_types_by_name['CInputTextMsg'] = _CINPUTTEXTMSG
DESCRIPTOR.message_types_by_name['CSetTitleMsg'] = _CSETTITLEMSG
DESCRIPTOR.message_types_by_name['CSetCaptureSizeMsg'] = _CSETCAPTURESIZEMSG
DESCRIPTOR.message_types_by_name['CSetIconMsg'] = _CSETICONMSG
DESCRIPTOR.message_types_by_name['CSetFlashStateMsg'] = _CSETFLASHSTATEMSG
DESCRIPTOR.message_types_by_name['CShowCursorMsg'] = _CSHOWCURSORMSG
DESCRIPTOR.message_types_by_name['CHideCursorMsg'] = _CHIDECURSORMSG
DESCRIPTOR.message_types_by_name['CSetCursorMsg'] = _CSETCURSORMSG
DESCRIPTOR.message_types_by_name['CGetCursorImageMsg'] = _CGETCURSORIMAGEMSG
DESCRIPTOR.message_types_by_name['CSetCursorImageMsg'] = _CSETCURSORIMAGEMSG
DESCRIPTOR.message_types_by_name['CVideoDecoderInfoMsg'] = _CVIDEODECODERINFOMSG
DESCRIPTOR.message_types_by_name['CVideoEncoderInfoMsg'] = _CVIDEOENCODERINFOMSG
DESCRIPTOR.message_types_by_name['CPauseMsg'] = _CPAUSEMSG
DESCRIPTOR.message_types_by_name['CResumeMsg'] = _CRESUMEMSG
DESCRIPTOR.message_types_by_name['CEnableHighResCaptureMsg'] = _CENABLEHIGHRESCAPTUREMSG
DESCRIPTOR.message_types_by_name['CDisableHighResCaptureMsg'] = _CDISABLEHIGHRESCAPTUREMSG
DESCRIPTOR.message_types_by_name['CToggleMagnificationMsg'] = _CTOGGLEMAGNIFICATIONMSG
DESCRIPTOR.message_types_by_name['CSetCapslockMsg'] = _CSETCAPSLOCKMSG
DESCRIPTOR.message_types_by_name['CStreamingKeymapEntry'] = _CSTREAMINGKEYMAPENTRY
DESCRIPTOR.message_types_by_name['CStreamingKeymap'] = _CSTREAMINGKEYMAP
DESCRIPTOR.message_types_by_name['CSetKeymapMsg'] = _CSETKEYMAPMSG
DESCRIPTOR.message_types_by_name['CStopRequest'] = _CSTOPREQUEST
DESCRIPTOR.message_types_by_name['CQuitRequest'] = _CQUITREQUEST
DESCRIPTOR.message_types_by_name['CDeleteCursorMsg'] = _CDELETECURSORMSG
DESCRIPTOR.message_types_by_name['CSetStreamingClientConfig'] = _CSETSTREAMINGCLIENTCONFIG
DESCRIPTOR.message_types_by_name['CSetQoSMsg'] = _CSETQOSMSG
DESCRIPTOR.message_types_by_name['CSetTargetFramerateMsg'] = _CSETTARGETFRAMERATEMSG
DESCRIPTOR.message_types_by_name['CSetTargetBitrateMsg'] = _CSETTARGETBITRATEMSG
DESCRIPTOR.message_types_by_name['COverlayEnabledMsg'] = _COVERLAYENABLEDMSG
DESCRIPTOR.message_types_by_name['CSetGammaRampMsg'] = _CSETGAMMARAMPMSG
DESCRIPTOR.message_types_by_name['CSetActivityMsg'] = _CSETACTIVITYMSG
DESCRIPTOR.message_types_by_name['CSystemSuspendMsg'] = _CSYSTEMSUSPENDMSG
DESCRIPTOR.message_types_by_name['CVirtualHereRequestMsg'] = _CVIRTUALHEREREQUESTMSG
DESCRIPTOR.message_types_by_name['CVirtualHereReadyMsg'] = _CVIRTUALHEREREADYMSG
DESCRIPTOR.message_types_by_name['CVirtualHereShareDeviceMsg'] = _CVIRTUALHERESHAREDEVICEMSG
DESCRIPTOR.message_types_by_name['CSetSpectatorModeMsg'] = _CSETSPECTATORMODEMSG
DESCRIPTOR.message_types_by_name['CRemoteHIDMsg'] = _CREMOTEHIDMSG
DESCRIPTOR.message_types_by_name['CTouchConfigActiveMsg'] = _CTOUCHCONFIGACTIVEMSG
DESCRIPTOR.message_types_by_name['CGetTouchConfigDataMsg'] = _CGETTOUCHCONFIGDATAMSG
DESCRIPTOR.message_types_by_name['CSetTouchConfigDataMsg'] = _CSETTOUCHCONFIGDATAMSG
DESCRIPTOR.message_types_by_name['CSaveTouchConfigLayoutMsg'] = _CSAVETOUCHCONFIGLAYOUTMSG
DESCRIPTOR.message_types_by_name['CTouchActionSetActiveMsg'] = _CTOUCHACTIONSETACTIVEMSG
DESCRIPTOR.message_types_by_name['CTouchActionSetLayerAddedMsg'] = _CTOUCHACTIONSETLAYERADDEDMSG
DESCRIPTOR.message_types_by_name['CTouchActionSetLayerRemovedMsg'] = _CTOUCHACTIONSETLAYERREMOVEDMSG
DESCRIPTOR.message_types_by_name['CGetTouchIconDataMsg'] = _CGETTOUCHICONDATAMSG
DESCRIPTOR.message_types_by_name['CSetTouchIconDataMsg'] = _CSETTOUCHICONDATAMSG
DESCRIPTOR.message_types_by_name['CRemotePlayTogetherGroupUpdateMsg'] = _CREMOTEPLAYTOGETHERGROUPUPDATEMSG
DESCRIPTOR.message_types_by_name['CSetInputTemporarilyDisabledMsg'] = _CSETINPUTTEMPORARILYDISABLEDMSG
DESCRIPTOR.message_types_by_name['CSetQualityOverrideMsg'] = _CSETQUALITYOVERRIDEMSG
DESCRIPTOR.message_types_by_name['CSetBitrateOverrideMsg'] = _CSETBITRATEOVERRIDEMSG
DESCRIPTOR.message_types_by_name['CShowOnScreenKeyboardMsg'] = _CSHOWONSCREENKEYBOARDMSG
DESCRIPTOR.message_types_by_name['CStreamDataLostMsg'] = _CSTREAMDATALOSTMSG
DESCRIPTOR.message_types_by_name['CAudioFormat'] = _CAUDIOFORMAT
DESCRIPTOR.message_types_by_name['CVideoFormat'] = _CVIDEOFORMAT
DESCRIPTOR.message_types_by_name['CFrameEvent'] = _CFRAMEEVENT
DESCRIPTOR.message_types_by_name['CFrameStats'] = _CFRAMESTATS
DESCRIPTOR.message_types_by_name['CFrameStatAccumulatedValue'] = _CFRAMESTATACCUMULATEDVALUE
DESCRIPTOR.message_types_by_name['CFrameStatsListMsg'] = _CFRAMESTATSLISTMSG
DESCRIPTOR.message_types_by_name['CStreamingSessionStats'] = _CSTREAMINGSESSIONSTATS
DESCRIPTOR.message_types_by_name['CDebugDumpMsg'] = _CDEBUGDUMPMSG
DESCRIPTOR.message_types_by_name['CLogMsg'] = _CLOGMSG
DESCRIPTOR.message_types_by_name['CLogUploadMsg'] = _CLOGUPLOADMSG
DESCRIPTOR.message_types_by_name['CTransportSignalMsg'] = _CTRANSPORTSIGNALMSG
DESCRIPTOR.message_types_by_name['CControllerConfigMsg'] = _CCONTROLLERCONFIGMSG
DESCRIPTOR.enum_types_by_name['EStreamChannel'] = _ESTREAMCHANNEL
DESCRIPTOR.enum_types_by_name['EStreamDiscoveryMessage'] = _ESTREAMDISCOVERYMESSAGE
DESCRIPTOR.enum_types_by_name['EStreamControlMessage'] = _ESTREAMCONTROLMESSAGE
DESCRIPTOR.enum_types_by_name['EStreamVersion'] = _ESTREAMVERSION
DESCRIPTOR.enum_types_by_name['EStreamAudioCodec'] = _ESTREAMAUDIOCODEC
DESCRIPTOR.enum_types_by_name['EStreamVideoCodec'] = _ESTREAMVIDEOCODEC
DESCRIPTOR.enum_types_by_name['EStreamQualityPreference'] = _ESTREAMQUALITYPREFERENCE
DESCRIPTOR.enum_types_by_name['EStreamBitrate'] = _ESTREAMBITRATE
DESCRIPTOR.enum_types_by_name['EStreamColorspace'] = _ESTREAMCOLORSPACE
DESCRIPTOR.enum_types_by_name['EStreamP2PScope'] = _ESTREAMP2PSCOPE
DESCRIPTOR.enum_types_by_name['EStreamHostPlayAudioPreference'] = _ESTREAMHOSTPLAYAUDIOPREFERENCE
DESCRIPTOR.enum_types_by_name['EStreamingDataType'] = _ESTREAMINGDATATYPE
DESCRIPTOR.enum_types_by_name['EStreamMouseButton'] = _ESTREAMMOUSEBUTTON
DESCRIPTOR.enum_types_by_name['EStreamMouseWheelDirection'] = _ESTREAMMOUSEWHEELDIRECTION
DESCRIPTOR.enum_types_by_name['EStreamFramerateLimiter'] = _ESTREAMFRAMERATELIMITER
DESCRIPTOR.enum_types_by_name['EStreamActivity'] = _ESTREAMACTIVITY
DESCRIPTOR.enum_types_by_name['EStreamDataMessage'] = _ESTREAMDATAMESSAGE
DESCRIPTOR.enum_types_by_name['EAudioFormat'] = _EAUDIOFORMAT
DESCRIPTOR.enum_types_by_name['EVideoFormat'] = _EVIDEOFORMAT
DESCRIPTOR.enum_types_by_name['EStreamStatsMessage'] = _ESTREAMSTATSMESSAGE
DESCRIPTOR.enum_types_by_name['EStreamFrameEvent'] = _ESTREAMFRAMEEVENT
DESCRIPTOR.enum_types_by_name['EStreamFrameResult'] = _ESTREAMFRAMERESULT
DESCRIPTOR.enum_types_by_name['EFrameAccumulatedStat'] = _EFRAMEACCUMULATEDSTAT
DESCRIPTOR.enum_types_by_name['ELogFileType'] = _ELOGFILETYPE
DESCRIPTOR.enum_types_by_name['EStreamControllerConfigMsg'] = _ESTREAMCONTROLLERCONFIGMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDiscoveryPingRequest = _reflection.GeneratedProtocolMessageType('CDiscoveryPingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CDISCOVERYPINGREQUEST,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CDiscoveryPingRequest)
  })
_sym_db.RegisterMessage(CDiscoveryPingRequest)

CDiscoveryPingResponse = _reflection.GeneratedProtocolMessageType('CDiscoveryPingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CDISCOVERYPINGRESPONSE,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CDiscoveryPingResponse)
  })
_sym_db.RegisterMessage(CDiscoveryPingResponse)

CStreamingClientHandshakeInfo = _reflection.GeneratedProtocolMessageType('CStreamingClientHandshakeInfo', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGCLIENTHANDSHAKEINFO,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingClientHandshakeInfo)
  })
_sym_db.RegisterMessage(CStreamingClientHandshakeInfo)

CClientHandshakeMsg = _reflection.GeneratedProtocolMessageType('CClientHandshakeMsg', (_message.Message,), {
  'DESCRIPTOR' : _CCLIENTHANDSHAKEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CClientHandshakeMsg)
  })
_sym_db.RegisterMessage(CClientHandshakeMsg)

CStreamingServerHandshakeInfo = _reflection.GeneratedProtocolMessageType('CStreamingServerHandshakeInfo', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGSERVERHANDSHAKEINFO,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingServerHandshakeInfo)
  })
_sym_db.RegisterMessage(CStreamingServerHandshakeInfo)

CServerHandshakeMsg = _reflection.GeneratedProtocolMessageType('CServerHandshakeMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSERVERHANDSHAKEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CServerHandshakeMsg)
  })
_sym_db.RegisterMessage(CServerHandshakeMsg)

CAuthenticationRequestMsg = _reflection.GeneratedProtocolMessageType('CAuthenticationRequestMsg', (_message.Message,), {
  'DESCRIPTOR' : _CAUTHENTICATIONREQUESTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CAuthenticationRequestMsg)
  })
_sym_db.RegisterMessage(CAuthenticationRequestMsg)

CAuthenticationResponseMsg = _reflection.GeneratedProtocolMessageType('CAuthenticationResponseMsg', (_message.Message,), {
  'DESCRIPTOR' : _CAUTHENTICATIONRESPONSEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CAuthenticationResponseMsg)
  })
_sym_db.RegisterMessage(CAuthenticationResponseMsg)

CKeepAliveMsg = _reflection.GeneratedProtocolMessageType('CKeepAliveMsg', (_message.Message,), {
  'DESCRIPTOR' : _CKEEPALIVEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CKeepAliveMsg)
  })
_sym_db.RegisterMessage(CKeepAliveMsg)

CStartNetworkTestMsg = _reflection.GeneratedProtocolMessageType('CStartNetworkTestMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTARTNETWORKTESTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStartNetworkTestMsg)
  })
_sym_db.RegisterMessage(CStartNetworkTestMsg)

CStreamVideoMode = _reflection.GeneratedProtocolMessageType('CStreamVideoMode', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMVIDEOMODE,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamVideoMode)
  })
_sym_db.RegisterMessage(CStreamVideoMode)

CStreamingClientCaps = _reflection.GeneratedProtocolMessageType('CStreamingClientCaps', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGCLIENTCAPS,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingClientCaps)
  })
_sym_db.RegisterMessage(CStreamingClientCaps)

CStreamingClientConfig = _reflection.GeneratedProtocolMessageType('CStreamingClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGCLIENTCONFIG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingClientConfig)
  })
_sym_db.RegisterMessage(CStreamingClientConfig)

CStreamingServerConfig = _reflection.GeneratedProtocolMessageType('CStreamingServerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGSERVERCONFIG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingServerConfig)
  })
_sym_db.RegisterMessage(CStreamingServerConfig)

CNegotiatedConfig = _reflection.GeneratedProtocolMessageType('CNegotiatedConfig', (_message.Message,), {
  'DESCRIPTOR' : _CNEGOTIATEDCONFIG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CNegotiatedConfig)
  })
_sym_db.RegisterMessage(CNegotiatedConfig)

CNegotiationInitMsg = _reflection.GeneratedProtocolMessageType('CNegotiationInitMsg', (_message.Message,), {
  'DESCRIPTOR' : _CNEGOTIATIONINITMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CNegotiationInitMsg)
  })
_sym_db.RegisterMessage(CNegotiationInitMsg)

CNegotiationSetConfigMsg = _reflection.GeneratedProtocolMessageType('CNegotiationSetConfigMsg', (_message.Message,), {
  'DESCRIPTOR' : _CNEGOTIATIONSETCONFIGMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CNegotiationSetConfigMsg)
  })
_sym_db.RegisterMessage(CNegotiationSetConfigMsg)

CNegotiationCompleteMsg = _reflection.GeneratedProtocolMessageType('CNegotiationCompleteMsg', (_message.Message,), {
  'DESCRIPTOR' : _CNEGOTIATIONCOMPLETEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CNegotiationCompleteMsg)
  })
_sym_db.RegisterMessage(CNegotiationCompleteMsg)

CStartAudioDataMsg = _reflection.GeneratedProtocolMessageType('CStartAudioDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTARTAUDIODATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStartAudioDataMsg)
  })
_sym_db.RegisterMessage(CStartAudioDataMsg)

CStopAudioDataMsg = _reflection.GeneratedProtocolMessageType('CStopAudioDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTOPAUDIODATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStopAudioDataMsg)
  })
_sym_db.RegisterMessage(CStopAudioDataMsg)

CStartVideoDataMsg = _reflection.GeneratedProtocolMessageType('CStartVideoDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTARTVIDEODATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStartVideoDataMsg)
  })
_sym_db.RegisterMessage(CStartVideoDataMsg)

CStopVideoDataMsg = _reflection.GeneratedProtocolMessageType('CStopVideoDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTOPVIDEODATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStopVideoDataMsg)
  })
_sym_db.RegisterMessage(CStopVideoDataMsg)

CRecordedInput = _reflection.GeneratedProtocolMessageType('CRecordedInput', (_message.Message,), {
  'DESCRIPTOR' : _CRECORDEDINPUT,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CRecordedInput)
  })
_sym_db.RegisterMessage(CRecordedInput)

CRecordedInputStream = _reflection.GeneratedProtocolMessageType('CRecordedInputStream', (_message.Message,), {
  'DESCRIPTOR' : _CRECORDEDINPUTSTREAM,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CRecordedInputStream)
  })
_sym_db.RegisterMessage(CRecordedInputStream)

CInputLatencyTestMsg = _reflection.GeneratedProtocolMessageType('CInputLatencyTestMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTLATENCYTESTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputLatencyTestMsg)
  })
_sym_db.RegisterMessage(CInputLatencyTestMsg)

CInputTouchFingerDownMsg = _reflection.GeneratedProtocolMessageType('CInputTouchFingerDownMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTTOUCHFINGERDOWNMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputTouchFingerDownMsg)
  })
_sym_db.RegisterMessage(CInputTouchFingerDownMsg)

CInputTouchFingerMotionMsg = _reflection.GeneratedProtocolMessageType('CInputTouchFingerMotionMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTTOUCHFINGERMOTIONMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputTouchFingerMotionMsg)
  })
_sym_db.RegisterMessage(CInputTouchFingerMotionMsg)

CInputTouchFingerUpMsg = _reflection.GeneratedProtocolMessageType('CInputTouchFingerUpMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTTOUCHFINGERUPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputTouchFingerUpMsg)
  })
_sym_db.RegisterMessage(CInputTouchFingerUpMsg)

CInputMouseMotionMsg = _reflection.GeneratedProtocolMessageType('CInputMouseMotionMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTMOUSEMOTIONMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputMouseMotionMsg)
  })
_sym_db.RegisterMessage(CInputMouseMotionMsg)

CInputMouseWheelMsg = _reflection.GeneratedProtocolMessageType('CInputMouseWheelMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTMOUSEWHEELMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputMouseWheelMsg)
  })
_sym_db.RegisterMessage(CInputMouseWheelMsg)

CInputMouseDownMsg = _reflection.GeneratedProtocolMessageType('CInputMouseDownMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTMOUSEDOWNMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputMouseDownMsg)
  })
_sym_db.RegisterMessage(CInputMouseDownMsg)

CInputMouseUpMsg = _reflection.GeneratedProtocolMessageType('CInputMouseUpMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTMOUSEUPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputMouseUpMsg)
  })
_sym_db.RegisterMessage(CInputMouseUpMsg)

CInputKeyDownMsg = _reflection.GeneratedProtocolMessageType('CInputKeyDownMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTKEYDOWNMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputKeyDownMsg)
  })
_sym_db.RegisterMessage(CInputKeyDownMsg)

CInputKeyUpMsg = _reflection.GeneratedProtocolMessageType('CInputKeyUpMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTKEYUPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputKeyUpMsg)
  })
_sym_db.RegisterMessage(CInputKeyUpMsg)

CInputTextMsg = _reflection.GeneratedProtocolMessageType('CInputTextMsg', (_message.Message,), {
  'DESCRIPTOR' : _CINPUTTEXTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CInputTextMsg)
  })
_sym_db.RegisterMessage(CInputTextMsg)

CSetTitleMsg = _reflection.GeneratedProtocolMessageType('CSetTitleMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETTITLEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetTitleMsg)
  })
_sym_db.RegisterMessage(CSetTitleMsg)

CSetCaptureSizeMsg = _reflection.GeneratedProtocolMessageType('CSetCaptureSizeMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETCAPTURESIZEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetCaptureSizeMsg)
  })
_sym_db.RegisterMessage(CSetCaptureSizeMsg)

CSetIconMsg = _reflection.GeneratedProtocolMessageType('CSetIconMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETICONMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetIconMsg)
  })
_sym_db.RegisterMessage(CSetIconMsg)

CSetFlashStateMsg = _reflection.GeneratedProtocolMessageType('CSetFlashStateMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETFLASHSTATEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetFlashStateMsg)
  })
_sym_db.RegisterMessage(CSetFlashStateMsg)

CShowCursorMsg = _reflection.GeneratedProtocolMessageType('CShowCursorMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSHOWCURSORMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CShowCursorMsg)
  })
_sym_db.RegisterMessage(CShowCursorMsg)

CHideCursorMsg = _reflection.GeneratedProtocolMessageType('CHideCursorMsg', (_message.Message,), {
  'DESCRIPTOR' : _CHIDECURSORMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CHideCursorMsg)
  })
_sym_db.RegisterMessage(CHideCursorMsg)

CSetCursorMsg = _reflection.GeneratedProtocolMessageType('CSetCursorMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETCURSORMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetCursorMsg)
  })
_sym_db.RegisterMessage(CSetCursorMsg)

CGetCursorImageMsg = _reflection.GeneratedProtocolMessageType('CGetCursorImageMsg', (_message.Message,), {
  'DESCRIPTOR' : _CGETCURSORIMAGEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CGetCursorImageMsg)
  })
_sym_db.RegisterMessage(CGetCursorImageMsg)

CSetCursorImageMsg = _reflection.GeneratedProtocolMessageType('CSetCursorImageMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETCURSORIMAGEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetCursorImageMsg)
  })
_sym_db.RegisterMessage(CSetCursorImageMsg)

CVideoDecoderInfoMsg = _reflection.GeneratedProtocolMessageType('CVideoDecoderInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEODECODERINFOMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVideoDecoderInfoMsg)
  })
_sym_db.RegisterMessage(CVideoDecoderInfoMsg)

CVideoEncoderInfoMsg = _reflection.GeneratedProtocolMessageType('CVideoEncoderInfoMsg', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEOENCODERINFOMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVideoEncoderInfoMsg)
  })
_sym_db.RegisterMessage(CVideoEncoderInfoMsg)

CPauseMsg = _reflection.GeneratedProtocolMessageType('CPauseMsg', (_message.Message,), {
  'DESCRIPTOR' : _CPAUSEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CPauseMsg)
  })
_sym_db.RegisterMessage(CPauseMsg)

CResumeMsg = _reflection.GeneratedProtocolMessageType('CResumeMsg', (_message.Message,), {
  'DESCRIPTOR' : _CRESUMEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CResumeMsg)
  })
_sym_db.RegisterMessage(CResumeMsg)

CEnableHighResCaptureMsg = _reflection.GeneratedProtocolMessageType('CEnableHighResCaptureMsg', (_message.Message,), {
  'DESCRIPTOR' : _CENABLEHIGHRESCAPTUREMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CEnableHighResCaptureMsg)
  })
_sym_db.RegisterMessage(CEnableHighResCaptureMsg)

CDisableHighResCaptureMsg = _reflection.GeneratedProtocolMessageType('CDisableHighResCaptureMsg', (_message.Message,), {
  'DESCRIPTOR' : _CDISABLEHIGHRESCAPTUREMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CDisableHighResCaptureMsg)
  })
_sym_db.RegisterMessage(CDisableHighResCaptureMsg)

CToggleMagnificationMsg = _reflection.GeneratedProtocolMessageType('CToggleMagnificationMsg', (_message.Message,), {
  'DESCRIPTOR' : _CTOGGLEMAGNIFICATIONMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CToggleMagnificationMsg)
  })
_sym_db.RegisterMessage(CToggleMagnificationMsg)

CSetCapslockMsg = _reflection.GeneratedProtocolMessageType('CSetCapslockMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETCAPSLOCKMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetCapslockMsg)
  })
_sym_db.RegisterMessage(CSetCapslockMsg)

CStreamingKeymapEntry = _reflection.GeneratedProtocolMessageType('CStreamingKeymapEntry', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGKEYMAPENTRY,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingKeymapEntry)
  })
_sym_db.RegisterMessage(CStreamingKeymapEntry)

CStreamingKeymap = _reflection.GeneratedProtocolMessageType('CStreamingKeymap', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGKEYMAP,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingKeymap)
  })
_sym_db.RegisterMessage(CStreamingKeymap)

CSetKeymapMsg = _reflection.GeneratedProtocolMessageType('CSetKeymapMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETKEYMAPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetKeymapMsg)
  })
_sym_db.RegisterMessage(CSetKeymapMsg)

CStopRequest = _reflection.GeneratedProtocolMessageType('CStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _CSTOPREQUEST,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStopRequest)
  })
_sym_db.RegisterMessage(CStopRequest)

CQuitRequest = _reflection.GeneratedProtocolMessageType('CQuitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CQUITREQUEST,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CQuitRequest)
  })
_sym_db.RegisterMessage(CQuitRequest)

CDeleteCursorMsg = _reflection.GeneratedProtocolMessageType('CDeleteCursorMsg', (_message.Message,), {
  'DESCRIPTOR' : _CDELETECURSORMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CDeleteCursorMsg)
  })
_sym_db.RegisterMessage(CDeleteCursorMsg)

CSetStreamingClientConfig = _reflection.GeneratedProtocolMessageType('CSetStreamingClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _CSETSTREAMINGCLIENTCONFIG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetStreamingClientConfig)
  })
_sym_db.RegisterMessage(CSetStreamingClientConfig)

CSetQoSMsg = _reflection.GeneratedProtocolMessageType('CSetQoSMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETQOSMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetQoSMsg)
  })
_sym_db.RegisterMessage(CSetQoSMsg)

CSetTargetFramerateMsg = _reflection.GeneratedProtocolMessageType('CSetTargetFramerateMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETTARGETFRAMERATEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetTargetFramerateMsg)
  })
_sym_db.RegisterMessage(CSetTargetFramerateMsg)

CSetTargetBitrateMsg = _reflection.GeneratedProtocolMessageType('CSetTargetBitrateMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETTARGETBITRATEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetTargetBitrateMsg)
  })
_sym_db.RegisterMessage(CSetTargetBitrateMsg)

COverlayEnabledMsg = _reflection.GeneratedProtocolMessageType('COverlayEnabledMsg', (_message.Message,), {
  'DESCRIPTOR' : _COVERLAYENABLEDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:COverlayEnabledMsg)
  })
_sym_db.RegisterMessage(COverlayEnabledMsg)

CSetGammaRampMsg = _reflection.GeneratedProtocolMessageType('CSetGammaRampMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETGAMMARAMPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetGammaRampMsg)
  })
_sym_db.RegisterMessage(CSetGammaRampMsg)

CSetActivityMsg = _reflection.GeneratedProtocolMessageType('CSetActivityMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETACTIVITYMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetActivityMsg)
  })
_sym_db.RegisterMessage(CSetActivityMsg)

CSystemSuspendMsg = _reflection.GeneratedProtocolMessageType('CSystemSuspendMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSYSTEMSUSPENDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSystemSuspendMsg)
  })
_sym_db.RegisterMessage(CSystemSuspendMsg)

CVirtualHereRequestMsg = _reflection.GeneratedProtocolMessageType('CVirtualHereRequestMsg', (_message.Message,), {
  'DESCRIPTOR' : _CVIRTUALHEREREQUESTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVirtualHereRequestMsg)
  })
_sym_db.RegisterMessage(CVirtualHereRequestMsg)

CVirtualHereReadyMsg = _reflection.GeneratedProtocolMessageType('CVirtualHereReadyMsg', (_message.Message,), {
  'DESCRIPTOR' : _CVIRTUALHEREREADYMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVirtualHereReadyMsg)
  })
_sym_db.RegisterMessage(CVirtualHereReadyMsg)

CVirtualHereShareDeviceMsg = _reflection.GeneratedProtocolMessageType('CVirtualHereShareDeviceMsg', (_message.Message,), {
  'DESCRIPTOR' : _CVIRTUALHERESHAREDEVICEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVirtualHereShareDeviceMsg)
  })
_sym_db.RegisterMessage(CVirtualHereShareDeviceMsg)

CSetSpectatorModeMsg = _reflection.GeneratedProtocolMessageType('CSetSpectatorModeMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETSPECTATORMODEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetSpectatorModeMsg)
  })
_sym_db.RegisterMessage(CSetSpectatorModeMsg)

CRemoteHIDMsg = _reflection.GeneratedProtocolMessageType('CRemoteHIDMsg', (_message.Message,), {
  'DESCRIPTOR' : _CREMOTEHIDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CRemoteHIDMsg)
  })
_sym_db.RegisterMessage(CRemoteHIDMsg)

CTouchConfigActiveMsg = _reflection.GeneratedProtocolMessageType('CTouchConfigActiveMsg', (_message.Message,), {
  'DESCRIPTOR' : _CTOUCHCONFIGACTIVEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CTouchConfigActiveMsg)
  })
_sym_db.RegisterMessage(CTouchConfigActiveMsg)

CGetTouchConfigDataMsg = _reflection.GeneratedProtocolMessageType('CGetTouchConfigDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CGETTOUCHCONFIGDATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CGetTouchConfigDataMsg)
  })
_sym_db.RegisterMessage(CGetTouchConfigDataMsg)

CSetTouchConfigDataMsg = _reflection.GeneratedProtocolMessageType('CSetTouchConfigDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETTOUCHCONFIGDATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetTouchConfigDataMsg)
  })
_sym_db.RegisterMessage(CSetTouchConfigDataMsg)

CSaveTouchConfigLayoutMsg = _reflection.GeneratedProtocolMessageType('CSaveTouchConfigLayoutMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSAVETOUCHCONFIGLAYOUTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSaveTouchConfigLayoutMsg)
  })
_sym_db.RegisterMessage(CSaveTouchConfigLayoutMsg)

CTouchActionSetActiveMsg = _reflection.GeneratedProtocolMessageType('CTouchActionSetActiveMsg', (_message.Message,), {
  'DESCRIPTOR' : _CTOUCHACTIONSETACTIVEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CTouchActionSetActiveMsg)
  })
_sym_db.RegisterMessage(CTouchActionSetActiveMsg)

CTouchActionSetLayerAddedMsg = _reflection.GeneratedProtocolMessageType('CTouchActionSetLayerAddedMsg', (_message.Message,), {
  'DESCRIPTOR' : _CTOUCHACTIONSETLAYERADDEDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CTouchActionSetLayerAddedMsg)
  })
_sym_db.RegisterMessage(CTouchActionSetLayerAddedMsg)

CTouchActionSetLayerRemovedMsg = _reflection.GeneratedProtocolMessageType('CTouchActionSetLayerRemovedMsg', (_message.Message,), {
  'DESCRIPTOR' : _CTOUCHACTIONSETLAYERREMOVEDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CTouchActionSetLayerRemovedMsg)
  })
_sym_db.RegisterMessage(CTouchActionSetLayerRemovedMsg)

CGetTouchIconDataMsg = _reflection.GeneratedProtocolMessageType('CGetTouchIconDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CGETTOUCHICONDATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CGetTouchIconDataMsg)
  })
_sym_db.RegisterMessage(CGetTouchIconDataMsg)

CSetTouchIconDataMsg = _reflection.GeneratedProtocolMessageType('CSetTouchIconDataMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETTOUCHICONDATAMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetTouchIconDataMsg)
  })
_sym_db.RegisterMessage(CSetTouchIconDataMsg)

CRemotePlayTogetherGroupUpdateMsg = _reflection.GeneratedProtocolMessageType('CRemotePlayTogetherGroupUpdateMsg', (_message.Message,), {

  'Player' : _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
    'DESCRIPTOR' : _CREMOTEPLAYTOGETHERGROUPUPDATEMSG_PLAYER,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CRemotePlayTogetherGroupUpdateMsg.Player)
    })
  ,
  'DESCRIPTOR' : _CREMOTEPLAYTOGETHERGROUPUPDATEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CRemotePlayTogetherGroupUpdateMsg)
  })
_sym_db.RegisterMessage(CRemotePlayTogetherGroupUpdateMsg)
_sym_db.RegisterMessage(CRemotePlayTogetherGroupUpdateMsg.Player)

CSetInputTemporarilyDisabledMsg = _reflection.GeneratedProtocolMessageType('CSetInputTemporarilyDisabledMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETINPUTTEMPORARILYDISABLEDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetInputTemporarilyDisabledMsg)
  })
_sym_db.RegisterMessage(CSetInputTemporarilyDisabledMsg)

CSetQualityOverrideMsg = _reflection.GeneratedProtocolMessageType('CSetQualityOverrideMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETQUALITYOVERRIDEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetQualityOverrideMsg)
  })
_sym_db.RegisterMessage(CSetQualityOverrideMsg)

CSetBitrateOverrideMsg = _reflection.GeneratedProtocolMessageType('CSetBitrateOverrideMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSETBITRATEOVERRIDEMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CSetBitrateOverrideMsg)
  })
_sym_db.RegisterMessage(CSetBitrateOverrideMsg)

CShowOnScreenKeyboardMsg = _reflection.GeneratedProtocolMessageType('CShowOnScreenKeyboardMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSHOWONSCREENKEYBOARDMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CShowOnScreenKeyboardMsg)
  })
_sym_db.RegisterMessage(CShowOnScreenKeyboardMsg)

CStreamDataLostMsg = _reflection.GeneratedProtocolMessageType('CStreamDataLostMsg', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMDATALOSTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamDataLostMsg)
  })
_sym_db.RegisterMessage(CStreamDataLostMsg)

CAudioFormat = _reflection.GeneratedProtocolMessageType('CAudioFormat', (_message.Message,), {
  'DESCRIPTOR' : _CAUDIOFORMAT,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CAudioFormat)
  })
_sym_db.RegisterMessage(CAudioFormat)

CVideoFormat = _reflection.GeneratedProtocolMessageType('CVideoFormat', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEOFORMAT,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CVideoFormat)
  })
_sym_db.RegisterMessage(CVideoFormat)

CFrameEvent = _reflection.GeneratedProtocolMessageType('CFrameEvent', (_message.Message,), {
  'DESCRIPTOR' : _CFRAMEEVENT,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CFrameEvent)
  })
_sym_db.RegisterMessage(CFrameEvent)

CFrameStats = _reflection.GeneratedProtocolMessageType('CFrameStats', (_message.Message,), {
  'DESCRIPTOR' : _CFRAMESTATS,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CFrameStats)
  })
_sym_db.RegisterMessage(CFrameStats)

CFrameStatAccumulatedValue = _reflection.GeneratedProtocolMessageType('CFrameStatAccumulatedValue', (_message.Message,), {
  'DESCRIPTOR' : _CFRAMESTATACCUMULATEDVALUE,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CFrameStatAccumulatedValue)
  })
_sym_db.RegisterMessage(CFrameStatAccumulatedValue)

CFrameStatsListMsg = _reflection.GeneratedProtocolMessageType('CFrameStatsListMsg', (_message.Message,), {
  'DESCRIPTOR' : _CFRAMESTATSLISTMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CFrameStatsListMsg)
  })
_sym_db.RegisterMessage(CFrameStatsListMsg)

CStreamingSessionStats = _reflection.GeneratedProtocolMessageType('CStreamingSessionStats', (_message.Message,), {
  'DESCRIPTOR' : _CSTREAMINGSESSIONSTATS,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CStreamingSessionStats)
  })
_sym_db.RegisterMessage(CStreamingSessionStats)

CDebugDumpMsg = _reflection.GeneratedProtocolMessageType('CDebugDumpMsg', (_message.Message,), {
  'DESCRIPTOR' : _CDEBUGDUMPMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CDebugDumpMsg)
  })
_sym_db.RegisterMessage(CDebugDumpMsg)

CLogMsg = _reflection.GeneratedProtocolMessageType('CLogMsg', (_message.Message,), {
  'DESCRIPTOR' : _CLOGMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CLogMsg)
  })
_sym_db.RegisterMessage(CLogMsg)

CLogUploadMsg = _reflection.GeneratedProtocolMessageType('CLogUploadMsg', (_message.Message,), {
  'DESCRIPTOR' : _CLOGUPLOADMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CLogUploadMsg)
  })
_sym_db.RegisterMessage(CLogUploadMsg)

CTransportSignalMsg = _reflection.GeneratedProtocolMessageType('CTransportSignalMsg', (_message.Message,), {

  'WebRTCMessage' : _reflection.GeneratedProtocolMessageType('WebRTCMessage', (_message.Message,), {

    'Candidate' : _reflection.GeneratedProtocolMessageType('Candidate', (_message.Message,), {
      'DESCRIPTOR' : _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE_CANDIDATE,
      '__module__' : 'steammessages_remoteplay_pb2'
      # @@protoc_insertion_point(class_scope:CTransportSignalMsg.WebRTCMessage.Candidate)
      })
    ,
    'DESCRIPTOR' : _CTRANSPORTSIGNALMSG_WEBRTCMESSAGE,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CTransportSignalMsg.WebRTCMessage)
    })
  ,
  'DESCRIPTOR' : _CTRANSPORTSIGNALMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CTransportSignalMsg)
  })
_sym_db.RegisterMessage(CTransportSignalMsg)
_sym_db.RegisterMessage(CTransportSignalMsg.WebRTCMessage)
_sym_db.RegisterMessage(CTransportSignalMsg.WebRTCMessage.Candidate)

CControllerConfigMsg = _reflection.GeneratedProtocolMessageType('CControllerConfigMsg', (_message.Message,), {

  'ControllerConfigResponse' : _reflection.GeneratedProtocolMessageType('ControllerConfigResponse', (_message.Message,), {
    'DESCRIPTOR' : _CCONTROLLERCONFIGMSG_CONTROLLERCONFIGRESPONSE,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CControllerConfigMsg.ControllerConfigResponse)
    })
  ,

  'ControllerPersonalizationResponse' : _reflection.GeneratedProtocolMessageType('ControllerPersonalizationResponse', (_message.Message,), {
    'DESCRIPTOR' : _CCONTROLLERCONFIGMSG_CONTROLLERPERSONALIZATIONRESPONSE,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CControllerConfigMsg.ControllerPersonalizationResponse)
    })
  ,

  'ControllerActiveConfigChangeResponse' : _reflection.GeneratedProtocolMessageType('ControllerActiveConfigChangeResponse', (_message.Message,), {
    'DESCRIPTOR' : _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGCHANGERESPONSE,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CControllerConfigMsg.ControllerActiveConfigChangeResponse)
    })
  ,

  'ControllerActiveConfigMsg' : _reflection.GeneratedProtocolMessageType('ControllerActiveConfigMsg', (_message.Message,), {
    'DESCRIPTOR' : _CCONTROLLERCONFIGMSG_CONTROLLERACTIVECONFIGMSG,
    '__module__' : 'steammessages_remoteplay_pb2'
    # @@protoc_insertion_point(class_scope:CControllerConfigMsg.ControllerActiveConfigMsg)
    })
  ,
  'DESCRIPTOR' : _CCONTROLLERCONFIGMSG,
  '__module__' : 'steammessages_remoteplay_pb2'
  # @@protoc_insertion_point(class_scope:CControllerConfigMsg)
  })
_sym_db.RegisterMessage(CControllerConfigMsg)
_sym_db.RegisterMessage(CControllerConfigMsg.ControllerConfigResponse)
_sym_db.RegisterMessage(CControllerConfigMsg.ControllerPersonalizationResponse)
_sym_db.RegisterMessage(CControllerConfigMsg.ControllerActiveConfigChangeResponse)
_sym_db.RegisterMessage(CControllerConfigMsg.ControllerActiveConfigMsg)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
