# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_broadcast.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dsteammessages_broadcast.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xf1\x01\n(CBroadcast_BeginBroadcastSession_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\x1a\n\x12\x63lient_instance_id\x18\x03 \x01(\x04\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0e\n\x06\x63\x65llid\x18\x05 \x01(\r\x12\x12\n\nrtmp_token\x18\x06 \x01(\x04\x12\x18\n\x10thumbnail_upload\x18\x07 \x01(\x08\x12\x13\n\x0b\x63lient_beta\x18\x08 \x01(\t\x12\r\n\x05sysid\x18\t \x01(\r\x12\x14\n\x0c\x61llow_webrtc\x18\n \x01(\x08\"\x9c\x03\n)CBroadcast_BeginBroadcastSession_Response\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12P\n\x18thumbnail_upload_address\x18\x02 \x01(\tB.\x82\xb5\x18*Http address to upload the thumbnail data.\x12\x65\n\x16thumbnail_upload_token\x18\x03 \x01(\tBE\x82\xb5\x18\x41token to authorize as broadcaster to upload content to the relay.\x12K\n\x1athumbnail_interval_seconds\x18\x04 \x01(\rB\'\x82\xb5\x18#how many seconds between thumbnails\x12S\n\x1aheartbeat_interval_seconds\x18\x05 \x01(\rB/\x82\xb5\x18+how many seconds between session heartbeats\">\n&CBroadcast_EndBroadcastSession_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\")\n\'CBroadcast_EndBroadcastSession_Response\"\x88\x02\n\'CBroadcast_StartBroadcastUpload_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x63\x65llid\x18\x02 \x01(\r\x12\x0f\n\x07\x61s_rtmp\x18\x03 \x01(\x08\x12\x15\n\rdelay_seconds\x18\x04 \x01(\r\x12R\n\nrtmp_token\x18\x05 \x01(\x04:\x01\x30\x42;\x82\xb5\x18\x37Only set during RTMP uploads; secret key from the user.\x12\x19\n\x11upload_ip_address\x18\x06 \x01(\r\x12\x11\n\tis_replay\x18\x07 \x01(\x08\x12\r\n\x05sysid\x18\x08 \x01(\r\"\xa2\x01\n(CBroadcast_StartBroadcastUpload_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\t\x12\x16\n\x0eupload_address\x18\x02 \x01(\t\x12\x1b\n\x13\x62roadcast_upload_id\x18\x03 \x01(\x06\x12\x15\n\renable_replay\x18\x06 \x01(\x08\x12\x14\n\x0chttp_address\x18\x07 \x01(\t\"g\n1CBroadcast_NotifyBroadcastUploadStop_Notification\x12\x1b\n\x13\x62roadcast_upload_id\x18\x01 \x01(\x06\x12\x15\n\rupload_result\x18\x02 \x01(\r\"\x89\x03\n!CBroadcast_WatchBroadcast_Request\x12)\n\x07steamid\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x62roadcaster steamID.\x12X\n\x15\x65xisting_broadcast_id\x18\x02 \x01(\x06\x42\x39\x82\xb5\x18\x35\x62roadcast session ID (optional, rejoin if specified).\x12\x62\n\x0cviewer_token\x18\x03 \x01(\x06\x42L\x82\xb5\x18Hviewer token received from last WatchRequest call, from browser storage.\x12\x13\n\x0b\x63lient_cell\x18\x05 \x01(\r\x12S\n\x0ewatch_location\x18\x06 \x01(\x0e\x32\x18.EBroadcastWatchLocation:!k_EBroadcastWatchLocation_Invalid\x12\x11\n\tis_webrtc\x18\x07 \x01(\x08\"\xfa\x07\n\"CBroadcast_WatchBroadcast_Response\x12[\n\x08response\x18\x01 \x01(\x0e\x32\x32.CBroadcast_WatchBroadcast_Response.EWatchResponse:\x15k_EWatchResponseReady\x12\x0f\n\x07mpd_url\x18\x02 \x01(\t\x12\x14\n\x0c\x62roadcast_id\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x04\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x06 \x01(\r\x12\x12\n\npermission\x18\x07 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x08 \x01(\x08\x12\x15\n\rseconds_delay\x18\t \x01(\x05\x12\x14\n\x0cviewer_token\x18\n \x01(\x06\x12\x1b\n\x13hls_m3u8_master_url\x18\x0b \x01(\t\x12\x1a\n\x12heartbeat_interval\x18\x0c \x01(\x05\x12\x15\n\rthumbnail_url\x18\r \x01(\t\x12\x11\n\tis_webrtc\x18\x0e \x01(\x08\x12\x19\n\x11webrtc_session_id\x18\x0f \x01(\x06\x12\x18\n\x10webrtc_offer_sdp\x18\x10 \x01(\t\x12\x1a\n\x12webrtc_turn_server\x18\x11 \x01(\t\x12\x11\n\tis_replay\x18\x12 \x01(\x08\x12\x10\n\x08\x64uration\x18\x13 \x01(\x05\x12\x1f\n\x17\x63\x64n_auth_url_parameters\x18\x14 \x01(\t\"\xcf\x03\n\x0e\x45WatchResponse\x12\x19\n\x15k_EWatchResponseReady\x10\x01\x12 \n\x1ck_EWatchResponseNotAvailable\x10\x02\x12&\n\"k_EWatchResponseWaitingForApproval\x10\x03\x12#\n\x1fk_EWatchResponseWaitingForStart\x10\x04\x12\"\n\x1ek_EWatchResponseInvalidSession\x10\x05\x12%\n!k_EWatchResponseTooManyBroadcasts\x10\x06\x12\'\n#k_EWatchResponseWaitingForReconnect\x10\x07\x12&\n\"k_EWatchResponseSystemNotSupported\x10\x08\x12\"\n\x1ek_EWatchResponseUserRestricted\x10\t\x12#\n\x1fk_EWatchResponseClientOutOfDate\x10\n\x12%\n!k_EWatchResponsePoorUploadQuality\x10\x0b\x12\'\n#k_EWatchResponseMissingSubscription\x10\x0c\"\xae\x02\n*CBroadcast_HeartbeatBroadcast_Notification\x12)\n\x07steamid\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x62roadcaster steamID.\x12/\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x42\x19\x82\xb5\x18\x15\x62roadcast session ID.\x12\x62\n\x0cviewer_token\x18\x03 \x01(\x06\x42L\x82\xb5\x18Hviewer token received from last WatchRequest call, from browser storage.\x12@\n\x0erepresentation\x18\x04 \x01(\rB(\x82\xb5\x18$video stream representation watching\"\xef\x01\n-CBroadcast_StopWatchingBroadcast_Notification\x12)\n\x07steamid\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x62roadcaster steamID.\x12/\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x42\x19\x82\xb5\x18\x15\x62roadcast session ID.\x12\x62\n\x0cviewer_token\x18\x03 \x01(\x06\x42L\x82\xb5\x18Hviewer token received from last WatchRequest call, from browser storage.\"\xb0\x01\n%CBroadcast_GetBroadcastStatus_Request\x12)\n\x07steamid\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x62roadcaster steamID.\x12\\\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x42\x46\x82\xb5\x18\x42\x62roadcast session ID to proof that user is allowed to see details.\"\xd1\x02\n&CBroadcast_GetBroadcastStatus_Response\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x03 \x01(\r\x12\x12\n\npermission\x18\x04 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x05 \x01(\x08\x12\x15\n\rseconds_delay\x18\x06 \x01(\x05\x12\x14\n\x0cis_publisher\x18\x07 \x01(\x08\x12\x15\n\rthumbnail_url\x18\x08 \x01(\t\x12\x17\n\x0fupdate_interval\x18\t \x01(\x05\x12\x14\n\x0cis_uploading\x18\n \x01(\x08\x12\x10\n\x08\x64uration\x18\x0b \x01(\r\x12\x11\n\tis_replay\x18\x0c \x01(\x08\x12\x18\n\x10is_capturing_vod\x18\r \x01(\x08\x12\x1c\n\x14is_store_whitelisted\x18\x0e \x01(\x08\"Q\n(CBroadcast_GetBroadcastThumbnail_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\"\x82\x01\n)CBroadcast_GetBroadcastThumbnail_Response\x12\x15\n\rthumbnail_url\x18\x01 \x01(\t\x12\x17\n\x0fupdate_interval\x18\x02 \x01(\x05\x12\x13\n\x0bnum_viewers\x18\x03 \x01(\x05\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\"R\n$CBroadcast_InviteToBroadcast_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61pproval_response\x18\x02 \x01(\x08\"8\n%CBroadcast_InviteToBroadcast_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\"|\n-CBroadcast_SendBroadcastStateToServer_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10game_data_config\x18\x04 \x01(\t\"0\n.CBroadcast_SendBroadcastStateToServer_Response\"O\n7CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"x\n\'CBroadcast_GetBroadcastChatInfo_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x12\x11\n\tclient_ip\x18\x03 \x01(\r\x12\x13\n\x0b\x63lient_cell\x18\x04 \x01(\r\"o\n(CBroadcast_GetBroadcastChatInfo_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x03 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x04 \x03(\r\"\xea\x01\n\"CBroadcast_PostChatMessage_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\r\x12V\n\x08language\x18\x04 \x01(\r:\x01\x30\x42\x41\x82\xb5\x18=ELanguage of the user posting the message, default is english\x12\x35\n\x0c\x63ountry_code\x18\x05 \x01(\tB\x1f\x82\xb5\x18\x1bThe two letter country code\"{\n#CBroadcast_PostChatMessage_Response\x12\x14\n\x0cpersona_name\x18\x01 \x01(\t\x12\x0f\n\x07in_game\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x1d\n\x15\x63ooldown_time_seconds\x18\x04 \x01(\x05\"K\n)CBroadcast_UpdateChatMessageFlair_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\r\n\x05\x66lair\x18\x02 \x01(\t\"\\\n*CBroadcast_UpdateChatMessageFlair_Response\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x06\x12\r\n\x05\x66lair\x18\x03 \x01(\t\"`\n(CBroadcast_MuteBroadcastChatUser_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\r\n\x05muted\x18\x03 \x01(\x08\"+\n)CBroadcast_MuteBroadcastChatUser_Response\"N\n%CBroadcast_RemoveUserChatText_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"(\n&CBroadcast_RemoveUserChatText_Response\"U\n,CBroadcast_GetBroadcastChatUserNames_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x03(\x06\"\xba\x01\n-CBroadcast_GetBroadcastChatUserNames_Response\x12Q\n\rpersona_names\x18\x01 \x03(\x0b\x32:.CBroadcast_GetBroadcastChatUserNames_Response.PersonaName\x1a\x36\n\x0bPersonaName\x12\x16\n\x08steam_id\x18\x01 \x01(\x06\x42\x04\xc0\xb6\x18\x01\x12\x0f\n\x07persona\x18\x02 \x01(\t\"\x99\x01\n!CBroadcast_StartBuildClip_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1c\n\x14\x62roadcast_session_id\x18\x02 \x01(\x06\x12\x15\n\rfirst_segment\x18\x03 \x01(\x05\x12\x14\n\x0cnum_segments\x18\x04 \x01(\x05\x12\x18\n\x10\x63lip_description\x18\x05 \x01(\t\"?\n\"CBroadcast_StartBuildClip_Response\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x06\"B\n%CBroadcast_GetBuildClipStatus_Request\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x06\"(\n&CBroadcast_GetBuildClipStatus_Response\"\xc2\x01\n!CBroadcast_SetClipDetails_Request\x12&\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x42\x0b\x82\xb5\x18\x07\x43lip ID\x12.\n\nstart_time\x18\x02 \x01(\rB\x1a\x82\xb5\x18\x16start time of the clip\x12*\n\x08\x65nd_time\x18\x03 \x01(\rB\x18\x82\xb5\x18\x14\x65nd time of the clip\x12\x19\n\x11video_description\x18\x04 \x01(\t\"$\n\"CBroadcast_SetClipDetails_Response\"h\n!CBroadcast_GetClipDetails_Request\x12\x43\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x42(\x82\xb5\x18$List of clip IDs we want details for\"\xcf\x04\n\"CBroadcast_GetClipDetails_Response\x12\x30\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x42\x15\x82\xb5\x18\x11\x62roadcast clip ID\x12.\n\x08video_id\x18\x02 \x01(\x04\x42\x1c\x82\xb5\x18\x18matching unique video ID\x12,\n\nchannel_id\x18\x03 \x01(\x04\x42\x18\x82\xb5\x18\x14\x42roadcast Channel ID\x12\x30\n\x06\x61pp_id\x18\x04 \x01(\rB \x82\xb5\x18\x1c\x41pp ID stream is tagged with\x12<\n\x15\x61\x63\x63ountid_broadcaster\x18\x05 \x01(\rB\x1d\x82\xb5\x18\x19\x41\x63\x63ount ID of broadcaster\x12\x39\n\x13\x61\x63\x63ountid_clipmaker\x18\x06 \x01(\rB\x1c\x82\xb5\x18\x18\x41\x63\x63ount ID of clip-maker\x12\x45\n\x11video_description\x18\x07 \x01(\tB*\x82\xb5\x18&Short name or description of this clip\x12;\n\nstart_time\x18\x08 \x01(\rB\'\x82\xb5\x18#Wall time clip was broadcasted live\x12\x36\n\x13length_milliseconds\x18\t \x01(\rB\x19\x82\xb5\x18\x15length of video in MS\x12\x32\n\x0ethumbnail_path\x18\n \x01(\tB\x1a\x82\xb5\x18\x16Path for thumbnail URL\"\xa7\x05\n\x1e\x43\x42roadcast_SetRTMPInfo_Request\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\x12\x14\n\x0cupdate_token\x18\x02 \x01(\x08\x12\x17\n\x0f\x62roadcast_delay\x18\x03 \x01(\x05\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\r\x12\x17\n\x0frequired_app_id\x18\x05 \x01(\r\x12\x9c\x01\n\x19\x62roadcast_chat_permission\x18\x06 \x01(\x0e\x32\x19.EBroadcastChatPermission: k_EBroadcastChatPermissionPublicB<\x82\xb5\x18\x38Who is permitted to send a chat message during broadcast\x12N\n\x10\x62roadcast_buffer\x18\x07 \x01(\x05\x42\x34\x82\xb5\x18\x30Previous seconds we keep of the stream available\x12>\n\x07steamid\x18\x08 \x01(\x06\x42-\x82\xb5\x18)broadcaster steamID if not logged-in user\x12\x43\n\x0f\x63hat_rate_limit\x18\t \x01(\rB*\x82\xb5\x18&Seconds required between chat messages\x12\x37\n\renable_replay\x18\n \x01(\x08\x42 \x82\xb5\x18\x1c\x45nable replay of last upload\x12\x62\n\x14is_partner_chat_only\x18\x0b \x01(\x08\x42\x44\x82\xb5\x18@When true, then only steamwork partner can create chat messages.\"!\n\x1f\x43\x42roadcast_SetRTMPInfo_Response\"l\n\x1e\x43\x42roadcast_GetRTMPInfo_Request\x12\n\n\x02ip\x18\x01 \x01(\r\x12>\n\x07steamid\x18\x02 \x01(\x06\x42-\x82\xb5\x18)broadcaster steamID if not logged-in user\"\x94\x05\n\x1f\x43\x42roadcast_GetRTMPInfo_Response\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\x12\x11\n\trtmp_host\x18\x02 \x01(\t\x12\x12\n\nrtmp_token\x18\x03 \x01(\t\x12\x17\n\x0f\x62roadcast_delay\x18\x04 \x01(\x05\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\r\x12\x17\n\x0frequired_app_id\x18\x06 \x01(\r\x12\x9c\x01\n\x19\x62roadcast_chat_permission\x18\x07 \x01(\x0e\x32\x19.EBroadcastChatPermission: k_EBroadcastChatPermissionPublicB<\x82\xb5\x18\x38Who is permitted to send a chat message during broadcast\x12?\n\x10\x62roadcast_buffer\x18\x08 \x01(\x05\x42%\x82\xb5\x18!Seconds we keep streams available\x12(\n\x07steamid\x18\t \x01(\x06\x42\x17\x82\xb5\x18\x13\x62roadcaster steamID\x12\x43\n\x0f\x63hat_rate_limit\x18\n \x01(\rB*\x82\xb5\x18&Seconds required between chat messages\x12\x37\n\renable_replay\x18\x0b \x01(\x08\x42 \x82\xb5\x18\x1c\x45nable replay of last upload\x12\x62\n\x14is_partner_chat_only\x18\x0c \x01(\x08\x42\x44\x82\xb5\x18@When true, then only steamwork partner can create chat messages.\"a\n,CBroadcast_WebRTCHaveTURNServer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x13\n\x0bturn_server\x18\x02 \x01(\t\"\x9a\x01\n$CBroadcast_WebRTCStartResult_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\x12\x0f\n\x07started\x18\x02 \x01(\x08\x12\r\n\x05offer\x18\x03 \x01(\t\x12\x14\n\x0cresolution_x\x18\x04 \x01(\r\x12\x14\n\x0cresolution_y\x18\x05 \x01(\r\x12\x0b\n\x03\x66ps\x18\x06 \x01(\r\"\'\n%CBroadcast_WebRTCStartResult_Response\"=\n CBroadcast_WebRTCStopped_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\"#\n!CBroadcast_WebRTCStopped_Response\"l\n\"CBroadcast_WebRTCSetAnswer_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\"%\n#CBroadcast_WebRTCSetAnswer_Response\";\n)CBroadcast_WebRTCLookupTURNServer_Request\x12\x0e\n\x06\x63\x65llid\x18\x01 \x01(\r\"A\n*CBroadcast_WebRTCLookupTURNServer_Response\x12\x13\n\x0bturn_server\x18\x01 \x01(\t\"Z\n\x1b\x43\x42roadcast_WebRTC_Candidate\x12\x0f\n\x07sdp_mid\x18\x01 \x01(\t\x12\x17\n\x0fsdp_mline_index\x18\x02 \x01(\x05\x12\x11\n\tcandidate\x18\x03 \x01(\t\"w\n)CBroadcast_WebRTCAddHostCandidate_Request\x12\x19\n\x11webrtc_session_id\x18\x01 \x01(\x06\x12/\n\tcandidate\x18\x02 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\",\n*CBroadcast_WebRTCAddHostCandidate_Response\"\x96\x01\n+CBroadcast_WebRTCAddViewerCandidate_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12/\n\tcandidate\x18\x03 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\".\n,CBroadcast_WebRTCAddViewerCandidate_Response\"\x82\x01\n*CBroadcast_WebRTCGetHostCandidates_Request\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x1c\n\x14\x63\x61ndidate_generation\x18\x03 \x01(\r\"}\n+CBroadcast_WebRTCGetHostCandidates_Response\x12\x1c\n\x14\x63\x61ndidate_generation\x18\x01 \x01(\r\x12\x30\n\ncandidates\x18\x02 \x03(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate\"\xa4\x03\n*CBroadcast_GetBroadcastUploadStats_Request\x12:\n\trow_limit\x18\x01 \x01(\r:\x03\x31\x30\x30\x42\"\x82\xb5\x18\x1eHow many at maximum to return.\x12%\n\nstart_time\x18\x02 \x01(\r:\x01\x30\x42\x0e\x82\xb5\x18\nStart time\x12P\n\tupload_id\x18\x03 \x01(\x04\x42=\x82\xb5\x18\x39Optional relay upload ID - not compatible with session_id\x12i\n\x07steamid\x18\x04 \x01(\x06\x42X\x82\xb5\x18TOptional the steamid whose stats you want, otherwise the user logged in - admin only\x12V\n\nsession_id\x18\x05 \x01(\x04\x42\x42\x82\xb5\x18>Optional broadcast session ID - not compatiable with upload_id\"\x89\t\n+CBroadcast_GetBroadcastUploadStats_Response\x12N\n\x0cupload_stats\x18\x01 \x03(\x0b\x32\x38.CBroadcast_GetBroadcastUploadStats_Response.UploadStats\x1a\x89\x08\n\x0bUploadStats\x12\x1b\n\rupload_result\x18\x01 \x01(\rB\x04\x82\xb5\x18\x00\x12\x37\n\x0ctime_stopped\x18\x02 \x01(\rB!\x82\xb5\x18\x1dtime broadcast upload stopped\x12\x36\n\x10seconds_uploaded\x18\x03 \x01(\rB\x1c\x82\xb5\x18\x18seconds of vido uploaded\x12/\n\x0bmax_viewers\x18\x04 \x01(\rB\x1a\x82\xb5\x18\x16max concurrent viewers\x12.\n\x0cresolution_x\x18\x05 \x01(\rB\x18\x82\xb5\x18\x14horizontal resultion\x12,\n\x0cresolution_y\x18\x06 \x01(\rB\x16\x82\xb5\x18\x12vertical resultion\x12\x1b\n\ravg_bandwidth\x18\x07 \x01(\rB\x04\x82\xb5\x18\x00\x12;\n\x0btotal_bytes\x18\x08 \x01(\x04\x42&\x82\xb5\x18\"total byte uploaded by broadcaster\x12$\n\x06\x61pp_id\x18\t \x01(\rB\x14\x82\xb5\x18\x10game broadcasted\x12;\n\x14total_unique_viewers\x18\n \x01(\rB\x1d\x82\xb5\x18\x19total unique viewers seen\x12Q\n\x15total_seconds_watched\x18\x0b \x01(\x04\x42\x32\x82\xb5\x18.total number of seconds watched by all viewers\x12\x37\n\x0ctime_started\x18\x0c \x01(\rB!\x82\xb5\x18\x1dtime broadcast upload started\x12\x30\n\tupload_id\x18\r \x01(\x04\x42\x1d\x82\xb5\x18\x19\x62roadcast relay upload id\x12\x33\n\rlocal_address\x18\x0e \x01(\tB\x1c\x82\xb5\x18\x18upload to server address\x12\x36\n\x0eremote_address\x18\x0f \x01(\tB\x1e\x82\xb5\x18\x1aupload from client address\x12\x30\n\x11\x66rames_per_second\x18\x10 \x01(\rB\x15\x82\xb5\x18\x11\x66rames per second\x12?\n\x13num_representations\x18\x11 \x01(\rB\"\x82\xb5\x18\x1enumber of video represetations\x12\x1f\n\x08\x61pp_name\x18\x12 \x01(\tB\r\x82\xb5\x18\tgame name\x12\x33\n\tis_replay\x18\x13 \x01(\x08\x42 \x82\xb5\x18\x1creplay of previous recording\x12,\n\nsession_id\x18\x14 \x01(\x04\x42\x18\x82\xb5\x18\x14\x62roadcast session id\"\xbd\x01\n*CBroadcast_GetBroadcastViewerStats_Request\x12\x30\n\tupload_id\x18\x01 \x01(\x04\x42\x1d\x82\xb5\x18\x19Get stats for this stream\x12]\n\x07steamid\x18\x02 \x01(\x06\x42L\x82\xb5\x18HOptional: The steamid of the broadcast whose details you are requesting.\"\x98\x03\n+CBroadcast_GetBroadcastViewerStats_Response\x12N\n\x0cviewer_stats\x18\x01 \x03(\x0b\x32\x38.CBroadcast_GetBroadcastViewerStats_Response.ViewerStats\x12P\n\rcountry_stats\x18\x02 \x03(\x0b\x32\x39.CBroadcast_GetBroadcastViewerStats_Response.CountryStats\x1a\x63\n\x0bViewerStats\x12 \n\x04time\x18\x01 \x01(\rB\x12\x82\xb5\x18\x0etime of record\x12\x32\n\x0bnum_viewers\x18\x02 \x01(\rB\x1d\x82\xb5\x18\x19\x63urrent number of viewers\x1a\x62\n\x0c\x43ountryStats\x12&\n\x0c\x63ountry_code\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0c\x63ountry code\x12*\n\x0bnum_viewers\x18\x02 \x01(\rB\x15\x82\xb5\x18\x11number of viewers\"\xf8\x01\n,CBroadcast_BroadcastViewerState_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x61\n\x05state\x18\x02 \x01(\x0e\x32:.CBroadcast_BroadcastViewerState_Notification.EViewerState:\x16k_EViewerNeedsApproval\"T\n\x0c\x45ViewerState\x12\x1a\n\x16k_EViewerNeedsApproval\x10\x01\x12\x15\n\x11k_EViewerWatching\x10\x02\x12\x11\n\rk_EViewerLeft\x10\x03\"F\n.CBroadcast_WaitingBroadcastViewer_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"\x8d\x02\n.CBroadcast_BroadcastUploadStarted_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x14\n\x0cupload_token\x18\x02 \x01(\t\x12\x16\n\x0eupload_address\x18\x03 \x01(\t\x12\x14\n\x0chttp_address\x18\x04 \x01(\t\x12\x1b\n\x13\x62roadcast_upload_id\x18\x05 \x01(\x06\x12S\n\x1aheartbeat_interval_seconds\x18\x06 \x01(\rB/\x82\xb5\x18+how many seconds between session heartbeats\x12\x0f\n\x07is_rtmp\x18\x07 \x01(\x08\"\x95\x01\n+CBroadcast_StopBroadcastUpload_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x1a\n\x12\x62roadcast_relay_id\x18\x02 \x01(\x06\x12\x15\n\rupload_result\x18\x03 \x01(\r\x12\x1d\n\x15too_many_poor_uploads\x18\x04 \x01(\x08\"=\n%CBroadcast_SessionClosed_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"L\n-CBroadcast_ViewerBroadcastInvite_Notification\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\"T\n\'CBroadcast_BroadcastStatus_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x13\n\x0bnum_viewers\x18\x02 \x01(\x05\"\x8e\x01\n,CBroadcast_BroadcastChannelLive_Notification\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x1e\n\x16\x62roadcast_channel_name\x18\x02 \x01(\t\x12 \n\x18\x62roadcast_channel_avatar\x18\x03 \x01(\t\"\xc1\x01\n,CBroadcast_SendThumbnailToRelay_Notification\x12\x1e\n\x16thumbnail_upload_token\x18\x01 \x01(\t\x12&\n\x1ethumbnail_broadcast_session_id\x18\x02 \x01(\x06\x12\x16\n\x0ethumbnail_data\x18\x03 \x01(\x0c\x12\x17\n\x0fthumbnail_width\x18\x04 \x01(\r\x12\x18\n\x10thumbnail_height\x18\x05 \x01(\r\"L\n,CBroadcast_WebRTCNeedTURNServer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\"\x8c\x01\n#CBroadcast_WebRTCStart_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x16\n\x0eviewer_steamid\x18\x03 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x04 \x01(\x06\"r\n\'CBroadcast_WebRTCSetAnswer_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\"\x9c\x01\n0CBroadcast_WebRTCAddViewerCandidate_Notification\x12\x1c\n\x14\x62roadcast_session_id\x18\x01 \x01(\x06\x12\x19\n\x11webrtc_session_id\x18\x02 \x01(\x06\x12/\n\tcandidate\x18\x03 \x01(\x0b\x32\x1c.CBroadcast_WebRTC_Candidate*\xf5\x04\n\x17\x45\x42roadcastWatchLocation\x12%\n!k_EBroadcastWatchLocation_Invalid\x10\x00\x12)\n%k_EBroadcastWatchLocation_SteamTV_Tab\x10\x01\x12\x30\n,k_EBroadcastWatchLocation_SteamTV_WatchParty\x10\x02\x12&\n\"k_EBroadcastWatchLocation_Chat_Tab\x10\x03\x12-\n)k_EBroadcastWatchLocation_Chat_WatchParty\x10\x04\x12+\n\'k_EBroadcastWatchLocation_CommunityPage\x10\x05\x12*\n&k_EBroadcastWatchLocation_StoreAppPage\x10\x06\x12$\n k_EBroadcastWatchLocation_InGame\x10\x07\x12(\n$k_EBroadcastWatchLocation_BigPicture\x10\x08\x12\'\n#k_EBroadcastWatchLocation_SalesPage\x10\t\x12)\n%k_EBroadcastWatchLocation_CuratorPage\x10\n\x12+\n\'k_EBroadcastWatchLocation_DeveloperPage\x10\x0b\x12*\n&k_EBroadcastWatchLocation_Chat_Friends\x10\x0c\x12)\n%k_EBroadcastWatchLocation_SteamTV_Web\x10\r*g\n\x18\x45\x42roadcastChatPermission\x12$\n k_EBroadcastChatPermissionPublic\x10\x00\x12%\n!k_EBroadcastChatPermissionOwnsApp\x10\x01\x32\x86+\n\tBroadcast\x12\xed\x01\n\x15\x42\x65ginBroadcastSession\x12).CBroadcast_BeginBroadcastSession_Request\x1a*.CBroadcast_BeginBroadcastSession_Response\"}\x82\xb5\x18yRequest from client to directory to begin a broadcast session. No data being sent to relay; just available for broadcast.\x12\xba\x01\n\x13\x45ndBroadcastSession\x12\'.CBroadcast_EndBroadcastSession_Request\x1a(.CBroadcast_EndBroadcastSession_Response\"P\x82\xb5\x18LRequest from client to stop a broadcast session. Any uploads will terminate.\x12\xac\x01\n\x14StartBroadcastUpload\x12(.CBroadcast_StartBroadcastUpload_Request\x1a).CBroadcast_StartBroadcastUpload_Response\"?\x82\xb5\x18;Request from client to begin sending video for a broadcast.\x12\x99\x01\n\x19NotifyBroadcastUploadStop\x12\x32.CBroadcast_NotifyBroadcastUploadStop_Notification\x1a\x0b.NoResponse\";\x82\xb5\x18\x37Tells directory that client stopped uploading broadcast\x12\x87\x01\n\x0eWatchBroadcast\x12\".CBroadcast_WatchBroadcast_Request\x1a#.CBroadcast_WatchBroadcast_Response\",\x82\xb5\x18(Request from viewer to watch a broadcast\x12\x81\x01\n\x12HeartbeatBroadcast\x12+.CBroadcast_HeartbeatBroadcast_Notification\x1a\x0b.NoResponse\"1\x82\xb5\x18-Notify directory that user is still watching.\x12\xc1\x01\n\x15StopWatchingBroadcast\x12..CBroadcast_StopWatchingBroadcast_Notification\x1a\x0b.NoResponse\"k\x82\xb5\x18gRequest to immediately stop watching a broadcast. Optional Method, if not called, viewer will time out.\x12\x96\x01\n\x12GetBroadcastStatus\x12&.CBroadcast_GetBroadcastStatus_Request\x1a\'.CBroadcast_GetBroadcastStatus_Response\"/\x82\xb5\x18+Request from viewer about broadcast details\x12\x97\x01\n\x15GetBroadcastThumbnail\x12).CBroadcast_GetBroadcastThumbnail_Request\x1a*.CBroadcast_GetBroadcastThumbnail_Response\"\'\x82\xb5\x18#Request thumbnail URL for broadcast\x12\xa2\x01\n\x11InviteToBroadcast\x12%.CBroadcast_InviteToBroadcast_Request\x1a&.CBroadcast_InviteToBroadcast_Response\">\x82\xb5\x18:Invites another steam user to watch the caller\'s broadcast\x12\xc8\x01\n\x1aSendBroadcastStateToServer\x12..CBroadcast_SendBroadcastStateToServer_Request\x1a/.CBroadcast_SendBroadcastStateToServer_Response\"I\x82\xb5\x18\x45Sends users current broadcast state (permissions, game) to the server\x12\xa2\x01\n\x1fNotifyBroadcastSessionHeartbeat\x12\x38.CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x1a\x0b.NoResponse\"8\x82\xb5\x18\x34Tells directory broadcast session is still available\x12\x94\x01\n\x14GetBroadcastChatInfo\x12(.CBroadcast_GetBroadcastChatInfo_Request\x1a).CBroadcast_GetBroadcastChatInfo_Response\"\'\x82\xb5\x18#Gets chat room info for a broadcast\x12\x8a\x01\n\x0fPostChatMessage\x12#.CBroadcast_PostChatMessage_Request\x1a$.CBroadcast_PostChatMessage_Response\",\x82\xb5\x18(Post chat message to specified chat room\x12\xab\x01\n\x16UpdateChatMessageFlair\x12*.CBroadcast_UpdateChatMessageFlair_Request\x1a+.CBroadcast_UpdateChatMessageFlair_Response\"8\x82\xb5\x18\x34Update chat message flair in the specified chat room\x12\x96\x01\n\x15MuteBroadcastChatUser\x12).CBroadcast_MuteBroadcastChatUser_Request\x1a*.CBroadcast_MuteBroadcastChatUser_Response\"&\x82\xb5\x18\"Mute a user in your broadcast chat\x12\x94\x01\n\x12RemoveUserChatText\x12&.CBroadcast_RemoveUserChatText_Request\x1a\'.CBroadcast_RemoveUserChatText_Response\"-\x82\xb5\x18)Tell all viewers to remove user chat text\x12\xa3\x01\n\x19GetBroadcastChatUserNames\x12-.CBroadcast_GetBroadcastChatUserNames_Request\x1a..CBroadcast_GetBroadcastChatUserNames_Response\"\'\x82\xb5\x18#Get names for list of users in chat\x12~\n\x0eStartBuildClip\x12\".CBroadcast_StartBuildClip_Request\x1a#.CBroadcast_StartBuildClip_Response\"#\x82\xb5\x18\x1fStart building a broadcast clip\x12\x8a\x01\n\x12GetBuildClipStatus\x12&.CBroadcast_GetBuildClipStatus_Request\x1a\'.CBroadcast_GetBuildClipStatus_Response\"#\x82\xb5\x18\x1fStart building a broadcast clip\x12w\n\x0eSetClipDetails\x12\".CBroadcast_SetClipDetails_Request\x1a#.CBroadcast_SetClipDetails_Response\"\x1c\x82\xb5\x18\x18Updates a broadcast clip\x12~\n\x0eGetClipDetails\x12\".CBroadcast_GetClipDetails_Request\x1a#.CBroadcast_GetClipDetails_Response\"#\x82\xb5\x18\x1fGet details for Broadcast Clips\x12n\n\x0bSetRTMPInfo\x12\x1f.CBroadcast_SetRTMPInfo_Request\x1a .CBroadcast_SetRTMPInfo_Response\"\x1c\x82\xb5\x18\x18Sets RTMP broadcast info\x12n\n\x0bGetRTMPInfo\x12\x1f.CBroadcast_GetRTMPInfo_Request\x1a .CBroadcast_GetRTMPInfo_Response\"\x1c\x82\xb5\x18\x18Gets RTMP broadcast info\x12\x9e\x01\n\x1aNotifyWebRTCHaveTURNServer\x12-.CBroadcast_WebRTCHaveTURNServer_Notification\x1a\x0b.NoResponse\"D\x82\xb5\x18@Notification from client to server with the client\'s TURN server\x12\xac\x01\n\x11WebRTCStartResult\x12%.CBroadcast_WebRTCStartResult_Request\x1a&.CBroadcast_WebRTCStartResult_Response\"H\x82\xb5\x18\x44Notify the server that a WebRTC session has been created by the host\x12\xa0\x01\n\rWebRTCStopped\x12!.CBroadcast_WebRTCStopped_Request\x1a\".CBroadcast_WebRTCStopped_Response\"H\x82\xb5\x18\x44Notify the server that a WebRTC session has been stopped by the host\x12\xa8\x01\n\x0fWebRTCSetAnswer\x12#.CBroadcast_WebRTCSetAnswer_Request\x1a$.CBroadcast_WebRTCSetAnswer_Response\"J\x82\xb5\x18\x46Notify the server that a WebRTC session has been created by the viewer\x12\xa2\x01\n\x16WebRTCLookupTURNServer\x12*.CBroadcast_WebRTCLookupTURNServer_Request\x1a+.CBroadcast_WebRTCLookupTURNServer_Response\"/\x82\xb5\x18+Lookup the best TURN server for this client\x12\xb1\x01\n\x16WebRTCAddHostCandidate\x12*.CBroadcast_WebRTCAddHostCandidate_Request\x1a+.CBroadcast_WebRTCAddHostCandidate_Response\">\x82\xb5\x18:Add an ICE candidate for the host side of a WebRTC session\x12\xb9\x01\n\x18WebRTCAddViewerCandidate\x12,.CBroadcast_WebRTCAddViewerCandidate_Request\x1a-.CBroadcast_WebRTCAddViewerCandidate_Response\"@\x82\xb5\x18<Add an ICE candidate for the viewer side of a WebRTC session\x12\xb6\x01\n\x17WebRTCGetHostCandidates\x12+.CBroadcast_WebRTCGetHostCandidates_Request\x1a,.CBroadcast_WebRTCGetHostCandidates_Response\"@\x82\xb5\x18<Get the ICE candidates for the host side of a WebRTC session\x12\x9e\x01\n\x17GetBroadcastUploadStats\x12+.CBroadcast_GetBroadcastUploadStats_Request\x1a,.CBroadcast_GetBroadcastUploadStats_Response\"(\x82\xb5\x18$Gets broadcast upload stats for user\x12\x9f\x01\n\x17GetBroadcastViewerStats\x12+.CBroadcast_GetBroadcastViewerStats_Request\x1a,.CBroadcast_GetBroadcastViewerStats_Response\")\x82\xb5\x18%Gets viewer stats for given broadcast\x1a*\x82\xb5\x18&Methods for Steam broadcast operations2\xc4\x11\n\x0f\x42roadcastClient\x12\xa1\x01\n\x1aNotifyBroadcastViewerState\x12-.CBroadcast_BroadcastViewerState_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43Notification from server to client that a viewers state has changed\x12\xbd\x01\n\x1cNotifyWaitingBroadcastViewer\x12/.CBroadcast_WaitingBroadcastViewer_Notification\x1a\x0b.NoResponse\"_\x82\xb5\x18[Notification from server to client one or more users is waiting for user to start broadcast\x12\xa7\x01\n\x1cNotifyBroadcastUploadStarted\x12/.CBroadcast_BroadcastUploadStarted_Notification\x1a\x0b.NoResponse\"I\x82\xb5\x18\x45Notification from server to client with information about a broadcast\x12\xd6\x01\n\x19NotifyStopBroadcastUpload\x12,.CBroadcast_StopBroadcastUpload_Notification\x1a\x0b.NoResponse\"~\x82\xb5\x18zNotification from server to client telling it to stop uploading when the last viewer has disconnected from their broadcast\x12\xb5\x01\n\x13NotifySessionClosed\x12&.CBroadcast_SessionClosed_Notification\x1a\x0b.NoResponse\"i\x82\xb5\x18\x65Notification from server to client telling it a session has been closed unexpectedly by the directory\x12\xc3\x01\n\x1bNotifyViewerBroadcastInvite\x12..CBroadcast_ViewerBroadcastInvite_Notification\x1a\x0b.NoResponse\"g\x82\xb5\x18\x63Notification from server to client that a broadcaster is inviting a viewer to watch their broadcast\x12\x95\x01\n\x15NotifyBroadcastStatus\x12(.CBroadcast_BroadcastStatus_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Notification from server to client about current broadcast status\x12\x9f\x01\n\x1aNotifyBroadcastChannelLive\x12-.CBroadcast_BroadcastChannelLive_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Notification from server to client about current broadcast status\x12p\n\x14SendThumbnailToRelay\x12-.CBroadcast_SendThumbnailToRelay_Notification\x1a\x0b.NoResponse\"\x1c\x82\xb5\x18\x18Send thumbnails to relay\x12\xa7\x01\n\x1aNotifyWebRTCNeedTURNServer\x12-.CBroadcast_WebRTCNeedTURNServer_Notification\x1a\x0b.NoResponse\"M\x82\xb5\x18INotification from server to client that it needs the client\'s TURN server\x12\x94\x01\n\x11NotifyWebRTCStart\x12$.CBroadcast_WebRTCStart_Notification\x1a\x0b.NoResponse\"L\x82\xb5\x18HNotification from server to client that it should start a WebRTC session\x12\x9f\x01\n\x15NotifyWebRTCSetAnswer\x12(.CBroadcast_WebRTCSetAnswer_Notification\x1a\x0b.NoResponse\"O\x82\xb5\x18KNotification from server to client about the broadcast viewer WebRTC answer\x12\xb6\x01\n\x1eNotifyWebRTCAddViewerCandidate\x12\x31.CBroadcast_WebRTCAddViewerCandidate_Notification\x1a\x0b.NoResponse\"T\x82\xb5\x18PNotification from server to client about a broadcast viewer WebRTC ICE candidate\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EBROADCASTWATCHLOCATION = _descriptor.EnumDescriptor(
  name='EBroadcastWatchLocation',
  full_name='EBroadcastWatchLocation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_SteamTV_Tab', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_SteamTV_WatchParty', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_Chat_Tab', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_Chat_WatchParty', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_CommunityPage', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_StoreAppPage', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_InGame', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_BigPicture', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_SalesPage', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_CuratorPage', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_DeveloperPage', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_Chat_Friends', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastWatchLocation_SteamTV_Web', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13955,
  serialized_end=14584,
)
_sym_db.RegisterEnumDescriptor(_EBROADCASTWATCHLOCATION)

EBroadcastWatchLocation = enum_type_wrapper.EnumTypeWrapper(_EBROADCASTWATCHLOCATION)
_EBROADCASTCHATPERMISSION = _descriptor.EnumDescriptor(
  name='EBroadcastChatPermission',
  full_name='EBroadcastChatPermission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastChatPermissionPublic', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastChatPermissionOwnsApp', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14586,
  serialized_end=14689,
)
_sym_db.RegisterEnumDescriptor(_EBROADCASTCHATPERMISSION)

EBroadcastChatPermission = enum_type_wrapper.EnumTypeWrapper(_EBROADCASTCHATPERMISSION)
k_EBroadcastWatchLocation_Invalid = 0
k_EBroadcastWatchLocation_SteamTV_Tab = 1
k_EBroadcastWatchLocation_SteamTV_WatchParty = 2
k_EBroadcastWatchLocation_Chat_Tab = 3
k_EBroadcastWatchLocation_Chat_WatchParty = 4
k_EBroadcastWatchLocation_CommunityPage = 5
k_EBroadcastWatchLocation_StoreAppPage = 6
k_EBroadcastWatchLocation_InGame = 7
k_EBroadcastWatchLocation_BigPicture = 8
k_EBroadcastWatchLocation_SalesPage = 9
k_EBroadcastWatchLocation_CuratorPage = 10
k_EBroadcastWatchLocation_DeveloperPage = 11
k_EBroadcastWatchLocation_Chat_Friends = 12
k_EBroadcastWatchLocation_SteamTV_Web = 13
k_EBroadcastChatPermissionPublic = 0
k_EBroadcastChatPermissionOwnsApp = 1


_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE = _descriptor.EnumDescriptor(
  name='EWatchResponse',
  full_name='CBroadcast_WatchBroadcast_Response.EWatchResponse',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseReady', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseNotAvailable', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForApproval', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForStart', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseInvalidSession', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseTooManyBroadcasts', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForReconnect', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseSystemNotSupported', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseUserRestricted', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseClientOutOfDate', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponsePoorUploadQuality', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseMissingSubscription', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2348,
  serialized_end=2811,
)
_sym_db.RegisterEnumDescriptor(_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE)

_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE = _descriptor.EnumDescriptor(
  name='EViewerState',
  full_name='CBroadcast_BroadcastViewerState_Notification.EViewerState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EViewerNeedsApproval', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EViewerWatching', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EViewerLeft', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12308,
  serialized_end=12392,
)
_sym_db.RegisterEnumDescriptor(_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE)


_CBROADCAST_BEGINBROADCASTSESSION_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_BeginBroadcastSession_Request',
  full_name='CBroadcast_BeginBroadcastSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_BeginBroadcastSession_Request.permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_BeginBroadcastSession_Request.gameid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_instance_id', full_name='CBroadcast_BeginBroadcastSession_Request.client_instance_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_BeginBroadcastSession_Request.title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CBroadcast_BeginBroadcastSession_Request.cellid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CBroadcast_BeginBroadcastSession_Request.rtmp_token', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_upload', full_name='CBroadcast_BeginBroadcastSession_Request.thumbnail_upload', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_beta', full_name='CBroadcast_BeginBroadcastSession_Request.client_beta', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sysid', full_name='CBroadcast_BeginBroadcastSession_Request.sysid', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_webrtc', full_name='CBroadcast_BeginBroadcastSession_Request.allow_webrtc', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=335,
)


_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_BeginBroadcastSession_Response',
  full_name='CBroadcast_BeginBroadcastSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_BeginBroadcastSession_Response.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_upload_address', full_name='CBroadcast_BeginBroadcastSession_Response.thumbnail_upload_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*Http address to upload the thumbnail data.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_upload_token', full_name='CBroadcast_BeginBroadcastSession_Response.thumbnail_upload_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Atoken to authorize as broadcaster to upload content to the relay.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_interval_seconds', full_name='CBroadcast_BeginBroadcastSession_Response.thumbnail_interval_seconds', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#how many seconds between thumbnails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval_seconds', full_name='CBroadcast_BeginBroadcastSession_Response.heartbeat_interval_seconds', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+how many seconds between session heartbeats', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=750,
)


_CBROADCAST_ENDBROADCASTSESSION_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_EndBroadcastSession_Request',
  full_name='CBroadcast_EndBroadcastSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_EndBroadcastSession_Request.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=814,
)


_CBROADCAST_ENDBROADCASTSESSION_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_EndBroadcastSession_Response',
  full_name='CBroadcast_EndBroadcastSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=857,
)


_CBROADCAST_STARTBROADCASTUPLOAD_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_StartBroadcastUpload_Request',
  full_name='CBroadcast_StartBroadcastUpload_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_StartBroadcastUpload_Request.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CBroadcast_StartBroadcastUpload_Request.cellid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='as_rtmp', full_name='CBroadcast_StartBroadcastUpload_Request.as_rtmp', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_seconds', full_name='CBroadcast_StartBroadcastUpload_Request.delay_seconds', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CBroadcast_StartBroadcastUpload_Request.rtmp_token', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307Only set during RTMP uploads; secret key from the user.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_ip_address', full_name='CBroadcast_StartBroadcastUpload_Request.upload_ip_address', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CBroadcast_StartBroadcastUpload_Request.is_replay', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sysid', full_name='CBroadcast_StartBroadcastUpload_Request.sysid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=1124,
)


_CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_StartBroadcastUpload_Response',
  full_name='CBroadcast_StartBroadcastUpload_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CBroadcast_StartBroadcastUpload_Response.upload_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_address', full_name='CBroadcast_StartBroadcastUpload_Response.upload_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_upload_id', full_name='CBroadcast_StartBroadcastUpload_Response.broadcast_upload_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_replay', full_name='CBroadcast_StartBroadcastUpload_Response.enable_replay', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_address', full_name='CBroadcast_StartBroadcastUpload_Response.http_address', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1289,
)


_CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_NotifyBroadcastUploadStop_Notification',
  full_name='CBroadcast_NotifyBroadcastUploadStop_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_upload_id', full_name='CBroadcast_NotifyBroadcastUploadStop_Notification.broadcast_upload_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_result', full_name='CBroadcast_NotifyBroadcastUploadStop_Notification.upload_result', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1291,
  serialized_end=1394,
)


_CBROADCAST_WATCHBROADCAST_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WatchBroadcast_Request',
  full_name='CBroadcast_WatchBroadcast_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_WatchBroadcast_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024broadcaster steamID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='existing_broadcast_id', full_name='CBroadcast_WatchBroadcast_Request.existing_broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305broadcast session ID (optional, rejoin if specified).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_WatchBroadcast_Request.viewer_token', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Hviewer token received from last WatchRequest call, from browser storage.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_cell', full_name='CBroadcast_WatchBroadcast_Request.client_cell', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_location', full_name='CBroadcast_WatchBroadcast_Request.watch_location', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_webrtc', full_name='CBroadcast_WatchBroadcast_Request.is_webrtc', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1790,
)


_CBROADCAST_WATCHBROADCAST_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WatchBroadcast_Response',
  full_name='CBroadcast_WatchBroadcast_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CBroadcast_WatchBroadcast_Response.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mpd_url', full_name='CBroadcast_WatchBroadcast_Response.mpd_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_WatchBroadcast_Response.broadcast_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_WatchBroadcast_Response.gameid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_WatchBroadcast_Response.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_WatchBroadcast_Response.num_viewers', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_WatchBroadcast_Response.permission', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rtmp', full_name='CBroadcast_WatchBroadcast_Response.is_rtmp', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_delay', full_name='CBroadcast_WatchBroadcast_Response.seconds_delay', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_WatchBroadcast_Response.viewer_token', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hls_m3u8_master_url', full_name='CBroadcast_WatchBroadcast_Response.hls_m3u8_master_url', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval', full_name='CBroadcast_WatchBroadcast_Response.heartbeat_interval', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='CBroadcast_WatchBroadcast_Response.thumbnail_url', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_webrtc', full_name='CBroadcast_WatchBroadcast_Response.is_webrtc', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WatchBroadcast_Response.webrtc_session_id', index=14,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_offer_sdp', full_name='CBroadcast_WatchBroadcast_Response.webrtc_offer_sdp', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_turn_server', full_name='CBroadcast_WatchBroadcast_Response.webrtc_turn_server', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CBroadcast_WatchBroadcast_Response.is_replay', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CBroadcast_WatchBroadcast_Response.duration', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cdn_auth_url_parameters', full_name='CBroadcast_WatchBroadcast_Response.cdn_auth_url_parameters', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=2811,
)


_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_HeartbeatBroadcast_Notification',
  full_name='CBroadcast_HeartbeatBroadcast_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_HeartbeatBroadcast_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024broadcaster steamID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_HeartbeatBroadcast_Notification.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025broadcast session ID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_HeartbeatBroadcast_Notification.viewer_token', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Hviewer token received from last WatchRequest call, from browser storage.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='representation', full_name='CBroadcast_HeartbeatBroadcast_Notification.representation', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$video stream representation watching', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2814,
  serialized_end=3116,
)


_CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_StopWatchingBroadcast_Notification',
  full_name='CBroadcast_StopWatchingBroadcast_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_StopWatchingBroadcast_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024broadcaster steamID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_StopWatchingBroadcast_Notification.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025broadcast session ID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_StopWatchingBroadcast_Notification.viewer_token', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Hviewer token received from last WatchRequest call, from browser storage.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3119,
  serialized_end=3358,
)


_CBROADCAST_GETBROADCASTSTATUS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastStatus_Request',
  full_name='CBroadcast_GetBroadcastStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastStatus_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024broadcaster steamID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_GetBroadcastStatus_Request.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Bbroadcast session ID to proof that user is allowed to see details.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3361,
  serialized_end=3537,
)


_CBROADCAST_GETBROADCASTSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastStatus_Response',
  full_name='CBroadcast_GetBroadcastStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_GetBroadcastStatus_Response.gameid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_GetBroadcastStatus_Response.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_GetBroadcastStatus_Response.num_viewers', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_GetBroadcastStatus_Response.permission', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rtmp', full_name='CBroadcast_GetBroadcastStatus_Response.is_rtmp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_delay', full_name='CBroadcast_GetBroadcastStatus_Response.seconds_delay', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_publisher', full_name='CBroadcast_GetBroadcastStatus_Response.is_publisher', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='CBroadcast_GetBroadcastStatus_Response.thumbnail_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_interval', full_name='CBroadcast_GetBroadcastStatus_Response.update_interval', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_uploading', full_name='CBroadcast_GetBroadcastStatus_Response.is_uploading', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CBroadcast_GetBroadcastStatus_Response.duration', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CBroadcast_GetBroadcastStatus_Response.is_replay', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_capturing_vod', full_name='CBroadcast_GetBroadcastStatus_Response.is_capturing_vod', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_store_whitelisted', full_name='CBroadcast_GetBroadcastStatus_Response.is_store_whitelisted', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3540,
  serialized_end=3877,
)


_CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastThumbnail_Request',
  full_name='CBroadcast_GetBroadcastThumbnail_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastThumbnail_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_GetBroadcastThumbnail_Request.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3879,
  serialized_end=3960,
)


_CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastThumbnail_Response',
  full_name='CBroadcast_GetBroadcastThumbnail_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='CBroadcast_GetBroadcastThumbnail_Response.thumbnail_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_interval', full_name='CBroadcast_GetBroadcastThumbnail_Response.update_interval', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_GetBroadcastThumbnail_Response.num_viewers', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CBroadcast_GetBroadcastThumbnail_Response.duration', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3963,
  serialized_end=4093,
)


_CBROADCAST_INVITETOBROADCAST_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_InviteToBroadcast_Request',
  full_name='CBroadcast_InviteToBroadcast_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_InviteToBroadcast_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approval_response', full_name='CBroadcast_InviteToBroadcast_Request.approval_response', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4095,
  serialized_end=4177,
)


_CBROADCAST_INVITETOBROADCAST_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_InviteToBroadcast_Response',
  full_name='CBroadcast_InviteToBroadcast_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CBroadcast_InviteToBroadcast_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4179,
  serialized_end=4235,
)


_CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_SendBroadcastStateToServer_Request',
  full_name='CBroadcast_SendBroadcastStateToServer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_SendBroadcastStateToServer_Request.permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_SendBroadcastStateToServer_Request.gameid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_SendBroadcastStateToServer_Request.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_data_config', full_name='CBroadcast_SendBroadcastStateToServer_Request.game_data_config', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4237,
  serialized_end=4361,
)


_CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_SendBroadcastStateToServer_Response',
  full_name='CBroadcast_SendBroadcastStateToServer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4363,
  serialized_end=4411,
)


_CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification',
  full_name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4413,
  serialized_end=4492,
)


_CBROADCAST_GETBROADCASTCHATINFO_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatInfo_Request',
  full_name='CBroadcast_GetBroadcastChatInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastChatInfo_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_GetBroadcastChatInfo_Request.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='CBroadcast_GetBroadcastChatInfo_Request.client_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_cell', full_name='CBroadcast_GetBroadcastChatInfo_Request.client_cell', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4494,
  serialized_end=4614,
)


_CBROADCAST_GETBROADCASTCHATINFO_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatInfo_Response',
  full_name='CBroadcast_GetBroadcastChatInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_GetBroadcastChatInfo_Response.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_url_template', full_name='CBroadcast_GetBroadcastChatInfo_Response.view_url_template', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flair_group_ids', full_name='CBroadcast_GetBroadcastChatInfo_Response.flair_group_ids', index=2,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4616,
  serialized_end=4727,
)


_CBROADCAST_POSTCHATMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_PostChatMessage_Request',
  full_name='CBroadcast_PostChatMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_PostChatMessage_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CBroadcast_PostChatMessage_Request.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='CBroadcast_PostChatMessage_Request.instance_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CBroadcast_PostChatMessage_Request.language', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030=ELanguage of the user posting the message, default is english', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CBroadcast_PostChatMessage_Request.country_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033The two letter country code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4730,
  serialized_end=4964,
)


_CBROADCAST_POSTCHATMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_PostChatMessage_Response',
  full_name='CBroadcast_PostChatMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CBroadcast_PostChatMessage_Response.persona_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_game', full_name='CBroadcast_PostChatMessage_Response.in_game', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='CBroadcast_PostChatMessage_Response.result', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cooldown_time_seconds', full_name='CBroadcast_PostChatMessage_Response.cooldown_time_seconds', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4966,
  serialized_end=5089,
)


_CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_UpdateChatMessageFlair_Request',
  full_name='CBroadcast_UpdateChatMessageFlair_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_UpdateChatMessageFlair_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flair', full_name='CBroadcast_UpdateChatMessageFlair_Request.flair', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5091,
  serialized_end=5166,
)


_CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_UpdateChatMessageFlair_Response',
  full_name='CBroadcast_UpdateChatMessageFlair_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CBroadcast_UpdateChatMessageFlair_Response.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_UpdateChatMessageFlair_Response.chat_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flair', full_name='CBroadcast_UpdateChatMessageFlair_Response.flair', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5168,
  serialized_end=5260,
)


_CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_MuteBroadcastChatUser_Request',
  full_name='CBroadcast_MuteBroadcastChatUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_MuteBroadcastChatUser_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_MuteBroadcastChatUser_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='muted', full_name='CBroadcast_MuteBroadcastChatUser_Request.muted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5262,
  serialized_end=5358,
)


_CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_MuteBroadcastChatUser_Response',
  full_name='CBroadcast_MuteBroadcastChatUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5360,
  serialized_end=5403,
)


_CBROADCAST_REMOVEUSERCHATTEXT_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_RemoveUserChatText_Request',
  full_name='CBroadcast_RemoveUserChatText_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_RemoveUserChatText_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_RemoveUserChatText_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5405,
  serialized_end=5483,
)


_CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_RemoveUserChatText_Response',
  full_name='CBroadcast_RemoveUserChatText_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5485,
  serialized_end=5525,
)


_CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatUserNames_Request',
  full_name='CBroadcast_GetBroadcastChatUserNames_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_GetBroadcastChatUserNames_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_GetBroadcastChatUserNames_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5527,
  serialized_end=5612,
)


_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME = _descriptor.Descriptor(
  name='PersonaName',
  full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\300\266\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona', full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName.persona', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5747,
  serialized_end=5801,
)

_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatUserNames_Response',
  full_name='CBroadcast_GetBroadcastChatUserNames_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_names', full_name='CBroadcast_GetBroadcastChatUserNames_Response.persona_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5615,
  serialized_end=5801,
)


_CBROADCAST_STARTBUILDCLIP_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_StartBuildClip_Request',
  full_name='CBroadcast_StartBuildClip_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_StartBuildClip_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_StartBuildClip_Request.broadcast_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_segment', full_name='CBroadcast_StartBuildClip_Request.first_segment', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_segments', full_name='CBroadcast_StartBuildClip_Request.num_segments', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clip_description', full_name='CBroadcast_StartBuildClip_Request.clip_description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5804,
  serialized_end=5957,
)


_CBROADCAST_STARTBUILDCLIP_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_StartBuildClip_Response',
  full_name='CBroadcast_StartBuildClip_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CBroadcast_StartBuildClip_Response.broadcast_clip_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5959,
  serialized_end=6022,
)


_CBROADCAST_GETBUILDCLIPSTATUS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBuildClipStatus_Request',
  full_name='CBroadcast_GetBuildClipStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CBroadcast_GetBuildClipStatus_Request.broadcast_clip_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6024,
  serialized_end=6090,
)


_CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBuildClipStatus_Response',
  full_name='CBroadcast_GetBuildClipStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6092,
  serialized_end=6132,
)


_CBROADCAST_SETCLIPDETAILS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_SetClipDetails_Request',
  full_name='CBroadcast_SetClipDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CBroadcast_SetClipDetails_Request.broadcast_clip_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\007Clip ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CBroadcast_SetClipDetails_Request.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026start time of the clip', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='CBroadcast_SetClipDetails_Request.end_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024end time of the clip', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_description', full_name='CBroadcast_SetClipDetails_Request.video_description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6135,
  serialized_end=6329,
)


_CBROADCAST_SETCLIPDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_SetClipDetails_Response',
  full_name='CBroadcast_SetClipDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6331,
  serialized_end=6367,
)


_CBROADCAST_GETCLIPDETAILS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetClipDetails_Request',
  full_name='CBroadcast_GetClipDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CBroadcast_GetClipDetails_Request.broadcast_clip_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$List of clip IDs we want details for', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6369,
  serialized_end=6473,
)


_CBROADCAST_GETCLIPDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetClipDetails_Response',
  full_name='CBroadcast_GetClipDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CBroadcast_GetClipDetails_Response.broadcast_clip_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021broadcast clip ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_id', full_name='CBroadcast_GetClipDetails_Response.video_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030matching unique video ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CBroadcast_GetClipDetails_Response.channel_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast Channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CBroadcast_GetClipDetails_Response.app_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034App ID stream is tagged with', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_broadcaster', full_name='CBroadcast_GetClipDetails_Response.accountid_broadcaster', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Account ID of broadcaster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_clipmaker', full_name='CBroadcast_GetClipDetails_Response.accountid_clipmaker', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030Account ID of clip-maker', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_description', full_name='CBroadcast_GetClipDetails_Response.video_description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Short name or description of this clip', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CBroadcast_GetClipDetails_Response.start_time', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#Wall time clip was broadcasted live', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_milliseconds', full_name='CBroadcast_GetClipDetails_Response.length_milliseconds', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025length of video in MS', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_path', full_name='CBroadcast_GetClipDetails_Response.thumbnail_path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026Path for thumbnail URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6476,
  serialized_end=7067,
)


_CBROADCAST_SETRTMPINFO_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_SetRTMPInfo_Request',
  full_name='CBroadcast_SetRTMPInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_permission', full_name='CBroadcast_SetRTMPInfo_Request.broadcast_permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_token', full_name='CBroadcast_SetRTMPInfo_Request.update_token', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_delay', full_name='CBroadcast_SetRTMPInfo_Request.broadcast_delay', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CBroadcast_SetRTMPInfo_Request.app_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_app_id', full_name='CBroadcast_SetRTMPInfo_Request.required_app_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_chat_permission', full_name='CBroadcast_SetRTMPInfo_Request.broadcast_chat_permission', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308Who is permitted to send a chat message during broadcast', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_buffer', full_name='CBroadcast_SetRTMPInfo_Request.broadcast_buffer', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Previous seconds we keep of the stream available', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_SetRTMPInfo_Request.steamid', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)broadcaster steamID if not logged-in user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_rate_limit', full_name='CBroadcast_SetRTMPInfo_Request.chat_rate_limit', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Seconds required between chat messages', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_replay', full_name='CBroadcast_SetRTMPInfo_Request.enable_replay', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Enable replay of last upload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_partner_chat_only', full_name='CBroadcast_SetRTMPInfo_Request.is_partner_chat_only', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@When true, then only steamwork partner can create chat messages.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7070,
  serialized_end=7749,
)


_CBROADCAST_SETRTMPINFO_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_SetRTMPInfo_Response',
  full_name='CBroadcast_SetRTMPInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7751,
  serialized_end=7784,
)


_CBROADCAST_GETRTMPINFO_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetRTMPInfo_Request',
  full_name='CBroadcast_GetRTMPInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='CBroadcast_GetRTMPInfo_Request.ip', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetRTMPInfo_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)broadcaster steamID if not logged-in user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7786,
  serialized_end=7894,
)


_CBROADCAST_GETRTMPINFO_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetRTMPInfo_Response',
  full_name='CBroadcast_GetRTMPInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_permission', full_name='CBroadcast_GetRTMPInfo_Response.broadcast_permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtmp_host', full_name='CBroadcast_GetRTMPInfo_Response.rtmp_host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CBroadcast_GetRTMPInfo_Response.rtmp_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_delay', full_name='CBroadcast_GetRTMPInfo_Response.broadcast_delay', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CBroadcast_GetRTMPInfo_Response.app_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_app_id', full_name='CBroadcast_GetRTMPInfo_Response.required_app_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_chat_permission', full_name='CBroadcast_GetRTMPInfo_Response.broadcast_chat_permission', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308Who is permitted to send a chat message during broadcast', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_buffer', full_name='CBroadcast_GetRTMPInfo_Response.broadcast_buffer', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Seconds we keep streams available', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetRTMPInfo_Response.steamid', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023broadcaster steamID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_rate_limit', full_name='CBroadcast_GetRTMPInfo_Response.chat_rate_limit', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Seconds required between chat messages', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_replay', full_name='CBroadcast_GetRTMPInfo_Response.enable_replay', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Enable replay of last upload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_partner_chat_only', full_name='CBroadcast_GetRTMPInfo_Response.is_partner_chat_only', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@When true, then only steamwork partner can create chat messages.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7897,
  serialized_end=8557,
)


_CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WebRTCHaveTURNServer_Notification',
  full_name='CBroadcast_WebRTCHaveTURNServer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_WebRTCHaveTURNServer_Notification.broadcast_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_server', full_name='CBroadcast_WebRTCHaveTURNServer_Notification.turn_server', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8559,
  serialized_end=8656,
)


_CBROADCAST_WEBRTCSTARTRESULT_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCStartResult_Request',
  full_name='CBroadcast_WebRTCStartResult_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCStartResult_Request.webrtc_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='CBroadcast_WebRTCStartResult_Request.started', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offer', full_name='CBroadcast_WebRTCStartResult_Request.offer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution_x', full_name='CBroadcast_WebRTCStartResult_Request.resolution_x', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution_y', full_name='CBroadcast_WebRTCStartResult_Request.resolution_y', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fps', full_name='CBroadcast_WebRTCStartResult_Request.fps', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8659,
  serialized_end=8813,
)


_CBROADCAST_WEBRTCSTARTRESULT_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCStartResult_Response',
  full_name='CBroadcast_WebRTCStartResult_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8815,
  serialized_end=8854,
)


_CBROADCAST_WEBRTCSTOPPED_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCStopped_Request',
  full_name='CBroadcast_WebRTCStopped_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCStopped_Request.webrtc_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8856,
  serialized_end=8917,
)


_CBROADCAST_WEBRTCSTOPPED_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCStopped_Response',
  full_name='CBroadcast_WebRTCStopped_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8919,
  serialized_end=8954,
)


_CBROADCAST_WEBRTCSETANSWER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCSetAnswer_Request',
  full_name='CBroadcast_WebRTCSetAnswer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CBroadcast_WebRTCSetAnswer_Request.broadcaster_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCSetAnswer_Request.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='CBroadcast_WebRTCSetAnswer_Request.answer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8956,
  serialized_end=9064,
)


_CBROADCAST_WEBRTCSETANSWER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCSetAnswer_Response',
  full_name='CBroadcast_WebRTCSetAnswer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9066,
  serialized_end=9103,
)


_CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCLookupTURNServer_Request',
  full_name='CBroadcast_WebRTCLookupTURNServer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CBroadcast_WebRTCLookupTURNServer_Request.cellid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9105,
  serialized_end=9164,
)


_CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCLookupTURNServer_Response',
  full_name='CBroadcast_WebRTCLookupTURNServer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_server', full_name='CBroadcast_WebRTCLookupTURNServer_Response.turn_server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9166,
  serialized_end=9231,
)


_CBROADCAST_WEBRTC_CANDIDATE = _descriptor.Descriptor(
  name='CBroadcast_WebRTC_Candidate',
  full_name='CBroadcast_WebRTC_Candidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdp_mid', full_name='CBroadcast_WebRTC_Candidate.sdp_mid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdp_mline_index', full_name='CBroadcast_WebRTC_Candidate.sdp_mline_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CBroadcast_WebRTC_Candidate.candidate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9233,
  serialized_end=9323,
)


_CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCAddHostCandidate_Request',
  full_name='CBroadcast_WebRTCAddHostCandidate_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCAddHostCandidate_Request.webrtc_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CBroadcast_WebRTCAddHostCandidate_Request.candidate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9325,
  serialized_end=9444,
)


_CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCAddHostCandidate_Response',
  full_name='CBroadcast_WebRTCAddHostCandidate_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9446,
  serialized_end=9490,
)


_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCAddViewerCandidate_Request',
  full_name='CBroadcast_WebRTCAddViewerCandidate_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CBroadcast_WebRTCAddViewerCandidate_Request.broadcaster_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCAddViewerCandidate_Request.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CBroadcast_WebRTCAddViewerCandidate_Request.candidate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9493,
  serialized_end=9643,
)


_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCAddViewerCandidate_Response',
  full_name='CBroadcast_WebRTCAddViewerCandidate_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9645,
  serialized_end=9691,
)


_CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WebRTCGetHostCandidates_Request',
  full_name='CBroadcast_WebRTCGetHostCandidates_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CBroadcast_WebRTCGetHostCandidates_Request.broadcaster_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCGetHostCandidates_Request.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate_generation', full_name='CBroadcast_WebRTCGetHostCandidates_Request.candidate_generation', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9694,
  serialized_end=9824,
)


_CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WebRTCGetHostCandidates_Response',
  full_name='CBroadcast_WebRTCGetHostCandidates_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate_generation', full_name='CBroadcast_WebRTCGetHostCandidates_Response.candidate_generation', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidates', full_name='CBroadcast_WebRTCGetHostCandidates_Response.candidates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9826,
  serialized_end=9951,
)


_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastUploadStats_Request',
  full_name='CBroadcast_GetBroadcastUploadStats_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_limit', full_name='CBroadcast_GetBroadcastUploadStats_Request.row_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\036How many at maximum to return.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CBroadcast_GetBroadcastUploadStats_Request.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\nStart time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_id', full_name='CBroadcast_GetBroadcastUploadStats_Request.upload_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309Optional relay upload ID - not compatible with session_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastUploadStats_Request.steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030TOptional the steamid whose stats you want, otherwise the user logged in - admin only', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='CBroadcast_GetBroadcastUploadStats_Request.session_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>Optional broadcast session ID - not compatiable with upload_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9954,
  serialized_end=10374,
)


_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS = _descriptor.Descriptor(
  name='UploadStats',
  full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_result', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.upload_result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stopped', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.time_stopped', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035time broadcast upload stopped', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_uploaded', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.seconds_uploaded', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030seconds of vido uploaded', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_viewers', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.max_viewers', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026max concurrent viewers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution_x', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.resolution_x', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024horizontal resultion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution_y', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.resolution_y', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\022vertical resultion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_bandwidth', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.avg_bandwidth', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.total_bytes', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"total byte uploaded by broadcaster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.app_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020game broadcasted', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_unique_viewers', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.total_unique_viewers', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031total unique viewers seen', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_seconds_watched', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.total_seconds_watched', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.total number of seconds watched by all viewers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_started', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.time_started', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035time broadcast upload started', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_id', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.upload_id', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031broadcast relay upload id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_address', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.local_address', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030upload to server address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_address', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.remote_address', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032upload from client address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frames_per_second', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.frames_per_second', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021frames per second', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_representations', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.num_representations', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\036number of video represetations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.app_name', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\tgame name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_replay', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.is_replay', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034replay of previous recording', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='CBroadcast_GetBroadcastUploadStats_Response.UploadStats.session_id', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024broadcast session id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10505,
  serialized_end=11538,
)

_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastUploadStats_Response',
  full_name='CBroadcast_GetBroadcastUploadStats_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_stats', full_name='CBroadcast_GetBroadcastUploadStats_Response.upload_stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10377,
  serialized_end=11538,
)


_CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastViewerStats_Request',
  full_name='CBroadcast_GetBroadcastViewerStats_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_id', full_name='CBroadcast_GetBroadcastViewerStats_Request.upload_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Get stats for this stream', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastViewerStats_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030HOptional: The steamid of the broadcast whose details you are requesting.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11541,
  serialized_end=11730,
)


_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS = _descriptor.Descriptor(
  name='ViewerStats',
  full_name='CBroadcast_GetBroadcastViewerStats_Response.ViewerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='CBroadcast_GetBroadcastViewerStats_Response.ViewerStats.time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016time of record', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_GetBroadcastViewerStats_Response.ViewerStats.num_viewers', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031current number of viewers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11942,
  serialized_end=12041,
)

_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS = _descriptor.Descriptor(
  name='CountryStats',
  full_name='CBroadcast_GetBroadcastViewerStats_Response.CountryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CBroadcast_GetBroadcastViewerStats_Response.CountryStats.country_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014country code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_GetBroadcastViewerStats_Response.CountryStats.num_viewers', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021number of viewers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12043,
  serialized_end=12141,
)

_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastViewerStats_Response',
  full_name='CBroadcast_GetBroadcastViewerStats_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewer_stats', full_name='CBroadcast_GetBroadcastViewerStats_Response.viewer_stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_stats', full_name='CBroadcast_GetBroadcastViewerStats_Response.country_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS, _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11733,
  serialized_end=12141,
)


_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastViewerState_Notification',
  full_name='CBroadcast_BroadcastViewerState_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_BroadcastViewerState_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='CBroadcast_BroadcastViewerState_Notification.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12144,
  serialized_end=12392,
)


_CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WaitingBroadcastViewer_Notification',
  full_name='CBroadcast_WaitingBroadcastViewer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_WaitingBroadcastViewer_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12394,
  serialized_end=12464,
)


_CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastUploadStarted_Notification',
  full_name='CBroadcast_BroadcastUploadStarted_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_BroadcastUploadStarted_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CBroadcast_BroadcastUploadStarted_Notification.upload_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_address', full_name='CBroadcast_BroadcastUploadStarted_Notification.upload_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_address', full_name='CBroadcast_BroadcastUploadStarted_Notification.http_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_upload_id', full_name='CBroadcast_BroadcastUploadStarted_Notification.broadcast_upload_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval_seconds', full_name='CBroadcast_BroadcastUploadStarted_Notification.heartbeat_interval_seconds', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+how many seconds between session heartbeats', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rtmp', full_name='CBroadcast_BroadcastUploadStarted_Notification.is_rtmp', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12467,
  serialized_end=12736,
)


_CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_StopBroadcastUpload_Notification',
  full_name='CBroadcast_StopBroadcastUpload_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_StopBroadcastUpload_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_relay_id', full_name='CBroadcast_StopBroadcastUpload_Notification.broadcast_relay_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_result', full_name='CBroadcast_StopBroadcastUpload_Notification.upload_result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='too_many_poor_uploads', full_name='CBroadcast_StopBroadcastUpload_Notification.too_many_poor_uploads', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12739,
  serialized_end=12888,
)


_CBROADCAST_SESSIONCLOSED_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_SessionClosed_Notification',
  full_name='CBroadcast_SessionClosed_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_SessionClosed_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12890,
  serialized_end=12951,
)


_CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_ViewerBroadcastInvite_Notification',
  full_name='CBroadcast_ViewerBroadcastInvite_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CBroadcast_ViewerBroadcastInvite_Notification.broadcaster_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12953,
  serialized_end=13029,
)


_CBROADCAST_BROADCASTSTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastStatus_Notification',
  full_name='CBroadcast_BroadcastStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_BroadcastStatus_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_BroadcastStatus_Notification.num_viewers', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13031,
  serialized_end=13115,
)


_CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastChannelLive_Notification',
  full_name='CBroadcast_BroadcastChannelLive_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CBroadcast_BroadcastChannelLive_Notification.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_channel_name', full_name='CBroadcast_BroadcastChannelLive_Notification.broadcast_channel_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_channel_avatar', full_name='CBroadcast_BroadcastChannelLive_Notification.broadcast_channel_avatar', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13118,
  serialized_end=13260,
)


_CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_SendThumbnailToRelay_Notification',
  full_name='CBroadcast_SendThumbnailToRelay_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thumbnail_upload_token', full_name='CBroadcast_SendThumbnailToRelay_Notification.thumbnail_upload_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_broadcast_session_id', full_name='CBroadcast_SendThumbnailToRelay_Notification.thumbnail_broadcast_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_data', full_name='CBroadcast_SendThumbnailToRelay_Notification.thumbnail_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_width', full_name='CBroadcast_SendThumbnailToRelay_Notification.thumbnail_width', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_height', full_name='CBroadcast_SendThumbnailToRelay_Notification.thumbnail_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13263,
  serialized_end=13456,
)


_CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WebRTCNeedTURNServer_Notification',
  full_name='CBroadcast_WebRTCNeedTURNServer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_WebRTCNeedTURNServer_Notification.broadcast_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13458,
  serialized_end=13534,
)


_CBROADCAST_WEBRTCSTART_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WebRTCStart_Notification',
  full_name='CBroadcast_WebRTCStart_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_WebRTCStart_Notification.broadcast_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCStart_Notification.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_steamid', full_name='CBroadcast_WebRTCStart_Notification.viewer_steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_WebRTCStart_Notification.viewer_token', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13537,
  serialized_end=13677,
)


_CBROADCAST_WEBRTCSETANSWER_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WebRTCSetAnswer_Notification',
  full_name='CBroadcast_WebRTCSetAnswer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_WebRTCSetAnswer_Notification.broadcast_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCSetAnswer_Notification.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='CBroadcast_WebRTCSetAnswer_Notification.answer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13679,
  serialized_end=13793,
)


_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WebRTCAddViewerCandidate_Notification',
  full_name='CBroadcast_WebRTCAddViewerCandidate_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CBroadcast_WebRTCAddViewerCandidate_Notification.broadcast_session_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webrtc_session_id', full_name='CBroadcast_WebRTCAddViewerCandidate_Notification.webrtc_session_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CBroadcast_WebRTCAddViewerCandidate_Notification.candidate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13796,
  serialized_end=13952,
)

_CBROADCAST_WATCHBROADCAST_REQUEST.fields_by_name['watch_location'].enum_type = _EBROADCASTWATCHLOCATION
_CBROADCAST_WATCHBROADCAST_RESPONSE.fields_by_name['response'].enum_type = _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE
_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE.containing_type = _CBROADCAST_WATCHBROADCAST_RESPONSE
_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME.containing_type = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE
_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE.fields_by_name['persona_names'].message_type = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['broadcast_chat_permission'].enum_type = _EBROADCASTCHATPERMISSION
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['broadcast_chat_permission'].enum_type = _EBROADCASTCHATPERMISSION
_CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST.fields_by_name['candidate'].message_type = _CBROADCAST_WEBRTC_CANDIDATE
_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST.fields_by_name['candidate'].message_type = _CBROADCAST_WEBRTC_CANDIDATE
_CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE.fields_by_name['candidates'].message_type = _CBROADCAST_WEBRTC_CANDIDATE
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.containing_type = _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE.fields_by_name['upload_stats'].message_type = _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS.containing_type = _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS.containing_type = _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE.fields_by_name['viewer_stats'].message_type = _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE.fields_by_name['country_stats'].message_type = _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS
_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION.fields_by_name['state'].enum_type = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE
_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE.containing_type = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION
_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION.fields_by_name['candidate'].message_type = _CBROADCAST_WEBRTC_CANDIDATE
DESCRIPTOR.message_types_by_name['CBroadcast_BeginBroadcastSession_Request'] = _CBROADCAST_BEGINBROADCASTSESSION_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_BeginBroadcastSession_Response'] = _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_EndBroadcastSession_Request'] = _CBROADCAST_ENDBROADCASTSESSION_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_EndBroadcastSession_Response'] = _CBROADCAST_ENDBROADCASTSESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_StartBroadcastUpload_Request'] = _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_StartBroadcastUpload_Response'] = _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_NotifyBroadcastUploadStop_Notification'] = _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WatchBroadcast_Request'] = _CBROADCAST_WATCHBROADCAST_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WatchBroadcast_Response'] = _CBROADCAST_WATCHBROADCAST_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_HeartbeatBroadcast_Notification'] = _CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_StopWatchingBroadcast_Notification'] = _CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastStatus_Request'] = _CBROADCAST_GETBROADCASTSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastStatus_Response'] = _CBROADCAST_GETBROADCASTSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastThumbnail_Request'] = _CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastThumbnail_Response'] = _CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_InviteToBroadcast_Request'] = _CBROADCAST_INVITETOBROADCAST_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_InviteToBroadcast_Response'] = _CBROADCAST_INVITETOBROADCAST_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_SendBroadcastStateToServer_Request'] = _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_SendBroadcastStateToServer_Response'] = _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_NotifyBroadcastSessionHeartbeat_Notification'] = _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatInfo_Request'] = _CBROADCAST_GETBROADCASTCHATINFO_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatInfo_Response'] = _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_PostChatMessage_Request'] = _CBROADCAST_POSTCHATMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_PostChatMessage_Response'] = _CBROADCAST_POSTCHATMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_UpdateChatMessageFlair_Request'] = _CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_UpdateChatMessageFlair_Response'] = _CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_MuteBroadcastChatUser_Request'] = _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_MuteBroadcastChatUser_Response'] = _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_RemoveUserChatText_Request'] = _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_RemoveUserChatText_Response'] = _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatUserNames_Request'] = _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatUserNames_Response'] = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_StartBuildClip_Request'] = _CBROADCAST_STARTBUILDCLIP_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_StartBuildClip_Response'] = _CBROADCAST_STARTBUILDCLIP_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBuildClipStatus_Request'] = _CBROADCAST_GETBUILDCLIPSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBuildClipStatus_Response'] = _CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_SetClipDetails_Request'] = _CBROADCAST_SETCLIPDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_SetClipDetails_Response'] = _CBROADCAST_SETCLIPDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetClipDetails_Request'] = _CBROADCAST_GETCLIPDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetClipDetails_Response'] = _CBROADCAST_GETCLIPDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_SetRTMPInfo_Request'] = _CBROADCAST_SETRTMPINFO_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_SetRTMPInfo_Response'] = _CBROADCAST_SETRTMPINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetRTMPInfo_Request'] = _CBROADCAST_GETRTMPINFO_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetRTMPInfo_Response'] = _CBROADCAST_GETRTMPINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCHaveTURNServer_Notification'] = _CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCStartResult_Request'] = _CBROADCAST_WEBRTCSTARTRESULT_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCStartResult_Response'] = _CBROADCAST_WEBRTCSTARTRESULT_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCStopped_Request'] = _CBROADCAST_WEBRTCSTOPPED_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCStopped_Response'] = _CBROADCAST_WEBRTCSTOPPED_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCSetAnswer_Request'] = _CBROADCAST_WEBRTCSETANSWER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCSetAnswer_Response'] = _CBROADCAST_WEBRTCSETANSWER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCLookupTURNServer_Request'] = _CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCLookupTURNServer_Response'] = _CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTC_Candidate'] = _CBROADCAST_WEBRTC_CANDIDATE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCAddHostCandidate_Request'] = _CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCAddHostCandidate_Response'] = _CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCAddViewerCandidate_Request'] = _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCAddViewerCandidate_Response'] = _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCGetHostCandidates_Request'] = _CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCGetHostCandidates_Response'] = _CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastUploadStats_Request'] = _CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastUploadStats_Response'] = _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastViewerStats_Request'] = _CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastViewerStats_Response'] = _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastViewerState_Notification'] = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WaitingBroadcastViewer_Notification'] = _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastUploadStarted_Notification'] = _CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_StopBroadcastUpload_Notification'] = _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_SessionClosed_Notification'] = _CBROADCAST_SESSIONCLOSED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_ViewerBroadcastInvite_Notification'] = _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastStatus_Notification'] = _CBROADCAST_BROADCASTSTATUS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastChannelLive_Notification'] = _CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_SendThumbnailToRelay_Notification'] = _CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCNeedTURNServer_Notification'] = _CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCStart_Notification'] = _CBROADCAST_WEBRTCSTART_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCSetAnswer_Notification'] = _CBROADCAST_WEBRTCSETANSWER_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WebRTCAddViewerCandidate_Notification'] = _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EBroadcastWatchLocation'] = _EBROADCASTWATCHLOCATION
DESCRIPTOR.enum_types_by_name['EBroadcastChatPermission'] = _EBROADCASTCHATPERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CBroadcast_BeginBroadcastSession_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_BeginBroadcastSession_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BEGINBROADCASTSESSION_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BeginBroadcastSession_Request)
  })
_sym_db.RegisterMessage(CBroadcast_BeginBroadcastSession_Request)

CBroadcast_BeginBroadcastSession_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_BeginBroadcastSession_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BeginBroadcastSession_Response)
  })
_sym_db.RegisterMessage(CBroadcast_BeginBroadcastSession_Response)

CBroadcast_EndBroadcastSession_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_EndBroadcastSession_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_ENDBROADCASTSESSION_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_EndBroadcastSession_Request)
  })
_sym_db.RegisterMessage(CBroadcast_EndBroadcastSession_Request)

CBroadcast_EndBroadcastSession_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_EndBroadcastSession_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_ENDBROADCASTSESSION_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_EndBroadcastSession_Response)
  })
_sym_db.RegisterMessage(CBroadcast_EndBroadcastSession_Response)

CBroadcast_StartBroadcastUpload_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBroadcastUpload_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBroadcastUpload_Request)
  })
_sym_db.RegisterMessage(CBroadcast_StartBroadcastUpload_Request)

CBroadcast_StartBroadcastUpload_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBroadcastUpload_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBroadcastUpload_Response)
  })
_sym_db.RegisterMessage(CBroadcast_StartBroadcastUpload_Response)

CBroadcast_NotifyBroadcastUploadStop_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_NotifyBroadcastUploadStop_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_NotifyBroadcastUploadStop_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_NotifyBroadcastUploadStop_Notification)

CBroadcast_WatchBroadcast_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WatchBroadcast_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WATCHBROADCAST_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WatchBroadcast_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WatchBroadcast_Request)

CBroadcast_WatchBroadcast_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WatchBroadcast_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WATCHBROADCAST_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WatchBroadcast_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WatchBroadcast_Response)

CBroadcast_HeartbeatBroadcast_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_HeartbeatBroadcast_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_HeartbeatBroadcast_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_HeartbeatBroadcast_Notification)

CBroadcast_StopWatchingBroadcast_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_StopWatchingBroadcast_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StopWatchingBroadcast_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_StopWatchingBroadcast_Notification)

CBroadcast_GetBroadcastStatus_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTSTATUS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastStatus_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastStatus_Request)

CBroadcast_GetBroadcastStatus_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTSTATUS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastStatus_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastStatus_Response)

CBroadcast_GetBroadcastThumbnail_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastThumbnail_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastThumbnail_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastThumbnail_Request)

CBroadcast_GetBroadcastThumbnail_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastThumbnail_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastThumbnail_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastThumbnail_Response)

CBroadcast_InviteToBroadcast_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_InviteToBroadcast_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_INVITETOBROADCAST_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_InviteToBroadcast_Request)
  })
_sym_db.RegisterMessage(CBroadcast_InviteToBroadcast_Request)

CBroadcast_InviteToBroadcast_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_InviteToBroadcast_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_INVITETOBROADCAST_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_InviteToBroadcast_Response)
  })
_sym_db.RegisterMessage(CBroadcast_InviteToBroadcast_Response)

CBroadcast_SendBroadcastStateToServer_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_SendBroadcastStateToServer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SendBroadcastStateToServer_Request)
  })
_sym_db.RegisterMessage(CBroadcast_SendBroadcastStateToServer_Request)

CBroadcast_SendBroadcastStateToServer_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_SendBroadcastStateToServer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SendBroadcastStateToServer_Response)
  })
_sym_db.RegisterMessage(CBroadcast_SendBroadcastStateToServer_Response)

CBroadcast_NotifyBroadcastSessionHeartbeat_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_NotifyBroadcastSessionHeartbeat_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_NotifyBroadcastSessionHeartbeat_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_NotifyBroadcastSessionHeartbeat_Notification)

CBroadcast_GetBroadcastChatInfo_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTCHATINFO_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatInfo_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatInfo_Request)

CBroadcast_GetBroadcastChatInfo_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatInfo_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatInfo_Response)

CBroadcast_PostChatMessage_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_PostChatMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_POSTCHATMESSAGE_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_PostChatMessage_Request)
  })
_sym_db.RegisterMessage(CBroadcast_PostChatMessage_Request)

CBroadcast_PostChatMessage_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_PostChatMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_POSTCHATMESSAGE_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_PostChatMessage_Response)
  })
_sym_db.RegisterMessage(CBroadcast_PostChatMessage_Response)

CBroadcast_UpdateChatMessageFlair_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_UpdateChatMessageFlair_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_UpdateChatMessageFlair_Request)
  })
_sym_db.RegisterMessage(CBroadcast_UpdateChatMessageFlair_Request)

CBroadcast_UpdateChatMessageFlair_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_UpdateChatMessageFlair_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_UpdateChatMessageFlair_Response)
  })
_sym_db.RegisterMessage(CBroadcast_UpdateChatMessageFlair_Response)

CBroadcast_MuteBroadcastChatUser_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_MuteBroadcastChatUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_MuteBroadcastChatUser_Request)
  })
_sym_db.RegisterMessage(CBroadcast_MuteBroadcastChatUser_Request)

CBroadcast_MuteBroadcastChatUser_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_MuteBroadcastChatUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_MuteBroadcastChatUser_Response)
  })
_sym_db.RegisterMessage(CBroadcast_MuteBroadcastChatUser_Response)

CBroadcast_RemoveUserChatText_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_RemoveUserChatText_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_RemoveUserChatText_Request)
  })
_sym_db.RegisterMessage(CBroadcast_RemoveUserChatText_Request)

CBroadcast_RemoveUserChatText_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_RemoveUserChatText_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_RemoveUserChatText_Response)
  })
_sym_db.RegisterMessage(CBroadcast_RemoveUserChatText_Response)

CBroadcast_GetBroadcastChatUserNames_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatUserNames_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Request)

CBroadcast_GetBroadcastChatUserNames_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatUserNames_Response', (_message.Message,), {

  'PersonaName' : _reflection.GeneratedProtocolMessageType('PersonaName', (_message.Message,), {
    'DESCRIPTOR' : _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME,
    '__module__' : 'steammessages_broadcast_pb2'
    # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Response.PersonaName)
    })
  ,
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Response)
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Response.PersonaName)

CBroadcast_StartBuildClip_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBuildClip_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STARTBUILDCLIP_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBuildClip_Request)
  })
_sym_db.RegisterMessage(CBroadcast_StartBuildClip_Request)

CBroadcast_StartBuildClip_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBuildClip_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STARTBUILDCLIP_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBuildClip_Response)
  })
_sym_db.RegisterMessage(CBroadcast_StartBuildClip_Response)

CBroadcast_GetBuildClipStatus_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBuildClipStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBUILDCLIPSTATUS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBuildClipStatus_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBuildClipStatus_Request)

CBroadcast_GetBuildClipStatus_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBuildClipStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBuildClipStatus_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBuildClipStatus_Response)

CBroadcast_SetClipDetails_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_SetClipDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SETCLIPDETAILS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SetClipDetails_Request)
  })
_sym_db.RegisterMessage(CBroadcast_SetClipDetails_Request)

CBroadcast_SetClipDetails_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_SetClipDetails_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SETCLIPDETAILS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SetClipDetails_Response)
  })
_sym_db.RegisterMessage(CBroadcast_SetClipDetails_Response)

CBroadcast_GetClipDetails_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetClipDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETCLIPDETAILS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetClipDetails_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetClipDetails_Request)

CBroadcast_GetClipDetails_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetClipDetails_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETCLIPDETAILS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetClipDetails_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetClipDetails_Response)

CBroadcast_SetRTMPInfo_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_SetRTMPInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SETRTMPINFO_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SetRTMPInfo_Request)
  })
_sym_db.RegisterMessage(CBroadcast_SetRTMPInfo_Request)

CBroadcast_SetRTMPInfo_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_SetRTMPInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SETRTMPINFO_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SetRTMPInfo_Response)
  })
_sym_db.RegisterMessage(CBroadcast_SetRTMPInfo_Response)

CBroadcast_GetRTMPInfo_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetRTMPInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETRTMPINFO_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetRTMPInfo_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetRTMPInfo_Request)

CBroadcast_GetRTMPInfo_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetRTMPInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETRTMPINFO_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetRTMPInfo_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetRTMPInfo_Response)

CBroadcast_WebRTCHaveTURNServer_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCHaveTURNServer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCHaveTURNServer_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCHaveTURNServer_Notification)

CBroadcast_WebRTCStartResult_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCStartResult_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSTARTRESULT_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCStartResult_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCStartResult_Request)

CBroadcast_WebRTCStartResult_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCStartResult_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSTARTRESULT_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCStartResult_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCStartResult_Response)

CBroadcast_WebRTCStopped_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCStopped_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSTOPPED_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCStopped_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCStopped_Request)

CBroadcast_WebRTCStopped_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCStopped_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSTOPPED_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCStopped_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCStopped_Response)

CBroadcast_WebRTCSetAnswer_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCSetAnswer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSETANSWER_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCSetAnswer_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCSetAnswer_Request)

CBroadcast_WebRTCSetAnswer_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCSetAnswer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSETANSWER_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCSetAnswer_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCSetAnswer_Response)

CBroadcast_WebRTCLookupTURNServer_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCLookupTURNServer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCLookupTURNServer_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCLookupTURNServer_Request)

CBroadcast_WebRTCLookupTURNServer_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCLookupTURNServer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCLookupTURNServer_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCLookupTURNServer_Response)

CBroadcast_WebRTC_Candidate = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTC_Candidate', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTC_CANDIDATE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTC_Candidate)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTC_Candidate)

CBroadcast_WebRTCAddHostCandidate_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCAddHostCandidate_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCAddHostCandidate_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCAddHostCandidate_Request)

CBroadcast_WebRTCAddHostCandidate_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCAddHostCandidate_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCAddHostCandidate_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCAddHostCandidate_Response)

CBroadcast_WebRTCAddViewerCandidate_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCAddViewerCandidate_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCAddViewerCandidate_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCAddViewerCandidate_Request)

CBroadcast_WebRTCAddViewerCandidate_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCAddViewerCandidate_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCAddViewerCandidate_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCAddViewerCandidate_Response)

CBroadcast_WebRTCGetHostCandidates_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCGetHostCandidates_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCGetHostCandidates_Request)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCGetHostCandidates_Request)

CBroadcast_WebRTCGetHostCandidates_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCGetHostCandidates_Response', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCGetHostCandidates_Response)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCGetHostCandidates_Response)

CBroadcast_GetBroadcastUploadStats_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastUploadStats_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastUploadStats_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastUploadStats_Request)

CBroadcast_GetBroadcastUploadStats_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastUploadStats_Response', (_message.Message,), {

  'UploadStats' : _reflection.GeneratedProtocolMessageType('UploadStats', (_message.Message,), {
    'DESCRIPTOR' : _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS,
    '__module__' : 'steammessages_broadcast_pb2'
    # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastUploadStats_Response.UploadStats)
    })
  ,
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastUploadStats_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastUploadStats_Response)
_sym_db.RegisterMessage(CBroadcast_GetBroadcastUploadStats_Response.UploadStats)

CBroadcast_GetBroadcastViewerStats_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastViewerStats_Request', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastViewerStats_Request)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastViewerStats_Request)

CBroadcast_GetBroadcastViewerStats_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastViewerStats_Response', (_message.Message,), {

  'ViewerStats' : _reflection.GeneratedProtocolMessageType('ViewerStats', (_message.Message,), {
    'DESCRIPTOR' : _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS,
    '__module__' : 'steammessages_broadcast_pb2'
    # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastViewerStats_Response.ViewerStats)
    })
  ,

  'CountryStats' : _reflection.GeneratedProtocolMessageType('CountryStats', (_message.Message,), {
    'DESCRIPTOR' : _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS,
    '__module__' : 'steammessages_broadcast_pb2'
    # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastViewerStats_Response.CountryStats)
    })
  ,
  'DESCRIPTOR' : _CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastViewerStats_Response)
  })
_sym_db.RegisterMessage(CBroadcast_GetBroadcastViewerStats_Response)
_sym_db.RegisterMessage(CBroadcast_GetBroadcastViewerStats_Response.ViewerStats)
_sym_db.RegisterMessage(CBroadcast_GetBroadcastViewerStats_Response.CountryStats)

CBroadcast_BroadcastViewerState_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastViewerState_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastViewerState_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_BroadcastViewerState_Notification)

CBroadcast_WaitingBroadcastViewer_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WaitingBroadcastViewer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WaitingBroadcastViewer_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WaitingBroadcastViewer_Notification)

CBroadcast_BroadcastUploadStarted_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastUploadStarted_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastUploadStarted_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_BroadcastUploadStarted_Notification)

CBroadcast_StopBroadcastUpload_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_StopBroadcastUpload_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StopBroadcastUpload_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_StopBroadcastUpload_Notification)

CBroadcast_SessionClosed_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_SessionClosed_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SESSIONCLOSED_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SessionClosed_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_SessionClosed_Notification)

CBroadcast_ViewerBroadcastInvite_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_ViewerBroadcastInvite_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_ViewerBroadcastInvite_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_ViewerBroadcastInvite_Notification)

CBroadcast_BroadcastStatus_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastStatus_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BROADCASTSTATUS_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastStatus_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_BroadcastStatus_Notification)

CBroadcast_BroadcastChannelLive_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastChannelLive_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastChannelLive_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_BroadcastChannelLive_Notification)

CBroadcast_SendThumbnailToRelay_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_SendThumbnailToRelay_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SendThumbnailToRelay_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_SendThumbnailToRelay_Notification)

CBroadcast_WebRTCNeedTURNServer_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCNeedTURNServer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCNeedTURNServer_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCNeedTURNServer_Notification)

CBroadcast_WebRTCStart_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCStart_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSTART_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCStart_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCStart_Notification)

CBroadcast_WebRTCSetAnswer_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCSetAnswer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCSETANSWER_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCSetAnswer_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCSetAnswer_Notification)

CBroadcast_WebRTCAddViewerCandidate_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WebRTCAddViewerCandidate_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION,
  '__module__' : 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WebRTCAddViewerCandidate_Notification)
  })
_sym_db.RegisterMessage(CBroadcast_WebRTCAddViewerCandidate_Notification)


DESCRIPTOR._options = None
_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE.fields_by_name['thumbnail_upload_address']._options = None
_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE.fields_by_name['thumbnail_upload_token']._options = None
_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE.fields_by_name['thumbnail_interval_seconds']._options = None
_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE.fields_by_name['heartbeat_interval_seconds']._options = None
_CBROADCAST_STARTBROADCASTUPLOAD_REQUEST.fields_by_name['rtmp_token']._options = None
_CBROADCAST_WATCHBROADCAST_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_WATCHBROADCAST_REQUEST.fields_by_name['existing_broadcast_id']._options = None
_CBROADCAST_WATCHBROADCAST_REQUEST.fields_by_name['viewer_token']._options = None
_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION.fields_by_name['steamid']._options = None
_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION.fields_by_name['broadcast_id']._options = None
_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION.fields_by_name['viewer_token']._options = None
_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION.fields_by_name['representation']._options = None
_CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION.fields_by_name['steamid']._options = None
_CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION.fields_by_name['broadcast_id']._options = None
_CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION.fields_by_name['viewer_token']._options = None
_CBROADCAST_GETBROADCASTSTATUS_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_GETBROADCASTSTATUS_REQUEST.fields_by_name['broadcast_id']._options = None
_CBROADCAST_POSTCHATMESSAGE_REQUEST.fields_by_name['language']._options = None
_CBROADCAST_POSTCHATMESSAGE_REQUEST.fields_by_name['country_code']._options = None
_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME.fields_by_name['steam_id']._options = None
_CBROADCAST_SETCLIPDETAILS_REQUEST.fields_by_name['broadcast_clip_id']._options = None
_CBROADCAST_SETCLIPDETAILS_REQUEST.fields_by_name['start_time']._options = None
_CBROADCAST_SETCLIPDETAILS_REQUEST.fields_by_name['end_time']._options = None
_CBROADCAST_GETCLIPDETAILS_REQUEST.fields_by_name['broadcast_clip_id']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['broadcast_clip_id']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['video_id']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['channel_id']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['app_id']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['accountid_broadcaster']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['accountid_clipmaker']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['video_description']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['start_time']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['length_milliseconds']._options = None
_CBROADCAST_GETCLIPDETAILS_RESPONSE.fields_by_name['thumbnail_path']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['broadcast_chat_permission']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['broadcast_buffer']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['chat_rate_limit']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['enable_replay']._options = None
_CBROADCAST_SETRTMPINFO_REQUEST.fields_by_name['is_partner_chat_only']._options = None
_CBROADCAST_GETRTMPINFO_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['broadcast_chat_permission']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['broadcast_buffer']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['steamid']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['chat_rate_limit']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['enable_replay']._options = None
_CBROADCAST_GETRTMPINFO_RESPONSE.fields_by_name['is_partner_chat_only']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST.fields_by_name['row_limit']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST.fields_by_name['start_time']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST.fields_by_name['upload_id']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST.fields_by_name['session_id']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['upload_result']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['time_stopped']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['seconds_uploaded']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['max_viewers']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['resolution_x']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['resolution_y']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['avg_bandwidth']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['total_bytes']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['app_id']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['total_unique_viewers']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['total_seconds_watched']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['time_started']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['upload_id']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['local_address']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['remote_address']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['frames_per_second']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['num_representations']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['app_name']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['is_replay']._options = None
_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE_UPLOADSTATS.fields_by_name['session_id']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST.fields_by_name['upload_id']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST.fields_by_name['steamid']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS.fields_by_name['time']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_VIEWERSTATS.fields_by_name['num_viewers']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS.fields_by_name['country_code']._options = None
_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE_COUNTRYSTATS.fields_by_name['num_viewers']._options = None
_CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION.fields_by_name['heartbeat_interval_seconds']._options = None

_BROADCAST = _descriptor.ServiceDescriptor(
  name='Broadcast',
  full_name='Broadcast',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030&Methods for Steam broadcast operations',
  create_key=_descriptor._internal_create_key,
  serialized_start=14692,
  serialized_end=20202,
  methods=[
  _descriptor.MethodDescriptor(
    name='BeginBroadcastSession',
    full_name='Broadcast.BeginBroadcastSession',
    index=0,
    containing_service=None,
    input_type=_CBROADCAST_BEGINBROADCASTSESSION_REQUEST,
    output_type=_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE,
    serialized_options=b'\202\265\030yRequest from client to directory to begin a broadcast session. No data being sent to relay; just available for broadcast.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndBroadcastSession',
    full_name='Broadcast.EndBroadcastSession',
    index=1,
    containing_service=None,
    input_type=_CBROADCAST_ENDBROADCASTSESSION_REQUEST,
    output_type=_CBROADCAST_ENDBROADCASTSESSION_RESPONSE,
    serialized_options=b'\202\265\030LRequest from client to stop a broadcast session. Any uploads will terminate.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartBroadcastUpload',
    full_name='Broadcast.StartBroadcastUpload',
    index=2,
    containing_service=None,
    input_type=_CBROADCAST_STARTBROADCASTUPLOAD_REQUEST,
    output_type=_CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE,
    serialized_options=b'\202\265\030;Request from client to begin sending video for a broadcast.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastUploadStop',
    full_name='Broadcast.NotifyBroadcastUploadStop',
    index=3,
    containing_service=None,
    input_type=_CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0307Tells directory that client stopped uploading broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchBroadcast',
    full_name='Broadcast.WatchBroadcast',
    index=4,
    containing_service=None,
    input_type=_CBROADCAST_WATCHBROADCAST_REQUEST,
    output_type=_CBROADCAST_WATCHBROADCAST_RESPONSE,
    serialized_options=b'\202\265\030(Request from viewer to watch a broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HeartbeatBroadcast',
    full_name='Broadcast.HeartbeatBroadcast',
    index=5,
    containing_service=None,
    input_type=_CBROADCAST_HEARTBEATBROADCAST_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030-Notify directory that user is still watching.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopWatchingBroadcast',
    full_name='Broadcast.StopWatchingBroadcast',
    index=6,
    containing_service=None,
    input_type=_CBROADCAST_STOPWATCHINGBROADCAST_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030gRequest to immediately stop watching a broadcast. Optional Method, if not called, viewer will time out.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastStatus',
    full_name='Broadcast.GetBroadcastStatus',
    index=7,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTSTATUS_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTSTATUS_RESPONSE,
    serialized_options=b'\202\265\030+Request from viewer about broadcast details',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastThumbnail',
    full_name='Broadcast.GetBroadcastThumbnail',
    index=8,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTTHUMBNAIL_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTTHUMBNAIL_RESPONSE,
    serialized_options=b'\202\265\030#Request thumbnail URL for broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InviteToBroadcast',
    full_name='Broadcast.InviteToBroadcast',
    index=9,
    containing_service=None,
    input_type=_CBROADCAST_INVITETOBROADCAST_REQUEST,
    output_type=_CBROADCAST_INVITETOBROADCAST_RESPONSE,
    serialized_options=b'\202\265\030:Invites another steam user to watch the caller\'s broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendBroadcastStateToServer',
    full_name='Broadcast.SendBroadcastStateToServer',
    index=10,
    containing_service=None,
    input_type=_CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST,
    output_type=_CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE,
    serialized_options=b'\202\265\030ESends users current broadcast state (permissions, game) to the server',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastSessionHeartbeat',
    full_name='Broadcast.NotifyBroadcastSessionHeartbeat',
    index=11,
    containing_service=None,
    input_type=_CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0304Tells directory broadcast session is still available',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChatInfo',
    full_name='Broadcast.GetBroadcastChatInfo',
    index=12,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTCHATINFO_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTCHATINFO_RESPONSE,
    serialized_options=b'\202\265\030#Gets chat room info for a broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostChatMessage',
    full_name='Broadcast.PostChatMessage',
    index=13,
    containing_service=None,
    input_type=_CBROADCAST_POSTCHATMESSAGE_REQUEST,
    output_type=_CBROADCAST_POSTCHATMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030(Post chat message to specified chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateChatMessageFlair',
    full_name='Broadcast.UpdateChatMessageFlair',
    index=14,
    containing_service=None,
    input_type=_CBROADCAST_UPDATECHATMESSAGEFLAIR_REQUEST,
    output_type=_CBROADCAST_UPDATECHATMESSAGEFLAIR_RESPONSE,
    serialized_options=b'\202\265\0304Update chat message flair in the specified chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MuteBroadcastChatUser',
    full_name='Broadcast.MuteBroadcastChatUser',
    index=15,
    containing_service=None,
    input_type=_CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST,
    output_type=_CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE,
    serialized_options=b'\202\265\030\"Mute a user in your broadcast chat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveUserChatText',
    full_name='Broadcast.RemoveUserChatText',
    index=16,
    containing_service=None,
    input_type=_CBROADCAST_REMOVEUSERCHATTEXT_REQUEST,
    output_type=_CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE,
    serialized_options=b'\202\265\030)Tell all viewers to remove user chat text',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChatUserNames',
    full_name='Broadcast.GetBroadcastChatUserNames',
    index=17,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE,
    serialized_options=b'\202\265\030#Get names for list of users in chat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartBuildClip',
    full_name='Broadcast.StartBuildClip',
    index=18,
    containing_service=None,
    input_type=_CBROADCAST_STARTBUILDCLIP_REQUEST,
    output_type=_CBROADCAST_STARTBUILDCLIP_RESPONSE,
    serialized_options=b'\202\265\030\037Start building a broadcast clip',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBuildClipStatus',
    full_name='Broadcast.GetBuildClipStatus',
    index=19,
    containing_service=None,
    input_type=_CBROADCAST_GETBUILDCLIPSTATUS_REQUEST,
    output_type=_CBROADCAST_GETBUILDCLIPSTATUS_RESPONSE,
    serialized_options=b'\202\265\030\037Start building a broadcast clip',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetClipDetails',
    full_name='Broadcast.SetClipDetails',
    index=20,
    containing_service=None,
    input_type=_CBROADCAST_SETCLIPDETAILS_REQUEST,
    output_type=_CBROADCAST_SETCLIPDETAILS_RESPONSE,
    serialized_options=b'\202\265\030\030Updates a broadcast clip',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClipDetails',
    full_name='Broadcast.GetClipDetails',
    index=21,
    containing_service=None,
    input_type=_CBROADCAST_GETCLIPDETAILS_REQUEST,
    output_type=_CBROADCAST_GETCLIPDETAILS_RESPONSE,
    serialized_options=b'\202\265\030\037Get details for Broadcast Clips',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRTMPInfo',
    full_name='Broadcast.SetRTMPInfo',
    index=22,
    containing_service=None,
    input_type=_CBROADCAST_SETRTMPINFO_REQUEST,
    output_type=_CBROADCAST_SETRTMPINFO_RESPONSE,
    serialized_options=b'\202\265\030\030Sets RTMP broadcast info',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRTMPInfo',
    full_name='Broadcast.GetRTMPInfo',
    index=23,
    containing_service=None,
    input_type=_CBROADCAST_GETRTMPINFO_REQUEST,
    output_type=_CBROADCAST_GETRTMPINFO_RESPONSE,
    serialized_options=b'\202\265\030\030Gets RTMP broadcast info',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCHaveTURNServer',
    full_name='Broadcast.NotifyWebRTCHaveTURNServer',
    index=24,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCHAVETURNSERVER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030@Notification from client to server with the client\'s TURN server',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCStartResult',
    full_name='Broadcast.WebRTCStartResult',
    index=25,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCSTARTRESULT_REQUEST,
    output_type=_CBROADCAST_WEBRTCSTARTRESULT_RESPONSE,
    serialized_options=b'\202\265\030DNotify the server that a WebRTC session has been created by the host',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCStopped',
    full_name='Broadcast.WebRTCStopped',
    index=26,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCSTOPPED_REQUEST,
    output_type=_CBROADCAST_WEBRTCSTOPPED_RESPONSE,
    serialized_options=b'\202\265\030DNotify the server that a WebRTC session has been stopped by the host',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCSetAnswer',
    full_name='Broadcast.WebRTCSetAnswer',
    index=27,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCSETANSWER_REQUEST,
    output_type=_CBROADCAST_WEBRTCSETANSWER_RESPONSE,
    serialized_options=b'\202\265\030FNotify the server that a WebRTC session has been created by the viewer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCLookupTURNServer',
    full_name='Broadcast.WebRTCLookupTURNServer',
    index=28,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCLOOKUPTURNSERVER_REQUEST,
    output_type=_CBROADCAST_WEBRTCLOOKUPTURNSERVER_RESPONSE,
    serialized_options=b'\202\265\030+Lookup the best TURN server for this client',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCAddHostCandidate',
    full_name='Broadcast.WebRTCAddHostCandidate',
    index=29,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCADDHOSTCANDIDATE_REQUEST,
    output_type=_CBROADCAST_WEBRTCADDHOSTCANDIDATE_RESPONSE,
    serialized_options=b'\202\265\030:Add an ICE candidate for the host side of a WebRTC session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCAddViewerCandidate',
    full_name='Broadcast.WebRTCAddViewerCandidate',
    index=30,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_REQUEST,
    output_type=_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_RESPONSE,
    serialized_options=b'\202\265\030<Add an ICE candidate for the viewer side of a WebRTC session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WebRTCGetHostCandidates',
    full_name='Broadcast.WebRTCGetHostCandidates',
    index=31,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCGETHOSTCANDIDATES_REQUEST,
    output_type=_CBROADCAST_WEBRTCGETHOSTCANDIDATES_RESPONSE,
    serialized_options=b'\202\265\030<Get the ICE candidates for the host side of a WebRTC session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastUploadStats',
    full_name='Broadcast.GetBroadcastUploadStats',
    index=32,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTUPLOADSTATS_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTUPLOADSTATS_RESPONSE,
    serialized_options=b'\202\265\030$Gets broadcast upload stats for user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastViewerStats',
    full_name='Broadcast.GetBroadcastViewerStats',
    index=33,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTVIEWERSTATS_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTVIEWERSTATS_RESPONSE,
    serialized_options=b'\202\265\030%Gets viewer stats for given broadcast',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROADCAST)

DESCRIPTOR.services_by_name['Broadcast'] = _BROADCAST


_BROADCASTCLIENT = _descriptor.ServiceDescriptor(
  name='BroadcastClient',
  full_name='BroadcastClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=20205,
  serialized_end=22449,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastViewerState',
    full_name='BroadcastClient.NotifyBroadcastViewerState',
    index=0,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030CNotification from server to client that a viewers state has changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWaitingBroadcastViewer',
    full_name='BroadcastClient.NotifyWaitingBroadcastViewer',
    index=1,
    containing_service=None,
    input_type=_CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030[Notification from server to client one or more users is waiting for user to start broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastUploadStarted',
    full_name='BroadcastClient.NotifyBroadcastUploadStarted',
    index=2,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTUPLOADSTARTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ENotification from server to client with information about a broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyStopBroadcastUpload',
    full_name='BroadcastClient.NotifyStopBroadcastUpload',
    index=3,
    containing_service=None,
    input_type=_CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030zNotification from server to client telling it to stop uploading when the last viewer has disconnected from their broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifySessionClosed',
    full_name='BroadcastClient.NotifySessionClosed',
    index=4,
    containing_service=None,
    input_type=_CBROADCAST_SESSIONCLOSED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030eNotification from server to client telling it a session has been closed unexpectedly by the directory',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyViewerBroadcastInvite',
    full_name='BroadcastClient.NotifyViewerBroadcastInvite',
    index=5,
    containing_service=None,
    input_type=_CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030cNotification from server to client that a broadcaster is inviting a viewer to watch their broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastStatus',
    full_name='BroadcastClient.NotifyBroadcastStatus',
    index=6,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTSTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ANotification from server to client about current broadcast status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastChannelLive',
    full_name='BroadcastClient.NotifyBroadcastChannelLive',
    index=7,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTCHANNELLIVE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ANotification from server to client about current broadcast status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendThumbnailToRelay',
    full_name='BroadcastClient.SendThumbnailToRelay',
    index=8,
    containing_service=None,
    input_type=_CBROADCAST_SENDTHUMBNAILTORELAY_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030\030Send thumbnails to relay',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCNeedTURNServer',
    full_name='BroadcastClient.NotifyWebRTCNeedTURNServer',
    index=9,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCNEEDTURNSERVER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030INotification from server to client that it needs the client\'s TURN server',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCStart',
    full_name='BroadcastClient.NotifyWebRTCStart',
    index=10,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCSTART_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030HNotification from server to client that it should start a WebRTC session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCSetAnswer',
    full_name='BroadcastClient.NotifyWebRTCSetAnswer',
    index=11,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCSETANSWER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030KNotification from server to client about the broadcast viewer WebRTC answer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCAddViewerCandidate',
    full_name='BroadcastClient.NotifyWebRTCAddViewerCandidate',
    index=12,
    containing_service=None,
    input_type=_CBROADCAST_WEBRTCADDVIEWERCANDIDATE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030PNotification from server to client about a broadcast viewer WebRTC ICE candidate',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROADCASTCLIENT)

DESCRIPTOR.services_by_name['BroadcastClient'] = _BROADCASTCLIENT

Broadcast = service_reflection.GeneratedServiceType('Broadcast', (_service.Service,), dict(
  DESCRIPTOR = _BROADCAST,
  __module__ = 'steammessages_broadcast_pb2'
  ))

Broadcast_Stub = service_reflection.GeneratedServiceStubType('Broadcast_Stub', (Broadcast,), dict(
  DESCRIPTOR = _BROADCAST,
  __module__ = 'steammessages_broadcast_pb2'
  ))


BroadcastClient = service_reflection.GeneratedServiceType('BroadcastClient', (_service.Service,), dict(
  DESCRIPTOR = _BROADCASTCLIENT,
  __module__ = 'steammessages_broadcast_pb2'
  ))

BroadcastClient_Stub = service_reflection.GeneratedServiceStubType('BroadcastClient_Stub', (BroadcastClient,), dict(
  DESCRIPTOR = _BROADCASTCLIENT,
  __module__ = 'steammessages_broadcast_pb2'
  ))


# @@protoc_insertion_point(module_scope)
