# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_chat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_clientserver_friends_pb2 as steammessages__clientserver__friends__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_chat.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18steammessages_chat.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a(steammessages_clientserver_friends.proto\"*\n(CChat_RequestFriendPersonaStates_Request\"+\n)CChat_RequestFriendPersonaStates_Response\"\xce\x01\n%CChatRoom_CreateChatRoomGroup_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_invited\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10steamid_invitees\x18\x04 \x03(\x06\x12$\n\x1cwatching_broadcast_accountid\x18\x06 \x01(\r\x12%\n\x1dwatching_broadcast_channel_id\x18\x07 \x01(\x04\";\n\tCChatRole\x12\x0f\n\x07role_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\"\xd4\x02\n\x10\x43\x43hatRoleActions\x12\x0f\n\x07role_id\x18\x01 \x01(\x04\x12(\n can_create_rename_delete_channel\x18\x02 \x01(\x08\x12\x10\n\x08\x63\x61n_kick\x18\x03 \x01(\x08\x12\x0f\n\x07\x63\x61n_ban\x18\x04 \x01(\x08\x12\x12\n\ncan_invite\x18\x05 \x01(\x08\x12&\n\x1e\x63\x61n_change_tagline_avatar_name\x18\x06 \x01(\x08\x12\x10\n\x08\x63\x61n_chat\x18\x07 \x01(\x08\x12\x18\n\x10\x63\x61n_view_history\x18\x08 \x01(\x08\x12\x1e\n\x16\x63\x61n_change_group_roles\x18\t \x01(\x08\x12\x1d\n\x15\x63\x61n_change_user_roles\x18\n \x01(\x08\x12\x17\n\x0f\x63\x61n_mention_all\x18\x0b \x01(\x08\x12\"\n\x1a\x63\x61n_set_watching_broadcast\x18\x0c \x01(\x08\"c\n\x10\x43\x43hatPartyBeacon\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_owner\x18\x02 \x01(\x06\x12\x11\n\tbeacon_id\x18\x03 \x01(\x06\x12\x15\n\rgame_metadata\x18\x04 \x01(\t\"\xbc\x03\n\x19\x43\x43hatRoomGroupHeaderState\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x11\n\tchat_name\x18\x02 \x01(\t\x12\x0e\n\x06\x63lanid\x18\r \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x0e \x01(\r\x12\r\n\x05\x61ppid\x18\x15 \x01(\r\x12\x0f\n\x07tagline\x18\x0f \x01(\t\x12\x12\n\navatar_sha\x18\x10 \x01(\x0c\x12\x17\n\x0f\x64\x65\x66\x61ult_role_id\x18\x11 \x01(\x04\x12\x19\n\x05roles\x18\x12 \x03(\x0b\x32\n.CChatRole\x12\'\n\x0crole_actions\x18\x13 \x03(\x0b\x32\x11.CChatRoleActions\x12$\n\x1cwatching_broadcast_accountid\x18\x14 \x01(\r\x12(\n\rparty_beacons\x18\x16 \x03(\x0b\x32\x11.CChatPartyBeacon\x12%\n\x1dwatching_broadcast_channel_id\x18\x17 \x01(\x04\x12\x1a\n\x12\x61\x63tive_minigame_id\x18\x18 \x01(\x04\x12\x16\n\x0e\x61vatar_ugc_url\x18\x19 \x01(\t\x12\x10\n\x08\x64isabled\x18\x1a \x01(\x08\"\xd3\x01\n\x0f\x43\x43hatRoomMember\x12\x11\n\taccountid\x18\x01 \x01(\r\x12@\n\x05state\x18\x03 \x01(\x0e\x32\x13.EChatRoomJoinState:\x1ck_EChatRoomJoinState_Default\x12?\n\x04rank\x18\x04 \x01(\x0e\x32\x13.EChatRoomGroupRank:\x1ck_EChatRoomGroupRank_Default\x12\x18\n\x10time_kick_expire\x18\x06 \x01(\r\x12\x10\n\x08role_ids\x18\x07 \x03(\x04\"\xca\x01\n\x0e\x43\x43hatRoomState\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x11\n\tchat_name\x18\x02 \x01(\t\x12\x15\n\rvoice_allowed\x18\x03 \x01(\x08\x12\x18\n\x10members_in_voice\x18\x04 \x03(\r\x12\x19\n\x11time_last_message\x18\x05 \x01(\r\x12\x12\n\nsort_order\x18\x06 \x01(\r\x12\x14\n\x0clast_message\x18\x07 \x01(\t\x12\x1e\n\x16\x61\x63\x63ountid_last_message\x18\x08 \x01(\r\"\xca\x01\n\x13\x43\x43hatRoomGroupState\x12\x30\n\x0cheader_state\x18\x01 \x01(\x0b\x32\x1a.CChatRoomGroupHeaderState\x12!\n\x07members\x18\x02 \x03(\x0b\x32\x10.CChatRoomMember\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x04 \x01(\x04\x12#\n\nchat_rooms\x18\x05 \x03(\x0b\x32\x0f.CChatRoomState\x12 \n\x06kicked\x18\x07 \x03(\x0b\x32\x10.CChatRoomMember\"\xfb\x02\n\x12\x43UserChatRoomState\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\x15\n\rtime_last_ack\x18\x03 \x01(\r\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x04 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x05 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x19\n\x11time_last_mention\x18\x06 \x01(\r\x12%\n\x16unread_indicator_muted\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x11time_first_unread\x18\x08 \x01(\r\"\x89\x03\n\x17\x43UserChatRoomGroupState\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\x31\n\x14user_chat_room_state\x18\x03 \x03(\x0b\x32\x13.CUserChatRoomState\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x04 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x05 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1b\n\x13time_last_group_ack\x18\x06 \x01(\r\x12%\n\x16unread_indicator_muted\x18\x07 \x01(\x08:\x05\x66\x61lse\"\x97\x01\n&CChatRoom_CreateChatRoomGroup_Response\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12#\n\x05state\x18\x02 \x01(\x0b\x32\x14.CChatRoomGroupState\x12\x31\n\x0fuser_chat_state\x18\x03 \x01(\x0b\x32\x18.CUserChatRoomGroupState\"J\n#CChatRoom_SaveChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n$CChatRoom_SaveChatRoomGroup_Response\"L\n%CChatRoom_RenameChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n&CChatRoom_RenameChatRoomGroup_Response\x12\x0c\n\x04name\x18\x01 \x01(\t\"S\n)CChatRoom_SetChatRoomGroupTagline_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07tagline\x18\x02 \x01(\t\",\n*CChatRoom_SetChatRoomGroupTagline_Response\"U\n(CChatRoom_SetChatRoomGroupAvatar_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x12\n\navatar_sha\x18\x02 \x01(\x0c\"+\n)CChatRoom_SetChatRoomGroupAvatar_Response\"\x99\x01\n3CChatRoom_SetChatRoomGroupWatchingBroadcast_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12$\n\x1cwatching_broadcast_accountid\x18\x02 \x01(\r\x12%\n\x1dwatching_broadcast_channel_id\x18\x03 \x01(\x04\"6\n4CChatRoom_SetChatRoomGroupWatchingBroadcast_Response\"X\n.CChatRoom_JoinMiniGameForChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"F\n/CChatRoom_JoinMiniGameForChatRoomGroup_Response\x12\x13\n\x0bminigame_id\x18\x01 \x01(\x04\"l\n-CChatRoom_EndMiniGameForChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x13\n\x0bminigame_id\x18\x03 \x01(\x04\"0\n.CChatRoom_EndMiniGameForChatRoomGroup_Response\"X\n\x1a\x43\x43hatRoom_MuteUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x12\n\nexpiration\x18\x03 \x01(\x05\"\x1d\n\x1b\x43\x43hatRoom_MuteUser_Response\"X\n\x1a\x43\x43hatRoom_KickUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x12\n\nexpiration\x18\x03 \x01(\x05\"\x1d\n\x1b\x43\x43hatRoom_KickUser_Response\"^\n!CChatRoom_SetUserBanState_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\tban_state\x18\x03 \x01(\x08\"$\n\"CChatRoom_SetUserBanState_Response\"H\n\x1e\x43\x43hatRoom_RevokeInvite_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"!\n\x1f\x43\x43hatRoom_RevokeInvite_Response\"C\n\x1c\x43\x43hatRoom_CreateRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"C\n\x1d\x43\x43hatRoom_CreateRole_Response\x12\"\n\x07\x61\x63tions\x18\x02 \x01(\x0b\x32\x11.CChatRoleActions\"3\n\x1a\x43\x43hatRoom_GetRoles_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"8\n\x1b\x43\x43hatRoom_GetRoles_Response\x12\x19\n\x05roles\x18\x01 \x03(\x0b\x32\n.CChatRole\"T\n\x1c\x43\x43hatRoom_RenameRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x1f\n\x1d\x43\x43hatRoom_RenameRole_Response\"X\n\x1d\x43\x43hatRoom_ReorderRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\" \n\x1e\x43\x43hatRoom_ReorderRole_Response\"F\n\x1c\x43\x43hatRoom_DeleteRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\"\x1f\n\x1d\x43\x43hatRoom_DeleteRole_Response\"J\n CChatRoom_GetRoleActions_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\"G\n!CChatRoom_GetRoleActions_Response\x12\"\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x11.CChatRoleActions\"r\n$CChatRoom_ReplaceRoleActions_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\"\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32\x11.CChatRoleActions\"\'\n%CChatRoom_ReplaceRoleActions_Response\"Z\n\x1f\x43\x43hatRoom_AddRoleToUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\"\"\n CChatRoom_AddRoleToUser_Response\"K\n!CChatRoom_GetRolesForUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"6\n\"CChatRoom_GetRolesForUser_Response\x12\x10\n\x08role_ids\x18\x01 \x03(\x04\"_\n$CChatRoom_DeleteRoleFromUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\"\'\n%CChatRoom_DeleteRoleFromUser_Response\"b\n#CChatRoom_JoinChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0binvite_code\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\"\xa9\x01\n$CChatRoom_JoinChatRoomGroup_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CChatRoomGroupState\x12\x31\n\x0fuser_chat_state\x18\x03 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x14\n\x0cjoin_chat_id\x18\x04 \x01(\x04\x12\x13\n\x0btime_expire\x18\x05 \x01(\r\"\x86\x01\n-CChatRoom_InviteFriendToChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\x12\x1c\n\x14skip_friendsui_check\x18\x04 \x01(\x08\"0\n.CChatRoom_InviteFriendToChatRoomGroup_Response\"=\n$CChatRoom_LeaveChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\'\n%CChatRoom_LeaveChatRoomGroup_Response\"\\\n CChatRoom_CreateChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x61llow_voice\x18\x03 \x01(\x08\"G\n!CChatRoom_CreateChatRoom_Response\x12\"\n\tchat_room\x18\x01 \x01(\x0b\x32\x0f.CChatRoomState\"J\n CChatRoom_DeleteChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"#\n!CChatRoom_DeleteChatRoom_Response\"X\n CChatRoom_RenameChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"#\n!CChatRoom_RenameChatRoom_Response\"g\n!CChatRoom_ReorderChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x1a\n\x12move_after_chat_id\x18\x03 \x01(\x04\"$\n\"CChatRoom_ReorderChatRoom_Response\"t\n!CChatRoom_SendChatMessage_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x04 \x01(\x08\"\x8a\x01\n\"CChatRoom_SendChatMessage_Response\x12\x18\n\x10modified_message\x18\x01 \x01(\t\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x1f\n\x17message_without_bb_code\x18\x04 \x01(\t\"I\n\x1f\x43\x43hatRoom_JoinVoiceChat_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"8\n CChatRoom_JoinVoiceChat_Response\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x04\"J\n CChatRoom_LeaveVoiceChat_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"#\n!CChatRoom_LeaveVoiceChat_Response\"\xb4\x01\n#CChatRoom_GetMessageHistory_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x11\n\tlast_time\x18\x03 \x01(\r\x12\x14\n\x0clast_ordinal\x18\x04 \x01(\r\x12\x12\n\nstart_time\x18\x05 \x01(\r\x12\x15\n\rstart_ordinal\x18\x06 \x01(\r\x12\x11\n\tmax_count\x18\x07 \x01(\r\"\x86\x01\n\rServerMessage\x12\x46\n\x07message\x18\x01 \x01(\x0e\x32\x17.EChatRoomServerMessage:\x1ck_EChatRoomServerMsg_Invalid\x12\x14\n\x0cstring_param\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ountid_param\x18\x03 \x01(\r\"\xa2\x04\n$CChatRoom_GetMessageHistory_Response\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.CChatRoom_GetMessageHistory_Response.ChatMessage\x12\x16\n\x0emore_available\x18\x04 \x01(\x08\x1a\x9c\x03\n\x0b\x43hatMessage\x12\x0e\n\x06sender\x18\x01 \x01(\r\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12&\n\x0eserver_message\x18\x05 \x01(\x0b\x32\x0e.ServerMessage\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12T\n\treactions\x18\x07 \x03(\x0b\x32\x41.CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction\x1a\xb1\x01\n\x0fMessageReaction\x12\\\n\rreaction_type\x18\x01 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x02 \x01(\t\x12\x14\n\x0cnum_reactors\x18\x03 \x01(\r\x12\x18\n\x10has_user_reacted\x18\x04 \x01(\x08\"\'\n%CChatRoom_GetMyChatRoomGroups_Request\"\xb4\x05\n*CChatRoom_GetChatRoomGroupSummary_Response\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x63hat_group_name\x18\x02 \x01(\t\x12\x1b\n\x13\x61\x63tive_member_count\x18\x03 \x01(\r\x12!\n\x19\x61\x63tive_voice_member_count\x18\x04 \x01(\r\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x05 \x01(\x04\x12#\n\nchat_rooms\x18\x06 \x03(\x0b\x32\x0f.CChatRoomState\x12\x0e\n\x06\x63lanid\x18\x07 \x01(\r\x12\x1a\n\x12\x63hat_group_tagline\x18\x08 \x01(\t\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\t \x01(\r\x12\x13\n\x0btop_members\x18\n \x03(\r\x12\x1d\n\x15\x63hat_group_avatar_sha\x18\x0b \x01(\x0c\x12?\n\x04rank\x18\x0c \x01(\x0e\x32\x13.EChatRoomGroupRank:\x1ck_EChatRoomGroupRank_Default\x12\x17\n\x0f\x64\x65\x66\x61ult_role_id\x18\r \x01(\x04\x12\x10\n\x08role_ids\x18\x0e \x03(\x04\x12\'\n\x0crole_actions\x18\x0f \x03(\x0b\x32\x11.CChatRoleActions\x12$\n\x1cwatching_broadcast_accountid\x18\x10 \x01(\r\x12\r\n\x05\x61ppid\x18\x11 \x01(\r\x12(\n\rparty_beacons\x18\x12 \x03(\x0b\x32\x11.CChatPartyBeacon\x12%\n\x1dwatching_broadcast_channel_id\x18\x13 \x01(\x04\x12\x1a\n\x12\x61\x63tive_minigame_id\x18\x14 \x01(\x04\x12\x16\n\x0e\x61vatar_ugc_url\x18\x15 \x01(\t\x12\x10\n\x08\x64isabled\x18\x16 \x01(\x08\"\x93\x01\n\x14\x43\x43hatRoomSummaryPair\x12\x37\n\x15user_chat_group_state\x18\x01 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x42\n\rgroup_summary\x18\x02 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\"Y\n&CChatRoom_GetMyChatRoomGroups_Response\x12/\n\x10\x63hat_room_groups\x18\x01 \x03(\x0b\x32\x15.CChatRoomSummaryPair\"@\n\'CChatRoom_GetChatRoomGroupState_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"O\n(CChatRoom_GetChatRoomGroupState_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CChatRoomGroupState\"B\n)CChatRoom_GetChatRoomGroupSummary_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"d\n0CChatRoom_SetAppChatRoomGroupForceActive_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x19\n\x11requesting_app_id\x18\x02 \x01(\r\"`\n1CChatRoom_SetAppChatRoomGroupForceActive_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x1b\n\x13\x61\x63\x63ounts_in_channel\x18\x02 \x03(\r\"m\n9CChatRoom_SetAppChatRoomGroupStopForceActive_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x19\n\x11requesting_app_id\x18\x02 \x01(\r\"b\n%CChatRoom_AckChatMessage_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"c\n\"CChatRoom_CreateInviteLink_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x15\n\rseconds_valid\x18\x02 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\"Q\n#CChatRoom_CreateInviteLink_Response\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\x12\x15\n\rseconds_valid\x18\x02 \x01(\r\":\n#CChatRoom_GetInviteLinkInfo_Request\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\"\x8c\x02\n$CChatRoom_GetInviteLinkInfo_Response\x12\x16\n\x0esteamid_sender\x18\x03 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x04 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x06 \x01(\x04\x12\x42\n\rgroup_summary\x18\x08 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12\x37\n\x15user_chat_group_state\x18\t \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x18\n\x10time_kick_expire\x18\n \x01(\r\x12\x0e\n\x06\x62\x61nned\x18\x0b \x01(\x08\"w\n\x1f\x43\x43hatRoom_GetInviteInfo_Request\x12\x17\n\x0fsteamid_invitee\x18\x01 \x01(\x06\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\x12\x13\n\x0binvite_code\x18\x04 \x01(\t\"\x90\x01\n CChatRoom_GetInviteInfo_Response\x12\x42\n\rgroup_summary\x18\x01 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12\x18\n\x10time_kick_expire\x18\x02 \x01(\r\x12\x0e\n\x06\x62\x61nned\x18\x03 \x01(\x08\"A\n(CChatRoom_GetInviteLinksForGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\xd7\x01\n)CChatRoom_GetInviteLinksForGroup_Response\x12I\n\x0cinvite_links\x18\x01 \x03(\x0b\x32\x33.CChatRoom_GetInviteLinksForGroup_Response.LinkInfo\x1a_\n\x08LinkInfo\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\x04\"5\n\x1c\x43\x43hatRoom_GetBanList_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\xb5\x01\n\x1d\x43\x43hatRoom_GetBanList_Response\x12\x34\n\x04\x62\x61ns\x18\x01 \x03(\x0b\x32&.CChatRoom_GetBanList_Response.BanInfo\x1a^\n\x07\x42\x61nInfo\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_actor\x18\x02 \x01(\r\x12\x13\n\x0btime_banned\x18\x03 \x01(\r\x12\x12\n\nban_reason\x18\x04 \x01(\t\"8\n\x1f\x43\x43hatRoom_GetInviteList_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"X\n\x14\x43\x43hatRoomGroupInvite\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_actor\x18\x02 \x01(\r\x12\x14\n\x0ctime_invited\x18\x03 \x01(\r\"J\n CChatRoom_GetInviteList_Response\x12&\n\x07invites\x18\x01 \x03(\x0b\x32\x15.CChatRoomGroupInvite\"P\n\"CChatRoom_DeleteInviteLink_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0binvite_code\x18\x02 \x01(\t\"%\n#CChatRoom_DeleteInviteLink_Response\"\xf4\x01\n0CChatRoom_SetSessionActiveChatRoomGroups_Request\x12\x16\n\x0e\x63hat_group_ids\x18\x01 \x03(\x04\x12\"\n\x1a\x63hat_groups_data_requested\x18\x02 \x03(\x04\x12\x83\x01\n\x1cvirtualize_members_threshold\x18\x03 \x01(\x05\x42]\x82\xb5\x18YIf a chat room has more members than this threshold, we will opt in to a virtualized list\"\x89\x01\n1CChatRoom_SetSessionActiveChatRoomGroups_Response\x12)\n\x0b\x63hat_states\x18\x01 \x03(\x0b\x32\x14.CChatRoomGroupState\x12)\n!virtualize_members_chat_group_ids\x18\x02 \x03(\x04\"\xaa\x06\n-CChatRoom_SetUserChatGroupPreferences_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x63\n\x16\x63hat_group_preferences\x18\x02 \x01(\x0b\x32\x43.CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences\x12\x61\n\x15\x63hat_room_preferences\x18\x03 \x03(\x0b\x32\x42.CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences\x1a\x83\x02\n\x14\x43hatGroupPreferences\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x01 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x02 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1e\n\x16unread_indicator_muted\x18\x03 \x01(\x08\x1a\x93\x02\n\x13\x43hatRoomPreferences\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x02 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x03 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1e\n\x16unread_indicator_muted\x18\x04 \x01(\x08\"0\n.CChatRoom_SetUserChatGroupPreferences_Response\"\xc5\x01\n$CChatRoom_DeleteChatMessages_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12?\n\x08messages\x18\x03 \x03(\x0b\x32-.CChatRoom_DeleteChatMessages_Request.Message\x1a\x34\n\x07Message\x12\x18\n\x10server_timestamp\x18\x01 \x01(\r\x12\x0f\n\x07ordinal\x18\x02 \x01(\r\"\'\n%CChatRoom_DeleteChatMessages_Response\"\xe9\x03\n+CChatRoom_UpdateMemberListView_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12g\n\x07view_id\x18\x02 \x01(\x04\x42V\x82\xb5\x18RClient-generated ID.  Should send the same value on all requests for the same view\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x12\x8f\x01\n\x13\x63lient_changenumber\x18\x05 \x01(\x05\x42r\x82\xb5\x18nAny updates from this call on will have this changenumber present.  Can be used to guarantee in-order updates.\x12>\n\x0b\x64\x65lete_view\x18\x06 \x01(\x08\x42)\x82\xb5\x18%Indicates this view has been deleted.\x12$\n\x1cpersona_subscribe_accountids\x18\x07 \x03(\x05\x12&\n\x1epersona_unsubscribe_accountids\x18\x08 \x03(\x05\"\x97\x02\n\x1f\x43\x43hatRoom_SearchMembers_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\xb2\x01\n\tsearch_id\x18\x02 \x01(\x04\x42\x9e\x01\x82\xb5\x18\x99\x01\x43lient-supplied id.  For find-as-you-type searches, as search narrows the server will not return persona states previously returned for a given searchid.\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x13\n\x0bmax_results\x18\x04 \x01(\x05\"\xd4\x01\n CChatRoom_SearchMembers_Response\x12G\n\x10matching_members\x18\x01 \x03(\x0b\x32-.CChatRoom_SearchMembers_Response.MemberMatch\x12\x14\n\x0cstatus_flags\x18\x02 \x01(\r\x1aQ\n\x0bMemberMatch\x12\x11\n\taccountid\x18\x01 \x01(\x05\x12/\n\x07persona\x18\x02 \x01(\x0b\x32\x1e.CMsgClientPersonaState.Friend\"\xfc\x01\n\'CChatRoom_UpdateMessageReaction_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\rreaction_type\x18\x05 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\x0e\n\x06is_add\x18\x07 \x01(\x08\"@\n(CChatRoom_UpdateMessageReaction_Response\x12\x14\n\x0cnum_reactors\x18\x01 \x01(\r\"\x80\x02\n,CChatRoom_GetMessageReactionReactors_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\rreaction_type\x18\x05 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\r\"A\n-CChatRoom_GetMessageReactionReactors_Response\x12\x10\n\x08reactors\x18\x01 \x03(\r\"\x98\x01\n*CClanChatRooms_GetClanChatRoomInfo_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12Y\n\nautocreate\x18\x02 \x01(\x08:\x04trueB?\x82\xb5\x18;Create a default chat room if none has been created before.\"v\n+CClanChatRooms_GetClanChatRoomInfo_Response\x12G\n\x12\x63hat_group_summary\x18\x01 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\"[\n-CClanChatRooms_SetClanChatRoomPrivate_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x63hat_room_private\x18\x02 \x01(\x08\"K\n.CClanChatRooms_SetClanChatRoomPrivate_Response\x12\x19\n\x11\x63hat_room_private\x18\x01 \x01(\x08\"V\n\rCChatMentions\x12\x13\n\x0bmention_all\x18\x01 \x01(\x08\x12\x14\n\x0cmention_here\x18\x02 \x01(\x08\x12\x1a\n\x12mention_accountids\x18\x03 \x03(\r\"\xd5\x02\n*CChatRoom_IncomingChatMessage_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x16\n\x0esteamid_sender\x18\x03 \x01(\x06\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\r\x12 \n\x08mentions\x18\x06 \x01(\x0b\x32\x0e.CChatMentions\x12\x0f\n\x07ordinal\x18\x07 \x01(\r\x12&\n\x0eserver_message\x18\x08 \x01(\x0b\x32\x0e.ServerMessage\x12\x19\n\x11message_no_bbcode\x18\t \x01(\t\x12M\n\tchat_name\x18\n \x01(\tB:\x82\xb5\x18\x36\x41 name to use for the chat, intended for notifications\"\xea\x01\n*CChatRoom_ChatMessageModified_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12I\n\x08messages\x18\x03 \x03(\x0b\x32\x37.CChatRoom_ChatMessageModified_Notification.ChatMessage\x1aI\n\x0b\x43hatMessage\x12\x18\n\x10server_timestamp\x18\x01 \x01(\r\x12\x0f\n\x07ordinal\x18\x02 \x01(\r\x12\x0f\n\x07\x64\x65leted\x18\x03 \x01(\x08\"\xb6\x01\n(CChatRoom_MemberStateChange_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12 \n\x06member\x18\x02 \x01(\x0b\x32\x10.CChatRoomMember\x12Q\n\x06\x63hange\x18\x03 \x01(\x0e\x32\x1b.EChatRoomMemberStateChange:$k_EChatRoomMemberStateChange_Invalid\"^\n*CChatRoom_ChatRoomHeaderState_Notification\x12\x30\n\x0cheader_state\x18\x01 \x01(\x0b\x32\x1a.CChatRoomGroupHeaderState\"\x86\x01\n/CChatRoom_ChatRoomGroupRoomsChange_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x02 \x01(\x04\x12#\n\nchat_rooms\x18\x03 \x03(\x0b\x32\x0f.CChatRoomState\"d\n:CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\"\xa9\x02\n;ChatRoomClient_NotifyChatGroupUserStateChanged_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x37\n\x15user_chat_group_state\x18\x02 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x42\n\rgroup_summary\x18\x03 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12V\n\x0buser_action\x18\x04 \x01(\x0e\x32\x1b.EChatRoomMemberStateChange:$k_EChatRoomMemberStateChange_Invalid\"N\n4ChatRoomClient_NotifyChatRoomDisconnect_Notification\x12\x16\n\x0e\x63hat_group_ids\x18\x01 \x03(\x04\"\x94\x02\n\x17\x43\x43hatRoomMemberListView\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x12\x13\n\x0btotal_count\x18\x05 \x01(\x05\x12\x61\n\x13\x63lient_changenumber\x18\x06 \x01(\x05\x42\x44\x82\xb5\x18@Value sent by the client on the last UpdateMemberListView call. \x12\x65\n\x13server_changenumber\x18\x07 \x01(\x05\x42H\x82\xb5\x18\x44Value incremented by the server on each MemberListViewUpdated call. \"O\n\x1c\x43\x43hatRoomMemberSummaryCounts\x12\x0e\n\x06ingame\x18\x01 \x01(\x05\x12\x0e\n\x06online\x18\x02 \x01(\x05\x12\x0f\n\x07offline\x18\x03 \x01(\x05\"\x8f\x04\n2CChatRoomClient_MemberListViewUpdated_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12M\n\x07view_id\x18\x02 \x01(\x04\x42<\x82\xb5\x18\x38Thew view_id supplied when the client created the view. \x12&\n\x04view\x18\x03 \x01(\x0b\x32\x18.CChatRoomMemberListView\x12X\n\x07members\x18\x04 \x03(\x0b\x32G.CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry\x12\x14\n\x0cstatus_flags\x18\x05 \x01(\r\x12\x35\n\x0emember_summary\x18\x06 \x01(\x0b\x32\x1d.CChatRoomMemberSummaryCounts\x12;\n\x13subscribed_personas\x18\x07 \x03(\x0b\x32\x1e.CMsgClientPersonaState.Friend\x1ag\n\x13MemberListViewEntry\x12\x0c\n\x04rank\x18\x01 \x01(\x05\x12\x11\n\taccountid\x18\x02 \x01(\r\x12/\n\x07persona\x18\x03 \x01(\x0b\x32\x1e.CMsgClientPersonaState.Friend\"\x8c\x02\n&CChatRoom_MessageReaction_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\x0f\n\x07reactor\x18\x05 \x01(\x06\x12\\\n\rreaction_type\x18\x06 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x07 \x01(\t\x12\x0e\n\x06is_add\x18\x08 \x01(\x08\"\xdf\x15\n2CChatUsability_ClientUsabilityMetrics_Notification\x12\x16\n\x0emetrics_run_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lient_build\x18\x02 \x01(\r\x12\x17\n\x0fmetrics_version\x18\x03 \x01(\r\x12\x0e\n\x06in_web\x18\x04 \x01(\x08\x12N\n\x08settings\x18\n \x01(\x0b\x32<.CChatUsability_ClientUsabilityMetrics_Notification.Settings\x12Y\n\x0evoice_settings\x18\x0b \x01(\x0b\x32\x41.CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings\x12M\n\x08ui_state\x18\x0c \x01(\x0b\x32;.CChatUsability_ClientUsabilityMetrics_Notification.UIState\x12L\n\x07metrics\x18\r \x01(\x0b\x32;.CChatUsability_ClientUsabilityMetrics_Notification.Metrics\x1a\xd9\x06\n\x08Settings\x12!\n\x19notifications_show_ingame\x18\x01 \x01(\x08\x12!\n\x19notifications_show_online\x18\x02 \x01(\x08\x12\"\n\x1anotifications_show_message\x18\x03 \x01(\x08\x12.\n&notifications_events_and_announcements\x18\x04 \x01(\x08\x12\x1a\n\x12sounds_play_ingame\x18\x05 \x01(\x08\x12\x1a\n\x12sounds_play_online\x18\x06 \x01(\x08\x12\x1b\n\x13sounds_play_message\x18\x07 \x01(\x08\x12\'\n\x1fsounds_events_and_announcements\x18\x08 \x01(\x08\x12\x1e\n\x16\x61lways_new_chat_window\x18\t \x01(\x08\x12\'\n\x1f\x66orce_alphabetic_friend_sorting\x18\n \x01(\x08\x12\x17\n\x0f\x63hat_flash_mode\x18\x0b \x01(\x05\x12\x1b\n\x13remember_open_chats\x18\x0c \x01(\x08\x12\x1c\n\x14\x63ompact_quick_access\x18\r \x01(\x08\x12\x1c\n\x14\x63ompact_friends_list\x18\x0e \x01(\x08\x12\x31\n)notifications_show_chat_room_notification\x18\x0f \x01(\x08\x12*\n\"sounds_play_chat_room_notification\x18\x10 \x01(\x08\x12*\n\"hide_offline_friends_in_tag_groups\x18\x11 \x01(\x08\x12 \n\x18hide_categorized_friends\x18\x12 \x01(\x08\x12*\n\"categorize_in_game_friends_by_game\x18\x13 \x01(\x08\x12\x16\n\x0e\x63hat_font_size\x18\x14 \x01(\x05\x12\x17\n\x0fuse24hour_clock\x18\x15 \x01(\x08\x12\x1b\n\x13\x64o_not_disturb_mode\x18\x16 \x01(\x08\x12\x1e\n\x16\x64isable_embed_inlining\x18\x17 \x01(\x08\x12\x19\n\x11sign_into_friends\x18\x18 \x01(\x08\x12\x18\n\x10\x61nimated_avatars\x18\x19 \x01(\x08\x1a\xea\x02\n\rVoiceSettings\x12\x18\n\x10voice_input_gain\x18\x01 \x01(\x02\x12\x19\n\x11voice_output_gain\x18\x02 \x01(\x02\x12\x18\n\x10noise_gate_level\x18\x03 \x01(\x05\x12#\n\x1bvoice_use_echo_cancellation\x18\x04 \x01(\x08\x12$\n\x1cvoice_use_noise_cancellation\x18\x05 \x01(\x08\x12#\n\x1bvoice_use_auto_gain_control\x18\x06 \x01(\x08\x12 \n\x18selected_non_default_mic\x18\x07 \x01(\x08\x12#\n\x1bselected_non_default_output\x18\x08 \x01(\x08\x12\x1c\n\x14push_to_talk_enabled\x18\t \x01(\x08\x12\x1c\n\x14push_to_mute_enabled\x18\n \x01(\x08\x12\x17\n\x0fplay_ptt_sounds\x18\x0b \x01(\x08\x1a\xfd\x05\n\x07UIState\x12\x1b\n\x13\x66riends_list_height\x18\x01 \x01(\x05\x12\x1a\n\x12\x66riends_list_width\x18\x02 \x01(\x05\x12\x1b\n\x13\x66riends_list_docked\x18\x03 \x01(\x08\x12\x1e\n\x16\x66riends_list_collapsed\x18\x04 \x01(\x08\x12\'\n\x1f\x66riends_list_group_chats_height\x18\x05 \x01(\x05\x12\x1c\n\x14\x66riends_list_visible\x18\x06 \x01(\x08\x12\x1a\n\x12\x63hat_popups_opened\x18\x07 \x01(\x05\x12\x1e\n\x16group_chat_tabs_opened\x18\x08 \x01(\x05\x12\x1f\n\x17\x66riend_chat_tabs_opened\x18\t \x01(\x05\x12\x19\n\x11\x63hat_window_width\x18\n \x01(\x05\x12\x1a\n\x12\x63hat_window_height\x18\x0b \x01(\x05\x12l\n\x11\x63\x61tegory_collapse\x18\x0c \x01(\x0b\x32Q.CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState\x12%\n\x1dgroup_chat_left_col_collapsed\x18\r \x01(\x05\x12&\n\x1egroup_chat_right_col_collapsed\x18\x0e \x01(\x05\x12 \n\x18in_one_on_one_voice_chat\x18\x0f \x01(\x08\x12\x1b\n\x13in_group_voice_chat\x18\x10 \x01(\x08\x1a\xa4\x01\n\x15\x43\x61tegoryCollapseState\x12\x19\n\x11in_game_collapsed\x18\x01 \x01(\x08\x12\x18\n\x10online_collapsed\x18\x02 \x01(\x08\x12\x19\n\x11offline_collapsed\x18\x03 \x01(\x08\x12\x1d\n\x15game_groups_collapsed\x18\x04 \x01(\x05\x12\x1c\n\x14\x63\x61tegories_collapsed\x18\x05 \x01(\x05\x1a\xc0\x02\n\x07Metrics\x12\x15\n\rfriends_count\x18\x01 \x01(\x05\x12\x1e\n\x16\x66riends_category_count\x18\x02 \x01(\x05\x12!\n\x19\x66riends_categorized_count\x18\x03 \x01(\x05\x12\x1c\n\x14\x66riends_online_count\x18\x04 \x01(\x05\x12\x1d\n\x15\x66riends_in_game_count\x18\x05 \x01(\x05\x12\'\n\x1f\x66riends_in_game_singleton_count\x18\x06 \x01(\x05\x12\x18\n\x10game_group_count\x18\x07 \x01(\x05\x12\x1e\n\x16\x66riends_favorite_count\x18\x08 \x01(\x05\x12\x18\n\x10group_chat_count\x18\t \x01(\x05\x12!\n\x19group_chat_favorite_count\x18\n \x01(\x05\"S\n9CChatUsability_RequestClientUsabilityMetrics_Notification\x12\x16\n\x0emetrics_run_id\x18\x01 \x01(\r*\x9c\x01\n\x12\x45\x43hatRoomJoinState\x12 \n\x1ck_EChatRoomJoinState_Default\x10\x00\x12\x1d\n\x19k_EChatRoomJoinState_None\x10\x01\x12\x1f\n\x1bk_EChatRoomJoinState_Joined\x10\x02\x12$\n k_EChatRoomJoinState_TestInvalid\x10\x63*\xa4\x02\n\x12\x45\x43hatRoomGroupRank\x12 \n\x1ck_EChatRoomGroupRank_Default\x10\x00\x12\x1f\n\x1bk_EChatRoomGroupRank_Viewer\x10\n\x12\x1e\n\x1ak_EChatRoomGroupRank_Guest\x10\x0f\x12\x1f\n\x1bk_EChatRoomGroupRank_Member\x10\x14\x12\"\n\x1ek_EChatRoomGroupRank_Moderator\x10\x1e\x12 \n\x1ck_EChatRoomGroupRank_Officer\x10(\x12\x1e\n\x1ak_EChatRoomGroupRank_Owner\x10\x32\x12$\n k_EChatRoomGroupRank_TestInvalid\x10\x63*\xf4\x01\n\x1a\x45\x43hatRoomNotificationLevel\x12(\n$k_EChatroomNotificationLevel_Invalid\x10\x00\x12%\n!k_EChatroomNotificationLevel_None\x10\x01\x12*\n&k_EChatroomNotificationLevel_MentionMe\x10\x02\x12+\n\'k_EChatroomNotificationLevel_MentionAll\x10\x03\x12,\n(k_EChatroomNotificationLevel_AllMessages\x10\x04*\x97\x03\n\x16\x45\x43hatRoomServerMessage\x12 \n\x1ck_EChatRoomServerMsg_Invalid\x10\x00\x12\'\n#k_EChatRoomServerMsg_RenameChatRoom\x10\x01\x12\x1f\n\x1bk_EChatRoomServerMsg_Joined\x10\x02\x12\x1f\n\x1bk_EChatRoomServerMsg_Parted\x10\x03\x12\x1f\n\x1bk_EChatRoomServerMsg_Kicked\x10\x04\x12 \n\x1ck_EChatRoomServerMsg_Invited\x10\x05\x12(\n$k_EChatRoomServerMsg_InviteDismissed\x10\x08\x12/\n+k_EChatRoomServerMsg_ChatRoomTaglineChanged\x10\t\x12.\n*k_EChatRoomServerMsg_ChatRoomAvatarChanged\x10\n\x12\"\n\x1ek_EChatRoomServerMsg_AppCustom\x10\x0b*\xa3\x01\n\x1c\x45\x43hatRoomMessageReactionType\x12*\n&k_EChatRoomMessageReactionType_Invalid\x10\x00\x12+\n\'k_EChatRoomMessageReactionType_Emoticon\x10\x01\x12*\n&k_EChatRoomMessageReactionType_Sticker\x10\x02*\xcb\x03\n\x1a\x45\x43hatRoomMemberStateChange\x12(\n$k_EChatRoomMemberStateChange_Invalid\x10\x00\x12\'\n#k_EChatRoomMemberStateChange_Joined\x10\x01\x12\'\n#k_EChatRoomMemberStateChange_Parted\x10\x02\x12\'\n#k_EChatRoomMemberStateChange_Kicked\x10\x03\x12(\n$k_EChatRoomMemberStateChange_Invited\x10\x04\x12,\n(k_EChatRoomMemberStateChange_RankChanged\x10\x07\x12\x30\n,k_EChatRoomMemberStateChange_InviteDismissed\x10\x08\x12&\n\"k_EChatRoomMemberStateChange_Muted\x10\t\x12\'\n#k_EChatRoomMemberStateChange_Banned\x10\n\x12-\n)k_EChatRoomMemberStateChange_RolesChanged\x10\x0c\x32\x8b\x02\n\x04\x43hat\x12\xe7\x01\n\x1aRequestFriendPersonaStates\x12).CChat_RequestFriendPersonaStates_Request\x1a*.CChat_RequestFriendPersonaStates_Response\"r\x82\xb5\x18nRequest to be notified of online friend persona state information.  Responses sent via CMsgClientPersonaState.\x1a\x19\x82\xb5\x18\x15\x43hat-related services2\xb9>\n\x08\x43hatRoom\x12\xa3\x01\n\x13\x43reateChatRoomGroup\x12&.CChatRoom_CreateChatRoomGroup_Request\x1a\'.CChatRoom_CreateChatRoomGroup_Response\";\x82\xb5\x18\x37\x43reate\'s a chat group that can contain other chat rooms\x12z\n\x11SaveChatRoomGroup\x12$.CChatRoom_SaveChatRoomGroup_Request\x1a%.CChatRoom_SaveChatRoomGroup_Response\"\x18\x82\xb5\x18\x14Saves\'s a chat group\x12\x84\x01\n\x13RenameChatRoomGroup\x12&.CChatRoom_RenameChatRoomGroup_Request\x1a\'.CChatRoom_RenameChatRoomGroup_Response\"\x1c\x82\xb5\x18\x18Rename a chat room group\x12\x99\x01\n\x17SetChatRoomGroupTagline\x12*.CChatRoom_SetChatRoomGroupTagline_Request\x1a+.CChatRoom_SetChatRoomGroupTagline_Response\"%\x82\xb5\x18!Set tagline for a chat room group\x12\x99\x01\n\x16SetChatRoomGroupAvatar\x12).CChatRoom_SetChatRoomGroupAvatar_Request\x1a*.CChatRoom_SetChatRoomGroupAvatar_Response\"(\x82\xb5\x18$Set avatar SHA for a chat room group\x12\xcb\x01\n!SetChatRoomGroupWatchingBroadcast\x12\x34.CChatRoom_SetChatRoomGroupWatchingBroadcast_Request\x1a\x35.CChatRoom_SetChatRoomGroupWatchingBroadcast_Response\"9\x82\xb5\x18\x35Sets a broadcast that the chat room group is watching\x12\xe3\x01\n\x1cJoinMiniGameForChatRoomGroup\x12/.CChatRoom_JoinMiniGameForChatRoomGroup_Request\x1a\x30.CChatRoom_JoinMiniGameForChatRoomGroup_Response\"`\x82\xb5\x18\\Joins the minigame for the chat room group or starts a new one (Winter 2019 sale party game)\x12\xac\x01\n\x1b\x45ndMiniGameForChatRoomGroup\x12..CChatRoom_EndMiniGameForChatRoomGroup_Request\x1a/.CChatRoom_EndMiniGameForChatRoomGroup_Response\",\x82\xb5\x18(Ends the minigame in the chat room group\x12\x64\n\x0fMuteUserInGroup\x12\x1b.CChatRoom_MuteUser_Request\x1a\x1c.CChatRoom_MuteUser_Response\"\x16\x82\xb5\x18\x12Mute user in group\x12h\n\x11KickUserFromGroup\x12\x1b.CChatRoom_KickUser_Request\x1a\x1c.CChatRoom_KickUser_Response\"\x18\x82\xb5\x18\x14Kick user from group\x12y\n\x0fSetUserBanState\x12\".CChatRoom_SetUserBanState_Request\x1a#.CChatRoom_SetUserBanState_Response\"\x1d\x82\xb5\x18\x19\x42\x61n/unban user from group\x12\x82\x01\n\x13RevokeInviteToGroup\x12\x1f.CChatRoom_RevokeInvite_Request\x1a .CChatRoom_RevokeInvite_Response\"(\x82\xb5\x18$Revoke a direct invitation of a user\x12\x65\n\nCreateRole\x12\x1d.CChatRoom_CreateRole_Request\x1a\x1e.CChatRoom_CreateRole_Response\"\x18\x82\xb5\x18\x14\x43reate role for goup\x12\x61\n\x08GetRoles\x12\x1b.CChatRoom_GetRoles_Request\x1a\x1c.CChatRoom_GetRoles_Response\"\x1a\x82\xb5\x18\x16Get all roles in group\x12\x65\n\nRenameRole\x12\x1d.CChatRoom_RenameRole_Request\x1a\x1e.CChatRoom_RenameRole_Response\"\x18\x82\xb5\x18\x14Rename role for goup\x12l\n\x0bReorderRole\x12\x1e.CChatRoom_ReorderRole_Request\x1a\x1f.CChatRoom_ReorderRole_Response\"\x1c\x82\xb5\x18\x18Reorder role with a goup\x12g\n\nDeleteRole\x12\x1d.CChatRoom_DeleteRole_Request\x1a\x1e.CChatRoom_DeleteRole_Response\"\x1a\x82\xb5\x18\x16\x44\x65lete role from group\x12\x87\x01\n\x0eGetRoleActions\x12!.CChatRoom_GetRoleActions_Request\x1a\".CChatRoom_GetRoleActions_Response\".\x82\xb5\x18*Get all defined roles and actions in group\x12\x86\x01\n\x12ReplaceRoleActions\x12%.CChatRoom_ReplaceRoleActions_Request\x1a&.CChatRoom_ReplaceRoleActions_Response\"!\x82\xb5\x18\x1dReplace role actions in group\x12s\n\rAddRoleToUser\x12 .CChatRoom_AddRoleToUser_Request\x1a!.CChatRoom_AddRoleToUser_Response\"\x1d\x82\xb5\x18\x19\x41\x64\x64 role to user in group\x12\x87\x01\n\x0fGetRolesForUser\x12\".CChatRoom_GetRolesForUser_Request\x1a#.CChatRoom_GetRolesForUser_Response\"+\x82\xb5\x18\'Get all roles assigned to user in group\x12\x87\x01\n\x12\x44\x65leteRoleFromUser\x12%.CChatRoom_DeleteRoleFromUser_Request\x1a&.CChatRoom_DeleteRoleFromUser_Response\"\"\x82\xb5\x18\x1e\x44\x65lete role from user in group\x12\x81\x01\n\x11JoinChatRoomGroup\x12$.CChatRoom_JoinChatRoomGroup_Request\x1a%.CChatRoom_JoinChatRoomGroup_Response\"\x1f\x82\xb5\x18\x1bJoin a multi-user chat room\x12\xad\x01\n\x1bInviteFriendToChatRoomGroup\x12..CChatRoom_InviteFriendToChatRoomGroup_Request\x1a/.CChatRoom_InviteFriendToChatRoomGroup_Response\"-\x82\xb5\x18)Invite a friend to a multi-user chat room\x12\x97\x01\n\x12LeaveChatRoomGroup\x12%.CChatRoom_LeaveChatRoomGroup_Request\x1a&.CChatRoom_LeaveChatRoomGroup_Response\"2\x82\xb5\x18.Leaves a chat room group and all related chats\x12\x89\x01\n\x0e\x43reateChatRoom\x12!.CChatRoom_CreateChatRoom_Request\x1a\".CChatRoom_CreateChatRoom_Response\"0\x82\xb5\x18,Creates a chat room inside a chat room group\x12\x89\x01\n\x0e\x44\x65leteChatRoom\x12!.CChatRoom_DeleteChatRoom_Request\x1a\".CChatRoom_DeleteChatRoom_Response\"0\x82\xb5\x18,Deletes a chat room inside a chat room group\x12\x89\x01\n\x0eRenameChatRoom\x12!.CChatRoom_RenameChatRoom_Request\x1a\".CChatRoom_RenameChatRoom_Response\"0\x82\xb5\x18,Renames a chat room inside a chat room group\x12\x8d\x01\n\x0fReorderChatRoom\x12\".CChatRoom_ReorderChatRoom_Request\x1a#.CChatRoom_ReorderChatRoom_Response\"1\x82\xb5\x18-Reorders a chat room inside a chat room group\x12\x8d\x01\n\x0fSendChatMessage\x12\".CChatRoom_SendChatMessage_Request\x1a#.CChatRoom_SendChatMessage_Response\"1\x82\xb5\x18-Send a chat message to a multi-user chat room\x12\xa7\x01\n\rJoinVoiceChat\x12 .CChatRoom_JoinVoiceChat_Request\x1a!.CChatRoom_JoinVoiceChat_Response\"Q\x82\xb5\x18MJoin the voice chat in a multi-room chat (should already be in the chat room)\x12\x86\x01\n\x0eLeaveVoiceChat\x12!.CChatRoom_LeaveVoiceChat_Request\x1a\".CChatRoom_LeaveVoiceChat_Response\"-\x82\xb5\x18)Leave the voice chat in a multi-room chat\x12\xc3\x01\n\x11GetMessageHistory\x12$.CChatRoom_GetMessageHistory_Request\x1a%.CChatRoom_GetMessageHistory_Response\"a\x82\xb5\x18]Get the history of messages in a chat room.  You must currently be a member of the chat room.\x12\x88\x01\n\x13GetMyChatRoomGroups\x12&.CChatRoom_GetMyChatRoomGroups_Request\x1a\'.CChatRoom_GetMyChatRoomGroups_Response\" \x82\xb5\x18\x1cGet a list of our chat rooms\x12\x9a\x01\n\x15GetChatRoomGroupState\x12(.CChatRoom_GetChatRoomGroupState_Request\x1a).CChatRoom_GetChatRoomGroupState_Response\",\x82\xb5\x18(Get information about a single chat room\x12\xa5\x01\n\x17GetChatRoomGroupSummary\x12*.CChatRoom_GetChatRoomGroupSummary_Request\x1a+.CChatRoom_GetChatRoomGroupSummary_Response\"1\x82\xb5\x18-Get basic information about a chat room group\x12\xd3\x01\n\x1eSetAppChatRoomGroupForceActive\x12\x31.CChatRoom_SetAppChatRoomGroupForceActive_Request\x1a\x32.CChatRoom_SetAppChatRoomGroupForceActive_Response\"J\x82\xb5\x18\x46\x46orce a group chat to be considered active on the server for this user\x12\xd3\x01\n\"SetAppChatRoomGroupStopForceActive\x12:.CChatRoom_SetAppChatRoomGroupStopForceActive_Notification\x1a\x0b.NoResponse\"d\x82\xb5\x18`If a group chat is forced active (see SetAppChatRoomGroupForceActive), decrement the force count\x12\x8f\x01\n\x0e\x41\x63kChatMessage\x12&.CChatRoom_AckChatMessage_Notification\x1a\x0b.NoResponse\"H\x82\xb5\x18\x44\x41\x63knowledge that we have seen the most recent chat message in a chat\x12\x81\x01\n\x10\x43reateInviteLink\x12#.CChatRoom_CreateInviteLink_Request\x1a$.CChatRoom_CreateInviteLink_Response\"\"\x82\xb5\x18\x1e\x43reates a chatroom invite link\x12\x90\x01\n\x11GetInviteLinkInfo\x12$.CChatRoom_GetInviteLinkInfo_Request\x1a%.CChatRoom_GetInviteLinkInfo_Response\".\x82\xb5\x18*Returns chat room info about provided link\x12\xaa\x01\n\rGetInviteInfo\x12 .CChatRoom_GetInviteInfo_Request\x1a!.CChatRoom_GetInviteInfo_Response\"T\x82\xb5\x18PReturns chat room info about any invite involving the sender and passed group id\x12\xa5\x01\n\x16GetInviteLinksForGroup\x12).CChatRoom_GetInviteLinksForGroup_Request\x1a*.CChatRoom_GetInviteLinksForGroup_Response\"4\x82\xb5\x18\x30Returns all invite links for the specified group\x12\x8b\x01\n\nGetBanList\x12\x1d.CChatRoom_GetBanList_Request\x1a\x1e.CChatRoom_GetBanList_Response\">\x82\xb5\x18:Gets a list of users who have been banned from a chat room\x12\x93\x01\n\rGetInviteList\x12 .CChatRoom_GetInviteList_Request\x1a!.CChatRoom_GetInviteList_Response\"=\x82\xb5\x18\x39Gets a list of users who have been invited to a chat room\x12\x80\x01\n\x10\x44\x65leteInviteLink\x12#.CChatRoom_DeleteInviteLink_Request\x1a$.CChatRoom_DeleteInviteLink_Response\"!\x82\xb5\x18\x1d\x44\x65letes specified invite link\x12\xc4\x01\n\x1eSetSessionActiveChatRoomGroups\x12\x31.CChatRoom_SetSessionActiveChatRoomGroups_Request\x1a\x32.CChatRoom_SetSessionActiveChatRoomGroups_Response\";\x82\xb5\x18\x37Set which chat rooms we are using in the active session\x12\xb9\x01\n\x1bSetUserChatGroupPreferences\x12..CChatRoom_SetUserChatGroupPreferences_Request\x1a/.CChatRoom_SetUserChatGroupPreferences_Response\"9\x82\xb5\x18\x35Set preferences around chat notifications for a group\x12\x88\x01\n\x12\x44\x65leteChatMessages\x12%.CChatRoom_DeleteChatMessages_Request\x1a&.CChatRoom_DeleteChatMessages_Response\"#\x82\xb5\x18\x1f\x44\x65letes specified chat messages\x12\x9a\x01\n\x14UpdateMemberListView\x12,.CChatRoom_UpdateMemberListView_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43\x41 client is indicating it has an active view into the members list.\x12{\n\rSearchMembers\x12 .CChatRoom_SearchMembers_Request\x1a!.CChatRoom_SearchMembers_Response\"%\x82\xb5\x18!Search chat room members by name.\x12\xa5\x01\n\x15UpdateMessageReaction\x12(.CChatRoom_UpdateMessageReaction_Request\x1a).CChatRoom_UpdateMessageReaction_Response\"7\x82\xb5\x18\x33\x41\x64\x64s/removes a reaction to/from a chat room message\x12\xb4\x01\n\x1aGetMessageReactionReactors\x12-.CChatRoom_GetMessageReactionReactors_Request\x1a..CChatRoom_GetMessageReactionReactors_Response\"7\x82\xb5\x18\x33\x46\x65tches a list of reactors for a specified reaction\x1a\x42\x82\xb5\x18>Service for joining, managing, and using multi-user chat rooms2\xae\x03\n\rClanChatRooms\x12\xb8\x01\n\x13GetClanChatRoomInfo\x12+.CClanChatRooms_GetClanChatRoomInfo_Request\x1a,.CClanChatRooms_GetClanChatRoomInfo_Response\"F\x82\xb5\x18\x42Get a list of chat rooms for a clan, optionally creating a new one\x12\xb2\x01\n\x16SetClanChatRoomPrivate\x12..CClanChatRooms_SetClanChatRoomPrivate_Request\x1a/.CClanChatRooms_SetClanChatRoomPrivate_Response\"7\x82\xb5\x18\x33Set a clan chat room to be members only (or public)\x1a-\x82\xb5\x18)Methods for getting clan chat information2\xef\x0e\n\x0e\x43hatRoomClient\x12{\n\x19NotifyIncomingChatMessage\x12+.CChatRoom_IncomingChatMessage_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 New chat message for a chat room\x12\x94\x01\n\x19NotifyChatMessageModified\x12+.CChatRoom_ChatMessageModified_Notification\x1a\x0b.NoResponse\"=\x82\xb5\x18\x39\x41n existing chat message has been modified on the backend\x12\x95\x01\n\x17NotifyMemberStateChange\x12).CChatRoom_MemberStateChange_Notification\x1a\x0b.NoResponse\"B\x82\xb5\x18>A chat room member\'s state has changed (join/part/permissions)\x12\x88\x01\n\x1fNotifyChatRoomHeaderStateChange\x12+.CChatRoom_ChatRoomHeaderState_Notification\x1a\x0b.NoResponse\"+\x82\xb5\x18\'Chat Room header / metadata has changed\x12\xa6\x01\n\x1eNotifyChatRoomGroupRoomsChange\x12\x30.CChatRoom_ChatRoomGroupRoomsChange_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Something about a chatroom group changed (created, deleted, etc.)\x12\xd5\x01\n#NotifyShouldRejoinChatRoomVoiceChat\x12;.CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification\x1a\x0b.NoResponse\"d\x82\xb5\x18`Voice chat was recreated or dropped on the backend and client needs to rejoin to remain in chat.\x12\xb3\x01\n\x1fNotifyChatGroupUserStateChanged\x12<.ChatRoomClient_NotifyChatGroupUserStateChanged_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41User chat group state (preferences, ack state, etc) have changed.\x12\x8f\x01\n\x18NotifyAckChatMessageEcho\x12&.CChatRoom_AckChatMessage_Notification\x1a\x0b.NoResponse\">\x82\xb5\x18:A session acked an unread message, echo to other sessions.\x12\xed\x01\n\x18NotifyChatRoomDisconnect\x12\x35.ChatRoomClient_NotifyChatRoomDisconnect_Notification\x1a\x0b.NoResponse\"\x8c\x01\x82\xb5\x18\x87\x01The ChatRoom server hosting the chat rooms has reconnected to the user\'s Chat server (may have restarted), client should refresh state.\x12\xd5\x01\n\x1bNotifyMemberListViewUpdated\x12\x33.CChatRoomClient_MemberListViewUpdated_Notification\x1a\x0b.NoResponse\"t\x82\xb5\x18pThe list of members for a chat room with virtualized member list has changed on the server (or client requested)\x12g\n\x15NotifyMessageReaction\x12\'.CChatRoom_MessageReaction_Notification\x1a\x0b.NoResponse\"\x18\x82\xb5\x18\x14New message reaction\x1a,\x82\xb5\x18$Client notifications for chat events\xc0\xb5\x18\x02\x32\xc2\x01\n\rChatUsability\x12\x86\x01\n\x1cNotifyClientUsabilityMetrics\x12\x33.CChatUsability_ClientUsabilityMetrics_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 Incoming metrics from the client\x1a(\x82\xb5\x18$Client notifications for chat events2\xe2\x01\n\x13\x43hatUsabilityClient\x12\x99\x01\n#NotifyRequestClientUsabilityMetrics\x12:.CChatUsability_RequestClientUsabilityMetrics_Notification\x1a\x0b.NoResponse\")\x82\xb5\x18%Request client send usability metrics\x1a/\x82\xb5\x18\'Client notifications for chat usability\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,steammessages__clientserver__friends__pb2.DESCRIPTOR,])

_ECHATROOMJOINSTATE = _descriptor.EnumDescriptor(
  name='EChatRoomJoinState',
  full_name='EChatRoomJoinState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomJoinState_Default', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomJoinState_None', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomJoinState_Joined', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomJoinState_TestInvalid', index=3, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20686,
  serialized_end=20842,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMJOINSTATE)

EChatRoomJoinState = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMJOINSTATE)
_ECHATROOMGROUPRANK = _descriptor.EnumDescriptor(
  name='EChatRoomGroupRank',
  full_name='EChatRoomGroupRank',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Default', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Viewer', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Guest', index=2, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Member', index=3, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Moderator', index=4, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Officer', index=5, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_Owner', index=6, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomGroupRank_TestInvalid', index=7, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20845,
  serialized_end=21137,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMGROUPRANK)

EChatRoomGroupRank = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMGROUPRANK)
_ECHATROOMNOTIFICATIONLEVEL = _descriptor.EnumDescriptor(
  name='EChatRoomNotificationLevel',
  full_name='EChatRoomNotificationLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatroomNotificationLevel_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatroomNotificationLevel_None', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatroomNotificationLevel_MentionMe', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatroomNotificationLevel_MentionAll', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatroomNotificationLevel_AllMessages', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21140,
  serialized_end=21384,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMNOTIFICATIONLEVEL)

EChatRoomNotificationLevel = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMNOTIFICATIONLEVEL)
_ECHATROOMSERVERMESSAGE = _descriptor.EnumDescriptor(
  name='EChatRoomServerMessage',
  full_name='EChatRoomServerMessage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_RenameChatRoom', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_Joined', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_Parted', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_Kicked', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_Invited', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_InviteDismissed', index=6, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_ChatRoomTaglineChanged', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_ChatRoomAvatarChanged', index=8, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomServerMsg_AppCustom', index=9, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21387,
  serialized_end=21794,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMSERVERMESSAGE)

EChatRoomServerMessage = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMSERVERMESSAGE)
_ECHATROOMMESSAGEREACTIONTYPE = _descriptor.EnumDescriptor(
  name='EChatRoomMessageReactionType',
  full_name='EChatRoomMessageReactionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMessageReactionType_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMessageReactionType_Emoticon', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMessageReactionType_Sticker', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21797,
  serialized_end=21960,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMMESSAGEREACTIONTYPE)

EChatRoomMessageReactionType = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMMESSAGEREACTIONTYPE)
_ECHATROOMMEMBERSTATECHANGE = _descriptor.EnumDescriptor(
  name='EChatRoomMemberStateChange',
  full_name='EChatRoomMemberStateChange',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Joined', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Parted', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Kicked', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Invited', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_RankChanged', index=5, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_InviteDismissed', index=6, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Muted', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_Banned', index=8, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EChatRoomMemberStateChange_RolesChanged', index=9, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21963,
  serialized_end=22422,
)
_sym_db.RegisterEnumDescriptor(_ECHATROOMMEMBERSTATECHANGE)

EChatRoomMemberStateChange = enum_type_wrapper.EnumTypeWrapper(_ECHATROOMMEMBERSTATECHANGE)
k_EChatRoomJoinState_Default = 0
k_EChatRoomJoinState_None = 1
k_EChatRoomJoinState_Joined = 2
k_EChatRoomJoinState_TestInvalid = 99
k_EChatRoomGroupRank_Default = 0
k_EChatRoomGroupRank_Viewer = 10
k_EChatRoomGroupRank_Guest = 15
k_EChatRoomGroupRank_Member = 20
k_EChatRoomGroupRank_Moderator = 30
k_EChatRoomGroupRank_Officer = 40
k_EChatRoomGroupRank_Owner = 50
k_EChatRoomGroupRank_TestInvalid = 99
k_EChatroomNotificationLevel_Invalid = 0
k_EChatroomNotificationLevel_None = 1
k_EChatroomNotificationLevel_MentionMe = 2
k_EChatroomNotificationLevel_MentionAll = 3
k_EChatroomNotificationLevel_AllMessages = 4
k_EChatRoomServerMsg_Invalid = 0
k_EChatRoomServerMsg_RenameChatRoom = 1
k_EChatRoomServerMsg_Joined = 2
k_EChatRoomServerMsg_Parted = 3
k_EChatRoomServerMsg_Kicked = 4
k_EChatRoomServerMsg_Invited = 5
k_EChatRoomServerMsg_InviteDismissed = 8
k_EChatRoomServerMsg_ChatRoomTaglineChanged = 9
k_EChatRoomServerMsg_ChatRoomAvatarChanged = 10
k_EChatRoomServerMsg_AppCustom = 11
k_EChatRoomMessageReactionType_Invalid = 0
k_EChatRoomMessageReactionType_Emoticon = 1
k_EChatRoomMessageReactionType_Sticker = 2
k_EChatRoomMemberStateChange_Invalid = 0
k_EChatRoomMemberStateChange_Joined = 1
k_EChatRoomMemberStateChange_Parted = 2
k_EChatRoomMemberStateChange_Kicked = 3
k_EChatRoomMemberStateChange_Invited = 4
k_EChatRoomMemberStateChange_RankChanged = 7
k_EChatRoomMemberStateChange_InviteDismissed = 8
k_EChatRoomMemberStateChange_Muted = 9
k_EChatRoomMemberStateChange_Banned = 10
k_EChatRoomMemberStateChange_RolesChanged = 12



_CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST = _descriptor.Descriptor(
  name='CChat_RequestFriendPersonaStates_Request',
  full_name='CChat_RequestFriendPersonaStates_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=172,
)


_CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE = _descriptor.Descriptor(
  name='CChat_RequestFriendPersonaStates_Response',
  full_name='CChat_RequestFriendPersonaStates_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=217,
)


_CCHATROOM_CREATECHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_CreateChatRoomGroup_Request',
  full_name='CChatRoom_CreateChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CChatRoom_CreateChatRoomGroup_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_invited', full_name='CChatRoom_CreateChatRoomGroup_Request.steamid_invited', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_CreateChatRoomGroup_Request.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_invitees', full_name='CChatRoom_CreateChatRoomGroup_Request.steamid_invitees', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_accountid', full_name='CChatRoom_CreateChatRoomGroup_Request.watching_broadcast_accountid', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_channel_id', full_name='CChatRoom_CreateChatRoomGroup_Request.watching_broadcast_channel_id', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=426,
)


_CCHATROLE = _descriptor.Descriptor(
  name='CChatRole',
  full_name='CChatRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRole.role_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRole.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRole.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=487,
)


_CCHATROLEACTIONS = _descriptor.Descriptor(
  name='CChatRoleActions',
  full_name='CChatRoleActions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoleActions.role_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_create_rename_delete_channel', full_name='CChatRoleActions.can_create_rename_delete_channel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_kick', full_name='CChatRoleActions.can_kick', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_ban', full_name='CChatRoleActions.can_ban', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_invite', full_name='CChatRoleActions.can_invite', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_change_tagline_avatar_name', full_name='CChatRoleActions.can_change_tagline_avatar_name', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_chat', full_name='CChatRoleActions.can_chat', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_view_history', full_name='CChatRoleActions.can_view_history', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_change_group_roles', full_name='CChatRoleActions.can_change_group_roles', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_change_user_roles', full_name='CChatRoleActions.can_change_user_roles', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_mention_all', full_name='CChatRoleActions.can_mention_all', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_set_watching_broadcast', full_name='CChatRoleActions.can_set_watching_broadcast', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=830,
)


_CCHATPARTYBEACON = _descriptor.Descriptor(
  name='CChatPartyBeacon',
  full_name='CChatPartyBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CChatPartyBeacon.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_owner', full_name='CChatPartyBeacon.steamid_owner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='CChatPartyBeacon.beacon_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_metadata', full_name='CChatPartyBeacon.game_metadata', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=832,
  serialized_end=931,
)


_CCHATROOMGROUPHEADERSTATE = _descriptor.Descriptor(
  name='CChatRoomGroupHeaderState',
  full_name='CChatRoomGroupHeaderState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoomGroupHeaderState.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_name', full_name='CChatRoomGroupHeaderState.chat_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CChatRoomGroupHeaderState.clanid', index=2,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_owner', full_name='CChatRoomGroupHeaderState.accountid_owner', index=3,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CChatRoomGroupHeaderState.appid', index=4,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagline', full_name='CChatRoomGroupHeaderState.tagline', index=5,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_sha', full_name='CChatRoomGroupHeaderState.avatar_sha', index=6,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_role_id', full_name='CChatRoomGroupHeaderState.default_role_id', index=7,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='CChatRoomGroupHeaderState.roles', index=8,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_actions', full_name='CChatRoomGroupHeaderState.role_actions', index=9,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_accountid', full_name='CChatRoomGroupHeaderState.watching_broadcast_accountid', index=10,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_beacons', full_name='CChatRoomGroupHeaderState.party_beacons', index=11,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_channel_id', full_name='CChatRoomGroupHeaderState.watching_broadcast_channel_id', index=12,
      number=23, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_minigame_id', full_name='CChatRoomGroupHeaderState.active_minigame_id', index=13,
      number=24, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_ugc_url', full_name='CChatRoomGroupHeaderState.avatar_ugc_url', index=14,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='CChatRoomGroupHeaderState.disabled', index=15,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1378,
)


_CCHATROOMMEMBER = _descriptor.Descriptor(
  name='CChatRoomMember',
  full_name='CChatRoomMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CChatRoomMember.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='CChatRoomMember.state', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CChatRoomMember.rank', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_kick_expire', full_name='CChatRoomMember.time_kick_expire', index=3,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_ids', full_name='CChatRoomMember.role_ids', index=4,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1592,
)


_CCHATROOMSTATE = _descriptor.Descriptor(
  name='CChatRoomState',
  full_name='CChatRoomState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoomState.chat_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_name', full_name='CChatRoomState.chat_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_allowed', full_name='CChatRoomState.voice_allowed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members_in_voice', full_name='CChatRoomState.members_in_voice', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_message', full_name='CChatRoomState.time_last_message', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='CChatRoomState.sort_order', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message', full_name='CChatRoomState.last_message', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_last_message', full_name='CChatRoomState.accountid_last_message', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1595,
  serialized_end=1797,
)


_CCHATROOMGROUPSTATE = _descriptor.Descriptor(
  name='CChatRoomGroupState',
  full_name='CChatRoomGroupState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_state', full_name='CChatRoomGroupState.header_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='CChatRoomGroupState.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_chat_id', full_name='CChatRoomGroupState.default_chat_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_rooms', full_name='CChatRoomGroupState.chat_rooms', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kicked', full_name='CChatRoomGroupState.kicked', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1800,
  serialized_end=2002,
)


_CUSERCHATROOMSTATE = _descriptor.Descriptor(
  name='CUserChatRoomState',
  full_name='CUserChatRoomState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CUserChatRoomState.chat_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_joined', full_name='CUserChatRoomState.time_joined', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_ack', full_name='CUserChatRoomState.time_last_ack', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_notification_level', full_name='CUserChatRoomState.desktop_notification_level', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mobile_notification_level', full_name='CUserChatRoomState.mobile_notification_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_mention', full_name='CUserChatRoomState.time_last_mention', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_indicator_muted', full_name='CUserChatRoomState.unread_indicator_muted', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_first_unread', full_name='CUserChatRoomState.time_first_unread', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2384,
)


_CUSERCHATROOMGROUPSTATE = _descriptor.Descriptor(
  name='CUserChatRoomGroupState',
  full_name='CUserChatRoomGroupState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CUserChatRoomGroupState.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_joined', full_name='CUserChatRoomGroupState.time_joined', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_chat_room_state', full_name='CUserChatRoomGroupState.user_chat_room_state', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_notification_level', full_name='CUserChatRoomGroupState.desktop_notification_level', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mobile_notification_level', full_name='CUserChatRoomGroupState.mobile_notification_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_group_ack', full_name='CUserChatRoomGroupState.time_last_group_ack', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_indicator_muted', full_name='CUserChatRoomGroupState.unread_indicator_muted', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2387,
  serialized_end=2780,
)


_CCHATROOM_CREATECHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_CreateChatRoomGroup_Response',
  full_name='CChatRoom_CreateChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_CreateChatRoomGroup_Response.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='CChatRoom_CreateChatRoomGroup_Response.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_chat_state', full_name='CChatRoom_CreateChatRoomGroup_Response.user_chat_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2783,
  serialized_end=2934,
)


_CCHATROOM_SAVECHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SaveChatRoomGroup_Request',
  full_name='CChatRoom_SaveChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SaveChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_SaveChatRoomGroup_Request.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2936,
  serialized_end=3010,
)


_CCHATROOM_SAVECHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SaveChatRoomGroup_Response',
  full_name='CChatRoom_SaveChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3012,
  serialized_end=3050,
)


_CCHATROOM_RENAMECHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_RenameChatRoomGroup_Request',
  full_name='CChatRoom_RenameChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_RenameChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_RenameChatRoomGroup_Request.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3052,
  serialized_end=3128,
)


_CCHATROOM_RENAMECHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_RenameChatRoomGroup_Response',
  full_name='CChatRoom_RenameChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_RenameChatRoomGroup_Response.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3130,
  serialized_end=3184,
)


_CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupTagline_Request',
  full_name='CChatRoom_SetChatRoomGroupTagline_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetChatRoomGroupTagline_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagline', full_name='CChatRoom_SetChatRoomGroupTagline_Request.tagline', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3186,
  serialized_end=3269,
)


_CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupTagline_Response',
  full_name='CChatRoom_SetChatRoomGroupTagline_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3271,
  serialized_end=3315,
)


_CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupAvatar_Request',
  full_name='CChatRoom_SetChatRoomGroupAvatar_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetChatRoomGroupAvatar_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_sha', full_name='CChatRoom_SetChatRoomGroupAvatar_Request.avatar_sha', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3317,
  serialized_end=3402,
)


_CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupAvatar_Response',
  full_name='CChatRoom_SetChatRoomGroupAvatar_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3404,
  serialized_end=3447,
)


_CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Request',
  full_name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_accountid', full_name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Request.watching_broadcast_accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_channel_id', full_name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Request.watching_broadcast_channel_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3603,
)


_CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Response',
  full_name='CChatRoom_SetChatRoomGroupWatchingBroadcast_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3605,
  serialized_end=3659,
)


_CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_JoinMiniGameForChatRoomGroup_Request',
  full_name='CChatRoom_JoinMiniGameForChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_JoinMiniGameForChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_JoinMiniGameForChatRoomGroup_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3661,
  serialized_end=3749,
)


_CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_JoinMiniGameForChatRoomGroup_Response',
  full_name='CChatRoom_JoinMiniGameForChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minigame_id', full_name='CChatRoom_JoinMiniGameForChatRoomGroup_Response.minigame_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3751,
  serialized_end=3821,
)


_CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_EndMiniGameForChatRoomGroup_Request',
  full_name='CChatRoom_EndMiniGameForChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_EndMiniGameForChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_EndMiniGameForChatRoomGroup_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minigame_id', full_name='CChatRoom_EndMiniGameForChatRoomGroup_Request.minigame_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3823,
  serialized_end=3931,
)


_CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_EndMiniGameForChatRoomGroup_Response',
  full_name='CChatRoom_EndMiniGameForChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3933,
  serialized_end=3981,
)


_CCHATROOM_MUTEUSER_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_MuteUser_Request',
  full_name='CChatRoom_MuteUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_MuteUser_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_MuteUser_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='CChatRoom_MuteUser_Request.expiration', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3983,
  serialized_end=4071,
)


_CCHATROOM_MUTEUSER_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_MuteUser_Response',
  full_name='CChatRoom_MuteUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4073,
  serialized_end=4102,
)


_CCHATROOM_KICKUSER_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_KickUser_Request',
  full_name='CChatRoom_KickUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_KickUser_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_KickUser_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='CChatRoom_KickUser_Request.expiration', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4104,
  serialized_end=4192,
)


_CCHATROOM_KICKUSER_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_KickUser_Response',
  full_name='CChatRoom_KickUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4194,
  serialized_end=4223,
)


_CCHATROOM_SETUSERBANSTATE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetUserBanState_Request',
  full_name='CChatRoom_SetUserBanState_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetUserBanState_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_SetUserBanState_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ban_state', full_name='CChatRoom_SetUserBanState_Request.ban_state', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4225,
  serialized_end=4319,
)


_CCHATROOM_SETUSERBANSTATE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetUserBanState_Response',
  full_name='CChatRoom_SetUserBanState_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4321,
  serialized_end=4357,
)


_CCHATROOM_REVOKEINVITE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_RevokeInvite_Request',
  full_name='CChatRoom_RevokeInvite_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_RevokeInvite_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_RevokeInvite_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4359,
  serialized_end=4431,
)


_CCHATROOM_REVOKEINVITE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_RevokeInvite_Response',
  full_name='CChatRoom_RevokeInvite_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4433,
  serialized_end=4466,
)


_CCHATROOM_CREATEROLE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_CreateRole_Request',
  full_name='CChatRoom_CreateRole_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_CreateRole_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_CreateRole_Request.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4468,
  serialized_end=4535,
)


_CCHATROOM_CREATEROLE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_CreateRole_Response',
  full_name='CChatRoom_CreateRole_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='CChatRoom_CreateRole_Response.actions', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4537,
  serialized_end=4604,
)


_CCHATROOM_GETROLES_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetRoles_Request',
  full_name='CChatRoom_GetRoles_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetRoles_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4606,
  serialized_end=4657,
)


_CCHATROOM_GETROLES_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetRoles_Response',
  full_name='CChatRoom_GetRoles_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='CChatRoom_GetRoles_Response.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4659,
  serialized_end=4715,
)


_CCHATROOM_RENAMEROLE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_RenameRole_Request',
  full_name='CChatRoom_RenameRole_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_RenameRole_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_RenameRole_Request.role_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_RenameRole_Request.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4717,
  serialized_end=4801,
)


_CCHATROOM_RENAMEROLE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_RenameRole_Response',
  full_name='CChatRoom_RenameRole_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4803,
  serialized_end=4834,
)


_CCHATROOM_REORDERROLE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_ReorderRole_Request',
  full_name='CChatRoom_ReorderRole_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_ReorderRole_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_ReorderRole_Request.role_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_ReorderRole_Request.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4836,
  serialized_end=4924,
)


_CCHATROOM_REORDERROLE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_ReorderRole_Response',
  full_name='CChatRoom_ReorderRole_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4926,
  serialized_end=4958,
)


_CCHATROOM_DELETEROLE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_DeleteRole_Request',
  full_name='CChatRoom_DeleteRole_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_DeleteRole_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_DeleteRole_Request.role_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4960,
  serialized_end=5030,
)


_CCHATROOM_DELETEROLE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_DeleteRole_Response',
  full_name='CChatRoom_DeleteRole_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5032,
  serialized_end=5063,
)


_CCHATROOM_GETROLEACTIONS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetRoleActions_Request',
  full_name='CChatRoom_GetRoleActions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetRoleActions_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_GetRoleActions_Request.role_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5065,
  serialized_end=5139,
)


_CCHATROOM_GETROLEACTIONS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetRoleActions_Response',
  full_name='CChatRoom_GetRoleActions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='CChatRoom_GetRoleActions_Response.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5141,
  serialized_end=5212,
)


_CCHATROOM_REPLACEROLEACTIONS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_ReplaceRoleActions_Request',
  full_name='CChatRoom_ReplaceRoleActions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_ReplaceRoleActions_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_ReplaceRoleActions_Request.role_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='CChatRoom_ReplaceRoleActions_Request.actions', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5214,
  serialized_end=5328,
)


_CCHATROOM_REPLACEROLEACTIONS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_ReplaceRoleActions_Response',
  full_name='CChatRoom_ReplaceRoleActions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5330,
  serialized_end=5369,
)


_CCHATROOM_ADDROLETOUSER_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_AddRoleToUser_Request',
  full_name='CChatRoom_AddRoleToUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_AddRoleToUser_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_AddRoleToUser_Request.role_id', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_AddRoleToUser_Request.steamid', index=2,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5371,
  serialized_end=5461,
)


_CCHATROOM_ADDROLETOUSER_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_AddRoleToUser_Response',
  full_name='CChatRoom_AddRoleToUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5463,
  serialized_end=5497,
)


_CCHATROOM_GETROLESFORUSER_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetRolesForUser_Request',
  full_name='CChatRoom_GetRolesForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetRolesForUser_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_GetRolesForUser_Request.steamid', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5499,
  serialized_end=5574,
)


_CCHATROOM_GETROLESFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetRolesForUser_Response',
  full_name='CChatRoom_GetRolesForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_ids', full_name='CChatRoom_GetRolesForUser_Response.role_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5576,
  serialized_end=5630,
)


_CCHATROOM_DELETEROLEFROMUSER_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_DeleteRoleFromUser_Request',
  full_name='CChatRoom_DeleteRoleFromUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_DeleteRoleFromUser_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='CChatRoom_DeleteRoleFromUser_Request.role_id', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_DeleteRoleFromUser_Request.steamid', index=2,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5632,
  serialized_end=5727,
)


_CCHATROOM_DELETEROLEFROMUSER_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_DeleteRoleFromUser_Response',
  full_name='CChatRoom_DeleteRoleFromUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5729,
  serialized_end=5768,
)


_CCHATROOM_JOINCHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_JoinChatRoomGroup_Request',
  full_name='CChatRoom_JoinChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_JoinChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_JoinChatRoomGroup_Request.invite_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_JoinChatRoomGroup_Request.chat_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5770,
  serialized_end=5868,
)


_CCHATROOM_JOINCHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_JoinChatRoomGroup_Response',
  full_name='CChatRoom_JoinChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CChatRoom_JoinChatRoomGroup_Response.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_chat_state', full_name='CChatRoom_JoinChatRoomGroup_Response.user_chat_state', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_chat_id', full_name='CChatRoom_JoinChatRoomGroup_Response.join_chat_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_expire', full_name='CChatRoom_JoinChatRoomGroup_Response.time_expire', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5871,
  serialized_end=6040,
)


_CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_InviteFriendToChatRoomGroup_Request',
  full_name='CChatRoom_InviteFriendToChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_InviteFriendToChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CChatRoom_InviteFriendToChatRoomGroup_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_InviteFriendToChatRoomGroup_Request.chat_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_friendsui_check', full_name='CChatRoom_InviteFriendToChatRoomGroup_Request.skip_friendsui_check', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6043,
  serialized_end=6177,
)


_CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_InviteFriendToChatRoomGroup_Response',
  full_name='CChatRoom_InviteFriendToChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6179,
  serialized_end=6227,
)


_CCHATROOM_LEAVECHATROOMGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_LeaveChatRoomGroup_Request',
  full_name='CChatRoom_LeaveChatRoomGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_LeaveChatRoomGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6229,
  serialized_end=6290,
)


_CCHATROOM_LEAVECHATROOMGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_LeaveChatRoomGroup_Response',
  full_name='CChatRoom_LeaveChatRoomGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6292,
  serialized_end=6331,
)


_CCHATROOM_CREATECHATROOM_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_CreateChatRoom_Request',
  full_name='CChatRoom_CreateChatRoom_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_CreateChatRoom_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_CreateChatRoom_Request.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_voice', full_name='CChatRoom_CreateChatRoom_Request.allow_voice', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6333,
  serialized_end=6425,
)


_CCHATROOM_CREATECHATROOM_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_CreateChatRoom_Response',
  full_name='CChatRoom_CreateChatRoom_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_room', full_name='CChatRoom_CreateChatRoom_Response.chat_room', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6427,
  serialized_end=6498,
)


_CCHATROOM_DELETECHATROOM_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_DeleteChatRoom_Request',
  full_name='CChatRoom_DeleteChatRoom_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_DeleteChatRoom_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_DeleteChatRoom_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6500,
  serialized_end=6574,
)


_CCHATROOM_DELETECHATROOM_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_DeleteChatRoom_Response',
  full_name='CChatRoom_DeleteChatRoom_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6576,
  serialized_end=6611,
)


_CCHATROOM_RENAMECHATROOM_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_RenameChatRoom_Request',
  full_name='CChatRoom_RenameChatRoom_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_RenameChatRoom_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_RenameChatRoom_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CChatRoom_RenameChatRoom_Request.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6613,
  serialized_end=6701,
)


_CCHATROOM_RENAMECHATROOM_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_RenameChatRoom_Response',
  full_name='CChatRoom_RenameChatRoom_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6703,
  serialized_end=6738,
)


_CCHATROOM_REORDERCHATROOM_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_ReorderChatRoom_Request',
  full_name='CChatRoom_ReorderChatRoom_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_ReorderChatRoom_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_ReorderChatRoom_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_after_chat_id', full_name='CChatRoom_ReorderChatRoom_Request.move_after_chat_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6740,
  serialized_end=6843,
)


_CCHATROOM_REORDERCHATROOM_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_ReorderChatRoom_Response',
  full_name='CChatRoom_ReorderChatRoom_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6845,
  serialized_end=6881,
)


_CCHATROOM_SENDCHATMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SendChatMessage_Request',
  full_name='CChatRoom_SendChatMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SendChatMessage_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_SendChatMessage_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CChatRoom_SendChatMessage_Request.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo_to_sender', full_name='CChatRoom_SendChatMessage_Request.echo_to_sender', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6883,
  serialized_end=6999,
)


_CCHATROOM_SENDCHATMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SendChatMessage_Response',
  full_name='CChatRoom_SendChatMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modified_message', full_name='CChatRoom_SendChatMessage_Response.modified_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_SendChatMessage_Response.server_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_SendChatMessage_Response.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_without_bb_code', full_name='CChatRoom_SendChatMessage_Response.message_without_bb_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7002,
  serialized_end=7140,
)


_CCHATROOM_JOINVOICECHAT_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_JoinVoiceChat_Request',
  full_name='CChatRoom_JoinVoiceChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_JoinVoiceChat_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_JoinVoiceChat_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7142,
  serialized_end=7215,
)


_CCHATROOM_JOINVOICECHAT_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_JoinVoiceChat_Response',
  full_name='CChatRoom_JoinVoiceChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CChatRoom_JoinVoiceChat_Response.voice_chatid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7217,
  serialized_end=7273,
)


_CCHATROOM_LEAVEVOICECHAT_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_LeaveVoiceChat_Request',
  full_name='CChatRoom_LeaveVoiceChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_LeaveVoiceChat_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_LeaveVoiceChat_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7275,
  serialized_end=7349,
)


_CCHATROOM_LEAVEVOICECHAT_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_LeaveVoiceChat_Response',
  full_name='CChatRoom_LeaveVoiceChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7351,
  serialized_end=7386,
)


_CCHATROOM_GETMESSAGEHISTORY_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetMessageHistory_Request',
  full_name='CChatRoom_GetMessageHistory_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetMessageHistory_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_GetMessageHistory_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time', full_name='CChatRoom_GetMessageHistory_Request.last_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_ordinal', full_name='CChatRoom_GetMessageHistory_Request.last_ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CChatRoom_GetMessageHistory_Request.start_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_ordinal', full_name='CChatRoom_GetMessageHistory_Request.start_ordinal', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_count', full_name='CChatRoom_GetMessageHistory_Request.max_count', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7389,
  serialized_end=7569,
)


_SERVERMESSAGE = _descriptor.Descriptor(
  name='ServerMessage',
  full_name='ServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ServerMessage.message', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_param', full_name='ServerMessage.string_param', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_param', full_name='ServerMessage.accountid_param', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7572,
  serialized_end=7706,
)


_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION = _descriptor.Descriptor(
  name='MessageReaction',
  full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction.reaction_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction.reaction', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_reactors', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction.num_reactors', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_user_reacted', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction.has_user_reacted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8078,
  serialized_end=8255,
)

_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE = _descriptor.Descriptor(
  name='ChatMessage',
  full_name='CChatRoom_GetMessageHistory_Response.ChatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.sender', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.server_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_message', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.server_message', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.deleted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='CChatRoom_GetMessageHistory_Response.ChatMessage.reactions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7843,
  serialized_end=8255,
)

_CCHATROOM_GETMESSAGEHISTORY_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetMessageHistory_Response',
  full_name='CChatRoom_GetMessageHistory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='CChatRoom_GetMessageHistory_Response.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more_available', full_name='CChatRoom_GetMessageHistory_Response.more_available', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7709,
  serialized_end=8255,
)


_CCHATROOM_GETMYCHATROOMGROUPS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetMyChatRoomGroups_Request',
  full_name='CChatRoom_GetMyChatRoomGroups_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8257,
  serialized_end=8296,
)


_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetChatRoomGroupSummary_Response',
  full_name='CChatRoom_GetChatRoomGroupSummary_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetChatRoomGroupSummary_Response.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_name', full_name='CChatRoom_GetChatRoomGroupSummary_Response.chat_group_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_member_count', full_name='CChatRoom_GetChatRoomGroupSummary_Response.active_member_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_voice_member_count', full_name='CChatRoom_GetChatRoomGroupSummary_Response.active_voice_member_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_chat_id', full_name='CChatRoom_GetChatRoomGroupSummary_Response.default_chat_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_rooms', full_name='CChatRoom_GetChatRoomGroupSummary_Response.chat_rooms', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CChatRoom_GetChatRoomGroupSummary_Response.clanid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_tagline', full_name='CChatRoom_GetChatRoomGroupSummary_Response.chat_group_tagline', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_owner', full_name='CChatRoom_GetChatRoomGroupSummary_Response.accountid_owner', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top_members', full_name='CChatRoom_GetChatRoomGroupSummary_Response.top_members', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_avatar_sha', full_name='CChatRoom_GetChatRoomGroupSummary_Response.chat_group_avatar_sha', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CChatRoom_GetChatRoomGroupSummary_Response.rank', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_role_id', full_name='CChatRoom_GetChatRoomGroupSummary_Response.default_role_id', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_ids', full_name='CChatRoom_GetChatRoomGroupSummary_Response.role_ids', index=13,
      number=14, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_actions', full_name='CChatRoom_GetChatRoomGroupSummary_Response.role_actions', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_accountid', full_name='CChatRoom_GetChatRoomGroupSummary_Response.watching_broadcast_accountid', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CChatRoom_GetChatRoomGroupSummary_Response.appid', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_beacons', full_name='CChatRoom_GetChatRoomGroupSummary_Response.party_beacons', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watching_broadcast_channel_id', full_name='CChatRoom_GetChatRoomGroupSummary_Response.watching_broadcast_channel_id', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_minigame_id', full_name='CChatRoom_GetChatRoomGroupSummary_Response.active_minigame_id', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_ugc_url', full_name='CChatRoom_GetChatRoomGroupSummary_Response.avatar_ugc_url', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='CChatRoom_GetChatRoomGroupSummary_Response.disabled', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8299,
  serialized_end=8991,
)


_CCHATROOMSUMMARYPAIR = _descriptor.Descriptor(
  name='CChatRoomSummaryPair',
  full_name='CChatRoomSummaryPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_chat_group_state', full_name='CChatRoomSummaryPair.user_chat_group_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_summary', full_name='CChatRoomSummaryPair.group_summary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8994,
  serialized_end=9141,
)


_CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetMyChatRoomGroups_Response',
  full_name='CChatRoom_GetMyChatRoomGroups_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_room_groups', full_name='CChatRoom_GetMyChatRoomGroups_Response.chat_room_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9143,
  serialized_end=9232,
)


_CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetChatRoomGroupState_Request',
  full_name='CChatRoom_GetChatRoomGroupState_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetChatRoomGroupState_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9234,
  serialized_end=9298,
)


_CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetChatRoomGroupState_Response',
  full_name='CChatRoom_GetChatRoomGroupState_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CChatRoom_GetChatRoomGroupState_Response.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9300,
  serialized_end=9379,
)


_CCHATROOM_GETCHATROOMGROUPSUMMARY_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetChatRoomGroupSummary_Request',
  full_name='CChatRoom_GetChatRoomGroupSummary_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetChatRoomGroupSummary_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9381,
  serialized_end=9447,
)


_CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetAppChatRoomGroupForceActive_Request',
  full_name='CChatRoom_SetAppChatRoomGroupForceActive_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetAppChatRoomGroupForceActive_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requesting_app_id', full_name='CChatRoom_SetAppChatRoomGroupForceActive_Request.requesting_app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9449,
  serialized_end=9549,
)


_CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetAppChatRoomGroupForceActive_Response',
  full_name='CChatRoom_SetAppChatRoomGroupForceActive_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CChatRoom_SetAppChatRoomGroupForceActive_Response.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts_in_channel', full_name='CChatRoom_SetAppChatRoomGroupForceActive_Response.accounts_in_channel', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9551,
  serialized_end=9647,
)


_CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_SetAppChatRoomGroupStopForceActive_Notification',
  full_name='CChatRoom_SetAppChatRoomGroupStopForceActive_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetAppChatRoomGroupStopForceActive_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requesting_app_id', full_name='CChatRoom_SetAppChatRoomGroupStopForceActive_Notification.requesting_app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9649,
  serialized_end=9758,
)


_CCHATROOM_ACKCHATMESSAGE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_AckChatMessage_Notification',
  full_name='CChatRoom_AckChatMessage_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_AckChatMessage_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_AckChatMessage_Notification.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CChatRoom_AckChatMessage_Notification.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9760,
  serialized_end=9858,
)


_CCHATROOM_CREATEINVITELINK_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_CreateInviteLink_Request',
  full_name='CChatRoom_CreateInviteLink_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_CreateInviteLink_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_valid', full_name='CChatRoom_CreateInviteLink_Request.seconds_valid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_CreateInviteLink_Request.chat_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9860,
  serialized_end=9959,
)


_CCHATROOM_CREATEINVITELINK_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_CreateInviteLink_Response',
  full_name='CChatRoom_CreateInviteLink_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_CreateInviteLink_Response.invite_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_valid', full_name='CChatRoom_CreateInviteLink_Response.seconds_valid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9961,
  serialized_end=10042,
)


_CCHATROOM_GETINVITELINKINFO_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetInviteLinkInfo_Request',
  full_name='CChatRoom_GetInviteLinkInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_GetInviteLinkInfo_Request.invite_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10044,
  serialized_end=10102,
)


_CCHATROOM_GETINVITELINKINFO_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetInviteLinkInfo_Response',
  full_name='CChatRoom_GetInviteLinkInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_sender', full_name='CChatRoom_GetInviteLinkInfo_Response.steamid_sender', index=0,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='CChatRoom_GetInviteLinkInfo_Response.time_expires', index=1,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_GetInviteLinkInfo_Response.chat_id', index=2,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_summary', full_name='CChatRoom_GetInviteLinkInfo_Response.group_summary', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_chat_group_state', full_name='CChatRoom_GetInviteLinkInfo_Response.user_chat_group_state', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_kick_expire', full_name='CChatRoom_GetInviteLinkInfo_Response.time_kick_expire', index=5,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banned', full_name='CChatRoom_GetInviteLinkInfo_Response.banned', index=6,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10105,
  serialized_end=10373,
)


_CCHATROOM_GETINVITEINFO_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetInviteInfo_Request',
  full_name='CChatRoom_GetInviteInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_invitee', full_name='CChatRoom_GetInviteInfo_Request.steamid_invitee', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetInviteInfo_Request.chat_group_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_GetInviteInfo_Request.chat_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_GetInviteInfo_Request.invite_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10375,
  serialized_end=10494,
)


_CCHATROOM_GETINVITEINFO_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetInviteInfo_Response',
  full_name='CChatRoom_GetInviteInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_summary', full_name='CChatRoom_GetInviteInfo_Response.group_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_kick_expire', full_name='CChatRoom_GetInviteInfo_Response.time_kick_expire', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banned', full_name='CChatRoom_GetInviteInfo_Response.banned', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10497,
  serialized_end=10641,
)


_CCHATROOM_GETINVITELINKSFORGROUP_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetInviteLinksForGroup_Request',
  full_name='CChatRoom_GetInviteLinksForGroup_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetInviteLinksForGroup_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10643,
  serialized_end=10708,
)


_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO = _descriptor.Descriptor(
  name='LinkInfo',
  full_name='CChatRoom_GetInviteLinksForGroup_Response.LinkInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_GetInviteLinksForGroup_Response.LinkInfo.invite_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_creator', full_name='CChatRoom_GetInviteLinksForGroup_Response.LinkInfo.steamid_creator', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='CChatRoom_GetInviteLinksForGroup_Response.LinkInfo.time_expires', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_GetInviteLinksForGroup_Response.LinkInfo.chat_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10831,
  serialized_end=10926,
)

_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetInviteLinksForGroup_Response',
  full_name='CChatRoom_GetInviteLinksForGroup_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_links', full_name='CChatRoom_GetInviteLinksForGroup_Response.invite_links', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10711,
  serialized_end=10926,
)


_CCHATROOM_GETBANLIST_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetBanList_Request',
  full_name='CChatRoom_GetBanList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetBanList_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10928,
  serialized_end=10981,
)


_CCHATROOM_GETBANLIST_RESPONSE_BANINFO = _descriptor.Descriptor(
  name='BanInfo',
  full_name='CChatRoom_GetBanList_Response.BanInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CChatRoom_GetBanList_Response.BanInfo.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_actor', full_name='CChatRoom_GetBanList_Response.BanInfo.accountid_actor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_banned', full_name='CChatRoom_GetBanList_Response.BanInfo.time_banned', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ban_reason', full_name='CChatRoom_GetBanList_Response.BanInfo.ban_reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11071,
  serialized_end=11165,
)

_CCHATROOM_GETBANLIST_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetBanList_Response',
  full_name='CChatRoom_GetBanList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bans', full_name='CChatRoom_GetBanList_Response.bans', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_GETBANLIST_RESPONSE_BANINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10984,
  serialized_end=11165,
)


_CCHATROOM_GETINVITELIST_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetInviteList_Request',
  full_name='CChatRoom_GetInviteList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetInviteList_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11167,
  serialized_end=11223,
)


_CCHATROOMGROUPINVITE = _descriptor.Descriptor(
  name='CChatRoomGroupInvite',
  full_name='CChatRoomGroupInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CChatRoomGroupInvite.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_actor', full_name='CChatRoomGroupInvite.accountid_actor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_invited', full_name='CChatRoomGroupInvite.time_invited', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11225,
  serialized_end=11313,
)


_CCHATROOM_GETINVITELIST_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetInviteList_Response',
  full_name='CChatRoom_GetInviteList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invites', full_name='CChatRoom_GetInviteList_Response.invites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11315,
  serialized_end=11389,
)


_CCHATROOM_DELETEINVITELINK_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_DeleteInviteLink_Request',
  full_name='CChatRoom_DeleteInviteLink_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_DeleteInviteLink_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_code', full_name='CChatRoom_DeleteInviteLink_Request.invite_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11391,
  serialized_end=11471,
)


_CCHATROOM_DELETEINVITELINK_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_DeleteInviteLink_Response',
  full_name='CChatRoom_DeleteInviteLink_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11473,
  serialized_end=11510,
)


_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetSessionActiveChatRoomGroups_Request',
  full_name='CChatRoom_SetSessionActiveChatRoomGroups_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_ids', full_name='CChatRoom_SetSessionActiveChatRoomGroups_Request.chat_group_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_groups_data_requested', full_name='CChatRoom_SetSessionActiveChatRoomGroups_Request.chat_groups_data_requested', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtualize_members_threshold', full_name='CChatRoom_SetSessionActiveChatRoomGroups_Request.virtualize_members_threshold', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030YIf a chat room has more members than this threshold, we will opt in to a virtualized list', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11513,
  serialized_end=11757,
)


_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetSessionActiveChatRoomGroups_Response',
  full_name='CChatRoom_SetSessionActiveChatRoomGroups_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_states', full_name='CChatRoom_SetSessionActiveChatRoomGroups_Response.chat_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtualize_members_chat_group_ids', full_name='CChatRoom_SetSessionActiveChatRoomGroups_Response.virtualize_members_chat_group_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11760,
  serialized_end=11897,
)


_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES = _descriptor.Descriptor(
  name='ChatGroupPreferences',
  full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='desktop_notification_level', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences.desktop_notification_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mobile_notification_level', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences.mobile_notification_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_indicator_muted', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences.unread_indicator_muted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12173,
  serialized_end=12432,
)

_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES = _descriptor.Descriptor(
  name='ChatRoomPreferences',
  full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences.chat_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desktop_notification_level', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences.desktop_notification_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mobile_notification_level', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences.mobile_notification_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_indicator_muted', full_name='CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences.unread_indicator_muted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12435,
  serialized_end=12710,
)

_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SetUserChatGroupPreferences_Request',
  full_name='CChatRoom_SetUserChatGroupPreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SetUserChatGroupPreferences_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_preferences', full_name='CChatRoom_SetUserChatGroupPreferences_Request.chat_group_preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_room_preferences', full_name='CChatRoom_SetUserChatGroupPreferences_Request.chat_room_preferences', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES, _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11900,
  serialized_end=12710,
)


_CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SetUserChatGroupPreferences_Response',
  full_name='CChatRoom_SetUserChatGroupPreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12712,
  serialized_end=12760,
)


_CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='CChatRoom_DeleteChatMessages_Request.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_DeleteChatMessages_Request.Message.server_timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_DeleteChatMessages_Request.Message.ordinal', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12908,
  serialized_end=12960,
)

_CCHATROOM_DELETECHATMESSAGES_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_DeleteChatMessages_Request',
  full_name='CChatRoom_DeleteChatMessages_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_DeleteChatMessages_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_DeleteChatMessages_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='CChatRoom_DeleteChatMessages_Request.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12763,
  serialized_end=12960,
)


_CCHATROOM_DELETECHATMESSAGES_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_DeleteChatMessages_Response',
  full_name='CChatRoom_DeleteChatMessages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12962,
  serialized_end=13001,
)


_CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_UpdateMemberListView_Notification',
  full_name='CChatRoom_UpdateMemberListView_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_UpdateMemberListView_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_id', full_name='CChatRoom_UpdateMemberListView_Notification.view_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030RClient-generated ID.  Should send the same value on all requests for the same view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='CChatRoom_UpdateMemberListView_Notification.start', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='CChatRoom_UpdateMemberListView_Notification.end', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_changenumber', full_name='CChatRoom_UpdateMemberListView_Notification.client_changenumber', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030nAny updates from this call on will have this changenumber present.  Can be used to guarantee in-order updates.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_view', full_name='CChatRoom_UpdateMemberListView_Notification.delete_view', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Indicates this view has been deleted.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_subscribe_accountids', full_name='CChatRoom_UpdateMemberListView_Notification.persona_subscribe_accountids', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona_unsubscribe_accountids', full_name='CChatRoom_UpdateMemberListView_Notification.persona_unsubscribe_accountids', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13004,
  serialized_end=13493,
)


_CCHATROOM_SEARCHMEMBERS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_SearchMembers_Request',
  full_name='CChatRoom_SearchMembers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_SearchMembers_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_id', full_name='CChatRoom_SearchMembers_Request.search_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\231\001Client-supplied id.  For find-as-you-type searches, as search narrows the server will not return persona states previously returned for a given searchid.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='CChatRoom_SearchMembers_Request.search_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='CChatRoom_SearchMembers_Request.max_results', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13496,
  serialized_end=13775,
)


_CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH = _descriptor.Descriptor(
  name='MemberMatch',
  full_name='CChatRoom_SearchMembers_Response.MemberMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CChatRoom_SearchMembers_Response.MemberMatch.accountid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona', full_name='CChatRoom_SearchMembers_Response.MemberMatch.persona', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13909,
  serialized_end=13990,
)

_CCHATROOM_SEARCHMEMBERS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_SearchMembers_Response',
  full_name='CChatRoom_SearchMembers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matching_members', full_name='CChatRoom_SearchMembers_Response.matching_members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_flags', full_name='CChatRoom_SearchMembers_Response.status_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13778,
  serialized_end=13990,
)


_CCHATROOM_UPDATEMESSAGEREACTION_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_UpdateMessageReaction_Request',
  full_name='CChatRoom_UpdateMessageReaction_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_UpdateMessageReaction_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_UpdateMessageReaction_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_UpdateMessageReaction_Request.server_timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_UpdateMessageReaction_Request.ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CChatRoom_UpdateMessageReaction_Request.reaction_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CChatRoom_UpdateMessageReaction_Request.reaction', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_add', full_name='CChatRoom_UpdateMessageReaction_Request.is_add', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13993,
  serialized_end=14245,
)


_CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_UpdateMessageReaction_Response',
  full_name='CChatRoom_UpdateMessageReaction_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_reactors', full_name='CChatRoom_UpdateMessageReaction_Response.num_reactors', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14247,
  serialized_end=14311,
)


_CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST = _descriptor.Descriptor(
  name='CChatRoom_GetMessageReactionReactors_Request',
  full_name='CChatRoom_GetMessageReactionReactors_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_GetMessageReactionReactors_Request.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_GetMessageReactionReactors_Request.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_GetMessageReactionReactors_Request.server_timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_GetMessageReactionReactors_Request.ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CChatRoom_GetMessageReactionReactors_Request.reaction_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CChatRoom_GetMessageReactionReactors_Request.reaction', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='CChatRoom_GetMessageReactionReactors_Request.limit', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14314,
  serialized_end=14570,
)


_CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE = _descriptor.Descriptor(
  name='CChatRoom_GetMessageReactionReactors_Response',
  full_name='CChatRoom_GetMessageReactionReactors_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reactors', full_name='CChatRoom_GetMessageReactionReactors_Response.reactors', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14572,
  serialized_end=14637,
)


_CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST = _descriptor.Descriptor(
  name='CClanChatRooms_GetClanChatRoomInfo_Request',
  full_name='CClanChatRooms_GetClanChatRoomInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CClanChatRooms_GetClanChatRoomInfo_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autocreate', full_name='CClanChatRooms_GetClanChatRoomInfo_Request.autocreate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030;Create a default chat room if none has been created before.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14640,
  serialized_end=14792,
)


_CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE = _descriptor.Descriptor(
  name='CClanChatRooms_GetClanChatRoomInfo_Response',
  full_name='CClanChatRooms_GetClanChatRoomInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_summary', full_name='CClanChatRooms_GetClanChatRoomInfo_Response.chat_group_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14794,
  serialized_end=14912,
)


_CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST = _descriptor.Descriptor(
  name='CClanChatRooms_SetClanChatRoomPrivate_Request',
  full_name='CClanChatRooms_SetClanChatRoomPrivate_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CClanChatRooms_SetClanChatRoomPrivate_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_room_private', full_name='CClanChatRooms_SetClanChatRoomPrivate_Request.chat_room_private', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14914,
  serialized_end=15005,
)


_CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE = _descriptor.Descriptor(
  name='CClanChatRooms_SetClanChatRoomPrivate_Response',
  full_name='CClanChatRooms_SetClanChatRoomPrivate_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_room_private', full_name='CClanChatRooms_SetClanChatRoomPrivate_Response.chat_room_private', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15007,
  serialized_end=15082,
)


_CCHATMENTIONS = _descriptor.Descriptor(
  name='CChatMentions',
  full_name='CChatMentions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mention_all', full_name='CChatMentions.mention_all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mention_here', full_name='CChatMentions.mention_here', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mention_accountids', full_name='CChatMentions.mention_accountids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15084,
  serialized_end=15170,
)


_CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_IncomingChatMessage_Notification',
  full_name='CChatRoom_IncomingChatMessage_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_IncomingChatMessage_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_IncomingChatMessage_Notification.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_sender', full_name='CChatRoom_IncomingChatMessage_Notification.steamid_sender', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CChatRoom_IncomingChatMessage_Notification.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CChatRoom_IncomingChatMessage_Notification.timestamp', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mentions', full_name='CChatRoom_IncomingChatMessage_Notification.mentions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_IncomingChatMessage_Notification.ordinal', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_message', full_name='CChatRoom_IncomingChatMessage_Notification.server_message', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_no_bbcode', full_name='CChatRoom_IncomingChatMessage_Notification.message_no_bbcode', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_name', full_name='CChatRoom_IncomingChatMessage_Notification.chat_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306A name to use for the chat, intended for notifications', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15173,
  serialized_end=15514,
)


_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE = _descriptor.Descriptor(
  name='ChatMessage',
  full_name='CChatRoom_ChatMessageModified_Notification.ChatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_ChatMessageModified_Notification.ChatMessage.server_timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_ChatMessageModified_Notification.ChatMessage.ordinal', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='CChatRoom_ChatMessageModified_Notification.ChatMessage.deleted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15678,
  serialized_end=15751,
)

_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_ChatMessageModified_Notification',
  full_name='CChatRoom_ChatMessageModified_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_ChatMessageModified_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_ChatMessageModified_Notification.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='CChatRoom_ChatMessageModified_Notification.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15517,
  serialized_end=15751,
)


_CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_MemberStateChange_Notification',
  full_name='CChatRoom_MemberStateChange_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_MemberStateChange_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='CChatRoom_MemberStateChange_Notification.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='CChatRoom_MemberStateChange_Notification.change', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15754,
  serialized_end=15936,
)


_CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_ChatRoomHeaderState_Notification',
  full_name='CChatRoom_ChatRoomHeaderState_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_state', full_name='CChatRoom_ChatRoomHeaderState_Notification.header_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15938,
  serialized_end=16032,
)


_CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_ChatRoomGroupRoomsChange_Notification',
  full_name='CChatRoom_ChatRoomGroupRoomsChange_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_ChatRoomGroupRoomsChange_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_chat_id', full_name='CChatRoom_ChatRoomGroupRoomsChange_Notification.default_chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_rooms', full_name='CChatRoom_ChatRoomGroupRoomsChange_Notification.chat_rooms', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16035,
  serialized_end=16169,
)


_CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification',
  full_name='CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification.chat_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification.chat_group_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16171,
  serialized_end=16271,
)


_CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification',
  full_name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_chat_group_state', full_name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification.user_chat_group_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_summary', full_name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification.group_summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_action', full_name='ChatRoomClient_NotifyChatGroupUserStateChanged_Notification.user_action', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16274,
  serialized_end=16571,
)


_CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION = _descriptor.Descriptor(
  name='ChatRoomClient_NotifyChatRoomDisconnect_Notification',
  full_name='ChatRoomClient_NotifyChatRoomDisconnect_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_ids', full_name='ChatRoomClient_NotifyChatRoomDisconnect_Notification.chat_group_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16573,
  serialized_end=16651,
)


_CCHATROOMMEMBERLISTVIEW = _descriptor.Descriptor(
  name='CChatRoomMemberListView',
  full_name='CChatRoomMemberListView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='CChatRoomMemberListView.start', index=0,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='CChatRoomMemberListView.end', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_count', full_name='CChatRoomMemberListView.total_count', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_changenumber', full_name='CChatRoomMemberListView.client_changenumber', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@Value sent by the client on the last UpdateMemberListView call. ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_changenumber', full_name='CChatRoomMemberListView.server_changenumber', index=4,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DValue incremented by the server on each MemberListViewUpdated call. ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16654,
  serialized_end=16930,
)


_CCHATROOMMEMBERSUMMARYCOUNTS = _descriptor.Descriptor(
  name='CChatRoomMemberSummaryCounts',
  full_name='CChatRoomMemberSummaryCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingame', full_name='CChatRoomMemberSummaryCounts.ingame', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='CChatRoomMemberSummaryCounts.online', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline', full_name='CChatRoomMemberSummaryCounts.offline', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16932,
  serialized_end=17011,
)


_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY = _descriptor.Descriptor(
  name='MemberListViewEntry',
  full_name='CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry.rank', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persona', full_name='CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry.persona', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17438,
  serialized_end=17541,
)

_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoomClient_MemberListViewUpdated_Notification',
  full_name='CChatRoomClient_MemberListViewUpdated_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoomClient_MemberListViewUpdated_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_id', full_name='CChatRoomClient_MemberListViewUpdated_Notification.view_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308Thew view_id supplied when the client created the view. ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='CChatRoomClient_MemberListViewUpdated_Notification.view', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='CChatRoomClient_MemberListViewUpdated_Notification.members', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_flags', full_name='CChatRoomClient_MemberListViewUpdated_Notification.status_flags', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_summary', full_name='CChatRoomClient_MemberListViewUpdated_Notification.member_summary', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribed_personas', full_name='CChatRoomClient_MemberListViewUpdated_Notification.subscribed_personas', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17014,
  serialized_end=17541,
)


_CCHATROOM_MESSAGEREACTION_NOTIFICATION = _descriptor.Descriptor(
  name='CChatRoom_MessageReaction_Notification',
  full_name='CChatRoom_MessageReaction_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CChatRoom_MessageReaction_Notification.chat_group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CChatRoom_MessageReaction_Notification.chat_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CChatRoom_MessageReaction_Notification.server_timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CChatRoom_MessageReaction_Notification.ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactor', full_name='CChatRoom_MessageReaction_Notification.reactor', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CChatRoom_MessageReaction_Notification.reaction_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CChatRoom_MessageReaction_Notification.reaction', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_add', full_name='CChatRoom_MessageReaction_Notification.is_add', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17544,
  serialized_end=17812,
)


_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS = _descriptor.Descriptor(
  name='Settings',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notifications_show_ingame', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.notifications_show_ingame', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_show_online', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.notifications_show_online', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_show_message', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.notifications_show_message', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_events_and_announcements', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.notifications_events_and_announcements', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_play_ingame', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sounds_play_ingame', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_play_online', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sounds_play_online', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_play_message', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sounds_play_message', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_events_and_announcements', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sounds_events_and_announcements', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_new_chat_window', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.always_new_chat_window', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_alphabetic_friend_sorting', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.force_alphabetic_friend_sorting', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_flash_mode', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.chat_flash_mode', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remember_open_chats', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.remember_open_chats', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compact_quick_access', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.compact_quick_access', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compact_friends_list', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.compact_friends_list', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_show_chat_room_notification', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.notifications_show_chat_room_notification', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_play_chat_room_notification', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sounds_play_chat_room_notification', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_offline_friends_in_tag_groups', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.hide_offline_friends_in_tag_groups', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_categorized_friends', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.hide_categorized_friends', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categorize_in_game_friends_by_game', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.categorize_in_game_friends_by_game', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_font_size', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.chat_font_size', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use24hour_clock', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.use24hour_clock', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_not_disturb_mode', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.do_not_disturb_mode', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_embed_inlining', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.disable_embed_inlining', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_into_friends', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.sign_into_friends', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='animated_avatars', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Settings.animated_avatars', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18285,
  serialized_end=19142,
)

_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS = _descriptor.Descriptor(
  name='VoiceSettings',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_input_gain', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.voice_input_gain', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_output_gain', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.voice_output_gain', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noise_gate_level', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.noise_gate_level', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_use_echo_cancellation', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.voice_use_echo_cancellation', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_use_noise_cancellation', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.voice_use_noise_cancellation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_use_auto_gain_control', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.voice_use_auto_gain_control', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_non_default_mic', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.selected_non_default_mic', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_non_default_output', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.selected_non_default_output', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push_to_talk_enabled', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.push_to_talk_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push_to_mute_enabled', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.push_to_mute_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='play_ptt_sounds', full_name='CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings.play_ptt_sounds', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19145,
  serialized_end=19507,
)

_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE = _descriptor.Descriptor(
  name='CategoryCollapseState',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_game_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState.in_game_collapsed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState.online_collapsed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState.offline_collapsed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_groups_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState.game_groups_collapsed', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categories_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState.categories_collapsed', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20111,
  serialized_end=20275,
)

_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE = _descriptor.Descriptor(
  name='UIState',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friends_list_height', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_height', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_list_width', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_list_docked', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_docked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_list_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_collapsed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_list_group_chats_height', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_group_chats_height', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_list_visible', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friends_list_visible', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_popups_opened', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.chat_popups_opened', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_chat_tabs_opened', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.group_chat_tabs_opened', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friend_chat_tabs_opened', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.friend_chat_tabs_opened', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_window_width', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.chat_window_width', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_window_height', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.chat_window_height', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_collapse', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.category_collapse', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_chat_left_col_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.group_chat_left_col_collapsed', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_chat_right_col_collapsed', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.group_chat_right_col_collapsed', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_one_on_one_voice_chat', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.in_one_on_one_voice_chat', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_group_voice_chat', full_name='CChatUsability_ClientUsabilityMetrics_Notification.UIState.in_group_voice_chat', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19510,
  serialized_end=20275,
)

_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friends_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_category_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_category_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_categorized_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_categorized_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_online_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_online_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_in_game_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_in_game_count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_in_game_singleton_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_in_game_singleton_count', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_group_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.game_group_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_favorite_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.friends_favorite_count', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_chat_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.group_chat_count', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_chat_favorite_count', full_name='CChatUsability_ClientUsabilityMetrics_Notification.Metrics.group_chat_favorite_count', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20278,
  serialized_end=20598,
)

_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION = _descriptor.Descriptor(
  name='CChatUsability_ClientUsabilityMetrics_Notification',
  full_name='CChatUsability_ClientUsabilityMetrics_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics_run_id', full_name='CChatUsability_ClientUsabilityMetrics_Notification.metrics_run_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_build', full_name='CChatUsability_ClientUsabilityMetrics_Notification.client_build', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics_version', full_name='CChatUsability_ClientUsabilityMetrics_Notification.metrics_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_web', full_name='CChatUsability_ClientUsabilityMetrics_Notification.in_web', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CChatUsability_ClientUsabilityMetrics_Notification.settings', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_settings', full_name='CChatUsability_ClientUsabilityMetrics_Notification.voice_settings', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ui_state', full_name='CChatUsability_ClientUsabilityMetrics_Notification.ui_state', index=6,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='CChatUsability_ClientUsabilityMetrics_Notification.metrics', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS, _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS, _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE, _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17815,
  serialized_end=20598,
)


_CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION = _descriptor.Descriptor(
  name='CChatUsability_RequestClientUsabilityMetrics_Notification',
  full_name='CChatUsability_RequestClientUsabilityMetrics_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics_run_id', full_name='CChatUsability_RequestClientUsabilityMetrics_Notification.metrics_run_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20600,
  serialized_end=20683,
)

_CCHATROOMGROUPHEADERSTATE.fields_by_name['roles'].message_type = _CCHATROLE
_CCHATROOMGROUPHEADERSTATE.fields_by_name['role_actions'].message_type = _CCHATROLEACTIONS
_CCHATROOMGROUPHEADERSTATE.fields_by_name['party_beacons'].message_type = _CCHATPARTYBEACON
_CCHATROOMMEMBER.fields_by_name['state'].enum_type = _ECHATROOMJOINSTATE
_CCHATROOMMEMBER.fields_by_name['rank'].enum_type = _ECHATROOMGROUPRANK
_CCHATROOMGROUPSTATE.fields_by_name['header_state'].message_type = _CCHATROOMGROUPHEADERSTATE
_CCHATROOMGROUPSTATE.fields_by_name['members'].message_type = _CCHATROOMMEMBER
_CCHATROOMGROUPSTATE.fields_by_name['chat_rooms'].message_type = _CCHATROOMSTATE
_CCHATROOMGROUPSTATE.fields_by_name['kicked'].message_type = _CCHATROOMMEMBER
_CUSERCHATROOMSTATE.fields_by_name['desktop_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CUSERCHATROOMSTATE.fields_by_name['mobile_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CUSERCHATROOMGROUPSTATE.fields_by_name['user_chat_room_state'].message_type = _CUSERCHATROOMSTATE
_CUSERCHATROOMGROUPSTATE.fields_by_name['desktop_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CUSERCHATROOMGROUPSTATE.fields_by_name['mobile_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CCHATROOM_CREATECHATROOMGROUP_RESPONSE.fields_by_name['state'].message_type = _CCHATROOMGROUPSTATE
_CCHATROOM_CREATECHATROOMGROUP_RESPONSE.fields_by_name['user_chat_state'].message_type = _CUSERCHATROOMGROUPSTATE
_CCHATROOM_CREATEROLE_RESPONSE.fields_by_name['actions'].message_type = _CCHATROLEACTIONS
_CCHATROOM_GETROLES_RESPONSE.fields_by_name['roles'].message_type = _CCHATROLE
_CCHATROOM_GETROLEACTIONS_RESPONSE.fields_by_name['actions'].message_type = _CCHATROLEACTIONS
_CCHATROOM_REPLACEROLEACTIONS_REQUEST.fields_by_name['actions'].message_type = _CCHATROLEACTIONS
_CCHATROOM_JOINCHATROOMGROUP_RESPONSE.fields_by_name['state'].message_type = _CCHATROOMGROUPSTATE
_CCHATROOM_JOINCHATROOMGROUP_RESPONSE.fields_by_name['user_chat_state'].message_type = _CUSERCHATROOMGROUPSTATE
_CCHATROOM_CREATECHATROOM_RESPONSE.fields_by_name['chat_room'].message_type = _CCHATROOMSTATE
_SERVERMESSAGE.fields_by_name['message'].enum_type = _ECHATROOMSERVERMESSAGE
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION.fields_by_name['reaction_type'].enum_type = _ECHATROOMMESSAGEREACTIONTYPE
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION.containing_type = _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE.fields_by_name['server_message'].message_type = _SERVERMESSAGE
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE.fields_by_name['reactions'].message_type = _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE.containing_type = _CCHATROOM_GETMESSAGEHISTORY_RESPONSE
_CCHATROOM_GETMESSAGEHISTORY_RESPONSE.fields_by_name['messages'].message_type = _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE
_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE.fields_by_name['chat_rooms'].message_type = _CCHATROOMSTATE
_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE.fields_by_name['rank'].enum_type = _ECHATROOMGROUPRANK
_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE.fields_by_name['role_actions'].message_type = _CCHATROLEACTIONS
_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE.fields_by_name['party_beacons'].message_type = _CCHATPARTYBEACON
_CCHATROOMSUMMARYPAIR.fields_by_name['user_chat_group_state'].message_type = _CUSERCHATROOMGROUPSTATE
_CCHATROOMSUMMARYPAIR.fields_by_name['group_summary'].message_type = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
_CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE.fields_by_name['chat_room_groups'].message_type = _CCHATROOMSUMMARYPAIR
_CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE.fields_by_name['state'].message_type = _CCHATROOMGROUPSTATE
_CCHATROOM_GETINVITELINKINFO_RESPONSE.fields_by_name['group_summary'].message_type = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
_CCHATROOM_GETINVITELINKINFO_RESPONSE.fields_by_name['user_chat_group_state'].message_type = _CUSERCHATROOMGROUPSTATE
_CCHATROOM_GETINVITEINFO_RESPONSE.fields_by_name['group_summary'].message_type = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO.containing_type = _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE
_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE.fields_by_name['invite_links'].message_type = _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO
_CCHATROOM_GETBANLIST_RESPONSE_BANINFO.containing_type = _CCHATROOM_GETBANLIST_RESPONSE
_CCHATROOM_GETBANLIST_RESPONSE.fields_by_name['bans'].message_type = _CCHATROOM_GETBANLIST_RESPONSE_BANINFO
_CCHATROOM_GETINVITELIST_RESPONSE.fields_by_name['invites'].message_type = _CCHATROOMGROUPINVITE
_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE.fields_by_name['chat_states'].message_type = _CCHATROOMGROUPSTATE
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES.fields_by_name['desktop_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES.fields_by_name['mobile_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES.containing_type = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES.fields_by_name['desktop_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES.fields_by_name['mobile_notification_level'].enum_type = _ECHATROOMNOTIFICATIONLEVEL
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES.containing_type = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST.fields_by_name['chat_group_preferences'].message_type = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES
_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST.fields_by_name['chat_room_preferences'].message_type = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES
_CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE.containing_type = _CCHATROOM_DELETECHATMESSAGES_REQUEST
_CCHATROOM_DELETECHATMESSAGES_REQUEST.fields_by_name['messages'].message_type = _CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE
_CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH.fields_by_name['persona'].message_type = steammessages__clientserver__friends__pb2._CMSGCLIENTPERSONASTATE_FRIEND
_CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH.containing_type = _CCHATROOM_SEARCHMEMBERS_RESPONSE
_CCHATROOM_SEARCHMEMBERS_RESPONSE.fields_by_name['matching_members'].message_type = _CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH
_CCHATROOM_UPDATEMESSAGEREACTION_REQUEST.fields_by_name['reaction_type'].enum_type = _ECHATROOMMESSAGEREACTIONTYPE
_CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST.fields_by_name['reaction_type'].enum_type = _ECHATROOMMESSAGEREACTIONTYPE
_CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE.fields_by_name['chat_group_summary'].message_type = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
_CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION.fields_by_name['mentions'].message_type = _CCHATMENTIONS
_CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION.fields_by_name['server_message'].message_type = _SERVERMESSAGE
_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE.containing_type = _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION
_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION.fields_by_name['messages'].message_type = _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE
_CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION.fields_by_name['member'].message_type = _CCHATROOMMEMBER
_CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION.fields_by_name['change'].enum_type = _ECHATROOMMEMBERSTATECHANGE
_CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION.fields_by_name['header_state'].message_type = _CCHATROOMGROUPHEADERSTATE
_CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION.fields_by_name['chat_rooms'].message_type = _CCHATROOMSTATE
_CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION.fields_by_name['user_chat_group_state'].message_type = _CUSERCHATROOMGROUPSTATE
_CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION.fields_by_name['group_summary'].message_type = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
_CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION.fields_by_name['user_action'].enum_type = _ECHATROOMMEMBERSTATECHANGE
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY.fields_by_name['persona'].message_type = steammessages__clientserver__friends__pb2._CMSGCLIENTPERSONASTATE_FRIEND
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY.containing_type = _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION.fields_by_name['view'].message_type = _CCHATROOMMEMBERLISTVIEW
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION.fields_by_name['members'].message_type = _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION.fields_by_name['member_summary'].message_type = _CCHATROOMMEMBERSUMMARYCOUNTS
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION.fields_by_name['subscribed_personas'].message_type = steammessages__clientserver__friends__pb2._CMSGCLIENTPERSONASTATE_FRIEND
_CCHATROOM_MESSAGEREACTION_NOTIFICATION.fields_by_name['reaction_type'].enum_type = _ECHATROOMMESSAGEREACTIONTYPE
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS.containing_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS.containing_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE.containing_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE.fields_by_name['category_collapse'].message_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE.containing_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS.containing_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION.fields_by_name['settings'].message_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION.fields_by_name['voice_settings'].message_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION.fields_by_name['ui_state'].message_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE
_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION.fields_by_name['metrics'].message_type = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS
DESCRIPTOR.message_types_by_name['CChat_RequestFriendPersonaStates_Request'] = _CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST
DESCRIPTOR.message_types_by_name['CChat_RequestFriendPersonaStates_Response'] = _CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_CreateChatRoomGroup_Request'] = _CCHATROOM_CREATECHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRole'] = _CCHATROLE
DESCRIPTOR.message_types_by_name['CChatRoleActions'] = _CCHATROLEACTIONS
DESCRIPTOR.message_types_by_name['CChatPartyBeacon'] = _CCHATPARTYBEACON
DESCRIPTOR.message_types_by_name['CChatRoomGroupHeaderState'] = _CCHATROOMGROUPHEADERSTATE
DESCRIPTOR.message_types_by_name['CChatRoomMember'] = _CCHATROOMMEMBER
DESCRIPTOR.message_types_by_name['CChatRoomState'] = _CCHATROOMSTATE
DESCRIPTOR.message_types_by_name['CChatRoomGroupState'] = _CCHATROOMGROUPSTATE
DESCRIPTOR.message_types_by_name['CUserChatRoomState'] = _CUSERCHATROOMSTATE
DESCRIPTOR.message_types_by_name['CUserChatRoomGroupState'] = _CUSERCHATROOMGROUPSTATE
DESCRIPTOR.message_types_by_name['CChatRoom_CreateChatRoomGroup_Response'] = _CCHATROOM_CREATECHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SaveChatRoomGroup_Request'] = _CCHATROOM_SAVECHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SaveChatRoomGroup_Response'] = _CCHATROOM_SAVECHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_RenameChatRoomGroup_Request'] = _CCHATROOM_RENAMECHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_RenameChatRoomGroup_Response'] = _CCHATROOM_RENAMECHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupTagline_Request'] = _CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupTagline_Response'] = _CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupAvatar_Request'] = _CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupAvatar_Response'] = _CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupWatchingBroadcast_Request'] = _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetChatRoomGroupWatchingBroadcast_Response'] = _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_JoinMiniGameForChatRoomGroup_Request'] = _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_JoinMiniGameForChatRoomGroup_Response'] = _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_EndMiniGameForChatRoomGroup_Request'] = _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_EndMiniGameForChatRoomGroup_Response'] = _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_MuteUser_Request'] = _CCHATROOM_MUTEUSER_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_MuteUser_Response'] = _CCHATROOM_MUTEUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_KickUser_Request'] = _CCHATROOM_KICKUSER_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_KickUser_Response'] = _CCHATROOM_KICKUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetUserBanState_Request'] = _CCHATROOM_SETUSERBANSTATE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetUserBanState_Response'] = _CCHATROOM_SETUSERBANSTATE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_RevokeInvite_Request'] = _CCHATROOM_REVOKEINVITE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_RevokeInvite_Response'] = _CCHATROOM_REVOKEINVITE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_CreateRole_Request'] = _CCHATROOM_CREATEROLE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_CreateRole_Response'] = _CCHATROOM_CREATEROLE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetRoles_Request'] = _CCHATROOM_GETROLES_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetRoles_Response'] = _CCHATROOM_GETROLES_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_RenameRole_Request'] = _CCHATROOM_RENAMEROLE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_RenameRole_Response'] = _CCHATROOM_RENAMEROLE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_ReorderRole_Request'] = _CCHATROOM_REORDERROLE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_ReorderRole_Response'] = _CCHATROOM_REORDERROLE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteRole_Request'] = _CCHATROOM_DELETEROLE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteRole_Response'] = _CCHATROOM_DELETEROLE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetRoleActions_Request'] = _CCHATROOM_GETROLEACTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetRoleActions_Response'] = _CCHATROOM_GETROLEACTIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_ReplaceRoleActions_Request'] = _CCHATROOM_REPLACEROLEACTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_ReplaceRoleActions_Response'] = _CCHATROOM_REPLACEROLEACTIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_AddRoleToUser_Request'] = _CCHATROOM_ADDROLETOUSER_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_AddRoleToUser_Response'] = _CCHATROOM_ADDROLETOUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetRolesForUser_Request'] = _CCHATROOM_GETROLESFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetRolesForUser_Response'] = _CCHATROOM_GETROLESFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteRoleFromUser_Request'] = _CCHATROOM_DELETEROLEFROMUSER_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteRoleFromUser_Response'] = _CCHATROOM_DELETEROLEFROMUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_JoinChatRoomGroup_Request'] = _CCHATROOM_JOINCHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_JoinChatRoomGroup_Response'] = _CCHATROOM_JOINCHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_InviteFriendToChatRoomGroup_Request'] = _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_InviteFriendToChatRoomGroup_Response'] = _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_LeaveChatRoomGroup_Request'] = _CCHATROOM_LEAVECHATROOMGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_LeaveChatRoomGroup_Response'] = _CCHATROOM_LEAVECHATROOMGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_CreateChatRoom_Request'] = _CCHATROOM_CREATECHATROOM_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_CreateChatRoom_Response'] = _CCHATROOM_CREATECHATROOM_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteChatRoom_Request'] = _CCHATROOM_DELETECHATROOM_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteChatRoom_Response'] = _CCHATROOM_DELETECHATROOM_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_RenameChatRoom_Request'] = _CCHATROOM_RENAMECHATROOM_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_RenameChatRoom_Response'] = _CCHATROOM_RENAMECHATROOM_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_ReorderChatRoom_Request'] = _CCHATROOM_REORDERCHATROOM_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_ReorderChatRoom_Response'] = _CCHATROOM_REORDERCHATROOM_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SendChatMessage_Request'] = _CCHATROOM_SENDCHATMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SendChatMessage_Response'] = _CCHATROOM_SENDCHATMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_JoinVoiceChat_Request'] = _CCHATROOM_JOINVOICECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_JoinVoiceChat_Response'] = _CCHATROOM_JOINVOICECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_LeaveVoiceChat_Request'] = _CCHATROOM_LEAVEVOICECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_LeaveVoiceChat_Response'] = _CCHATROOM_LEAVEVOICECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetMessageHistory_Request'] = _CCHATROOM_GETMESSAGEHISTORY_REQUEST
DESCRIPTOR.message_types_by_name['ServerMessage'] = _SERVERMESSAGE
DESCRIPTOR.message_types_by_name['CChatRoom_GetMessageHistory_Response'] = _CCHATROOM_GETMESSAGEHISTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetMyChatRoomGroups_Request'] = _CCHATROOM_GETMYCHATROOMGROUPS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetChatRoomGroupSummary_Response'] = _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoomSummaryPair'] = _CCHATROOMSUMMARYPAIR
DESCRIPTOR.message_types_by_name['CChatRoom_GetMyChatRoomGroups_Response'] = _CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetChatRoomGroupState_Request'] = _CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetChatRoomGroupState_Response'] = _CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetChatRoomGroupSummary_Request'] = _CCHATROOM_GETCHATROOMGROUPSUMMARY_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetAppChatRoomGroupForceActive_Request'] = _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetAppChatRoomGroupForceActive_Response'] = _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetAppChatRoomGroupStopForceActive_Notification'] = _CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_AckChatMessage_Notification'] = _CCHATROOM_ACKCHATMESSAGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_CreateInviteLink_Request'] = _CCHATROOM_CREATEINVITELINK_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_CreateInviteLink_Response'] = _CCHATROOM_CREATEINVITELINK_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteLinkInfo_Request'] = _CCHATROOM_GETINVITELINKINFO_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteLinkInfo_Response'] = _CCHATROOM_GETINVITELINKINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteInfo_Request'] = _CCHATROOM_GETINVITEINFO_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteInfo_Response'] = _CCHATROOM_GETINVITEINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteLinksForGroup_Request'] = _CCHATROOM_GETINVITELINKSFORGROUP_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteLinksForGroup_Response'] = _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetBanList_Request'] = _CCHATROOM_GETBANLIST_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetBanList_Response'] = _CCHATROOM_GETBANLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteList_Request'] = _CCHATROOM_GETINVITELIST_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoomGroupInvite'] = _CCHATROOMGROUPINVITE
DESCRIPTOR.message_types_by_name['CChatRoom_GetInviteList_Response'] = _CCHATROOM_GETINVITELIST_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteInviteLink_Request'] = _CCHATROOM_DELETEINVITELINK_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteInviteLink_Response'] = _CCHATROOM_DELETEINVITELINK_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetSessionActiveChatRoomGroups_Request'] = _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetSessionActiveChatRoomGroups_Response'] = _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_SetUserChatGroupPreferences_Request'] = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SetUserChatGroupPreferences_Response'] = _CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteChatMessages_Request'] = _CCHATROOM_DELETECHATMESSAGES_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_DeleteChatMessages_Response'] = _CCHATROOM_DELETECHATMESSAGES_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_UpdateMemberListView_Notification'] = _CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_SearchMembers_Request'] = _CCHATROOM_SEARCHMEMBERS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_SearchMembers_Response'] = _CCHATROOM_SEARCHMEMBERS_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_UpdateMessageReaction_Request'] = _CCHATROOM_UPDATEMESSAGEREACTION_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_UpdateMessageReaction_Response'] = _CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE
DESCRIPTOR.message_types_by_name['CChatRoom_GetMessageReactionReactors_Request'] = _CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST
DESCRIPTOR.message_types_by_name['CChatRoom_GetMessageReactionReactors_Response'] = _CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE
DESCRIPTOR.message_types_by_name['CClanChatRooms_GetClanChatRoomInfo_Request'] = _CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST
DESCRIPTOR.message_types_by_name['CClanChatRooms_GetClanChatRoomInfo_Response'] = _CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CClanChatRooms_SetClanChatRoomPrivate_Request'] = _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST
DESCRIPTOR.message_types_by_name['CClanChatRooms_SetClanChatRoomPrivate_Response'] = _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE
DESCRIPTOR.message_types_by_name['CChatMentions'] = _CCHATMENTIONS
DESCRIPTOR.message_types_by_name['CChatRoom_IncomingChatMessage_Notification'] = _CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_ChatMessageModified_Notification'] = _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_MemberStateChange_Notification'] = _CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_ChatRoomHeaderState_Notification'] = _CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_ChatRoomGroupRoomsChange_Notification'] = _CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification'] = _CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['ChatRoomClient_NotifyChatGroupUserStateChanged_Notification'] = _CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['ChatRoomClient_NotifyChatRoomDisconnect_Notification'] = _CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoomMemberListView'] = _CCHATROOMMEMBERLISTVIEW
DESCRIPTOR.message_types_by_name['CChatRoomMemberSummaryCounts'] = _CCHATROOMMEMBERSUMMARYCOUNTS
DESCRIPTOR.message_types_by_name['CChatRoomClient_MemberListViewUpdated_Notification'] = _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatRoom_MessageReaction_Notification'] = _CCHATROOM_MESSAGEREACTION_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatUsability_ClientUsabilityMetrics_Notification'] = _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CChatUsability_RequestClientUsabilityMetrics_Notification'] = _CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EChatRoomJoinState'] = _ECHATROOMJOINSTATE
DESCRIPTOR.enum_types_by_name['EChatRoomGroupRank'] = _ECHATROOMGROUPRANK
DESCRIPTOR.enum_types_by_name['EChatRoomNotificationLevel'] = _ECHATROOMNOTIFICATIONLEVEL
DESCRIPTOR.enum_types_by_name['EChatRoomServerMessage'] = _ECHATROOMSERVERMESSAGE
DESCRIPTOR.enum_types_by_name['EChatRoomMessageReactionType'] = _ECHATROOMMESSAGEREACTIONTYPE
DESCRIPTOR.enum_types_by_name['EChatRoomMemberStateChange'] = _ECHATROOMMEMBERSTATECHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CChat_RequestFriendPersonaStates_Request = _reflection.GeneratedProtocolMessageType('CChat_RequestFriendPersonaStates_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChat_RequestFriendPersonaStates_Request)
  })
_sym_db.RegisterMessage(CChat_RequestFriendPersonaStates_Request)

CChat_RequestFriendPersonaStates_Response = _reflection.GeneratedProtocolMessageType('CChat_RequestFriendPersonaStates_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChat_RequestFriendPersonaStates_Response)
  })
_sym_db.RegisterMessage(CChat_RequestFriendPersonaStates_Response)

CChatRoom_CreateChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATECHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_CreateChatRoomGroup_Request)

CChatRole = _reflection.GeneratedProtocolMessageType('CChatRole', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROLE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRole)
  })
_sym_db.RegisterMessage(CChatRole)

CChatRoleActions = _reflection.GeneratedProtocolMessageType('CChatRoleActions', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROLEACTIONS,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoleActions)
  })
_sym_db.RegisterMessage(CChatRoleActions)

CChatPartyBeacon = _reflection.GeneratedProtocolMessageType('CChatPartyBeacon', (_message.Message,), {
  'DESCRIPTOR' : _CCHATPARTYBEACON,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatPartyBeacon)
  })
_sym_db.RegisterMessage(CChatPartyBeacon)

CChatRoomGroupHeaderState = _reflection.GeneratedProtocolMessageType('CChatRoomGroupHeaderState', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMGROUPHEADERSTATE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomGroupHeaderState)
  })
_sym_db.RegisterMessage(CChatRoomGroupHeaderState)

CChatRoomMember = _reflection.GeneratedProtocolMessageType('CChatRoomMember', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMMEMBER,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomMember)
  })
_sym_db.RegisterMessage(CChatRoomMember)

CChatRoomState = _reflection.GeneratedProtocolMessageType('CChatRoomState', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMSTATE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomState)
  })
_sym_db.RegisterMessage(CChatRoomState)

CChatRoomGroupState = _reflection.GeneratedProtocolMessageType('CChatRoomGroupState', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMGROUPSTATE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomGroupState)
  })
_sym_db.RegisterMessage(CChatRoomGroupState)

CUserChatRoomState = _reflection.GeneratedProtocolMessageType('CUserChatRoomState', (_message.Message,), {
  'DESCRIPTOR' : _CUSERCHATROOMSTATE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CUserChatRoomState)
  })
_sym_db.RegisterMessage(CUserChatRoomState)

CUserChatRoomGroupState = _reflection.GeneratedProtocolMessageType('CUserChatRoomGroupState', (_message.Message,), {
  'DESCRIPTOR' : _CUSERCHATROOMGROUPSTATE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CUserChatRoomGroupState)
  })
_sym_db.RegisterMessage(CUserChatRoomGroupState)

CChatRoom_CreateChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATECHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_CreateChatRoomGroup_Response)

CChatRoom_SaveChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SaveChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SAVECHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SaveChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SaveChatRoomGroup_Request)

CChatRoom_SaveChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SaveChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SAVECHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SaveChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SaveChatRoomGroup_Response)

CChatRoom_RenameChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMECHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_RenameChatRoomGroup_Request)

CChatRoom_RenameChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMECHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_RenameChatRoomGroup_Response)

CChatRoom_SetChatRoomGroupTagline_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupTagline_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupTagline_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupTagline_Request)

CChatRoom_SetChatRoomGroupTagline_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupTagline_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupTagline_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupTagline_Response)

CChatRoom_SetChatRoomGroupAvatar_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupAvatar_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupAvatar_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupAvatar_Request)

CChatRoom_SetChatRoomGroupAvatar_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupAvatar_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupAvatar_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupAvatar_Response)

CChatRoom_SetChatRoomGroupWatchingBroadcast_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupWatchingBroadcast_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupWatchingBroadcast_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupWatchingBroadcast_Request)

CChatRoom_SetChatRoomGroupWatchingBroadcast_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetChatRoomGroupWatchingBroadcast_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetChatRoomGroupWatchingBroadcast_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetChatRoomGroupWatchingBroadcast_Response)

CChatRoom_JoinMiniGameForChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinMiniGameForChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinMiniGameForChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_JoinMiniGameForChatRoomGroup_Request)

CChatRoom_JoinMiniGameForChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinMiniGameForChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinMiniGameForChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_JoinMiniGameForChatRoomGroup_Response)

CChatRoom_EndMiniGameForChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_EndMiniGameForChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_EndMiniGameForChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_EndMiniGameForChatRoomGroup_Request)

CChatRoom_EndMiniGameForChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_EndMiniGameForChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_EndMiniGameForChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_EndMiniGameForChatRoomGroup_Response)

CChatRoom_MuteUser_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_MuteUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_MUTEUSER_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_MuteUser_Request)
  })
_sym_db.RegisterMessage(CChatRoom_MuteUser_Request)

CChatRoom_MuteUser_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_MuteUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_MUTEUSER_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_MuteUser_Response)
  })
_sym_db.RegisterMessage(CChatRoom_MuteUser_Response)

CChatRoom_KickUser_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_KickUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_KICKUSER_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_KickUser_Request)
  })
_sym_db.RegisterMessage(CChatRoom_KickUser_Request)

CChatRoom_KickUser_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_KickUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_KICKUSER_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_KickUser_Response)
  })
_sym_db.RegisterMessage(CChatRoom_KickUser_Response)

CChatRoom_SetUserBanState_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetUserBanState_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETUSERBANSTATE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetUserBanState_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetUserBanState_Request)

CChatRoom_SetUserBanState_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetUserBanState_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETUSERBANSTATE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetUserBanState_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetUserBanState_Response)

CChatRoom_RevokeInvite_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_RevokeInvite_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REVOKEINVITE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RevokeInvite_Request)
  })
_sym_db.RegisterMessage(CChatRoom_RevokeInvite_Request)

CChatRoom_RevokeInvite_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_RevokeInvite_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REVOKEINVITE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RevokeInvite_Response)
  })
_sym_db.RegisterMessage(CChatRoom_RevokeInvite_Response)

CChatRoom_CreateRole_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateRole_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATEROLE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateRole_Request)
  })
_sym_db.RegisterMessage(CChatRoom_CreateRole_Request)

CChatRoom_CreateRole_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateRole_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATEROLE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateRole_Response)
  })
_sym_db.RegisterMessage(CChatRoom_CreateRole_Response)

CChatRoom_GetRoles_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRoles_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLES_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRoles_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetRoles_Request)

CChatRoom_GetRoles_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRoles_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLES_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRoles_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetRoles_Response)

CChatRoom_RenameRole_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameRole_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMEROLE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameRole_Request)
  })
_sym_db.RegisterMessage(CChatRoom_RenameRole_Request)

CChatRoom_RenameRole_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameRole_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMEROLE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameRole_Response)
  })
_sym_db.RegisterMessage(CChatRoom_RenameRole_Response)

CChatRoom_ReorderRole_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_ReorderRole_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REORDERROLE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReorderRole_Request)
  })
_sym_db.RegisterMessage(CChatRoom_ReorderRole_Request)

CChatRoom_ReorderRole_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_ReorderRole_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REORDERROLE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReorderRole_Response)
  })
_sym_db.RegisterMessage(CChatRoom_ReorderRole_Response)

CChatRoom_DeleteRole_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteRole_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEROLE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteRole_Request)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteRole_Request)

CChatRoom_DeleteRole_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteRole_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEROLE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteRole_Response)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteRole_Response)

CChatRoom_GetRoleActions_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRoleActions_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLEACTIONS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRoleActions_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetRoleActions_Request)

CChatRoom_GetRoleActions_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRoleActions_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLEACTIONS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRoleActions_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetRoleActions_Response)

CChatRoom_ReplaceRoleActions_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_ReplaceRoleActions_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REPLACEROLEACTIONS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReplaceRoleActions_Request)
  })
_sym_db.RegisterMessage(CChatRoom_ReplaceRoleActions_Request)

CChatRoom_ReplaceRoleActions_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_ReplaceRoleActions_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REPLACEROLEACTIONS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReplaceRoleActions_Response)
  })
_sym_db.RegisterMessage(CChatRoom_ReplaceRoleActions_Response)

CChatRoom_AddRoleToUser_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_AddRoleToUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_ADDROLETOUSER_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_AddRoleToUser_Request)
  })
_sym_db.RegisterMessage(CChatRoom_AddRoleToUser_Request)

CChatRoom_AddRoleToUser_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_AddRoleToUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_ADDROLETOUSER_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_AddRoleToUser_Response)
  })
_sym_db.RegisterMessage(CChatRoom_AddRoleToUser_Response)

CChatRoom_GetRolesForUser_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRolesForUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLESFORUSER_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRolesForUser_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetRolesForUser_Request)

CChatRoom_GetRolesForUser_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetRolesForUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETROLESFORUSER_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetRolesForUser_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetRolesForUser_Response)

CChatRoom_DeleteRoleFromUser_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteRoleFromUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEROLEFROMUSER_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteRoleFromUser_Request)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteRoleFromUser_Request)

CChatRoom_DeleteRoleFromUser_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteRoleFromUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEROLEFROMUSER_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteRoleFromUser_Response)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteRoleFromUser_Response)

CChatRoom_JoinChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINCHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_JoinChatRoomGroup_Request)

CChatRoom_JoinChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINCHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_JoinChatRoomGroup_Response)

CChatRoom_InviteFriendToChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_InviteFriendToChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_InviteFriendToChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_InviteFriendToChatRoomGroup_Request)

CChatRoom_InviteFriendToChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_InviteFriendToChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_InviteFriendToChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_InviteFriendToChatRoomGroup_Response)

CChatRoom_LeaveChatRoomGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_LeaveChatRoomGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_LEAVECHATROOMGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_LeaveChatRoomGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_LeaveChatRoomGroup_Request)

CChatRoom_LeaveChatRoomGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_LeaveChatRoomGroup_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_LEAVECHATROOMGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_LeaveChatRoomGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_LeaveChatRoomGroup_Response)

CChatRoom_CreateChatRoom_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateChatRoom_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATECHATROOM_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateChatRoom_Request)
  })
_sym_db.RegisterMessage(CChatRoom_CreateChatRoom_Request)

CChatRoom_CreateChatRoom_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateChatRoom_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATECHATROOM_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateChatRoom_Response)
  })
_sym_db.RegisterMessage(CChatRoom_CreateChatRoom_Response)

CChatRoom_DeleteChatRoom_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteChatRoom_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETECHATROOM_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteChatRoom_Request)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteChatRoom_Request)

CChatRoom_DeleteChatRoom_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteChatRoom_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETECHATROOM_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteChatRoom_Response)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteChatRoom_Response)

CChatRoom_RenameChatRoom_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameChatRoom_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMECHATROOM_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameChatRoom_Request)
  })
_sym_db.RegisterMessage(CChatRoom_RenameChatRoom_Request)

CChatRoom_RenameChatRoom_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_RenameChatRoom_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_RENAMECHATROOM_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_RenameChatRoom_Response)
  })
_sym_db.RegisterMessage(CChatRoom_RenameChatRoom_Response)

CChatRoom_ReorderChatRoom_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_ReorderChatRoom_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REORDERCHATROOM_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReorderChatRoom_Request)
  })
_sym_db.RegisterMessage(CChatRoom_ReorderChatRoom_Request)

CChatRoom_ReorderChatRoom_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_ReorderChatRoom_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_REORDERCHATROOM_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ReorderChatRoom_Response)
  })
_sym_db.RegisterMessage(CChatRoom_ReorderChatRoom_Response)

CChatRoom_SendChatMessage_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SendChatMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SENDCHATMESSAGE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SendChatMessage_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SendChatMessage_Request)

CChatRoom_SendChatMessage_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SendChatMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SENDCHATMESSAGE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SendChatMessage_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SendChatMessage_Response)

CChatRoom_JoinVoiceChat_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinVoiceChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINVOICECHAT_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinVoiceChat_Request)
  })
_sym_db.RegisterMessage(CChatRoom_JoinVoiceChat_Request)

CChatRoom_JoinVoiceChat_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_JoinVoiceChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_JOINVOICECHAT_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_JoinVoiceChat_Response)
  })
_sym_db.RegisterMessage(CChatRoom_JoinVoiceChat_Response)

CChatRoom_LeaveVoiceChat_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_LeaveVoiceChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_LEAVEVOICECHAT_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_LeaveVoiceChat_Request)
  })
_sym_db.RegisterMessage(CChatRoom_LeaveVoiceChat_Request)

CChatRoom_LeaveVoiceChat_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_LeaveVoiceChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_LEAVEVOICECHAT_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_LeaveVoiceChat_Response)
  })
_sym_db.RegisterMessage(CChatRoom_LeaveVoiceChat_Response)

CChatRoom_GetMessageHistory_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMessageHistory_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETMESSAGEHISTORY_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageHistory_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetMessageHistory_Request)

ServerMessage = _reflection.GeneratedProtocolMessageType('ServerMessage', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMESSAGE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:ServerMessage)
  })
_sym_db.RegisterMessage(ServerMessage)

CChatRoom_GetMessageHistory_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMessageHistory_Response', (_message.Message,), {

  'ChatMessage' : _reflection.GeneratedProtocolMessageType('ChatMessage', (_message.Message,), {

    'MessageReaction' : _reflection.GeneratedProtocolMessageType('MessageReaction', (_message.Message,), {
      'DESCRIPTOR' : _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION,
      '__module__' : 'steammessages_chat_pb2'
      # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction)
      })
    ,
    'DESCRIPTOR' : _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageHistory_Response.ChatMessage)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_GETMESSAGEHISTORY_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageHistory_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetMessageHistory_Response)
_sym_db.RegisterMessage(CChatRoom_GetMessageHistory_Response.ChatMessage)
_sym_db.RegisterMessage(CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction)

CChatRoom_GetMyChatRoomGroups_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMyChatRoomGroups_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETMYCHATROOMGROUPS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMyChatRoomGroups_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetMyChatRoomGroups_Request)

CChatRoom_GetChatRoomGroupSummary_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetChatRoomGroupSummary_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetChatRoomGroupSummary_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetChatRoomGroupSummary_Response)

CChatRoomSummaryPair = _reflection.GeneratedProtocolMessageType('CChatRoomSummaryPair', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMSUMMARYPAIR,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomSummaryPair)
  })
_sym_db.RegisterMessage(CChatRoomSummaryPair)

CChatRoom_GetMyChatRoomGroups_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMyChatRoomGroups_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMyChatRoomGroups_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetMyChatRoomGroups_Response)

CChatRoom_GetChatRoomGroupState_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetChatRoomGroupState_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetChatRoomGroupState_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetChatRoomGroupState_Request)

CChatRoom_GetChatRoomGroupState_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetChatRoomGroupState_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetChatRoomGroupState_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetChatRoomGroupState_Response)

CChatRoom_GetChatRoomGroupSummary_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetChatRoomGroupSummary_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETCHATROOMGROUPSUMMARY_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetChatRoomGroupSummary_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetChatRoomGroupSummary_Request)

CChatRoom_SetAppChatRoomGroupForceActive_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetAppChatRoomGroupForceActive_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetAppChatRoomGroupForceActive_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetAppChatRoomGroupForceActive_Request)

CChatRoom_SetAppChatRoomGroupForceActive_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetAppChatRoomGroupForceActive_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetAppChatRoomGroupForceActive_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetAppChatRoomGroupForceActive_Response)

CChatRoom_SetAppChatRoomGroupStopForceActive_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_SetAppChatRoomGroupStopForceActive_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetAppChatRoomGroupStopForceActive_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_SetAppChatRoomGroupStopForceActive_Notification)

CChatRoom_AckChatMessage_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_AckChatMessage_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_ACKCHATMESSAGE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_AckChatMessage_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_AckChatMessage_Notification)

CChatRoom_CreateInviteLink_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateInviteLink_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATEINVITELINK_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateInviteLink_Request)
  })
_sym_db.RegisterMessage(CChatRoom_CreateInviteLink_Request)

CChatRoom_CreateInviteLink_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_CreateInviteLink_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CREATEINVITELINK_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_CreateInviteLink_Response)
  })
_sym_db.RegisterMessage(CChatRoom_CreateInviteLink_Response)

CChatRoom_GetInviteLinkInfo_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteLinkInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITELINKINFO_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteLinkInfo_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteLinkInfo_Request)

CChatRoom_GetInviteLinkInfo_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteLinkInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITELINKINFO_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteLinkInfo_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteLinkInfo_Response)

CChatRoom_GetInviteInfo_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITEINFO_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteInfo_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteInfo_Request)

CChatRoom_GetInviteInfo_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITEINFO_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteInfo_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteInfo_Response)

CChatRoom_GetInviteLinksForGroup_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteLinksForGroup_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITELINKSFORGROUP_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteLinksForGroup_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteLinksForGroup_Request)

CChatRoom_GetInviteLinksForGroup_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteLinksForGroup_Response', (_message.Message,), {

  'LinkInfo' : _reflection.GeneratedProtocolMessageType('LinkInfo', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteLinksForGroup_Response.LinkInfo)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteLinksForGroup_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteLinksForGroup_Response)
_sym_db.RegisterMessage(CChatRoom_GetInviteLinksForGroup_Response.LinkInfo)

CChatRoom_GetBanList_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetBanList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETBANLIST_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetBanList_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetBanList_Request)

CChatRoom_GetBanList_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetBanList_Response', (_message.Message,), {

  'BanInfo' : _reflection.GeneratedProtocolMessageType('BanInfo', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_GETBANLIST_RESPONSE_BANINFO,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_GetBanList_Response.BanInfo)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_GETBANLIST_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetBanList_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetBanList_Response)
_sym_db.RegisterMessage(CChatRoom_GetBanList_Response.BanInfo)

CChatRoom_GetInviteList_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITELIST_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteList_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteList_Request)

CChatRoomGroupInvite = _reflection.GeneratedProtocolMessageType('CChatRoomGroupInvite', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMGROUPINVITE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomGroupInvite)
  })
_sym_db.RegisterMessage(CChatRoomGroupInvite)

CChatRoom_GetInviteList_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetInviteList_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETINVITELIST_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetInviteList_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetInviteList_Response)

CChatRoom_DeleteInviteLink_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteInviteLink_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEINVITELINK_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteInviteLink_Request)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteInviteLink_Request)

CChatRoom_DeleteInviteLink_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteInviteLink_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETEINVITELINK_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteInviteLink_Response)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteInviteLink_Response)

CChatRoom_SetSessionActiveChatRoomGroups_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetSessionActiveChatRoomGroups_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetSessionActiveChatRoomGroups_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetSessionActiveChatRoomGroups_Request)

CChatRoom_SetSessionActiveChatRoomGroups_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetSessionActiveChatRoomGroups_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetSessionActiveChatRoomGroups_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetSessionActiveChatRoomGroups_Response)

CChatRoom_SetUserChatGroupPreferences_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SetUserChatGroupPreferences_Request', (_message.Message,), {

  'ChatGroupPreferences' : _reflection.GeneratedProtocolMessageType('ChatGroupPreferences', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences)
    })
  ,

  'ChatRoomPreferences' : _reflection.GeneratedProtocolMessageType('ChatRoomPreferences', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetUserChatGroupPreferences_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SetUserChatGroupPreferences_Request)
_sym_db.RegisterMessage(CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences)
_sym_db.RegisterMessage(CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences)

CChatRoom_SetUserChatGroupPreferences_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SetUserChatGroupPreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SetUserChatGroupPreferences_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SetUserChatGroupPreferences_Response)

CChatRoom_DeleteChatMessages_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteChatMessages_Request', (_message.Message,), {

  'Message' : _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_DeleteChatMessages_Request.Message)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_DELETECHATMESSAGES_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteChatMessages_Request)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteChatMessages_Request)
_sym_db.RegisterMessage(CChatRoom_DeleteChatMessages_Request.Message)

CChatRoom_DeleteChatMessages_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_DeleteChatMessages_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_DELETECHATMESSAGES_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_DeleteChatMessages_Response)
  })
_sym_db.RegisterMessage(CChatRoom_DeleteChatMessages_Response)

CChatRoom_UpdateMemberListView_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_UpdateMemberListView_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_UpdateMemberListView_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_UpdateMemberListView_Notification)

CChatRoom_SearchMembers_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_SearchMembers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_SEARCHMEMBERS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SearchMembers_Request)
  })
_sym_db.RegisterMessage(CChatRoom_SearchMembers_Request)

CChatRoom_SearchMembers_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_SearchMembers_Response', (_message.Message,), {

  'MemberMatch' : _reflection.GeneratedProtocolMessageType('MemberMatch', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_SearchMembers_Response.MemberMatch)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_SEARCHMEMBERS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_SearchMembers_Response)
  })
_sym_db.RegisterMessage(CChatRoom_SearchMembers_Response)
_sym_db.RegisterMessage(CChatRoom_SearchMembers_Response.MemberMatch)

CChatRoom_UpdateMessageReaction_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_UpdateMessageReaction_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_UPDATEMESSAGEREACTION_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_UpdateMessageReaction_Request)
  })
_sym_db.RegisterMessage(CChatRoom_UpdateMessageReaction_Request)

CChatRoom_UpdateMessageReaction_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_UpdateMessageReaction_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_UpdateMessageReaction_Response)
  })
_sym_db.RegisterMessage(CChatRoom_UpdateMessageReaction_Response)

CChatRoom_GetMessageReactionReactors_Request = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMessageReactionReactors_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageReactionReactors_Request)
  })
_sym_db.RegisterMessage(CChatRoom_GetMessageReactionReactors_Request)

CChatRoom_GetMessageReactionReactors_Response = _reflection.GeneratedProtocolMessageType('CChatRoom_GetMessageReactionReactors_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_GetMessageReactionReactors_Response)
  })
_sym_db.RegisterMessage(CChatRoom_GetMessageReactionReactors_Response)

CClanChatRooms_GetClanChatRoomInfo_Request = _reflection.GeneratedProtocolMessageType('CClanChatRooms_GetClanChatRoomInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CClanChatRooms_GetClanChatRoomInfo_Request)
  })
_sym_db.RegisterMessage(CClanChatRooms_GetClanChatRoomInfo_Request)

CClanChatRooms_GetClanChatRoomInfo_Response = _reflection.GeneratedProtocolMessageType('CClanChatRooms_GetClanChatRoomInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CClanChatRooms_GetClanChatRoomInfo_Response)
  })
_sym_db.RegisterMessage(CClanChatRooms_GetClanChatRoomInfo_Response)

CClanChatRooms_SetClanChatRoomPrivate_Request = _reflection.GeneratedProtocolMessageType('CClanChatRooms_SetClanChatRoomPrivate_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CClanChatRooms_SetClanChatRoomPrivate_Request)
  })
_sym_db.RegisterMessage(CClanChatRooms_SetClanChatRoomPrivate_Request)

CClanChatRooms_SetClanChatRoomPrivate_Response = _reflection.GeneratedProtocolMessageType('CClanChatRooms_SetClanChatRoomPrivate_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CClanChatRooms_SetClanChatRoomPrivate_Response)
  })
_sym_db.RegisterMessage(CClanChatRooms_SetClanChatRoomPrivate_Response)

CChatMentions = _reflection.GeneratedProtocolMessageType('CChatMentions', (_message.Message,), {
  'DESCRIPTOR' : _CCHATMENTIONS,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatMentions)
  })
_sym_db.RegisterMessage(CChatMentions)

CChatRoom_IncomingChatMessage_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_IncomingChatMessage_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_IncomingChatMessage_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_IncomingChatMessage_Notification)

CChatRoom_ChatMessageModified_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_ChatMessageModified_Notification', (_message.Message,), {

  'ChatMessage' : _reflection.GeneratedProtocolMessageType('ChatMessage', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoom_ChatMessageModified_Notification.ChatMessage)
    })
  ,
  'DESCRIPTOR' : _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ChatMessageModified_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_ChatMessageModified_Notification)
_sym_db.RegisterMessage(CChatRoom_ChatMessageModified_Notification.ChatMessage)

CChatRoom_MemberStateChange_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_MemberStateChange_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_MemberStateChange_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_MemberStateChange_Notification)

CChatRoom_ChatRoomHeaderState_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_ChatRoomHeaderState_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ChatRoomHeaderState_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_ChatRoomHeaderState_Notification)

CChatRoom_ChatRoomGroupRoomsChange_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_ChatRoomGroupRoomsChange_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_ChatRoomGroupRoomsChange_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_ChatRoomGroupRoomsChange_Notification)

CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification)

ChatRoomClient_NotifyChatGroupUserStateChanged_Notification = _reflection.GeneratedProtocolMessageType('ChatRoomClient_NotifyChatGroupUserStateChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:ChatRoomClient_NotifyChatGroupUserStateChanged_Notification)
  })
_sym_db.RegisterMessage(ChatRoomClient_NotifyChatGroupUserStateChanged_Notification)

ChatRoomClient_NotifyChatRoomDisconnect_Notification = _reflection.GeneratedProtocolMessageType('ChatRoomClient_NotifyChatRoomDisconnect_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:ChatRoomClient_NotifyChatRoomDisconnect_Notification)
  })
_sym_db.RegisterMessage(ChatRoomClient_NotifyChatRoomDisconnect_Notification)

CChatRoomMemberListView = _reflection.GeneratedProtocolMessageType('CChatRoomMemberListView', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMMEMBERLISTVIEW,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomMemberListView)
  })
_sym_db.RegisterMessage(CChatRoomMemberListView)

CChatRoomMemberSummaryCounts = _reflection.GeneratedProtocolMessageType('CChatRoomMemberSummaryCounts', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOMMEMBERSUMMARYCOUNTS,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomMemberSummaryCounts)
  })
_sym_db.RegisterMessage(CChatRoomMemberSummaryCounts)

CChatRoomClient_MemberListViewUpdated_Notification = _reflection.GeneratedProtocolMessageType('CChatRoomClient_MemberListViewUpdated_Notification', (_message.Message,), {

  'MemberListViewEntry' : _reflection.GeneratedProtocolMessageType('MemberListViewEntry', (_message.Message,), {
    'DESCRIPTOR' : _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry)
    })
  ,
  'DESCRIPTOR' : _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoomClient_MemberListViewUpdated_Notification)
  })
_sym_db.RegisterMessage(CChatRoomClient_MemberListViewUpdated_Notification)
_sym_db.RegisterMessage(CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry)

CChatRoom_MessageReaction_Notification = _reflection.GeneratedProtocolMessageType('CChatRoom_MessageReaction_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATROOM_MESSAGEREACTION_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatRoom_MessageReaction_Notification)
  })
_sym_db.RegisterMessage(CChatRoom_MessageReaction_Notification)

CChatUsability_ClientUsabilityMetrics_Notification = _reflection.GeneratedProtocolMessageType('CChatUsability_ClientUsabilityMetrics_Notification', (_message.Message,), {

  'Settings' : _reflection.GeneratedProtocolMessageType('Settings', (_message.Message,), {
    'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification.Settings)
    })
  ,

  'VoiceSettings' : _reflection.GeneratedProtocolMessageType('VoiceSettings', (_message.Message,), {
    'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings)
    })
  ,

  'UIState' : _reflection.GeneratedProtocolMessageType('UIState', (_message.Message,), {

    'CategoryCollapseState' : _reflection.GeneratedProtocolMessageType('CategoryCollapseState', (_message.Message,), {
      'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE,
      '__module__' : 'steammessages_chat_pb2'
      # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState)
      })
    ,
    'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification.UIState)
    })
  ,

  'Metrics' : _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
    'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS,
    '__module__' : 'steammessages_chat_pb2'
    # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification.Metrics)
    })
  ,
  'DESCRIPTOR' : _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatUsability_ClientUsabilityMetrics_Notification)
  })
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification)
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification.Settings)
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings)
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification.UIState)
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState)
_sym_db.RegisterMessage(CChatUsability_ClientUsabilityMetrics_Notification.Metrics)

CChatUsability_RequestClientUsabilityMetrics_Notification = _reflection.GeneratedProtocolMessageType('CChatUsability_RequestClientUsabilityMetrics_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION,
  '__module__' : 'steammessages_chat_pb2'
  # @@protoc_insertion_point(class_scope:CChatUsability_RequestClientUsabilityMetrics_Notification)
  })
_sym_db.RegisterMessage(CChatUsability_RequestClientUsabilityMetrics_Notification)


DESCRIPTOR._options = None
_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST.fields_by_name['virtualize_members_threshold']._options = None
_CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION.fields_by_name['view_id']._options = None
_CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION.fields_by_name['client_changenumber']._options = None
_CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION.fields_by_name['delete_view']._options = None
_CCHATROOM_SEARCHMEMBERS_REQUEST.fields_by_name['search_id']._options = None
_CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST.fields_by_name['autocreate']._options = None
_CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION.fields_by_name['chat_name']._options = None
_CCHATROOMMEMBERLISTVIEW.fields_by_name['client_changenumber']._options = None
_CCHATROOMMEMBERLISTVIEW.fields_by_name['server_changenumber']._options = None
_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION.fields_by_name['view_id']._options = None

_CHAT = _descriptor.ServiceDescriptor(
  name='Chat',
  full_name='Chat',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\025Chat-related services',
  create_key=_descriptor._internal_create_key,
  serialized_start=22425,
  serialized_end=22692,
  methods=[
  _descriptor.MethodDescriptor(
    name='RequestFriendPersonaStates',
    full_name='Chat.RequestFriendPersonaStates',
    index=0,
    containing_service=None,
    input_type=_CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST,
    output_type=_CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE,
    serialized_options=b'\202\265\030nRequest to be notified of online friend persona state information.  Responses sent via CMsgClientPersonaState.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHAT)

DESCRIPTOR.services_by_name['Chat'] = _CHAT


_CHATROOM = _descriptor.ServiceDescriptor(
  name='ChatRoom',
  full_name='ChatRoom',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030>Service for joining, managing, and using multi-user chat rooms',
  create_key=_descriptor._internal_create_key,
  serialized_start=22695,
  serialized_end=30688,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateChatRoomGroup',
    full_name='ChatRoom.CreateChatRoomGroup',
    index=0,
    containing_service=None,
    input_type=_CCHATROOM_CREATECHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_CREATECHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\0307Create\'s a chat group that can contain other chat rooms',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveChatRoomGroup',
    full_name='ChatRoom.SaveChatRoomGroup',
    index=1,
    containing_service=None,
    input_type=_CCHATROOM_SAVECHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_SAVECHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030\024Saves\'s a chat group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RenameChatRoomGroup',
    full_name='ChatRoom.RenameChatRoomGroup',
    index=2,
    containing_service=None,
    input_type=_CCHATROOM_RENAMECHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_RENAMECHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030\030Rename a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetChatRoomGroupTagline',
    full_name='ChatRoom.SetChatRoomGroupTagline',
    index=3,
    containing_service=None,
    input_type=_CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST,
    output_type=_CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE,
    serialized_options=b'\202\265\030!Set tagline for a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetChatRoomGroupAvatar',
    full_name='ChatRoom.SetChatRoomGroupAvatar',
    index=4,
    containing_service=None,
    input_type=_CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST,
    output_type=_CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE,
    serialized_options=b'\202\265\030$Set avatar SHA for a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetChatRoomGroupWatchingBroadcast',
    full_name='ChatRoom.SetChatRoomGroupWatchingBroadcast',
    index=5,
    containing_service=None,
    input_type=_CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST,
    output_type=_CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE,
    serialized_options=b'\202\265\0305Sets a broadcast that the chat room group is watching',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinMiniGameForChatRoomGroup',
    full_name='ChatRoom.JoinMiniGameForChatRoomGroup',
    index=6,
    containing_service=None,
    input_type=_CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030\\Joins the minigame for the chat room group or starts a new one (Winter 2019 sale party game)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndMiniGameForChatRoomGroup',
    full_name='ChatRoom.EndMiniGameForChatRoomGroup',
    index=7,
    containing_service=None,
    input_type=_CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030(Ends the minigame in the chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MuteUserInGroup',
    full_name='ChatRoom.MuteUserInGroup',
    index=8,
    containing_service=None,
    input_type=_CCHATROOM_MUTEUSER_REQUEST,
    output_type=_CCHATROOM_MUTEUSER_RESPONSE,
    serialized_options=b'\202\265\030\022Mute user in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KickUserFromGroup',
    full_name='ChatRoom.KickUserFromGroup',
    index=9,
    containing_service=None,
    input_type=_CCHATROOM_KICKUSER_REQUEST,
    output_type=_CCHATROOM_KICKUSER_RESPONSE,
    serialized_options=b'\202\265\030\024Kick user from group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetUserBanState',
    full_name='ChatRoom.SetUserBanState',
    index=10,
    containing_service=None,
    input_type=_CCHATROOM_SETUSERBANSTATE_REQUEST,
    output_type=_CCHATROOM_SETUSERBANSTATE_RESPONSE,
    serialized_options=b'\202\265\030\031Ban/unban user from group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeInviteToGroup',
    full_name='ChatRoom.RevokeInviteToGroup',
    index=11,
    containing_service=None,
    input_type=_CCHATROOM_REVOKEINVITE_REQUEST,
    output_type=_CCHATROOM_REVOKEINVITE_RESPONSE,
    serialized_options=b'\202\265\030$Revoke a direct invitation of a user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRole',
    full_name='ChatRoom.CreateRole',
    index=12,
    containing_service=None,
    input_type=_CCHATROOM_CREATEROLE_REQUEST,
    output_type=_CCHATROOM_CREATEROLE_RESPONSE,
    serialized_options=b'\202\265\030\024Create role for goup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRoles',
    full_name='ChatRoom.GetRoles',
    index=13,
    containing_service=None,
    input_type=_CCHATROOM_GETROLES_REQUEST,
    output_type=_CCHATROOM_GETROLES_RESPONSE,
    serialized_options=b'\202\265\030\026Get all roles in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RenameRole',
    full_name='ChatRoom.RenameRole',
    index=14,
    containing_service=None,
    input_type=_CCHATROOM_RENAMEROLE_REQUEST,
    output_type=_CCHATROOM_RENAMEROLE_RESPONSE,
    serialized_options=b'\202\265\030\024Rename role for goup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReorderRole',
    full_name='ChatRoom.ReorderRole',
    index=15,
    containing_service=None,
    input_type=_CCHATROOM_REORDERROLE_REQUEST,
    output_type=_CCHATROOM_REORDERROLE_RESPONSE,
    serialized_options=b'\202\265\030\030Reorder role with a goup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRole',
    full_name='ChatRoom.DeleteRole',
    index=16,
    containing_service=None,
    input_type=_CCHATROOM_DELETEROLE_REQUEST,
    output_type=_CCHATROOM_DELETEROLE_RESPONSE,
    serialized_options=b'\202\265\030\026Delete role from group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRoleActions',
    full_name='ChatRoom.GetRoleActions',
    index=17,
    containing_service=None,
    input_type=_CCHATROOM_GETROLEACTIONS_REQUEST,
    output_type=_CCHATROOM_GETROLEACTIONS_RESPONSE,
    serialized_options=b'\202\265\030*Get all defined roles and actions in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReplaceRoleActions',
    full_name='ChatRoom.ReplaceRoleActions',
    index=18,
    containing_service=None,
    input_type=_CCHATROOM_REPLACEROLEACTIONS_REQUEST,
    output_type=_CCHATROOM_REPLACEROLEACTIONS_RESPONSE,
    serialized_options=b'\202\265\030\035Replace role actions in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddRoleToUser',
    full_name='ChatRoom.AddRoleToUser',
    index=19,
    containing_service=None,
    input_type=_CCHATROOM_ADDROLETOUSER_REQUEST,
    output_type=_CCHATROOM_ADDROLETOUSER_RESPONSE,
    serialized_options=b'\202\265\030\031Add role to user in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRolesForUser',
    full_name='ChatRoom.GetRolesForUser',
    index=20,
    containing_service=None,
    input_type=_CCHATROOM_GETROLESFORUSER_REQUEST,
    output_type=_CCHATROOM_GETROLESFORUSER_RESPONSE,
    serialized_options=b'\202\265\030\'Get all roles assigned to user in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRoleFromUser',
    full_name='ChatRoom.DeleteRoleFromUser',
    index=21,
    containing_service=None,
    input_type=_CCHATROOM_DELETEROLEFROMUSER_REQUEST,
    output_type=_CCHATROOM_DELETEROLEFROMUSER_RESPONSE,
    serialized_options=b'\202\265\030\036Delete role from user in group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinChatRoomGroup',
    full_name='ChatRoom.JoinChatRoomGroup',
    index=22,
    containing_service=None,
    input_type=_CCHATROOM_JOINCHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_JOINCHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030\033Join a multi-user chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InviteFriendToChatRoomGroup',
    full_name='ChatRoom.InviteFriendToChatRoomGroup',
    index=23,
    containing_service=None,
    input_type=_CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030)Invite a friend to a multi-user chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveChatRoomGroup',
    full_name='ChatRoom.LeaveChatRoomGroup',
    index=24,
    containing_service=None,
    input_type=_CCHATROOM_LEAVECHATROOMGROUP_REQUEST,
    output_type=_CCHATROOM_LEAVECHATROOMGROUP_RESPONSE,
    serialized_options=b'\202\265\030.Leaves a chat room group and all related chats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateChatRoom',
    full_name='ChatRoom.CreateChatRoom',
    index=25,
    containing_service=None,
    input_type=_CCHATROOM_CREATECHATROOM_REQUEST,
    output_type=_CCHATROOM_CREATECHATROOM_RESPONSE,
    serialized_options=b'\202\265\030,Creates a chat room inside a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteChatRoom',
    full_name='ChatRoom.DeleteChatRoom',
    index=26,
    containing_service=None,
    input_type=_CCHATROOM_DELETECHATROOM_REQUEST,
    output_type=_CCHATROOM_DELETECHATROOM_RESPONSE,
    serialized_options=b'\202\265\030,Deletes a chat room inside a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RenameChatRoom',
    full_name='ChatRoom.RenameChatRoom',
    index=27,
    containing_service=None,
    input_type=_CCHATROOM_RENAMECHATROOM_REQUEST,
    output_type=_CCHATROOM_RENAMECHATROOM_RESPONSE,
    serialized_options=b'\202\265\030,Renames a chat room inside a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReorderChatRoom',
    full_name='ChatRoom.ReorderChatRoom',
    index=28,
    containing_service=None,
    input_type=_CCHATROOM_REORDERCHATROOM_REQUEST,
    output_type=_CCHATROOM_REORDERCHATROOM_RESPONSE,
    serialized_options=b'\202\265\030-Reorders a chat room inside a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendChatMessage',
    full_name='ChatRoom.SendChatMessage',
    index=29,
    containing_service=None,
    input_type=_CCHATROOM_SENDCHATMESSAGE_REQUEST,
    output_type=_CCHATROOM_SENDCHATMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030-Send a chat message to a multi-user chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinVoiceChat',
    full_name='ChatRoom.JoinVoiceChat',
    index=30,
    containing_service=None,
    input_type=_CCHATROOM_JOINVOICECHAT_REQUEST,
    output_type=_CCHATROOM_JOINVOICECHAT_RESPONSE,
    serialized_options=b'\202\265\030MJoin the voice chat in a multi-room chat (should already be in the chat room)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveVoiceChat',
    full_name='ChatRoom.LeaveVoiceChat',
    index=31,
    containing_service=None,
    input_type=_CCHATROOM_LEAVEVOICECHAT_REQUEST,
    output_type=_CCHATROOM_LEAVEVOICECHAT_RESPONSE,
    serialized_options=b'\202\265\030)Leave the voice chat in a multi-room chat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMessageHistory',
    full_name='ChatRoom.GetMessageHistory',
    index=32,
    containing_service=None,
    input_type=_CCHATROOM_GETMESSAGEHISTORY_REQUEST,
    output_type=_CCHATROOM_GETMESSAGEHISTORY_RESPONSE,
    serialized_options=b'\202\265\030]Get the history of messages in a chat room.  You must currently be a member of the chat room.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMyChatRoomGroups',
    full_name='ChatRoom.GetMyChatRoomGroups',
    index=33,
    containing_service=None,
    input_type=_CCHATROOM_GETMYCHATROOMGROUPS_REQUEST,
    output_type=_CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE,
    serialized_options=b'\202\265\030\034Get a list of our chat rooms',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatRoomGroupState',
    full_name='ChatRoom.GetChatRoomGroupState',
    index=34,
    containing_service=None,
    input_type=_CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST,
    output_type=_CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE,
    serialized_options=b'\202\265\030(Get information about a single chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatRoomGroupSummary',
    full_name='ChatRoom.GetChatRoomGroupSummary',
    index=35,
    containing_service=None,
    input_type=_CCHATROOM_GETCHATROOMGROUPSUMMARY_REQUEST,
    output_type=_CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE,
    serialized_options=b'\202\265\030-Get basic information about a chat room group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAppChatRoomGroupForceActive',
    full_name='ChatRoom.SetAppChatRoomGroupForceActive',
    index=36,
    containing_service=None,
    input_type=_CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST,
    output_type=_CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE,
    serialized_options=b'\202\265\030FForce a group chat to be considered active on the server for this user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAppChatRoomGroupStopForceActive',
    full_name='ChatRoom.SetAppChatRoomGroupStopForceActive',
    index=37,
    containing_service=None,
    input_type=_CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030`If a group chat is forced active (see SetAppChatRoomGroupForceActive), decrement the force count',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AckChatMessage',
    full_name='ChatRoom.AckChatMessage',
    index=38,
    containing_service=None,
    input_type=_CCHATROOM_ACKCHATMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030DAcknowledge that we have seen the most recent chat message in a chat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateInviteLink',
    full_name='ChatRoom.CreateInviteLink',
    index=39,
    containing_service=None,
    input_type=_CCHATROOM_CREATEINVITELINK_REQUEST,
    output_type=_CCHATROOM_CREATEINVITELINK_RESPONSE,
    serialized_options=b'\202\265\030\036Creates a chatroom invite link',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInviteLinkInfo',
    full_name='ChatRoom.GetInviteLinkInfo',
    index=40,
    containing_service=None,
    input_type=_CCHATROOM_GETINVITELINKINFO_REQUEST,
    output_type=_CCHATROOM_GETINVITELINKINFO_RESPONSE,
    serialized_options=b'\202\265\030*Returns chat room info about provided link',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInviteInfo',
    full_name='ChatRoom.GetInviteInfo',
    index=41,
    containing_service=None,
    input_type=_CCHATROOM_GETINVITEINFO_REQUEST,
    output_type=_CCHATROOM_GETINVITEINFO_RESPONSE,
    serialized_options=b'\202\265\030PReturns chat room info about any invite involving the sender and passed group id',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInviteLinksForGroup',
    full_name='ChatRoom.GetInviteLinksForGroup',
    index=42,
    containing_service=None,
    input_type=_CCHATROOM_GETINVITELINKSFORGROUP_REQUEST,
    output_type=_CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE,
    serialized_options=b'\202\265\0300Returns all invite links for the specified group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBanList',
    full_name='ChatRoom.GetBanList',
    index=43,
    containing_service=None,
    input_type=_CCHATROOM_GETBANLIST_REQUEST,
    output_type=_CCHATROOM_GETBANLIST_RESPONSE,
    serialized_options=b'\202\265\030:Gets a list of users who have been banned from a chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInviteList',
    full_name='ChatRoom.GetInviteList',
    index=44,
    containing_service=None,
    input_type=_CCHATROOM_GETINVITELIST_REQUEST,
    output_type=_CCHATROOM_GETINVITELIST_RESPONSE,
    serialized_options=b'\202\265\0309Gets a list of users who have been invited to a chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteInviteLink',
    full_name='ChatRoom.DeleteInviteLink',
    index=45,
    containing_service=None,
    input_type=_CCHATROOM_DELETEINVITELINK_REQUEST,
    output_type=_CCHATROOM_DELETEINVITELINK_RESPONSE,
    serialized_options=b'\202\265\030\035Deletes specified invite link',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSessionActiveChatRoomGroups',
    full_name='ChatRoom.SetSessionActiveChatRoomGroups',
    index=46,
    containing_service=None,
    input_type=_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST,
    output_type=_CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE,
    serialized_options=b'\202\265\0307Set which chat rooms we are using in the active session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetUserChatGroupPreferences',
    full_name='ChatRoom.SetUserChatGroupPreferences',
    index=47,
    containing_service=None,
    input_type=_CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST,
    output_type=_CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\0305Set preferences around chat notifications for a group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteChatMessages',
    full_name='ChatRoom.DeleteChatMessages',
    index=48,
    containing_service=None,
    input_type=_CCHATROOM_DELETECHATMESSAGES_REQUEST,
    output_type=_CCHATROOM_DELETECHATMESSAGES_RESPONSE,
    serialized_options=b'\202\265\030\037Deletes specified chat messages',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMemberListView',
    full_name='ChatRoom.UpdateMemberListView',
    index=49,
    containing_service=None,
    input_type=_CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030CA client is indicating it has an active view into the members list.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchMembers',
    full_name='ChatRoom.SearchMembers',
    index=50,
    containing_service=None,
    input_type=_CCHATROOM_SEARCHMEMBERS_REQUEST,
    output_type=_CCHATROOM_SEARCHMEMBERS_RESPONSE,
    serialized_options=b'\202\265\030!Search chat room members by name.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMessageReaction',
    full_name='ChatRoom.UpdateMessageReaction',
    index=51,
    containing_service=None,
    input_type=_CCHATROOM_UPDATEMESSAGEREACTION_REQUEST,
    output_type=_CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE,
    serialized_options=b'\202\265\0303Adds/removes a reaction to/from a chat room message',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMessageReactionReactors',
    full_name='ChatRoom.GetMessageReactionReactors',
    index=52,
    containing_service=None,
    input_type=_CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST,
    output_type=_CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE,
    serialized_options=b'\202\265\0303Fetches a list of reactors for a specified reaction',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHATROOM)

DESCRIPTOR.services_by_name['ChatRoom'] = _CHATROOM


_CLANCHATROOMS = _descriptor.ServiceDescriptor(
  name='ClanChatRooms',
  full_name='ClanChatRooms',
  file=DESCRIPTOR,
  index=2,
  serialized_options=b'\202\265\030)Methods for getting clan chat information',
  create_key=_descriptor._internal_create_key,
  serialized_start=30691,
  serialized_end=31121,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetClanChatRoomInfo',
    full_name='ClanChatRooms.GetClanChatRoomInfo',
    index=0,
    containing_service=None,
    input_type=_CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST,
    output_type=_CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE,
    serialized_options=b'\202\265\030BGet a list of chat rooms for a clan, optionally creating a new one',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetClanChatRoomPrivate',
    full_name='ClanChatRooms.SetClanChatRoomPrivate',
    index=1,
    containing_service=None,
    input_type=_CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST,
    output_type=_CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE,
    serialized_options=b'\202\265\0303Set a clan chat room to be members only (or public)',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLANCHATROOMS)

DESCRIPTOR.services_by_name['ClanChatRooms'] = _CLANCHATROOMS


_CHATROOMCLIENT = _descriptor.ServiceDescriptor(
  name='ChatRoomClient',
  full_name='ChatRoomClient',
  file=DESCRIPTOR,
  index=3,
  serialized_options=b'\202\265\030$Client notifications for chat events\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=31124,
  serialized_end=33027,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyIncomingChatMessage',
    full_name='ChatRoomClient.NotifyIncomingChatMessage',
    index=0,
    containing_service=None,
    input_type=_CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 New chat message for a chat room',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyChatMessageModified',
    full_name='ChatRoomClient.NotifyChatMessageModified',
    index=1,
    containing_service=None,
    input_type=_CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0309An existing chat message has been modified on the backend',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyMemberStateChange',
    full_name='ChatRoomClient.NotifyMemberStateChange',
    index=2,
    containing_service=None,
    input_type=_CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030>A chat room member\'s state has changed (join/part/permissions)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyChatRoomHeaderStateChange',
    full_name='ChatRoomClient.NotifyChatRoomHeaderStateChange',
    index=3,
    containing_service=None,
    input_type=_CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030\'Chat Room header / metadata has changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyChatRoomGroupRoomsChange',
    full_name='ChatRoomClient.NotifyChatRoomGroupRoomsChange',
    index=4,
    containing_service=None,
    input_type=_CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ASomething about a chatroom group changed (created, deleted, etc.)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyShouldRejoinChatRoomVoiceChat',
    full_name='ChatRoomClient.NotifyShouldRejoinChatRoomVoiceChat',
    index=5,
    containing_service=None,
    input_type=_CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030`Voice chat was recreated or dropped on the backend and client needs to rejoin to remain in chat.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyChatGroupUserStateChanged',
    full_name='ChatRoomClient.NotifyChatGroupUserStateChanged',
    index=6,
    containing_service=None,
    input_type=_CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030AUser chat group state (preferences, ack state, etc) have changed.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyAckChatMessageEcho',
    full_name='ChatRoomClient.NotifyAckChatMessageEcho',
    index=7,
    containing_service=None,
    input_type=_CCHATROOM_ACKCHATMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030:A session acked an unread message, echo to other sessions.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyChatRoomDisconnect',
    full_name='ChatRoomClient.NotifyChatRoomDisconnect',
    index=8,
    containing_service=None,
    input_type=_CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030\207\001The ChatRoom server hosting the chat rooms has reconnected to the user\'s Chat server (may have restarted), client should refresh state.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyMemberListViewUpdated',
    full_name='ChatRoomClient.NotifyMemberListViewUpdated',
    index=9,
    containing_service=None,
    input_type=_CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030pThe list of members for a chat room with virtualized member list has changed on the server (or client requested)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyMessageReaction',
    full_name='ChatRoomClient.NotifyMessageReaction',
    index=10,
    containing_service=None,
    input_type=_CCHATROOM_MESSAGEREACTION_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030\024New message reaction',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHATROOMCLIENT)

DESCRIPTOR.services_by_name['ChatRoomClient'] = _CHATROOMCLIENT


_CHATUSABILITY = _descriptor.ServiceDescriptor(
  name='ChatUsability',
  full_name='ChatUsability',
  file=DESCRIPTOR,
  index=4,
  serialized_options=b'\202\265\030$Client notifications for chat events',
  create_key=_descriptor._internal_create_key,
  serialized_start=33030,
  serialized_end=33224,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyClientUsabilityMetrics',
    full_name='ChatUsability.NotifyClientUsabilityMetrics',
    index=0,
    containing_service=None,
    input_type=_CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 Incoming metrics from the client',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHATUSABILITY)

DESCRIPTOR.services_by_name['ChatUsability'] = _CHATUSABILITY


_CHATUSABILITYCLIENT = _descriptor.ServiceDescriptor(
  name='ChatUsabilityClient',
  full_name='ChatUsabilityClient',
  file=DESCRIPTOR,
  index=5,
  serialized_options=b'\202\265\030\'Client notifications for chat usability\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=33227,
  serialized_end=33453,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyRequestClientUsabilityMetrics',
    full_name='ChatUsabilityClient.NotifyRequestClientUsabilityMetrics',
    index=0,
    containing_service=None,
    input_type=_CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030%Request client send usability metrics',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHATUSABILITYCLIENT)

DESCRIPTOR.services_by_name['ChatUsabilityClient'] = _CHATUSABILITYCLIENT

Chat = service_reflection.GeneratedServiceType('Chat', (_service.Service,), dict(
  DESCRIPTOR = _CHAT,
  __module__ = 'steammessages_chat_pb2'
  ))

Chat_Stub = service_reflection.GeneratedServiceStubType('Chat_Stub', (Chat,), dict(
  DESCRIPTOR = _CHAT,
  __module__ = 'steammessages_chat_pb2'
  ))


ChatRoom = service_reflection.GeneratedServiceType('ChatRoom', (_service.Service,), dict(
  DESCRIPTOR = _CHATROOM,
  __module__ = 'steammessages_chat_pb2'
  ))

ChatRoom_Stub = service_reflection.GeneratedServiceStubType('ChatRoom_Stub', (ChatRoom,), dict(
  DESCRIPTOR = _CHATROOM,
  __module__ = 'steammessages_chat_pb2'
  ))


ClanChatRooms = service_reflection.GeneratedServiceType('ClanChatRooms', (_service.Service,), dict(
  DESCRIPTOR = _CLANCHATROOMS,
  __module__ = 'steammessages_chat_pb2'
  ))

ClanChatRooms_Stub = service_reflection.GeneratedServiceStubType('ClanChatRooms_Stub', (ClanChatRooms,), dict(
  DESCRIPTOR = _CLANCHATROOMS,
  __module__ = 'steammessages_chat_pb2'
  ))


ChatRoomClient = service_reflection.GeneratedServiceType('ChatRoomClient', (_service.Service,), dict(
  DESCRIPTOR = _CHATROOMCLIENT,
  __module__ = 'steammessages_chat_pb2'
  ))

ChatRoomClient_Stub = service_reflection.GeneratedServiceStubType('ChatRoomClient_Stub', (ChatRoomClient,), dict(
  DESCRIPTOR = _CHATROOMCLIENT,
  __module__ = 'steammessages_chat_pb2'
  ))


ChatUsability = service_reflection.GeneratedServiceType('ChatUsability', (_service.Service,), dict(
  DESCRIPTOR = _CHATUSABILITY,
  __module__ = 'steammessages_chat_pb2'
  ))

ChatUsability_Stub = service_reflection.GeneratedServiceStubType('ChatUsability_Stub', (ChatUsability,), dict(
  DESCRIPTOR = _CHATUSABILITY,
  __module__ = 'steammessages_chat_pb2'
  ))


ChatUsabilityClient = service_reflection.GeneratedServiceType('ChatUsabilityClient', (_service.Service,), dict(
  DESCRIPTOR = _CHATUSABILITYCLIENT,
  __module__ = 'steammessages_chat_pb2'
  ))

ChatUsabilityClient_Stub = service_reflection.GeneratedServiceStubType('ChatUsabilityClient_Stub', (ChatUsabilityClient,), dict(
  DESCRIPTOR = _CHATUSABILITYCLIENT,
  __module__ = 'steammessages_chat_pb2'
  ))


# @@protoc_insertion_point(module_scope)
