# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_player.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_player.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asteammessages_player.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"4\n2CPlayer_GetMutualFriendsForIncomingInvites_Request\"\\\n&CPlayer_IncomingInviteMutualFriendList\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12!\n\x19mutual_friend_account_ids\x18\x02 \x03(\r\"\x8c\x01\n3CPlayer_GetMutualFriendsForIncomingInvites_Response\x12U\n$incoming_invite_mutual_friends_lists\x18\x01 \x03(\x0b\x32\'.CPlayer_IncomingInviteMutualFriendList\"\x94\x06\n\x1d\x43Player_GetOwnedGames_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x04\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\\\n\x0finclude_appinfo\x18\x02 \x01(\x08\x42\x43\x82\xb5\x18?true if we want additional details (name, icon) about each game\x12\x8c\x01\n\x19include_played_free_games\x18\x03 \x01(\x08\x42i\x82\xb5\x18\x65\x46ree games are excluded by default.  If this is set, free games the user has played will be returned.\x12M\n\rappids_filter\x18\x04 \x03(\rB6\x82\xb5\x18\x32if set, restricts result set to the passed in apps\x12\\\n\x10include_free_sub\x18\x05 \x01(\x08\x42\x42\x82\xb5\x18>Some games are in the free sub, which are excluded by default.\x12\x46\n\x12skip_unvetted_apps\x18\x06 \x01(\x08:\x04trueB$\x82\xb5\x18 if set, skip unvetted store apps\x12:\n\x08language\x18\x07 \x01(\tB(\x82\xb5\x18$Will return appinfo in this language\x12\xa0\x01\n\x18include_extended_appinfo\x18\x08 \x01(\x08\x42~\x82\xb5\x18ztrue if we want even more details (capsule, sortas, and capabilities) about each game.  include_appinfo must also be true.\"\xde\x03\n\x1e\x43Player_GetOwnedGames_Response\x12\x12\n\ngame_count\x18\x01 \x01(\r\x12\x33\n\x05games\x18\x02 \x03(\x0b\x32$.CPlayer_GetOwnedGames_Response.Game\x1a\xf2\x02\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fplaytime_2weeks\x18\x03 \x01(\x05\x12\x18\n\x10playtime_forever\x18\x04 \x01(\x05\x12\x14\n\x0cimg_icon_url\x18\x05 \x01(\t\x12#\n\x1bhas_community_visible_stats\x18\x07 \x01(\x08\x12 \n\x18playtime_windows_forever\x18\x08 \x01(\x05\x12\x1c\n\x14playtime_mac_forever\x18\t \x01(\x05\x12\x1e\n\x16playtime_linux_forever\x18\n \x01(\x05\x12\x19\n\x11rtime_last_played\x18\x0b \x01(\r\x12\x18\n\x10\x63\x61psule_filename\x18\x0c \x01(\t\x12\x0f\n\x07sort_as\x18\r \x01(\t\x12\x14\n\x0chas_workshop\x18\x0e \x01(\x08\x12\x12\n\nhas_market\x18\x0f \x01(\x08\x12\x0f\n\x07has_dlc\x18\x10 \x01(\x08\"M\n\x1b\x43Player_GetPlayNext_Request\x12\x17\n\x0fmax_age_seconds\x18\x01 \x01(\r\x12\x15\n\rignore_appids\x18\x02 \x03(\r\"H\n\x1c\x43Player_GetPlayNext_Response\x12\x18\n\x10last_update_time\x18\x01 \x01(\r\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"7\n&CPlayer_GetFriendsGameplayInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xee\x05\n\'CPlayer_GetFriendsGameplayInfo_Response\x12K\n\tyour_info\x18\x01 \x01(\x0b\x32\x38.CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo\x12M\n\x07in_game\x18\x02 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12U\n\x0fplayed_recently\x18\x03 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12Q\n\x0bplayed_ever\x18\x04 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12J\n\x04owns\x18\x05 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12Q\n\x0bin_wishlist\x18\x06 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x1a^\n\x13\x46riendsGameplayInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x16\n\x0eminutes_played\x18\x02 \x01(\r\x12\x1e\n\x16minutes_played_forever\x18\x03 \x01(\r\x1a~\n\x0fOwnGameplayInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x16\n\x0eminutes_played\x18\x02 \x01(\r\x12\x1e\n\x16minutes_played_forever\x18\x03 \x01(\r\x12\x13\n\x0bin_wishlist\x18\x04 \x01(\x08\x12\r\n\x05owned\x18\x05 \x01(\x08\"3\n\"CPlayer_GetGameBadgeLevels_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xb5\x01\n#CPlayer_GetGameBadgeLevels_Response\x12\x14\n\x0cplayer_level\x18\x01 \x01(\r\x12:\n\x06\x62\x61\x64ges\x18\x02 \x03(\x0b\x32*.CPlayer_GetGameBadgeLevels_Response.Badge\x1a<\n\x05\x42\x61\x64ge\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x0e\n\x06series\x18\x02 \x01(\x05\x12\x14\n\x0c\x62order_color\x18\x03 \x01(\r\"l\n$CPlayer_GetProfileBackground_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x10\n\x08language\x18\x02 \x01(\t\"\xe9\x04\n\x0bProfileItem\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\x42\n\x0bimage_small\x18\x02 \x01(\tB-\x82\xb5\x18)small image used in backpack or selection\x12)\n\x0bimage_large\x18\x03 \x01(\tB\x14\x82\xb5\x18\x10the image itself\x12\x1e\n\x04name\x18\x04 \x01(\tB\x10\x82\xb5\x18\x0c\x65nglish name\x12\'\n\nitem_title\x18\x05 \x01(\tB\x13\x82\xb5\x18\x0flocalized title\x12\x33\n\x10item_description\x18\x06 \x01(\tB\x19\x82\xb5\x18\x15localized description\x12\r\n\x05\x61ppid\x18\x07 \x01(\r\x12\x11\n\titem_type\x18\x08 \x01(\r\x12\x12\n\nitem_class\x18\t \x01(\r\x12+\n\nmovie_webm\x18\n \x01(\tB\x17\x82\xb5\x18\x13URL to webm, if any\x12)\n\tmovie_mp4\x18\x0b \x01(\tB\x16\x82\xb5\x18\x12URL to mp4, if any\x12\x37\n\x10movie_webm_small\x18\r \x01(\tB\x1d\x82\xb5\x18\x19URL to small webm, if any\x12\x35\n\x0fmovie_mp4_small\x18\x0e \x01(\tB\x1c\x82\xb5\x18\x18URL to small mp4, if any\x12V\n\x0e\x65quipped_flags\x18\x0c \x01(\rB>\x82\xb5\x18:Special flags set when equipped (EProfileItemEquippedFlag)\"Q\n%CPlayer_GetProfileBackground_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"?\n$CPlayer_SetProfileBackground_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"\'\n%CPlayer_SetProfileBackground_Response\"p\n(CPlayer_GetMiniProfileBackground_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x10\n\x08language\x18\x02 \x01(\t\"U\n)CPlayer_GetMiniProfileBackground_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"C\n(CPlayer_SetMiniProfileBackground_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"+\n)CPlayer_SetMiniProfileBackground_Response\"f\n\x1e\x43Player_GetAvatarFrame_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x10\n\x08language\x18\x02 \x01(\t\"E\n\x1f\x43Player_GetAvatarFrame_Response\x12\"\n\x0c\x61vatar_frame\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"9\n\x1e\x43Player_SetAvatarFrame_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"!\n\x1f\x43Player_SetAvatarFrame_Response\"i\n!CPlayer_GetAnimatedAvatar_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x10\n\x08language\x18\x02 \x01(\t\"B\n\"CPlayer_GetAnimatedAvatar_Response\x12\x1c\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"<\n!CPlayer_SetAnimatedAvatar_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"$\n\"CPlayer_SetAnimatedAvatar_Response\"p\n(CPlayer_GetSteamDeckKeyboardSkin_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x10\n\x08language\x18\x02 \x01(\t\"[\n)CPlayer_GetSteamDeckKeyboardSkin_Response\x12.\n\x18steam_deck_keyboard_skin\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"C\n(CPlayer_SetSteamDeckKeyboardSkin_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"+\n)CPlayer_SetSteamDeckKeyboardSkin_Response\"_\n$CPlayer_GetProfileItemsOwned_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12%\n\x07\x66ilters\x18\x02 \x03(\x0e\x32\x14.ECommunityItemClass\"\xa9\x02\n%CPlayer_GetProfileItemsOwned_Response\x12)\n\x13profile_backgrounds\x18\x01 \x03(\x0b\x32\x0c.ProfileItem\x12.\n\x18mini_profile_backgrounds\x18\x02 \x03(\x0b\x32\x0c.ProfileItem\x12#\n\ravatar_frames\x18\x03 \x03(\x0b\x32\x0c.ProfileItem\x12&\n\x10\x61nimated_avatars\x18\x04 \x03(\x0b\x32\x0c.ProfileItem\x12\'\n\x11profile_modifiers\x18\x05 \x03(\x0b\x32\x0c.ProfileItem\x12/\n\x19steam_deck_keyboard_skins\x18\x06 \x03(\x0b\x32\x0c.ProfileItem\"L\n\'CPlayer_GetProfileItemsEquipped_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"\xa6\x02\n(CPlayer_GetProfileItemsEquipped_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\x12-\n\x17mini_profile_background\x18\x02 \x01(\x0b\x32\x0c.ProfileItem\x12\"\n\x0c\x61vatar_frame\x18\x03 \x01(\x0b\x32\x0c.ProfileItem\x12%\n\x0f\x61nimated_avatar\x18\x04 \x01(\x0b\x32\x0c.ProfileItem\x12&\n\x10profile_modifier\x18\x05 \x01(\x0b\x32\x0c.ProfileItem\x12.\n\x18steam_deck_keyboard_skin\x18\x06 \x01(\x0b\x32\x0c.ProfileItem\"z\n+CPlayer_SetEquippedProfileItemFlags_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\x32\n\x05\x66lags\x18\x02 \x01(\rB#\x82\xb5\x18\x1fSet of EProfileItemEquippedFlag\".\n,CPlayer_SetEquippedProfileItemFlags_Response\"!\n\x1f\x43Player_GetEmoticonList_Request\"\xdb\x01\n CPlayer_GetEmoticonList_Response\x12=\n\temoticons\x18\x01 \x03(\x0b\x32*.CPlayer_GetEmoticonList_Response.Emoticon\x1ax\n\x08\x45moticon\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x16\n\x0etime_last_used\x18\x03 \x01(\r\x12\x11\n\tuse_count\x18\x04 \x01(\r\x12\x15\n\rtime_received\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\"\\\n\'CPlayer_GetAchievementsProgress_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0e\n\x06\x61ppids\x18\x03 \x03(\r\"\x8d\x02\n(CPlayer_GetAchievementsProgress_Response\x12[\n\x14\x61\x63hievement_progress\x18\x01 \x03(\x0b\x32=.CPlayer_GetAchievementsProgress_Response.AchievementProgress\x1a\x83\x01\n\x13\x41\x63hievementProgress\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08unlocked\x18\x02 \x01(\r\x12\r\n\x05total\x18\x03 \x01(\r\x12\x12\n\npercentage\x18\x04 \x01(\x02\x12\x14\n\x0c\x61ll_unlocked\x18\x05 \x01(\x08\x12\x12\n\ncache_time\x18\x06 \x01(\r\"3\n CPlayer_GetFavoriteBadge_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\"\xb0\x01\n!CPlayer_GetFavoriteBadge_Response\x12\x1a\n\x12has_favorite_badge\x18\x01 \x01(\x08\x12\x0f\n\x07\x62\x61\x64geid\x18\x02 \x01(\r\x12\x17\n\x0f\x63ommunityitemid\x18\x03 \x01(\x04\x12\x11\n\titem_type\x18\x04 \x01(\r\x12\x14\n\x0c\x62order_color\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\x12\r\n\x05level\x18\x07 \x01(\r\"L\n CPlayer_SetFavoriteBadge_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61\x64geid\x18\x02 \x01(\r\"#\n!CPlayer_SetFavoriteBadge_Response\"\x8d\x01\n\'CPlayer_GetProfileCustomization_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\'\n\x1finclude_inactive_customizations\x18\x02 \x01(\x08\x12(\n include_purchased_customizations\x18\x03 \x01(\x08\"\xdd\x02\n\x18ProfileCustomizationSlot\x12\x0c\n\x04slot\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x03 \x01(\x04\x12\x14\n\x0citem_assetid\x18\x04 \x01(\x04\x12\x16\n\x0eitem_contextid\x18\x05 \x01(\x04\x12\r\n\x05notes\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x11\n\taccountid\x18\x08 \x01(\r\x12\x0f\n\x07\x62\x61\x64geid\x18\t \x01(\r\x12\x14\n\x0c\x62order_color\x18\n \x01(\r\x12\x14\n\x0citem_classid\x18\x0b \x01(\x04\x12\x17\n\x0fitem_instanceid\x18\x0c \x01(\x04\x12V\n\x10\x62\x61n_check_result\x18\r \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\"\xbd\x02\n\x14ProfileCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05large\x18\x02 \x01(\x08\x12(\n\x05slots\x18\x03 \x03(\x0b\x32\x19.ProfileCustomizationSlot\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12]\n\x13\x63ustomization_style\x18\x05 \x01(\x0e\x32\x1b.EProfileCustomizationStyle:#k_EProfileCustomizationStyleDefault\x12\x12\n\npurchaseid\x18\x06 \x01(\x04\x12\r\n\x05level\x18\x07 \x01(\r\"/\n\x0cProfileTheme\x12\x10\n\x08theme_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"1\n\x12ProfilePreferences\x12\x1b\n\x13hide_profile_awards\x18\x01 \x01(\x08\"\xc8\x03\n(CPlayer_GetProfileCustomization_Response\x12-\n\x0e\x63ustomizations\x18\x01 \x03(\x0b\x32\x15.ProfileCustomization\x12\x17\n\x0fslots_available\x18\x02 \x01(\r\x12$\n\rprofile_theme\x18\x03 \x01(\x0b\x32\r.ProfileTheme\x12\x62\n\x18purchased_customizations\x18\x04 \x03(\x0b\x32@.CPlayer_GetProfileCustomization_Response.PurchasedCustomization\x12\x30\n\x13profile_preferences\x18\x05 \x01(\x0b\x32\x13.ProfilePreferences\x1a\x97\x01\n\x16PurchasedCustomization\x12\x12\n\npurchaseid\x18\x01 \x01(\x04\x12Z\n\x12\x63ustomization_type\x18\x02 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05level\x18\x03 \x01(\r\"D\n1CPlayer_GetPurchasedProfileCustomizations_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xad\x02\n2CPlayer_GetPurchasedProfileCustomizations_Response\x12l\n\x18purchased_customizations\x18\x01 \x03(\x0b\x32J.CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization\x1a\x88\x01\n\x16PurchasedCustomization\x12\x12\n\npurchaseid\x18\x01 \x01(\x04\x12Z\n\x12\x63ustomization_type\x18\x02 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\"O\n<CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xba\x04\n=CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response\x12w\n\x18purchased_customizations\x18\x01 \x03(\x0b\x32U.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization\x12u\n\x17upgraded_customizations\x18\x02 \x03(\x0b\x32T.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization\x1a\x83\x01\n\x16PurchasedCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a\x82\x01\n\x15UpgradedCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05level\x18\x02 \x01(\r\"+\n)CPlayer_GetProfileThemesAvailable_Request\"S\n*CPlayer_GetProfileThemesAvailable_Response\x12%\n\x0eprofile_themes\x18\x01 \x03(\x0b\x32\r.ProfileTheme\"3\n\x1f\x43Player_SetProfileTheme_Request\x12\x10\n\x08theme_id\x18\x01 \x01(\t\"\"\n CPlayer_SetProfileTheme_Response\"Y\n%CPlayer_SetProfilePreferences_Request\x12\x30\n\x13profile_preferences\x18\x01 \x01(\x0b\x32\x13.ProfilePreferences\"(\n&CPlayer_SetProfilePreferences_Response\"I\n#CPlayer_PostStatusToFriends_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0bstatus_text\x18\x02 \x01(\t\"&\n$CPlayer_PostStatusToFriends_Response\"e\n\x1f\x43Player_GetPostedStatus_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x04\x42!\x82\xb5\x18\x1dThe player we\'re asking about\x12\x0e\n\x06postid\x18\x02 \x01(\x04\"z\n CPlayer_GetPostedStatus_Response\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06postid\x18\x02 \x01(\x04\x12\x13\n\x0bstatus_text\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\"4\n\"CPlayer_DeletePostedStatus_Request\x12\x0e\n\x06postid\x18\x01 \x01(\x04\"%\n#CPlayer_DeletePostedStatus_Response\"\x82\x01\n\"CPlayer_GetLastPlayedTimes_Request\x12\\\n\x0fmin_last_played\x18\x01 \x01(\rBC\x82\xb5\x18?The most recent last-played time the client already knows about\"\xea\x03\n#CPlayer_GetLastPlayedTimes_Response\x12\x38\n\x05games\x18\x01 \x03(\x0b\x32).CPlayer_GetLastPlayedTimes_Response.Game\x1a\x88\x03\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x15\n\rlast_playtime\x18\x02 \x01(\r\x12\x17\n\x0fplaytime_2weeks\x18\x03 \x01(\x05\x12\x18\n\x10playtime_forever\x18\x04 \x01(\x05\x12\x16\n\x0e\x66irst_playtime\x18\x05 \x01(\r\x12 \n\x18playtime_windows_forever\x18\x06 \x01(\x05\x12\x1c\n\x14playtime_mac_forever\x18\x07 \x01(\x05\x12\x1e\n\x16playtime_linux_forever\x18\x08 \x01(\x05\x12\x1e\n\x16\x66irst_windows_playtime\x18\t \x01(\r\x12\x1a\n\x12\x66irst_mac_playtime\x18\n \x01(\r\x12\x1c\n\x14\x66irst_linux_playtime\x18\x0b \x01(\r\x12\x1d\n\x15last_windows_playtime\x18\x0c \x01(\r\x12\x19\n\x11last_mac_playtime\x18\r \x01(\r\x12\x1b\n\x13last_linux_playtime\x18\x0e \x01(\r\"$\n\"CPlayer_GetTimeSSAAccepted_Request\"z\n#CPlayer_GetTimeSSAAccepted_Response\x12\x19\n\x11time_ssa_accepted\x18\x01 \x01(\r\x12\x18\n\x10time_ssa_updated\x18\x02 \x01(\r\x12\x1e\n\x16time_chinassa_accepted\x18\x03 \x01(\r\"w\n\x19\x43Player_AcceptSSA_Request\x12\x41\n\x0e\x61greement_type\x18\x01 \x01(\x0e\x32\x0f.EAgreementType:\x18k_EAgreementType_Invalid\x12\x17\n\x0ftime_signed_utc\x18\x02 \x01(\r\"\x1c\n\x1a\x43Player_AcceptSSA_Response\"!\n\x1f\x43Player_GetNicknameList_Request\"\x9e\x01\n CPlayer_GetNicknameList_Response\x12\x43\n\tnicknames\x18\x01 \x03(\x0b\x32\x30.CPlayer_GetNicknameList_Response.PlayerNickname\x1a\x35\n\x0ePlayerNickname\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\")\n\'CPlayer_GetPerFriendPreferences_Request\"\xd1\x05\n\x14PerFriendPreferences\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12_\n\x18notifications_showingame\x18\x03 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12_\n\x18notifications_showonline\x18\x04 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12\x61\n\x1anotifications_showmessages\x18\x05 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12X\n\x11sounds_showingame\x18\x06 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12X\n\x11sounds_showonline\x18\x07 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12Z\n\x13sounds_showmessages\x18\x08 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12_\n\x18notifications_sendmobile\x18\t \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\"V\n(CPlayer_GetPerFriendPreferences_Response\x12*\n\x0bpreferences\x18\x01 \x03(\x0b\x32\x15.PerFriendPreferences\"U\n\'CPlayer_SetPerFriendPreferences_Request\x12*\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x15.PerFriendPreferences\"*\n(CPlayer_SetPerFriendPreferences_Response\"c\n\x19\x43Player_AddFriend_Request\x12\x46\n\x07steamid\x18\x01 \x01(\x06\x42\x35\x82\xb5\x18\x31Steam ID of user to whom to send a friend invite.\"\x86\x02\n\x1a\x43Player_AddFriend_Response\x12O\n\x0binvite_sent\x18\x01 \x01(\x08\x42:\x82\xb5\x18\x36True if the operation was successful, false otherwise.\x12\x86\x01\n\x13\x66riend_relationship\x18\x02 \x01(\rBi\x82\xb5\x18\x65the resulting relationship.  Depending on state, may move directly to friends rather than invite sent\x12\x0e\n\x06result\x18\x03 \x01(\x05\"R\n\x1c\x43Player_RemoveFriend_Request\x12\x32\n\x07steamid\x18\x01 \x01(\x06\x42!\x82\xb5\x18\x1dSteam ID of friend to remove.\"\\\n\x1d\x43Player_RemoveFriend_Response\x12;\n\x13\x66riend_relationship\x18\x01 \x01(\rB\x1e\x82\xb5\x18\x1athe resulting relationship\"\x7f\n\x1c\x43Player_IgnoreFriend_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12N\n\x08unignore\x18\x02 \x01(\x08\x42<\x82\xb5\x18\x38If set, remove from ignore/block list instead of adding \"\\\n\x1d\x43Player_IgnoreFriend_Response\x12;\n\x13\x66riend_relationship\x18\x01 \x01(\rB\x1e\x82\xb5\x18\x1athe resulting relationship\")\n\'CPlayer_GetCommunityPreferences_Request\"\xd7\x02\n\x1c\x43Player_CommunityPreferences\x12)\n\x1bhide_adult_content_violence\x18\x01 \x01(\x08:\x04true\x12$\n\x16hide_adult_content_sex\x18\x02 \x01(\x08:\x04true\x12%\n\x16parenthesize_nicknames\x18\x04 \x01(\x08:\x05\x66\x61lse\x12V\n\x13text_filter_setting\x18\x05 \x01(\x0e\x32\x13.ETextFilterSetting:$k_ETextFilterSettingSteamLabOptedOut\x12(\n\x1atext_filter_ignore_friends\x18\x06 \x01(\x08:\x04true\x12\"\n\x1atext_filter_words_revision\x18\x07 \x01(\r\x12\x19\n\x11timestamp_updated\x18\x03 \x01(\r\"^\n(CPlayer_GetCommunityPreferences_Response\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\"]\n\'CPlayer_SetCommunityPreferences_Request\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\"*\n(CPlayer_SetCommunityPreferences_Response\"$\n\"CPlayer_GetTextFilterWords_Request\"\x8e\x01\n\x17\x43Player_TextFilterWords\x12\'\n\x1ftext_filter_custom_banned_words\x18\x01 \x03(\t\x12&\n\x1etext_filter_custom_clean_words\x18\x02 \x03(\t\x12\"\n\x1atext_filter_words_revision\x18\x03 \x01(\r\"N\n#CPlayer_GetTextFilterWords_Response\x12\'\n\x05words\x18\x01 \x01(\x0b\x32\x18.CPlayer_TextFilterWords\"@\n,CPlayer_GetNewSteamAnnouncementState_Request\x12\x10\n\x08language\x18\x01 \x01(\x05\"\xa6\x01\n-CPlayer_GetNewSteamAnnouncementState_Response\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x1d\n\x15\x61nnouncement_headline\x18\x02 \x01(\t\x12\x18\n\x10\x61nnouncement_url\x18\x03 \x01(\t\x12\x13\n\x0btime_posted\x18\x04 \x01(\r\x12\x18\n\x10\x61nnouncement_gid\x18\x05 \x01(\x04\"`\n/CPlayer_UpdateSteamAnnouncementLastRead_Request\x12\x18\n\x10\x61nnouncement_gid\x18\x01 \x01(\x04\x12\x13\n\x0btime_posted\x18\x02 \x01(\r\"2\n0CPlayer_UpdateSteamAnnouncementLastRead_Response\"$\n\"CPlayer_GetPrivacySettings_Request\"\xcc\x01\n\x10\x43PrivacySettings\x12\x15\n\rprivacy_state\x18\x01 \x01(\x05\x12\x1f\n\x17privacy_state_inventory\x18\x02 \x01(\x05\x12\x1b\n\x13privacy_state_gifts\x18\x03 \x01(\x05\x12 \n\x18privacy_state_ownedgames\x18\x04 \x01(\x05\x12\x1e\n\x16privacy_state_playtime\x18\x05 \x01(\x05\x12!\n\x19privacy_state_friendslist\x18\x06 \x01(\x05\"R\n#CPlayer_GetPrivacySettings_Response\x12+\n\x10privacy_settings\x18\x01 \x01(\x0b\x32\x11.CPrivacySettings\"3\n\"CPlayer_GetDurationControl_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xf0\x01\n#CPlayer_GetDurationControl_Response\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x0f\n\x07seconds\x18\x02 \x01(\x05\x12\x15\n\rseconds_today\x18\x03 \x01(\x05\x12\x1d\n\x15is_steamchina_account\x18\x04 \x01(\x08\x12\x17\n\x0fis_age_verified\x18\x05 \x01(\x08\x12\x1d\n\x15seconds_allowed_today\x18\x06 \x01(\r\x12 \n\x18\x61ge_verification_pending\x18\x07 \x01(\x08\x12\x14\n\x0c\x62lock_minors\x18\x08 \x01(\x08\"`\n$CPlayer_LastPlayedTimes_Notification\x12\x38\n\x05games\x18\x01 \x03(\x0b\x32).CPlayer_GetLastPlayedTimes_Response.Game\"j\n*CPlayer_FriendNicknameChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x17\n\x0fis_echo_to_self\x18\x03 \x01(\x08\"K\n6CPlayer_FriendEquippedProfileItemsChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\"\xa7\x01\n.CPlayer_NewSteamAnnouncementState_Notification\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x1d\n\x15\x61nnouncement_headline\x18\x02 \x01(\t\x12\x18\n\x10\x61nnouncement_url\x18\x03 \x01(\t\x12\x13\n\x0btime_posted\x18\x04 \x01(\r\x12\x18\n\x10\x61nnouncement_gid\x18\x05 \x01(\x04\"f\n0CPlayer_CommunityPreferencesChanged_Notification\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\"V\n+CPlayer_TextFilterWordsChanged_Notification\x12\'\n\x05words\x18\x01 \x01(\x0b\x32\x18.CPlayer_TextFilterWords\"q\n0CPlayer_PerFriendPreferencesChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12*\n\x0bpreferences\x18\x02 \x01(\x0b\x32\x15.PerFriendPreferences\"Z\n+CPlayer_PrivacySettingsChanged_Notification\x12+\n\x10privacy_settings\x18\x01 \x01(\x0b\x32\x11.CPrivacySettings*\x99\x02\n\x1a\x45ProfileCustomizationStyle\x12\'\n#k_EProfileCustomizationStyleDefault\x10\x00\x12(\n$k_EProfileCustomizationStyleSelected\x10\x01\x12&\n\"k_EProfileCustomizationStyleRarest\x10\x02\x12*\n&k_EProfileCustomizationStyleMostRecent\x10\x03\x12&\n\"k_EProfileCustomizationStyleRandom\x10\x04\x12,\n(k_EProfileCustomizationStyleHighestRated\x10\x05*v\n\x0e\x45\x41greementType\x12%\n\x18k_EAgreementType_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1e\n\x1ak_EAgreementType_GlobalSSA\x10\x00\x12\x1d\n\x19k_EAgreementType_ChinaSSA\x10\x01*\x85\x01\n\x14\x45NotificationSetting\x12*\n&k_ENotificationSettingNotifyUseDefault\x10\x00\x12 \n\x1ck_ENotificationSettingAlways\x10\x01\x12\x1f\n\x1bk_ENotificationSettingNever\x10\x02*\xb0\x01\n\x12\x45TextFilterSetting\x12(\n$k_ETextFilterSettingSteamLabOptedOut\x10\x00\x12\x1f\n\x1bk_ETextFilterSettingEnabled\x10\x01\x12-\n)k_ETextFilterSettingEnabledAllowProfanity\x10\x02\x12 \n\x1ck_ETextFilterSettingDisabled\x10\x03\x32\xd4;\n\x06Player\x12\xef\x01\n\"GetMutualFriendsForIncomingInvites\x12\x33.CPlayer_GetMutualFriendsForIncomingInvites_Request\x1a\x34.CPlayer_GetMutualFriendsForIncomingInvites_Response\"^\x82\xb5\x18ZGet me the mutual friends for each of my pending incoming invites (individuals and clans).\x12\x80\x01\n\rGetOwnedGames\x12\x1e.CPlayer_GetOwnedGames_Request\x1a\x1f.CPlayer_GetOwnedGames_Response\".\x82\xb5\x18*Return a list of games owned by the player\x12\x7f\n\x0bGetPlayNext\x12\x1c.CPlayer_GetPlayNext_Request\x1a\x1d.CPlayer_GetPlayNext_Response\"3\x82\xb5\x18/Return suggested games for player to play next.\x12\xb8\x01\n\x16GetFriendsGameplayInfo\x12\'.CPlayer_GetFriendsGameplayInfo_Request\x1a(.CPlayer_GetFriendsGameplayInfo_Response\"K\x82\xb5\x18GGet a list of friends who are playing, have played, own, or want a game\x12\xb6\x01\n\x12GetGameBadgeLevels\x12#.CPlayer_GetGameBadgeLevels_Request\x1a$.CPlayer_GetGameBadgeLevels_Response\"U\x82\xb5\x18QReturns the Steam Level of a user, the Badge level for the game, and if it\'s foil\x12\xa6\x01\n\x14GetProfileBackground\x12%.CPlayer_GetProfileBackground_Request\x1a&.CPlayer_GetProfileBackground_Response\"?\x82\xb5\x18;Gets which profile background is active for a specific user\x12\x8d\x01\n\x14SetProfileBackground\x12%.CPlayer_SetProfileBackground_Request\x1a&.CPlayer_SetProfileBackground_Response\"&\x82\xb5\x18\"Sets the user\'s profile background\x12\xb7\x01\n\x18GetMiniProfileBackground\x12).CPlayer_GetMiniProfileBackground_Request\x1a*.CPlayer_GetMiniProfileBackground_Response\"D\x82\xb5\x18@Gets which mini profile background is active for a specific user\x12\x9e\x01\n\x18SetMiniProfileBackground\x12).CPlayer_SetMiniProfileBackground_Request\x1a*.CPlayer_SetMiniProfileBackground_Response\"+\x82\xb5\x18\'Sets the user\'s mini profile background\x12\x8e\x01\n\x0eGetAvatarFrame\x12\x1f.CPlayer_GetAvatarFrame_Request\x1a .CPlayer_GetAvatarFrame_Response\"9\x82\xb5\x18\x35Gets which avatar frame is active for a specific user\x12\x87\x01\n\x0eSetAvatarFrame\x12\x1f.CPlayer_SetAvatarFrame_Request\x1a .CPlayer_SetAvatarFrame_Response\"2\x82\xb5\x18.Sets the user\'s avatar frame for their profile\x12\x9a\x01\n\x11GetAnimatedAvatar\x12\".CPlayer_GetAnimatedAvatar_Request\x1a#.CPlayer_GetAnimatedAvatar_Response\"<\x82\xb5\x18\x38Gets which animated avatar is active for a specific user\x12\x93\x01\n\x11SetAnimatedAvatar\x12\".CPlayer_SetAnimatedAvatar_Request\x1a#.CPlayer_SetAnimatedAvatar_Response\"5\x82\xb5\x18\x31Sets the user\'s animated avatar for their profile\x12\xb8\x01\n\x18GetSteamDeckKeyboardSkin\x12).CPlayer_GetSteamDeckKeyboardSkin_Request\x1a*.CPlayer_GetSteamDeckKeyboardSkin_Response\"E\x82\xb5\x18\x41Gets which Steam Deck keyboard skin is active for a specific user\x12\xa7\x01\n\x18SetSteamDeckKeyboardSkin\x12).CPlayer_SetSteamDeckKeyboardSkin_Request\x1a*.CPlayer_SetSteamDeckKeyboardSkin_Response\"4\x82\xb5\x18\x30Sets the user\'s current Steam Deck keyboard skin\x12\xa0\x01\n\x14GetProfileItemsOwned\x12%.CPlayer_GetProfileItemsOwned_Request\x1a&.CPlayer_GetProfileItemsOwned_Response\"9\x82\xb5\x18\x35Returns the items the user can equip on their profile\x12\xac\x01\n\x17GetProfileItemsEquipped\x12(.CPlayer_GetProfileItemsEquipped_Request\x1a).CPlayer_GetProfileItemsEquipped_Response\"<\x82\xb5\x18\x38Returns the items the user has equipped on their profile\x12\xa7\x01\n\x1bSetEquippedProfileItemFlags\x12,.CPlayer_SetEquippedProfileItemFlags_Request\x1a-.CPlayer_SetEquippedProfileItemFlags_Response\"+\x82\xb5\x18\'Sets special flags on the equipped item\x12\x91\x01\n\x0fGetEmoticonList\x12 .CPlayer_GetEmoticonList_Request\x1a!.CPlayer_GetEmoticonList_Response\"9\x82\xb5\x18\x35Gets a list of the emoticons a user has with metadata\x12\xb9\x01\n\x17GetAchievementsProgress\x12(.CPlayer_GetAchievementsProgress_Request\x1a).CPlayer_GetAchievementsProgress_Response\"I\x82\xb5\x18\x45Gets the achievement completion stats for the specified list of apps.\x12\x90\x01\n\x10GetFavoriteBadge\x12!.CPlayer_GetFavoriteBadge_Request\x1a\".CPlayer_GetFavoriteBadge_Response\"5\x82\xb5\x18\x31Gets the badge the user has set as their favorite\x12\x84\x01\n\x10SetFavoriteBadge\x12!.CPlayer_SetFavoriteBadge_Request\x1a\".CPlayer_SetFavoriteBadge_Response\")\x82\xb5\x18%Sets the badge  as the users favorite\x12\xa5\x01\n\x17GetProfileCustomization\x12(.CPlayer_GetProfileCustomization_Request\x1a).CPlayer_GetProfileCustomization_Response\"5\x82\xb5\x18\x31Returns the customizations (if any) for a profile\x12\xbe\x01\n!GetPurchasedProfileCustomizations\x12\x32.CPlayer_GetPurchasedProfileCustomizations_Request\x1a\x33.CPlayer_GetPurchasedProfileCustomizations_Response\"0\x82\xb5\x18,Returns the purchased profile customizations\x12\xec\x01\n,GetPurchasedAndUpgradedProfileCustomizations\x12=.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request\x1a>.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response\"=\x82\xb5\x18\x39Returns the purchased and upgraded profile customizations\x12\x9d\x01\n\x19GetProfileThemesAvailable\x12*.CPlayer_GetProfileThemesAvailable_Request\x1a+.CPlayer_GetProfileThemesAvailable_Response\"\'\x82\xb5\x18#Gets themes available for the user.\x12{\n\x0fSetProfileTheme\x12 .CPlayer_SetProfileTheme_Request\x1a!.CPlayer_SetProfileTheme_Response\"#\x82\xb5\x18\x1fSelects a theme for the profile\x12\x86\x01\n\x15SetProfilePreferences\x12&.CPlayer_SetProfilePreferences_Request\x1a\'.CPlayer_SetProfilePreferences_Response\"\x1c\x82\xb5\x18\x18Sets profile preferences\x12\x91\x01\n\x13PostStatusToFriends\x12$.CPlayer_PostStatusToFriends_Request\x1a%.CPlayer_PostStatusToFriends_Response\"-\x82\xb5\x18)Posts custom status text into the blotter\x12\x86\x01\n\x0fGetPostedStatus\x12 .CPlayer_GetPostedStatus_Request\x1a!.CPlayer_GetPostedStatus_Response\".\x82\xb5\x18*Gets a posted status text for a user by id\x12\x92\x01\n\x12\x44\x65letePostedStatus\x12#.CPlayer_DeletePostedStatus_Request\x1a$.CPlayer_DeletePostedStatus_Response\"1\x82\xb5\x18-Deletes a posted status text for a user by id\x12\x95\x01\n\x18\x43lientGetLastPlayedTimes\x12#.CPlayer_GetLastPlayedTimes_Request\x1a$.CPlayer_GetLastPlayedTimes_Response\".\x82\xb5\x18*Gets the last-played times for the account\x12\x91\x01\n\x12GetTimeSSAAccepted\x12#.CPlayer_GetTimeSSAAccepted_Request\x1a$.CPlayer_GetTimeSSAAccepted_Response\"0\x82\xb5\x18,Gets the time when the user accepted the SSA\x12\x63\n\tAcceptSSA\x12\x1a.CPlayer_AcceptSSA_Request\x1a\x1b.CPlayer_AcceptSSA_Response\"\x1d\x82\xb5\x18\x19User is accepting the SSA\x12\x94\x01\n\x0fGetNicknameList\x12 .CPlayer_GetNicknameList_Request\x1a!.CPlayer_GetNicknameList_Response\"<\x82\xb5\x18\x38Gets the list of nicknames this user has for other users\x12\xbd\x01\n\x17GetPerFriendPreferences\x12(.CPlayer_GetPerFriendPreferences_Request\x1a).CPlayer_GetPerFriendPreferences_Response\"M\x82\xb5\x18IGets the list of per-friend preferences this user has set for other users\x12\xb7\x01\n\x17SetPerFriendPreferences\x12(.CPlayer_SetPerFriendPreferences_Request\x1a).CPlayer_SetPerFriendPreferences_Response\"G\x82\xb5\x18\x43Sets the logged in user\'s per-friend preferences for the given user\x12s\n\tAddFriend\x12\x1a.CPlayer_AddFriend_Request\x1a\x1b.CPlayer_AddFriend_Response\"-\x82\xb5\x18)Invites another Steam user to be a friend\x12\x82\x01\n\x0cRemoveFriend\x12\x1d.CPlayer_RemoveFriend_Request\x1a\x1e.CPlayer_RemoveFriend_Response\"3\x82\xb5\x18/Removes a friend or ignores a friend suggestion\x12\xa6\x01\n\x0cIgnoreFriend\x12\x1d.CPlayer_IgnoreFriend_Request\x1a\x1e.CPlayer_IgnoreFriend_Response\"W\x82\xb5\x18SBlocks or unblocks communication with the user.  Despite name, can be a non-friend.\x12\x9e\x01\n\x17GetCommunityPreferences\x12(.CPlayer_GetCommunityPreferences_Request\x1a).CPlayer_GetCommunityPreferences_Response\".\x82\xb5\x18*Returns the player\'s community preferences\x12\x9b\x01\n\x17SetCommunityPreferences\x12(.CPlayer_SetCommunityPreferences_Request\x1a).CPlayer_SetCommunityPreferences_Response\"+\x82\xb5\x18\'Sets the player\'s community preferences\x12\x9b\x01\n\x12GetTextFilterWords\x12#.CPlayer_GetTextFilterWords_Request\x1a$.CPlayer_GetTextFilterWords_Response\":\x82\xb5\x18\x36Get the custom text filtering dictionary for this user\x12\xde\x01\n\x1cGetNewSteamAnnouncementState\x12-.CPlayer_GetNewSteamAnnouncementState_Request\x1a..CPlayer_GetNewSteamAnnouncementState_Response\"_\x82\xb5\x18[Calculates and returns what to display for UI that renders new steam announcement available\x12\xbc\x01\n\x1fUpdateSteamAnnouncementLastRead\x12\x30.CPlayer_UpdateSteamAnnouncementLastRead_Request\x1a\x31.CPlayer_UpdateSteamAnnouncementLastRead_Response\"4\x82\xb5\x18\x30Marks latest announcement timestamp read by user\x12\x82\x01\n\x12GetPrivacySettings\x12#.CPlayer_GetPrivacySettings_Request\x1a$.CPlayer_GetPrivacySettings_Response\"!\x82\xb5\x18\x1dGet current privacy settings.\x12\x8c\x01\n\x12GetDurationControl\x12#.CPlayer_GetDurationControl_Request\x1a$.CPlayer_GetDurationControl_Response\"+\x82\xb5\x18\'Get gameplay duration control settings.\x1a-\x82\xb5\x18)A service for accessing Steam player data2\xa6\x0b\n\x0cPlayerClient\x12\x8c\x01\n\x15NotifyLastPlayedTimes\x12%.CPlayer_LastPlayedTimes_Notification\x1a\x0b.NoResponse\"?\x82\xb5\x18;Notification from server to client of more recent play time\x12\xa4\x01\n\x1bNotifyFriendNicknameChanged\x12+.CPlayer_FriendNicknameChanged_Notification\x1a\x0b.NoResponse\"K\x82\xb5\x18GNotification from server to client that a friend\'s nickname has changed\x12\xcb\x01\n\'NotifyFriendEquippedProfileItemsChanged\x12\x37.CPlayer_FriendEquippedProfileItemsChanged_Notification\x1a\x0b.NoResponse\"Z\x82\xb5\x18VNotification from server to client that a friend\'s equipped profile items have changed\x12\xa4\x01\n\x1fNotifyNewSteamAnnouncementState\x12/.CPlayer_NewSteamAnnouncementState_Notification\x1a\x0b.NoResponse\"C\x82\xb5\x18?Notifies client of changes to steam announcement state for user\x12\xb9\x01\n!NotifyCommunityPreferencesChanged\x12\x31.CPlayer_CommunityPreferencesChanged_Notification\x1a\x0b.NoResponse\"T\x82\xb5\x18PNotification from server to client that their community preferences have changed\x12\xb2\x01\n\x1cNotifyTextFilterWordsChanged\x12,.CPlayer_TextFilterWordsChanged_Notification\x1a\x0b.NoResponse\"W\x82\xb5\x18SNotification from server to client that their text filtering dictionary has changed\x12\xaa\x01\n!NotifyPerFriendPreferencesChanged\x12\x31.CPlayer_PerFriendPreferencesChanged_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Notification from server that per-friend preferences have changed\x12\x9c\x01\n#NotifyPrivacyPrivacySettingsChanged\x12,.CPlayer_PrivacySettingsChanged_Notification\x1a\x0b.NoResponse\":\x82\xb5\x18\x36Notification from server that privacy settings changed\x1a.\x82\xb5\x18&Steam player data client notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,enums__pb2.DESCRIPTOR,])

_EPROFILECUSTOMIZATIONSTYLE = _descriptor.EnumDescriptor(
  name='EProfileCustomizationStyle',
  full_name='EProfileCustomizationStyle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleDefault', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleSelected', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleRarest', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleMostRecent', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleRandom', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCustomizationStyleHighestRated', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15707,
  serialized_end=15988,
)
_sym_db.RegisterEnumDescriptor(_EPROFILECUSTOMIZATIONSTYLE)

EProfileCustomizationStyle = enum_type_wrapper.EnumTypeWrapper(_EPROFILECUSTOMIZATIONSTYLE)
_EAGREEMENTTYPE = _descriptor.EnumDescriptor(
  name='EAgreementType',
  full_name='EAgreementType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EAgreementType_Invalid', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EAgreementType_GlobalSSA', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EAgreementType_ChinaSSA', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15990,
  serialized_end=16108,
)
_sym_db.RegisterEnumDescriptor(_EAGREEMENTTYPE)

EAgreementType = enum_type_wrapper.EnumTypeWrapper(_EAGREEMENTTYPE)
_ENOTIFICATIONSETTING = _descriptor.EnumDescriptor(
  name='ENotificationSetting',
  full_name='ENotificationSetting',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ENotificationSettingNotifyUseDefault', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ENotificationSettingAlways', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ENotificationSettingNever', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16111,
  serialized_end=16244,
)
_sym_db.RegisterEnumDescriptor(_ENOTIFICATIONSETTING)

ENotificationSetting = enum_type_wrapper.EnumTypeWrapper(_ENOTIFICATIONSETTING)
_ETEXTFILTERSETTING = _descriptor.EnumDescriptor(
  name='ETextFilterSetting',
  full_name='ETextFilterSetting',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETextFilterSettingSteamLabOptedOut', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETextFilterSettingEnabled', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETextFilterSettingEnabledAllowProfanity', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ETextFilterSettingDisabled', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16247,
  serialized_end=16423,
)
_sym_db.RegisterEnumDescriptor(_ETEXTFILTERSETTING)

ETextFilterSetting = enum_type_wrapper.EnumTypeWrapper(_ETEXTFILTERSETTING)
k_EProfileCustomizationStyleDefault = 0
k_EProfileCustomizationStyleSelected = 1
k_EProfileCustomizationStyleRarest = 2
k_EProfileCustomizationStyleMostRecent = 3
k_EProfileCustomizationStyleRandom = 4
k_EProfileCustomizationStyleHighestRated = 5
k_EAgreementType_Invalid = -1
k_EAgreementType_GlobalSSA = 0
k_EAgreementType_ChinaSSA = 1
k_ENotificationSettingNotifyUseDefault = 0
k_ENotificationSettingAlways = 1
k_ENotificationSettingNever = 2
k_ETextFilterSettingSteamLabOptedOut = 0
k_ETextFilterSettingEnabled = 1
k_ETextFilterSettingEnabledAllowProfanity = 2
k_ETextFilterSettingDisabled = 3



_CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetMutualFriendsForIncomingInvites_Request',
  full_name='CPlayer_GetMutualFriendsForIncomingInvites_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=155,
)


_CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST = _descriptor.Descriptor(
  name='CPlayer_IncomingInviteMutualFriendList',
  full_name='CPlayer_IncomingInviteMutualFriendList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_IncomingInviteMutualFriendList.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mutual_friend_account_ids', full_name='CPlayer_IncomingInviteMutualFriendList.mutual_friend_account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=249,
)


_CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetMutualFriendsForIncomingInvites_Response',
  full_name='CPlayer_GetMutualFriendsForIncomingInvites_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incoming_invite_mutual_friends_lists', full_name='CPlayer_GetMutualFriendsForIncomingInvites_Response.incoming_invite_mutual_friends_lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=392,
)


_CPLAYER_GETOWNEDGAMES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetOwnedGames_Request',
  full_name='CPlayer_GetOwnedGames_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetOwnedGames_Request.steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_appinfo', full_name='CPlayer_GetOwnedGames_Request.include_appinfo', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?true if we want additional details (name, icon) about each game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_played_free_games', full_name='CPlayer_GetOwnedGames_Request.include_played_free_games', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030eFree games are excluded by default.  If this is set, free games the user has played will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appids_filter', full_name='CPlayer_GetOwnedGames_Request.appids_filter', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302if set, restricts result set to the passed in apps', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_free_sub', full_name='CPlayer_GetOwnedGames_Request.include_free_sub', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030>Some games are in the free sub, which are excluded by default.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_unvetted_apps', full_name='CPlayer_GetOwnedGames_Request.skip_unvetted_apps', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 if set, skip unvetted store apps', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetOwnedGames_Request.language', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Will return appinfo in this language', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_extended_appinfo', full_name='CPlayer_GetOwnedGames_Request.include_extended_appinfo', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ztrue if we want even more details (capsule, sortas, and capabilities) about each game.  include_appinfo must also be true.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=1183,
)


_CPLAYER_GETOWNEDGAMES_RESPONSE_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CPlayer_GetOwnedGames_Response.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetOwnedGames_Response.Game.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CPlayer_GetOwnedGames_Response.Game.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_2weeks', full_name='CPlayer_GetOwnedGames_Response.Game.playtime_2weeks', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_forever', full_name='CPlayer_GetOwnedGames_Response.Game.playtime_forever', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='img_icon_url', full_name='CPlayer_GetOwnedGames_Response.Game.img_icon_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_community_visible_stats', full_name='CPlayer_GetOwnedGames_Response.Game.has_community_visible_stats', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_windows_forever', full_name='CPlayer_GetOwnedGames_Response.Game.playtime_windows_forever', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_mac_forever', full_name='CPlayer_GetOwnedGames_Response.Game.playtime_mac_forever', index=7,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_linux_forever', full_name='CPlayer_GetOwnedGames_Response.Game.playtime_linux_forever', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_last_played', full_name='CPlayer_GetOwnedGames_Response.Game.rtime_last_played', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capsule_filename', full_name='CPlayer_GetOwnedGames_Response.Game.capsule_filename', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_as', full_name='CPlayer_GetOwnedGames_Response.Game.sort_as', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_workshop', full_name='CPlayer_GetOwnedGames_Response.Game.has_workshop', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_market', full_name='CPlayer_GetOwnedGames_Response.Game.has_market', index=13,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_dlc', full_name='CPlayer_GetOwnedGames_Response.Game.has_dlc', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1294,
  serialized_end=1664,
)

_CPLAYER_GETOWNEDGAMES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetOwnedGames_Response',
  full_name='CPlayer_GetOwnedGames_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_count', full_name='CPlayer_GetOwnedGames_Response.game_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='games', full_name='CPlayer_GetOwnedGames_Response.games', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETOWNEDGAMES_RESPONSE_GAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1664,
)


_CPLAYER_GETPLAYNEXT_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPlayNext_Request',
  full_name='CPlayer_GetPlayNext_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_age_seconds', full_name='CPlayer_GetPlayNext_Request.max_age_seconds', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_appids', full_name='CPlayer_GetPlayNext_Request.ignore_appids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1743,
)


_CPLAYER_GETPLAYNEXT_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPlayNext_Response',
  full_name='CPlayer_GetPlayNext_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_update_time', full_name='CPlayer_GetPlayNext_Response.last_update_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appids', full_name='CPlayer_GetPlayNext_Response.appids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1745,
  serialized_end=1817,
)


_CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetFriendsGameplayInfo_Request',
  full_name='CPlayer_GetFriendsGameplayInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetFriendsGameplayInfo_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1819,
  serialized_end=1874,
)


_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO = _descriptor.Descriptor(
  name='FriendsGameplayInfo',
  full_name='CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes_played', full_name='CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo.minutes_played', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes_played_forever', full_name='CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo.minutes_played_forever', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2405,
  serialized_end=2499,
)

_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO = _descriptor.Descriptor(
  name='OwnGameplayInfo',
  full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes_played', full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo.minutes_played', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes_played_forever', full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo.minutes_played_forever', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_wishlist', full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo.in_wishlist', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owned', full_name='CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo.owned', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2501,
  serialized_end=2627,
)

_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetFriendsGameplayInfo_Response',
  full_name='CPlayer_GetFriendsGameplayInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='your_info', full_name='CPlayer_GetFriendsGameplayInfo_Response.your_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_game', full_name='CPlayer_GetFriendsGameplayInfo_Response.in_game', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='played_recently', full_name='CPlayer_GetFriendsGameplayInfo_Response.played_recently', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='played_ever', full_name='CPlayer_GetFriendsGameplayInfo_Response.played_ever', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owns', full_name='CPlayer_GetFriendsGameplayInfo_Response.owns', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_wishlist', full_name='CPlayer_GetFriendsGameplayInfo_Response.in_wishlist', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO, _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=2627,
)


_CPLAYER_GETGAMEBADGELEVELS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetGameBadgeLevels_Request',
  full_name='CPlayer_GetGameBadgeLevels_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetGameBadgeLevels_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2629,
  serialized_end=2680,
)


_CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE = _descriptor.Descriptor(
  name='Badge',
  full_name='CPlayer_GetGameBadgeLevels_Response.Badge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='CPlayer_GetGameBadgeLevels_Response.Badge.level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series', full_name='CPlayer_GetGameBadgeLevels_Response.Badge.series', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='border_color', full_name='CPlayer_GetGameBadgeLevels_Response.Badge.border_color', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2804,
  serialized_end=2864,
)

_CPLAYER_GETGAMEBADGELEVELS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetGameBadgeLevels_Response',
  full_name='CPlayer_GetGameBadgeLevels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_level', full_name='CPlayer_GetGameBadgeLevels_Response.player_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='badges', full_name='CPlayer_GetGameBadgeLevels_Response.badges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2683,
  serialized_end=2864,
)


_CPLAYER_GETPROFILEBACKGROUND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetProfileBackground_Request',
  full_name='CPlayer_GetProfileBackground_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetProfileBackground_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetProfileBackground_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2866,
  serialized_end=2974,
)


_PROFILEITEM = _descriptor.Descriptor(
  name='ProfileItem',
  full_name='ProfileItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='ProfileItem.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_small', full_name='ProfileItem.image_small', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)small image used in backpack or selection', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_large', full_name='ProfileItem.image_large', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020the image itself', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ProfileItem.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014english name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_title', full_name='ProfileItem.item_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\017localized title', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_description', full_name='ProfileItem.item_description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025localized description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='ProfileItem.appid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_type', full_name='ProfileItem.item_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_class', full_name='ProfileItem.item_class', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movie_webm', full_name='ProfileItem.movie_webm', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023URL to webm, if any', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movie_mp4', full_name='ProfileItem.movie_mp4', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\022URL to mp4, if any', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movie_webm_small', full_name='ProfileItem.movie_webm_small', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031URL to small webm, if any', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movie_mp4_small', full_name='ProfileItem.movie_mp4_small', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030URL to small mp4, if any', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equipped_flags', full_name='ProfileItem.equipped_flags', index=13,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030:Special flags set when equipped (EProfileItemEquippedFlag)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2977,
  serialized_end=3594,
)


_CPLAYER_GETPROFILEBACKGROUND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetProfileBackground_Response',
  full_name='CPlayer_GetProfileBackground_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_background', full_name='CPlayer_GetProfileBackground_Response.profile_background', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3596,
  serialized_end=3677,
)


_CPLAYER_SETPROFILEBACKGROUND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetProfileBackground_Request',
  full_name='CPlayer_SetProfileBackground_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetProfileBackground_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3679,
  serialized_end=3742,
)


_CPLAYER_SETPROFILEBACKGROUND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetProfileBackground_Response',
  full_name='CPlayer_SetProfileBackground_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3744,
  serialized_end=3783,
)


_CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetMiniProfileBackground_Request',
  full_name='CPlayer_GetMiniProfileBackground_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetMiniProfileBackground_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetMiniProfileBackground_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3785,
  serialized_end=3897,
)


_CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetMiniProfileBackground_Response',
  full_name='CPlayer_GetMiniProfileBackground_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_background', full_name='CPlayer_GetMiniProfileBackground_Response.profile_background', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3899,
  serialized_end=3984,
)


_CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetMiniProfileBackground_Request',
  full_name='CPlayer_SetMiniProfileBackground_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetMiniProfileBackground_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3986,
  serialized_end=4053,
)


_CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetMiniProfileBackground_Response',
  full_name='CPlayer_SetMiniProfileBackground_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4055,
  serialized_end=4098,
)


_CPLAYER_GETAVATARFRAME_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetAvatarFrame_Request',
  full_name='CPlayer_GetAvatarFrame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetAvatarFrame_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetAvatarFrame_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4202,
)


_CPLAYER_GETAVATARFRAME_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetAvatarFrame_Response',
  full_name='CPlayer_GetAvatarFrame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar_frame', full_name='CPlayer_GetAvatarFrame_Response.avatar_frame', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4204,
  serialized_end=4273,
)


_CPLAYER_SETAVATARFRAME_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetAvatarFrame_Request',
  full_name='CPlayer_SetAvatarFrame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetAvatarFrame_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4275,
  serialized_end=4332,
)


_CPLAYER_SETAVATARFRAME_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetAvatarFrame_Response',
  full_name='CPlayer_SetAvatarFrame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4334,
  serialized_end=4367,
)


_CPLAYER_GETANIMATEDAVATAR_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetAnimatedAvatar_Request',
  full_name='CPlayer_GetAnimatedAvatar_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetAnimatedAvatar_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetAnimatedAvatar_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4369,
  serialized_end=4474,
)


_CPLAYER_GETANIMATEDAVATAR_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetAnimatedAvatar_Response',
  full_name='CPlayer_GetAnimatedAvatar_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='CPlayer_GetAnimatedAvatar_Response.avatar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4476,
  serialized_end=4542,
)


_CPLAYER_SETANIMATEDAVATAR_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetAnimatedAvatar_Request',
  full_name='CPlayer_SetAnimatedAvatar_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetAnimatedAvatar_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4544,
  serialized_end=4604,
)


_CPLAYER_SETANIMATEDAVATAR_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetAnimatedAvatar_Response',
  full_name='CPlayer_SetAnimatedAvatar_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4606,
  serialized_end=4642,
)


_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetSteamDeckKeyboardSkin_Request',
  full_name='CPlayer_GetSteamDeckKeyboardSkin_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetSteamDeckKeyboardSkin_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetSteamDeckKeyboardSkin_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4644,
  serialized_end=4756,
)


_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetSteamDeckKeyboardSkin_Response',
  full_name='CPlayer_GetSteamDeckKeyboardSkin_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_deck_keyboard_skin', full_name='CPlayer_GetSteamDeckKeyboardSkin_Response.steam_deck_keyboard_skin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4758,
  serialized_end=4849,
)


_CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetSteamDeckKeyboardSkin_Request',
  full_name='CPlayer_SetSteamDeckKeyboardSkin_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetSteamDeckKeyboardSkin_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4851,
  serialized_end=4918,
)


_CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetSteamDeckKeyboardSkin_Response',
  full_name='CPlayer_SetSteamDeckKeyboardSkin_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4920,
  serialized_end=4963,
)


_CPLAYER_GETPROFILEITEMSOWNED_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetProfileItemsOwned_Request',
  full_name='CPlayer_GetProfileItemsOwned_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetProfileItemsOwned_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='CPlayer_GetProfileItemsOwned_Request.filters', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4965,
  serialized_end=5060,
)


_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetProfileItemsOwned_Response',
  full_name='CPlayer_GetProfileItemsOwned_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_backgrounds', full_name='CPlayer_GetProfileItemsOwned_Response.profile_backgrounds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mini_profile_backgrounds', full_name='CPlayer_GetProfileItemsOwned_Response.mini_profile_backgrounds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_frames', full_name='CPlayer_GetProfileItemsOwned_Response.avatar_frames', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='animated_avatars', full_name='CPlayer_GetProfileItemsOwned_Response.animated_avatars', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_modifiers', full_name='CPlayer_GetProfileItemsOwned_Response.profile_modifiers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_deck_keyboard_skins', full_name='CPlayer_GetProfileItemsOwned_Response.steam_deck_keyboard_skins', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5063,
  serialized_end=5360,
)


_CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetProfileItemsEquipped_Request',
  full_name='CPlayer_GetProfileItemsEquipped_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetProfileItemsEquipped_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetProfileItemsEquipped_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5362,
  serialized_end=5438,
)


_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetProfileItemsEquipped_Response',
  full_name='CPlayer_GetProfileItemsEquipped_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_background', full_name='CPlayer_GetProfileItemsEquipped_Response.profile_background', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mini_profile_background', full_name='CPlayer_GetProfileItemsEquipped_Response.mini_profile_background', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_frame', full_name='CPlayer_GetProfileItemsEquipped_Response.avatar_frame', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='animated_avatar', full_name='CPlayer_GetProfileItemsEquipped_Response.animated_avatar', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_modifier', full_name='CPlayer_GetProfileItemsEquipped_Response.profile_modifier', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_deck_keyboard_skin', full_name='CPlayer_GetProfileItemsEquipped_Response.steam_deck_keyboard_skin', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5441,
  serialized_end=5735,
)


_CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetEquippedProfileItemFlags_Request',
  full_name='CPlayer_SetEquippedProfileItemFlags_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetEquippedProfileItemFlags_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPlayer_SetEquippedProfileItemFlags_Request.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Set of EProfileItemEquippedFlag', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5737,
  serialized_end=5859,
)


_CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetEquippedProfileItemFlags_Response',
  full_name='CPlayer_SetEquippedProfileItemFlags_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5861,
  serialized_end=5907,
)


_CPLAYER_GETEMOTICONLIST_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetEmoticonList_Request',
  full_name='CPlayer_GetEmoticonList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5909,
  serialized_end=5942,
)


_CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON = _descriptor.Descriptor(
  name='Emoticon',
  full_name='CPlayer_GetEmoticonList_Response.Emoticon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CPlayer_GetEmoticonList_Response.Emoticon.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CPlayer_GetEmoticonList_Response.Emoticon.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_used', full_name='CPlayer_GetEmoticonList_Response.Emoticon.time_last_used', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_count', full_name='CPlayer_GetEmoticonList_Response.Emoticon.use_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_received', full_name='CPlayer_GetEmoticonList_Response.Emoticon.time_received', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetEmoticonList_Response.Emoticon.appid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6044,
  serialized_end=6164,
)

_CPLAYER_GETEMOTICONLIST_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetEmoticonList_Response',
  full_name='CPlayer_GetEmoticonList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emoticons', full_name='CPlayer_GetEmoticonList_Response.emoticons', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5945,
  serialized_end=6164,
)


_CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetAchievementsProgress_Request',
  full_name='CPlayer_GetAchievementsProgress_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetAchievementsProgress_Request.steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetAchievementsProgress_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appids', full_name='CPlayer_GetAchievementsProgress_Request.appids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6166,
  serialized_end=6258,
)


_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS = _descriptor.Descriptor(
  name='AchievementProgress',
  full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlocked', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.unlocked', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_unlocked', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.all_unlocked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_time', full_name='CPlayer_GetAchievementsProgress_Response.AchievementProgress.cache_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6399,
  serialized_end=6530,
)

_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetAchievementsProgress_Response',
  full_name='CPlayer_GetAchievementsProgress_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievement_progress', full_name='CPlayer_GetAchievementsProgress_Response.achievement_progress', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6261,
  serialized_end=6530,
)


_CPLAYER_GETFAVORITEBADGE_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetFavoriteBadge_Request',
  full_name='CPlayer_GetFavoriteBadge_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetFavoriteBadge_Request.steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6532,
  serialized_end=6583,
)


_CPLAYER_GETFAVORITEBADGE_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetFavoriteBadge_Response',
  full_name='CPlayer_GetFavoriteBadge_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_favorite_badge', full_name='CPlayer_GetFavoriteBadge_Response.has_favorite_badge', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='badgeid', full_name='CPlayer_GetFavoriteBadge_Response.badgeid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_GetFavoriteBadge_Response.communityitemid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_type', full_name='CPlayer_GetFavoriteBadge_Response.item_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='border_color', full_name='CPlayer_GetFavoriteBadge_Response.border_color', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetFavoriteBadge_Response.appid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='CPlayer_GetFavoriteBadge_Response.level', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6586,
  serialized_end=6762,
)


_CPLAYER_SETFAVORITEBADGE_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetFavoriteBadge_Request',
  full_name='CPlayer_SetFavoriteBadge_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communityitemid', full_name='CPlayer_SetFavoriteBadge_Request.communityitemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='badgeid', full_name='CPlayer_SetFavoriteBadge_Request.badgeid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6764,
  serialized_end=6840,
)


_CPLAYER_SETFAVORITEBADGE_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetFavoriteBadge_Response',
  full_name='CPlayer_SetFavoriteBadge_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6842,
  serialized_end=6877,
)


_CPLAYER_GETPROFILECUSTOMIZATION_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetProfileCustomization_Request',
  full_name='CPlayer_GetProfileCustomization_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetProfileCustomization_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_inactive_customizations', full_name='CPlayer_GetProfileCustomization_Request.include_inactive_customizations', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_purchased_customizations', full_name='CPlayer_GetProfileCustomization_Request.include_purchased_customizations', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6880,
  serialized_end=7021,
)


_PROFILECUSTOMIZATIONSLOT = _descriptor.Descriptor(
  name='ProfileCustomizationSlot',
  full_name='ProfileCustomizationSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot', full_name='ProfileCustomizationSlot.slot', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='ProfileCustomizationSlot.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='ProfileCustomizationSlot.publishedfileid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_assetid', full_name='ProfileCustomizationSlot.item_assetid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_contextid', full_name='ProfileCustomizationSlot.item_contextid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='ProfileCustomizationSlot.notes', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='ProfileCustomizationSlot.title', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='ProfileCustomizationSlot.accountid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='badgeid', full_name='ProfileCustomizationSlot.badgeid', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='border_color', full_name='ProfileCustomizationSlot.border_color', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_classid', full_name='ProfileCustomizationSlot.item_classid', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_instanceid', full_name='ProfileCustomizationSlot.item_instanceid', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ban_check_result', full_name='ProfileCustomizationSlot.ban_check_result', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7024,
  serialized_end=7373,
)


_PROFILECUSTOMIZATION = _descriptor.Descriptor(
  name='ProfileCustomization',
  full_name='ProfileCustomization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customization_type', full_name='ProfileCustomization.customization_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large', full_name='ProfileCustomization.large', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slots', full_name='ProfileCustomization.slots', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='ProfileCustomization.active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customization_style', full_name='ProfileCustomization.customization_style', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchaseid', full_name='ProfileCustomization.purchaseid', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='ProfileCustomization.level', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7376,
  serialized_end=7693,
)


_PROFILETHEME = _descriptor.Descriptor(
  name='ProfileTheme',
  full_name='ProfileTheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='theme_id', full_name='ProfileTheme.theme_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='ProfileTheme.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7695,
  serialized_end=7742,
)


_PROFILEPREFERENCES = _descriptor.Descriptor(
  name='ProfilePreferences',
  full_name='ProfilePreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hide_profile_awards', full_name='ProfilePreferences.hide_profile_awards', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7744,
  serialized_end=7793,
)


_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION = _descriptor.Descriptor(
  name='PurchasedCustomization',
  full_name='CPlayer_GetProfileCustomization_Response.PurchasedCustomization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purchaseid', full_name='CPlayer_GetProfileCustomization_Response.PurchasedCustomization.purchaseid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customization_type', full_name='CPlayer_GetProfileCustomization_Response.PurchasedCustomization.customization_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='CPlayer_GetProfileCustomization_Response.PurchasedCustomization.level', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8101,
  serialized_end=8252,
)

_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetProfileCustomization_Response',
  full_name='CPlayer_GetProfileCustomization_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customizations', full_name='CPlayer_GetProfileCustomization_Response.customizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slots_available', full_name='CPlayer_GetProfileCustomization_Response.slots_available', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_theme', full_name='CPlayer_GetProfileCustomization_Response.profile_theme', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchased_customizations', full_name='CPlayer_GetProfileCustomization_Response.purchased_customizations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_preferences', full_name='CPlayer_GetProfileCustomization_Response.profile_preferences', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7796,
  serialized_end=8252,
)


_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPurchasedProfileCustomizations_Request',
  full_name='CPlayer_GetPurchasedProfileCustomizations_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetPurchasedProfileCustomizations_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8254,
  serialized_end=8322,
)


_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION = _descriptor.Descriptor(
  name='PurchasedCustomization',
  full_name='CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purchaseid', full_name='CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization.purchaseid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customization_type', full_name='CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization.customization_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8101,
  serialized_end=8237,
)

_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPurchasedProfileCustomizations_Response',
  full_name='CPlayer_GetPurchasedProfileCustomizations_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purchased_customizations', full_name='CPlayer_GetPurchasedProfileCustomizations_Response.purchased_customizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8325,
  serialized_end=8626,
)


_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request',
  full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8628,
  serialized_end=8707,
)


_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION = _descriptor.Descriptor(
  name='PurchasedCustomization',
  full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customization_type', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization.customization_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9016,
  serialized_end=9147,
)

_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION = _descriptor.Descriptor(
  name='UpgradedCustomization',
  full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customization_type', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization.customization_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization.level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9150,
  serialized_end=9280,
)

_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response',
  full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purchased_customizations', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.purchased_customizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgraded_customizations', full_name='CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.upgraded_customizations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION, _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8710,
  serialized_end=9280,
)


_CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetProfileThemesAvailable_Request',
  full_name='CPlayer_GetProfileThemesAvailable_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9282,
  serialized_end=9325,
)


_CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetProfileThemesAvailable_Response',
  full_name='CPlayer_GetProfileThemesAvailable_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_themes', full_name='CPlayer_GetProfileThemesAvailable_Response.profile_themes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9327,
  serialized_end=9410,
)


_CPLAYER_SETPROFILETHEME_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetProfileTheme_Request',
  full_name='CPlayer_SetProfileTheme_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='theme_id', full_name='CPlayer_SetProfileTheme_Request.theme_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9412,
  serialized_end=9463,
)


_CPLAYER_SETPROFILETHEME_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetProfileTheme_Response',
  full_name='CPlayer_SetProfileTheme_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9465,
  serialized_end=9499,
)


_CPLAYER_SETPROFILEPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetProfilePreferences_Request',
  full_name='CPlayer_SetProfilePreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_preferences', full_name='CPlayer_SetProfilePreferences_Request.profile_preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9501,
  serialized_end=9590,
)


_CPLAYER_SETPROFILEPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetProfilePreferences_Response',
  full_name='CPlayer_SetProfilePreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9592,
  serialized_end=9632,
)


_CPLAYER_POSTSTATUSTOFRIENDS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_PostStatusToFriends_Request',
  full_name='CPlayer_PostStatusToFriends_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_PostStatusToFriends_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_text', full_name='CPlayer_PostStatusToFriends_Request.status_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9634,
  serialized_end=9707,
)


_CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_PostStatusToFriends_Response',
  full_name='CPlayer_PostStatusToFriends_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9709,
  serialized_end=9747,
)


_CPLAYER_GETPOSTEDSTATUS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPostedStatus_Request',
  full_name='CPlayer_GetPostedStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_GetPostedStatus_Request.steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The player we\'re asking about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postid', full_name='CPlayer_GetPostedStatus_Request.postid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9749,
  serialized_end=9850,
)


_CPLAYER_GETPOSTEDSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPostedStatus_Response',
  full_name='CPlayer_GetPostedStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPlayer_GetPostedStatus_Response.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postid', full_name='CPlayer_GetPostedStatus_Response.postid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_text', full_name='CPlayer_GetPostedStatus_Response.status_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='CPlayer_GetPostedStatus_Response.deleted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetPostedStatus_Response.appid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9852,
  serialized_end=9974,
)


_CPLAYER_DELETEPOSTEDSTATUS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_DeletePostedStatus_Request',
  full_name='CPlayer_DeletePostedStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='postid', full_name='CPlayer_DeletePostedStatus_Request.postid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9976,
  serialized_end=10028,
)


_CPLAYER_DELETEPOSTEDSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_DeletePostedStatus_Response',
  full_name='CPlayer_DeletePostedStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10030,
  serialized_end=10067,
)


_CPLAYER_GETLASTPLAYEDTIMES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetLastPlayedTimes_Request',
  full_name='CPlayer_GetLastPlayedTimes_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_last_played', full_name='CPlayer_GetLastPlayedTimes_Request.min_last_played', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030?The most recent last-played time the client already knows about', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10070,
  serialized_end=10200,
)


_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CPlayer_GetLastPlayedTimes_Response.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetLastPlayedTimes_Response.Game.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.last_playtime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_2weeks', full_name='CPlayer_GetLastPlayedTimes_Response.Game.playtime_2weeks', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_forever', full_name='CPlayer_GetLastPlayedTimes_Response.Game.playtime_forever', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.first_playtime', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_windows_forever', full_name='CPlayer_GetLastPlayedTimes_Response.Game.playtime_windows_forever', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_mac_forever', full_name='CPlayer_GetLastPlayedTimes_Response.Game.playtime_mac_forever', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playtime_linux_forever', full_name='CPlayer_GetLastPlayedTimes_Response.Game.playtime_linux_forever', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_windows_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.first_windows_playtime', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_mac_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.first_mac_playtime', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_linux_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.first_linux_playtime', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_windows_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.last_windows_playtime', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_mac_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.last_mac_playtime', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_linux_playtime', full_name='CPlayer_GetLastPlayedTimes_Response.Game.last_linux_playtime', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10301,
  serialized_end=10693,
)

_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetLastPlayedTimes_Response',
  full_name='CPlayer_GetLastPlayedTimes_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='games', full_name='CPlayer_GetLastPlayedTimes_Response.games', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10203,
  serialized_end=10693,
)


_CPLAYER_GETTIMESSAACCEPTED_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetTimeSSAAccepted_Request',
  full_name='CPlayer_GetTimeSSAAccepted_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10695,
  serialized_end=10731,
)


_CPLAYER_GETTIMESSAACCEPTED_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetTimeSSAAccepted_Response',
  full_name='CPlayer_GetTimeSSAAccepted_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ssa_accepted', full_name='CPlayer_GetTimeSSAAccepted_Response.time_ssa_accepted', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_ssa_updated', full_name='CPlayer_GetTimeSSAAccepted_Response.time_ssa_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_chinassa_accepted', full_name='CPlayer_GetTimeSSAAccepted_Response.time_chinassa_accepted', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10733,
  serialized_end=10855,
)


_CPLAYER_ACCEPTSSA_REQUEST = _descriptor.Descriptor(
  name='CPlayer_AcceptSSA_Request',
  full_name='CPlayer_AcceptSSA_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agreement_type', full_name='CPlayer_AcceptSSA_Request.agreement_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_signed_utc', full_name='CPlayer_AcceptSSA_Request.time_signed_utc', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10857,
  serialized_end=10976,
)


_CPLAYER_ACCEPTSSA_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_AcceptSSA_Response',
  full_name='CPlayer_AcceptSSA_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10978,
  serialized_end=11006,
)


_CPLAYER_GETNICKNAMELIST_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetNicknameList_Request',
  full_name='CPlayer_GetNicknameList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11008,
  serialized_end=11041,
)


_CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME = _descriptor.Descriptor(
  name='PlayerNickname',
  full_name='CPlayer_GetNicknameList_Response.PlayerNickname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPlayer_GetNicknameList_Response.PlayerNickname.accountid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='CPlayer_GetNicknameList_Response.PlayerNickname.nickname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11149,
  serialized_end=11202,
)

_CPLAYER_GETNICKNAMELIST_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetNicknameList_Response',
  full_name='CPlayer_GetNicknameList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nicknames', full_name='CPlayer_GetNicknameList_Response.nicknames', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11044,
  serialized_end=11202,
)


_CPLAYER_GETPERFRIENDPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPerFriendPreferences_Request',
  full_name='CPlayer_GetPerFriendPreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11204,
  serialized_end=11245,
)


_PERFRIENDPREFERENCES = _descriptor.Descriptor(
  name='PerFriendPreferences',
  full_name='PerFriendPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='PerFriendPreferences.accountid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='PerFriendPreferences.nickname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_showingame', full_name='PerFriendPreferences.notifications_showingame', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_showonline', full_name='PerFriendPreferences.notifications_showonline', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_showmessages', full_name='PerFriendPreferences.notifications_showmessages', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_showingame', full_name='PerFriendPreferences.sounds_showingame', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_showonline', full_name='PerFriendPreferences.sounds_showonline', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sounds_showmessages', full_name='PerFriendPreferences.sounds_showmessages', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifications_sendmobile', full_name='PerFriendPreferences.notifications_sendmobile', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11248,
  serialized_end=11969,
)


_CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPerFriendPreferences_Response',
  full_name='CPlayer_GetPerFriendPreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_GetPerFriendPreferences_Response.preferences', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11971,
  serialized_end=12057,
)


_CPLAYER_SETPERFRIENDPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetPerFriendPreferences_Request',
  full_name='CPlayer_SetPerFriendPreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_SetPerFriendPreferences_Request.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12059,
  serialized_end=12144,
)


_CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetPerFriendPreferences_Response',
  full_name='CPlayer_SetPerFriendPreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12146,
  serialized_end=12188,
)


_CPLAYER_ADDFRIEND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_AddFriend_Request',
  full_name='CPlayer_AddFriend_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_AddFriend_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301Steam ID of user to whom to send a friend invite.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12190,
  serialized_end=12289,
)


_CPLAYER_ADDFRIEND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_AddFriend_Response',
  full_name='CPlayer_AddFriend_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_sent', full_name='CPlayer_AddFriend_Response.invite_sent', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306True if the operation was successful, false otherwise.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friend_relationship', full_name='CPlayer_AddFriend_Response.friend_relationship', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ethe resulting relationship.  Depending on state, may move directly to friends rather than invite sent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='CPlayer_AddFriend_Response.result', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12292,
  serialized_end=12554,
)


_CPLAYER_REMOVEFRIEND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_RemoveFriend_Request',
  full_name='CPlayer_RemoveFriend_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_RemoveFriend_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Steam ID of friend to remove.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12556,
  serialized_end=12638,
)


_CPLAYER_REMOVEFRIEND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_RemoveFriend_Response',
  full_name='CPlayer_RemoveFriend_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_relationship', full_name='CPlayer_RemoveFriend_Response.friend_relationship', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032the resulting relationship', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12640,
  serialized_end=12732,
)


_CPLAYER_IGNOREFRIEND_REQUEST = _descriptor.Descriptor(
  name='CPlayer_IgnoreFriend_Request',
  full_name='CPlayer_IgnoreFriend_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CPlayer_IgnoreFriend_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unignore', full_name='CPlayer_IgnoreFriend_Request.unignore', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308If set, remove from ignore/block list instead of adding ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12734,
  serialized_end=12861,
)


_CPLAYER_IGNOREFRIEND_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_IgnoreFriend_Response',
  full_name='CPlayer_IgnoreFriend_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_relationship', full_name='CPlayer_IgnoreFriend_Response.friend_relationship', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032the resulting relationship', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12863,
  serialized_end=12955,
)


_CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetCommunityPreferences_Request',
  full_name='CPlayer_GetCommunityPreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12957,
  serialized_end=12998,
)


_CPLAYER_COMMUNITYPREFERENCES = _descriptor.Descriptor(
  name='CPlayer_CommunityPreferences',
  full_name='CPlayer_CommunityPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hide_adult_content_violence', full_name='CPlayer_CommunityPreferences.hide_adult_content_violence', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_adult_content_sex', full_name='CPlayer_CommunityPreferences.hide_adult_content_sex', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parenthesize_nicknames', full_name='CPlayer_CommunityPreferences.parenthesize_nicknames', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_filter_setting', full_name='CPlayer_CommunityPreferences.text_filter_setting', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_filter_ignore_friends', full_name='CPlayer_CommunityPreferences.text_filter_ignore_friends', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_filter_words_revision', full_name='CPlayer_CommunityPreferences.text_filter_words_revision', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_updated', full_name='CPlayer_CommunityPreferences.timestamp_updated', index=6,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13001,
  serialized_end=13344,
)


_CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetCommunityPreferences_Response',
  full_name='CPlayer_GetCommunityPreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_GetCommunityPreferences_Response.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13346,
  serialized_end=13440,
)


_CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CPlayer_SetCommunityPreferences_Request',
  full_name='CPlayer_SetCommunityPreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_SetCommunityPreferences_Request.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13442,
  serialized_end=13535,
)


_CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_SetCommunityPreferences_Response',
  full_name='CPlayer_SetCommunityPreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13537,
  serialized_end=13579,
)


_CPLAYER_GETTEXTFILTERWORDS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetTextFilterWords_Request',
  full_name='CPlayer_GetTextFilterWords_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13581,
  serialized_end=13617,
)


_CPLAYER_TEXTFILTERWORDS = _descriptor.Descriptor(
  name='CPlayer_TextFilterWords',
  full_name='CPlayer_TextFilterWords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_filter_custom_banned_words', full_name='CPlayer_TextFilterWords.text_filter_custom_banned_words', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_filter_custom_clean_words', full_name='CPlayer_TextFilterWords.text_filter_custom_clean_words', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_filter_words_revision', full_name='CPlayer_TextFilterWords.text_filter_words_revision', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13620,
  serialized_end=13762,
)


_CPLAYER_GETTEXTFILTERWORDS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetTextFilterWords_Response',
  full_name='CPlayer_GetTextFilterWords_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='CPlayer_GetTextFilterWords_Response.words', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13764,
  serialized_end=13842,
)


_CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetNewSteamAnnouncementState_Request',
  full_name='CPlayer_GetNewSteamAnnouncementState_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CPlayer_GetNewSteamAnnouncementState_Request.language', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13844,
  serialized_end=13908,
)


_CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetNewSteamAnnouncementState_Response',
  full_name='CPlayer_GetNewSteamAnnouncementState_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CPlayer_GetNewSteamAnnouncementState_Response.state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_headline', full_name='CPlayer_GetNewSteamAnnouncementState_Response.announcement_headline', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_url', full_name='CPlayer_GetNewSteamAnnouncementState_Response.announcement_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_posted', full_name='CPlayer_GetNewSteamAnnouncementState_Response.time_posted', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_gid', full_name='CPlayer_GetNewSteamAnnouncementState_Response.announcement_gid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13911,
  serialized_end=14077,
)


_CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST = _descriptor.Descriptor(
  name='CPlayer_UpdateSteamAnnouncementLastRead_Request',
  full_name='CPlayer_UpdateSteamAnnouncementLastRead_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_gid', full_name='CPlayer_UpdateSteamAnnouncementLastRead_Request.announcement_gid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_posted', full_name='CPlayer_UpdateSteamAnnouncementLastRead_Request.time_posted', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14079,
  serialized_end=14175,
)


_CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_UpdateSteamAnnouncementLastRead_Response',
  full_name='CPlayer_UpdateSteamAnnouncementLastRead_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14177,
  serialized_end=14227,
)


_CPLAYER_GETPRIVACYSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetPrivacySettings_Request',
  full_name='CPlayer_GetPrivacySettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14229,
  serialized_end=14265,
)


_CPRIVACYSETTINGS = _descriptor.Descriptor(
  name='CPrivacySettings',
  full_name='CPrivacySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='privacy_state', full_name='CPrivacySettings.privacy_state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy_state_inventory', full_name='CPrivacySettings.privacy_state_inventory', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy_state_gifts', full_name='CPrivacySettings.privacy_state_gifts', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy_state_ownedgames', full_name='CPrivacySettings.privacy_state_ownedgames', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy_state_playtime', full_name='CPrivacySettings.privacy_state_playtime', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy_state_friendslist', full_name='CPrivacySettings.privacy_state_friendslist', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14268,
  serialized_end=14472,
)


_CPLAYER_GETPRIVACYSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetPrivacySettings_Response',
  full_name='CPlayer_GetPrivacySettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='privacy_settings', full_name='CPlayer_GetPrivacySettings_Response.privacy_settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14474,
  serialized_end=14556,
)


_CPLAYER_GETDURATIONCONTROL_REQUEST = _descriptor.Descriptor(
  name='CPlayer_GetDurationControl_Request',
  full_name='CPlayer_GetDurationControl_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPlayer_GetDurationControl_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14558,
  serialized_end=14609,
)


_CPLAYER_GETDURATIONCONTROL_RESPONSE = _descriptor.Descriptor(
  name='CPlayer_GetDurationControl_Response',
  full_name='CPlayer_GetDurationControl_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='CPlayer_GetDurationControl_Response.is_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='CPlayer_GetDurationControl_Response.seconds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_today', full_name='CPlayer_GetDurationControl_Response.seconds_today', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_steamchina_account', full_name='CPlayer_GetDurationControl_Response.is_steamchina_account', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_age_verified', full_name='CPlayer_GetDurationControl_Response.is_age_verified', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_allowed_today', full_name='CPlayer_GetDurationControl_Response.seconds_allowed_today', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='age_verification_pending', full_name='CPlayer_GetDurationControl_Response.age_verification_pending', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_minors', full_name='CPlayer_GetDurationControl_Response.block_minors', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14612,
  serialized_end=14852,
)


_CPLAYER_LASTPLAYEDTIMES_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_LastPlayedTimes_Notification',
  full_name='CPlayer_LastPlayedTimes_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='games', full_name='CPlayer_LastPlayedTimes_Notification.games', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14854,
  serialized_end=14950,
)


_CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_FriendNicknameChanged_Notification',
  full_name='CPlayer_FriendNicknameChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPlayer_FriendNicknameChanged_Notification.accountid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='CPlayer_FriendNicknameChanged_Notification.nickname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_echo_to_self', full_name='CPlayer_FriendNicknameChanged_Notification.is_echo_to_self', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14952,
  serialized_end=15058,
)


_CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_FriendEquippedProfileItemsChanged_Notification',
  full_name='CPlayer_FriendEquippedProfileItemsChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPlayer_FriendEquippedProfileItemsChanged_Notification.accountid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15060,
  serialized_end=15135,
)


_CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_NewSteamAnnouncementState_Notification',
  full_name='CPlayer_NewSteamAnnouncementState_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CPlayer_NewSteamAnnouncementState_Notification.state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_headline', full_name='CPlayer_NewSteamAnnouncementState_Notification.announcement_headline', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_url', full_name='CPlayer_NewSteamAnnouncementState_Notification.announcement_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_posted', full_name='CPlayer_NewSteamAnnouncementState_Notification.time_posted', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_gid', full_name='CPlayer_NewSteamAnnouncementState_Notification.announcement_gid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15138,
  serialized_end=15305,
)


_CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_CommunityPreferencesChanged_Notification',
  full_name='CPlayer_CommunityPreferencesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_CommunityPreferencesChanged_Notification.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15307,
  serialized_end=15409,
)


_CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_TextFilterWordsChanged_Notification',
  full_name='CPlayer_TextFilterWordsChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='CPlayer_TextFilterWordsChanged_Notification.words', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15411,
  serialized_end=15497,
)


_CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_PerFriendPreferencesChanged_Notification',
  full_name='CPlayer_PerFriendPreferencesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPlayer_PerFriendPreferencesChanged_Notification.accountid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CPlayer_PerFriendPreferencesChanged_Notification.preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15499,
  serialized_end=15612,
)


_CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CPlayer_PrivacySettingsChanged_Notification',
  full_name='CPlayer_PrivacySettingsChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='privacy_settings', full_name='CPlayer_PrivacySettingsChanged_Notification.privacy_settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15614,
  serialized_end=15704,
)

_CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE.fields_by_name['incoming_invite_mutual_friends_lists'].message_type = _CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST
_CPLAYER_GETOWNEDGAMES_RESPONSE_GAME.containing_type = _CPLAYER_GETOWNEDGAMES_RESPONSE
_CPLAYER_GETOWNEDGAMES_RESPONSE.fields_by_name['games'].message_type = _CPLAYER_GETOWNEDGAMES_RESPONSE_GAME
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO.containing_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO.containing_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['your_info'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['in_game'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['played_recently'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['played_ever'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['owns'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO
_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE.fields_by_name['in_wishlist'].message_type = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO
_CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE.containing_type = _CPLAYER_GETGAMEBADGELEVELS_RESPONSE
_CPLAYER_GETGAMEBADGELEVELS_RESPONSE.fields_by_name['badges'].message_type = _CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE
_CPLAYER_GETPROFILEBACKGROUND_RESPONSE.fields_by_name['profile_background'].message_type = _PROFILEITEM
_CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE.fields_by_name['profile_background'].message_type = _PROFILEITEM
_CPLAYER_GETAVATARFRAME_RESPONSE.fields_by_name['avatar_frame'].message_type = _PROFILEITEM
_CPLAYER_GETANIMATEDAVATAR_RESPONSE.fields_by_name['avatar'].message_type = _PROFILEITEM
_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE.fields_by_name['steam_deck_keyboard_skin'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_REQUEST.fields_by_name['filters'].enum_type = enums__pb2._ECOMMUNITYITEMCLASS
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['profile_backgrounds'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['mini_profile_backgrounds'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['avatar_frames'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['animated_avatars'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['profile_modifiers'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE.fields_by_name['steam_deck_keyboard_skins'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['profile_background'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['mini_profile_background'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['avatar_frame'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['animated_avatar'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['profile_modifier'].message_type = _PROFILEITEM
_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE.fields_by_name['steam_deck_keyboard_skin'].message_type = _PROFILEITEM
_CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON.containing_type = _CPLAYER_GETEMOTICONLIST_RESPONSE
_CPLAYER_GETEMOTICONLIST_RESPONSE.fields_by_name['emoticons'].message_type = _CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON
_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS.containing_type = _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE
_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE.fields_by_name['achievement_progress'].message_type = _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS
_PROFILECUSTOMIZATIONSLOT.fields_by_name['ban_check_result'].enum_type = steammessages__base__pb2._EBANCONTENTCHECKRESULT
_PROFILECUSTOMIZATION.fields_by_name['customization_type'].enum_type = enums__pb2._EPROFILECUSTOMIZATIONTYPE
_PROFILECUSTOMIZATION.fields_by_name['slots'].message_type = _PROFILECUSTOMIZATIONSLOT
_PROFILECUSTOMIZATION.fields_by_name['customization_style'].enum_type = _EPROFILECUSTOMIZATIONSTYLE
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION.fields_by_name['customization_type'].enum_type = enums__pb2._EPROFILECUSTOMIZATIONTYPE
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION.containing_type = _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE.fields_by_name['customizations'].message_type = _PROFILECUSTOMIZATION
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE.fields_by_name['profile_theme'].message_type = _PROFILETHEME
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE.fields_by_name['purchased_customizations'].message_type = _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION
_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE.fields_by_name['profile_preferences'].message_type = _PROFILEPREFERENCES
_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION.fields_by_name['customization_type'].enum_type = enums__pb2._EPROFILECUSTOMIZATIONTYPE
_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION.containing_type = _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE
_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE.fields_by_name['purchased_customizations'].message_type = _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION.fields_by_name['customization_type'].enum_type = enums__pb2._EPROFILECUSTOMIZATIONTYPE
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION.containing_type = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION.fields_by_name['customization_type'].enum_type = enums__pb2._EPROFILECUSTOMIZATIONTYPE
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION.containing_type = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE.fields_by_name['purchased_customizations'].message_type = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION
_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE.fields_by_name['upgraded_customizations'].message_type = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION
_CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE.fields_by_name['profile_themes'].message_type = _PROFILETHEME
_CPLAYER_SETPROFILEPREFERENCES_REQUEST.fields_by_name['profile_preferences'].message_type = _PROFILEPREFERENCES
_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME.containing_type = _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE
_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE.fields_by_name['games'].message_type = _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME
_CPLAYER_ACCEPTSSA_REQUEST.fields_by_name['agreement_type'].enum_type = _EAGREEMENTTYPE
_CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME.containing_type = _CPLAYER_GETNICKNAMELIST_RESPONSE
_CPLAYER_GETNICKNAMELIST_RESPONSE.fields_by_name['nicknames'].message_type = _CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME
_PERFRIENDPREFERENCES.fields_by_name['notifications_showingame'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['notifications_showonline'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['notifications_showmessages'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['sounds_showingame'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['sounds_showonline'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['sounds_showmessages'].enum_type = _ENOTIFICATIONSETTING
_PERFRIENDPREFERENCES.fields_by_name['notifications_sendmobile'].enum_type = _ENOTIFICATIONSETTING
_CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE.fields_by_name['preferences'].message_type = _PERFRIENDPREFERENCES
_CPLAYER_SETPERFRIENDPREFERENCES_REQUEST.fields_by_name['preferences'].message_type = _PERFRIENDPREFERENCES
_CPLAYER_COMMUNITYPREFERENCES.fields_by_name['text_filter_setting'].enum_type = _ETEXTFILTERSETTING
_CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE.fields_by_name['preferences'].message_type = _CPLAYER_COMMUNITYPREFERENCES
_CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST.fields_by_name['preferences'].message_type = _CPLAYER_COMMUNITYPREFERENCES
_CPLAYER_GETTEXTFILTERWORDS_RESPONSE.fields_by_name['words'].message_type = _CPLAYER_TEXTFILTERWORDS
_CPLAYER_GETPRIVACYSETTINGS_RESPONSE.fields_by_name['privacy_settings'].message_type = _CPRIVACYSETTINGS
_CPLAYER_LASTPLAYEDTIMES_NOTIFICATION.fields_by_name['games'].message_type = _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME
_CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION.fields_by_name['preferences'].message_type = _CPLAYER_COMMUNITYPREFERENCES
_CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION.fields_by_name['words'].message_type = _CPLAYER_TEXTFILTERWORDS
_CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION.fields_by_name['preferences'].message_type = _PERFRIENDPREFERENCES
_CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION.fields_by_name['privacy_settings'].message_type = _CPRIVACYSETTINGS
DESCRIPTOR.message_types_by_name['CPlayer_GetMutualFriendsForIncomingInvites_Request'] = _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_IncomingInviteMutualFriendList'] = _CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST
DESCRIPTOR.message_types_by_name['CPlayer_GetMutualFriendsForIncomingInvites_Response'] = _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetOwnedGames_Request'] = _CPLAYER_GETOWNEDGAMES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetOwnedGames_Response'] = _CPLAYER_GETOWNEDGAMES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPlayNext_Request'] = _CPLAYER_GETPLAYNEXT_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetPlayNext_Response'] = _CPLAYER_GETPLAYNEXT_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetFriendsGameplayInfo_Request'] = _CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetFriendsGameplayInfo_Response'] = _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetGameBadgeLevels_Request'] = _CPLAYER_GETGAMEBADGELEVELS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetGameBadgeLevels_Response'] = _CPLAYER_GETGAMEBADGELEVELS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileBackground_Request'] = _CPLAYER_GETPROFILEBACKGROUND_REQUEST
DESCRIPTOR.message_types_by_name['ProfileItem'] = _PROFILEITEM
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileBackground_Response'] = _CPLAYER_GETPROFILEBACKGROUND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetProfileBackground_Request'] = _CPLAYER_SETPROFILEBACKGROUND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetProfileBackground_Response'] = _CPLAYER_SETPROFILEBACKGROUND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetMiniProfileBackground_Request'] = _CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetMiniProfileBackground_Response'] = _CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetMiniProfileBackground_Request'] = _CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetMiniProfileBackground_Response'] = _CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetAvatarFrame_Request'] = _CPLAYER_GETAVATARFRAME_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetAvatarFrame_Response'] = _CPLAYER_GETAVATARFRAME_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetAvatarFrame_Request'] = _CPLAYER_SETAVATARFRAME_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetAvatarFrame_Response'] = _CPLAYER_SETAVATARFRAME_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetAnimatedAvatar_Request'] = _CPLAYER_GETANIMATEDAVATAR_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetAnimatedAvatar_Response'] = _CPLAYER_GETANIMATEDAVATAR_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetAnimatedAvatar_Request'] = _CPLAYER_SETANIMATEDAVATAR_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetAnimatedAvatar_Response'] = _CPLAYER_SETANIMATEDAVATAR_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetSteamDeckKeyboardSkin_Request'] = _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetSteamDeckKeyboardSkin_Response'] = _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetSteamDeckKeyboardSkin_Request'] = _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetSteamDeckKeyboardSkin_Response'] = _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileItemsOwned_Request'] = _CPLAYER_GETPROFILEITEMSOWNED_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileItemsOwned_Response'] = _CPLAYER_GETPROFILEITEMSOWNED_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileItemsEquipped_Request'] = _CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileItemsEquipped_Response'] = _CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetEquippedProfileItemFlags_Request'] = _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetEquippedProfileItemFlags_Response'] = _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetEmoticonList_Request'] = _CPLAYER_GETEMOTICONLIST_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetEmoticonList_Response'] = _CPLAYER_GETEMOTICONLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetAchievementsProgress_Request'] = _CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetAchievementsProgress_Response'] = _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetFavoriteBadge_Request'] = _CPLAYER_GETFAVORITEBADGE_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetFavoriteBadge_Response'] = _CPLAYER_GETFAVORITEBADGE_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetFavoriteBadge_Request'] = _CPLAYER_SETFAVORITEBADGE_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetFavoriteBadge_Response'] = _CPLAYER_SETFAVORITEBADGE_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileCustomization_Request'] = _CPLAYER_GETPROFILECUSTOMIZATION_REQUEST
DESCRIPTOR.message_types_by_name['ProfileCustomizationSlot'] = _PROFILECUSTOMIZATIONSLOT
DESCRIPTOR.message_types_by_name['ProfileCustomization'] = _PROFILECUSTOMIZATION
DESCRIPTOR.message_types_by_name['ProfileTheme'] = _PROFILETHEME
DESCRIPTOR.message_types_by_name['ProfilePreferences'] = _PROFILEPREFERENCES
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileCustomization_Response'] = _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPurchasedProfileCustomizations_Request'] = _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetPurchasedProfileCustomizations_Response'] = _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request'] = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response'] = _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileThemesAvailable_Request'] = _CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetProfileThemesAvailable_Response'] = _CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetProfileTheme_Request'] = _CPLAYER_SETPROFILETHEME_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetProfileTheme_Response'] = _CPLAYER_SETPROFILETHEME_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetProfilePreferences_Request'] = _CPLAYER_SETPROFILEPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetProfilePreferences_Response'] = _CPLAYER_SETPROFILEPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_PostStatusToFriends_Request'] = _CPLAYER_POSTSTATUSTOFRIENDS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_PostStatusToFriends_Response'] = _CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPostedStatus_Request'] = _CPLAYER_GETPOSTEDSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetPostedStatus_Response'] = _CPLAYER_GETPOSTEDSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_DeletePostedStatus_Request'] = _CPLAYER_DELETEPOSTEDSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_DeletePostedStatus_Response'] = _CPLAYER_DELETEPOSTEDSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetLastPlayedTimes_Request'] = _CPLAYER_GETLASTPLAYEDTIMES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetLastPlayedTimes_Response'] = _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetTimeSSAAccepted_Request'] = _CPLAYER_GETTIMESSAACCEPTED_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetTimeSSAAccepted_Response'] = _CPLAYER_GETTIMESSAACCEPTED_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_AcceptSSA_Request'] = _CPLAYER_ACCEPTSSA_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_AcceptSSA_Response'] = _CPLAYER_ACCEPTSSA_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetNicknameList_Request'] = _CPLAYER_GETNICKNAMELIST_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetNicknameList_Response'] = _CPLAYER_GETNICKNAMELIST_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPerFriendPreferences_Request'] = _CPLAYER_GETPERFRIENDPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['PerFriendPreferences'] = _PERFRIENDPREFERENCES
DESCRIPTOR.message_types_by_name['CPlayer_GetPerFriendPreferences_Response'] = _CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetPerFriendPreferences_Request'] = _CPLAYER_SETPERFRIENDPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetPerFriendPreferences_Response'] = _CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_AddFriend_Request'] = _CPLAYER_ADDFRIEND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_AddFriend_Response'] = _CPLAYER_ADDFRIEND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_RemoveFriend_Request'] = _CPLAYER_REMOVEFRIEND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_RemoveFriend_Response'] = _CPLAYER_REMOVEFRIEND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_IgnoreFriend_Request'] = _CPLAYER_IGNOREFRIEND_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_IgnoreFriend_Response'] = _CPLAYER_IGNOREFRIEND_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetCommunityPreferences_Request'] = _CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_CommunityPreferences'] = _CPLAYER_COMMUNITYPREFERENCES
DESCRIPTOR.message_types_by_name['CPlayer_GetCommunityPreferences_Response'] = _CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_SetCommunityPreferences_Request'] = _CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_SetCommunityPreferences_Response'] = _CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetTextFilterWords_Request'] = _CPLAYER_GETTEXTFILTERWORDS_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_TextFilterWords'] = _CPLAYER_TEXTFILTERWORDS
DESCRIPTOR.message_types_by_name['CPlayer_GetTextFilterWords_Response'] = _CPLAYER_GETTEXTFILTERWORDS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetNewSteamAnnouncementState_Request'] = _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetNewSteamAnnouncementState_Response'] = _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_UpdateSteamAnnouncementLastRead_Request'] = _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_UpdateSteamAnnouncementLastRead_Response'] = _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetPrivacySettings_Request'] = _CPLAYER_GETPRIVACYSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CPrivacySettings'] = _CPRIVACYSETTINGS
DESCRIPTOR.message_types_by_name['CPlayer_GetPrivacySettings_Response'] = _CPLAYER_GETPRIVACYSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_GetDurationControl_Request'] = _CPLAYER_GETDURATIONCONTROL_REQUEST
DESCRIPTOR.message_types_by_name['CPlayer_GetDurationControl_Response'] = _CPLAYER_GETDURATIONCONTROL_RESPONSE
DESCRIPTOR.message_types_by_name['CPlayer_LastPlayedTimes_Notification'] = _CPLAYER_LASTPLAYEDTIMES_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_FriendNicknameChanged_Notification'] = _CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_FriendEquippedProfileItemsChanged_Notification'] = _CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_NewSteamAnnouncementState_Notification'] = _CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_CommunityPreferencesChanged_Notification'] = _CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_TextFilterWordsChanged_Notification'] = _CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_PerFriendPreferencesChanged_Notification'] = _CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CPlayer_PrivacySettingsChanged_Notification'] = _CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EProfileCustomizationStyle'] = _EPROFILECUSTOMIZATIONSTYLE
DESCRIPTOR.enum_types_by_name['EAgreementType'] = _EAGREEMENTTYPE
DESCRIPTOR.enum_types_by_name['ENotificationSetting'] = _ENOTIFICATIONSETTING
DESCRIPTOR.enum_types_by_name['ETextFilterSetting'] = _ETEXTFILTERSETTING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPlayer_GetMutualFriendsForIncomingInvites_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetMutualFriendsForIncomingInvites_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetMutualFriendsForIncomingInvites_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetMutualFriendsForIncomingInvites_Request)

CPlayer_IncomingInviteMutualFriendList = _reflection.GeneratedProtocolMessageType('CPlayer_IncomingInviteMutualFriendList', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_IncomingInviteMutualFriendList)
  })
_sym_db.RegisterMessage(CPlayer_IncomingInviteMutualFriendList)

CPlayer_GetMutualFriendsForIncomingInvites_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetMutualFriendsForIncomingInvites_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetMutualFriendsForIncomingInvites_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetMutualFriendsForIncomingInvites_Response)

CPlayer_GetOwnedGames_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetOwnedGames_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETOWNEDGAMES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetOwnedGames_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetOwnedGames_Request)

CPlayer_GetOwnedGames_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetOwnedGames_Response', (_message.Message,), {

  'Game' : _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETOWNEDGAMES_RESPONSE_GAME,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetOwnedGames_Response.Game)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETOWNEDGAMES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetOwnedGames_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetOwnedGames_Response)
_sym_db.RegisterMessage(CPlayer_GetOwnedGames_Response.Game)

CPlayer_GetPlayNext_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPlayNext_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPLAYNEXT_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPlayNext_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPlayNext_Request)

CPlayer_GetPlayNext_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPlayNext_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPLAYNEXT_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPlayNext_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPlayNext_Response)

CPlayer_GetFriendsGameplayInfo_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetFriendsGameplayInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetFriendsGameplayInfo_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetFriendsGameplayInfo_Request)

CPlayer_GetFriendsGameplayInfo_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetFriendsGameplayInfo_Response', (_message.Message,), {

  'FriendsGameplayInfo' : _reflection.GeneratedProtocolMessageType('FriendsGameplayInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo)
    })
  ,

  'OwnGameplayInfo' : _reflection.GeneratedProtocolMessageType('OwnGameplayInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetFriendsGameplayInfo_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetFriendsGameplayInfo_Response)
_sym_db.RegisterMessage(CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo)
_sym_db.RegisterMessage(CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo)

CPlayer_GetGameBadgeLevels_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetGameBadgeLevels_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETGAMEBADGELEVELS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetGameBadgeLevels_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetGameBadgeLevels_Request)

CPlayer_GetGameBadgeLevels_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetGameBadgeLevels_Response', (_message.Message,), {

  'Badge' : _reflection.GeneratedProtocolMessageType('Badge', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetGameBadgeLevels_Response.Badge)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETGAMEBADGELEVELS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetGameBadgeLevels_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetGameBadgeLevels_Response)
_sym_db.RegisterMessage(CPlayer_GetGameBadgeLevels_Response.Badge)

CPlayer_GetProfileBackground_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileBackground_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEBACKGROUND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileBackground_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileBackground_Request)

ProfileItem = _reflection.GeneratedProtocolMessageType('ProfileItem', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEITEM,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:ProfileItem)
  })
_sym_db.RegisterMessage(ProfileItem)

CPlayer_GetProfileBackground_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileBackground_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEBACKGROUND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileBackground_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileBackground_Response)

CPlayer_SetProfileBackground_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfileBackground_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILEBACKGROUND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfileBackground_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetProfileBackground_Request)

CPlayer_SetProfileBackground_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfileBackground_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILEBACKGROUND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfileBackground_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetProfileBackground_Response)

CPlayer_GetMiniProfileBackground_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetMiniProfileBackground_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetMiniProfileBackground_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetMiniProfileBackground_Request)

CPlayer_GetMiniProfileBackground_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetMiniProfileBackground_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetMiniProfileBackground_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetMiniProfileBackground_Response)

CPlayer_SetMiniProfileBackground_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetMiniProfileBackground_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetMiniProfileBackground_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetMiniProfileBackground_Request)

CPlayer_SetMiniProfileBackground_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetMiniProfileBackground_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetMiniProfileBackground_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetMiniProfileBackground_Response)

CPlayer_GetAvatarFrame_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetAvatarFrame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETAVATARFRAME_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAvatarFrame_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetAvatarFrame_Request)

CPlayer_GetAvatarFrame_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetAvatarFrame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETAVATARFRAME_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAvatarFrame_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetAvatarFrame_Response)

CPlayer_SetAvatarFrame_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetAvatarFrame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETAVATARFRAME_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetAvatarFrame_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetAvatarFrame_Request)

CPlayer_SetAvatarFrame_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetAvatarFrame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETAVATARFRAME_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetAvatarFrame_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetAvatarFrame_Response)

CPlayer_GetAnimatedAvatar_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetAnimatedAvatar_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETANIMATEDAVATAR_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAnimatedAvatar_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetAnimatedAvatar_Request)

CPlayer_GetAnimatedAvatar_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetAnimatedAvatar_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETANIMATEDAVATAR_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAnimatedAvatar_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetAnimatedAvatar_Response)

CPlayer_SetAnimatedAvatar_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetAnimatedAvatar_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETANIMATEDAVATAR_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetAnimatedAvatar_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetAnimatedAvatar_Request)

CPlayer_SetAnimatedAvatar_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetAnimatedAvatar_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETANIMATEDAVATAR_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetAnimatedAvatar_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetAnimatedAvatar_Response)

CPlayer_GetSteamDeckKeyboardSkin_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetSteamDeckKeyboardSkin_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetSteamDeckKeyboardSkin_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetSteamDeckKeyboardSkin_Request)

CPlayer_GetSteamDeckKeyboardSkin_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetSteamDeckKeyboardSkin_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetSteamDeckKeyboardSkin_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetSteamDeckKeyboardSkin_Response)

CPlayer_SetSteamDeckKeyboardSkin_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetSteamDeckKeyboardSkin_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetSteamDeckKeyboardSkin_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetSteamDeckKeyboardSkin_Request)

CPlayer_SetSteamDeckKeyboardSkin_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetSteamDeckKeyboardSkin_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetSteamDeckKeyboardSkin_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetSteamDeckKeyboardSkin_Response)

CPlayer_GetProfileItemsOwned_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileItemsOwned_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEITEMSOWNED_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileItemsOwned_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileItemsOwned_Request)

CPlayer_GetProfileItemsOwned_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileItemsOwned_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEITEMSOWNED_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileItemsOwned_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileItemsOwned_Response)

CPlayer_GetProfileItemsEquipped_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileItemsEquipped_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileItemsEquipped_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileItemsEquipped_Request)

CPlayer_GetProfileItemsEquipped_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileItemsEquipped_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileItemsEquipped_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileItemsEquipped_Response)

CPlayer_SetEquippedProfileItemFlags_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetEquippedProfileItemFlags_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetEquippedProfileItemFlags_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetEquippedProfileItemFlags_Request)

CPlayer_SetEquippedProfileItemFlags_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetEquippedProfileItemFlags_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetEquippedProfileItemFlags_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetEquippedProfileItemFlags_Response)

CPlayer_GetEmoticonList_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetEmoticonList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETEMOTICONLIST_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetEmoticonList_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetEmoticonList_Request)

CPlayer_GetEmoticonList_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetEmoticonList_Response', (_message.Message,), {

  'Emoticon' : _reflection.GeneratedProtocolMessageType('Emoticon', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetEmoticonList_Response.Emoticon)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETEMOTICONLIST_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetEmoticonList_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetEmoticonList_Response)
_sym_db.RegisterMessage(CPlayer_GetEmoticonList_Response.Emoticon)

CPlayer_GetAchievementsProgress_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetAchievementsProgress_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAchievementsProgress_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetAchievementsProgress_Request)

CPlayer_GetAchievementsProgress_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetAchievementsProgress_Response', (_message.Message,), {

  'AchievementProgress' : _reflection.GeneratedProtocolMessageType('AchievementProgress', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetAchievementsProgress_Response.AchievementProgress)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetAchievementsProgress_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetAchievementsProgress_Response)
_sym_db.RegisterMessage(CPlayer_GetAchievementsProgress_Response.AchievementProgress)

CPlayer_GetFavoriteBadge_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetFavoriteBadge_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETFAVORITEBADGE_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetFavoriteBadge_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetFavoriteBadge_Request)

CPlayer_GetFavoriteBadge_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetFavoriteBadge_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETFAVORITEBADGE_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetFavoriteBadge_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetFavoriteBadge_Response)

CPlayer_SetFavoriteBadge_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetFavoriteBadge_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETFAVORITEBADGE_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetFavoriteBadge_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetFavoriteBadge_Request)

CPlayer_SetFavoriteBadge_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetFavoriteBadge_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETFAVORITEBADGE_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetFavoriteBadge_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetFavoriteBadge_Response)

CPlayer_GetProfileCustomization_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileCustomization_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILECUSTOMIZATION_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileCustomization_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileCustomization_Request)

ProfileCustomizationSlot = _reflection.GeneratedProtocolMessageType('ProfileCustomizationSlot', (_message.Message,), {
  'DESCRIPTOR' : _PROFILECUSTOMIZATIONSLOT,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:ProfileCustomizationSlot)
  })
_sym_db.RegisterMessage(ProfileCustomizationSlot)

ProfileCustomization = _reflection.GeneratedProtocolMessageType('ProfileCustomization', (_message.Message,), {
  'DESCRIPTOR' : _PROFILECUSTOMIZATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:ProfileCustomization)
  })
_sym_db.RegisterMessage(ProfileCustomization)

ProfileTheme = _reflection.GeneratedProtocolMessageType('ProfileTheme', (_message.Message,), {
  'DESCRIPTOR' : _PROFILETHEME,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:ProfileTheme)
  })
_sym_db.RegisterMessage(ProfileTheme)

ProfilePreferences = _reflection.GeneratedProtocolMessageType('ProfilePreferences', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEPREFERENCES,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:ProfilePreferences)
  })
_sym_db.RegisterMessage(ProfilePreferences)

CPlayer_GetProfileCustomization_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileCustomization_Response', (_message.Message,), {

  'PurchasedCustomization' : _reflection.GeneratedProtocolMessageType('PurchasedCustomization', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetProfileCustomization_Response.PurchasedCustomization)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileCustomization_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileCustomization_Response)
_sym_db.RegisterMessage(CPlayer_GetProfileCustomization_Response.PurchasedCustomization)

CPlayer_GetPurchasedProfileCustomizations_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPurchasedProfileCustomizations_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedProfileCustomizations_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPurchasedProfileCustomizations_Request)

CPlayer_GetPurchasedProfileCustomizations_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPurchasedProfileCustomizations_Response', (_message.Message,), {

  'PurchasedCustomization' : _reflection.GeneratedProtocolMessageType('PurchasedCustomization', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedProfileCustomizations_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPurchasedProfileCustomizations_Response)
_sym_db.RegisterMessage(CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization)

CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request)

CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response', (_message.Message,), {

  'PurchasedCustomization' : _reflection.GeneratedProtocolMessageType('PurchasedCustomization', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization)
    })
  ,

  'UpgradedCustomization' : _reflection.GeneratedProtocolMessageType('UpgradedCustomization', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response)
_sym_db.RegisterMessage(CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization)
_sym_db.RegisterMessage(CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization)

CPlayer_GetProfileThemesAvailable_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileThemesAvailable_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileThemesAvailable_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileThemesAvailable_Request)

CPlayer_GetProfileThemesAvailable_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetProfileThemesAvailable_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetProfileThemesAvailable_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetProfileThemesAvailable_Response)

CPlayer_SetProfileTheme_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfileTheme_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILETHEME_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfileTheme_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetProfileTheme_Request)

CPlayer_SetProfileTheme_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfileTheme_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILETHEME_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfileTheme_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetProfileTheme_Response)

CPlayer_SetProfilePreferences_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfilePreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILEPREFERENCES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfilePreferences_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetProfilePreferences_Request)

CPlayer_SetProfilePreferences_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetProfilePreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPROFILEPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetProfilePreferences_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetProfilePreferences_Response)

CPlayer_PostStatusToFriends_Request = _reflection.GeneratedProtocolMessageType('CPlayer_PostStatusToFriends_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_POSTSTATUSTOFRIENDS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_PostStatusToFriends_Request)
  })
_sym_db.RegisterMessage(CPlayer_PostStatusToFriends_Request)

CPlayer_PostStatusToFriends_Response = _reflection.GeneratedProtocolMessageType('CPlayer_PostStatusToFriends_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_PostStatusToFriends_Response)
  })
_sym_db.RegisterMessage(CPlayer_PostStatusToFriends_Response)

CPlayer_GetPostedStatus_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPostedStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPOSTEDSTATUS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPostedStatus_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPostedStatus_Request)

CPlayer_GetPostedStatus_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPostedStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPOSTEDSTATUS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPostedStatus_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPostedStatus_Response)

CPlayer_DeletePostedStatus_Request = _reflection.GeneratedProtocolMessageType('CPlayer_DeletePostedStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_DELETEPOSTEDSTATUS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_DeletePostedStatus_Request)
  })
_sym_db.RegisterMessage(CPlayer_DeletePostedStatus_Request)

CPlayer_DeletePostedStatus_Response = _reflection.GeneratedProtocolMessageType('CPlayer_DeletePostedStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_DELETEPOSTEDSTATUS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_DeletePostedStatus_Response)
  })
_sym_db.RegisterMessage(CPlayer_DeletePostedStatus_Response)

CPlayer_GetLastPlayedTimes_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetLastPlayedTimes_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETLASTPLAYEDTIMES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetLastPlayedTimes_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetLastPlayedTimes_Request)

CPlayer_GetLastPlayedTimes_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetLastPlayedTimes_Response', (_message.Message,), {

  'Game' : _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetLastPlayedTimes_Response.Game)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetLastPlayedTimes_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetLastPlayedTimes_Response)
_sym_db.RegisterMessage(CPlayer_GetLastPlayedTimes_Response.Game)

CPlayer_GetTimeSSAAccepted_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetTimeSSAAccepted_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETTIMESSAACCEPTED_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetTimeSSAAccepted_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetTimeSSAAccepted_Request)

CPlayer_GetTimeSSAAccepted_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetTimeSSAAccepted_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETTIMESSAACCEPTED_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetTimeSSAAccepted_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetTimeSSAAccepted_Response)

CPlayer_AcceptSSA_Request = _reflection.GeneratedProtocolMessageType('CPlayer_AcceptSSA_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_ACCEPTSSA_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_AcceptSSA_Request)
  })
_sym_db.RegisterMessage(CPlayer_AcceptSSA_Request)

CPlayer_AcceptSSA_Response = _reflection.GeneratedProtocolMessageType('CPlayer_AcceptSSA_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_ACCEPTSSA_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_AcceptSSA_Response)
  })
_sym_db.RegisterMessage(CPlayer_AcceptSSA_Response)

CPlayer_GetNicknameList_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetNicknameList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETNICKNAMELIST_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetNicknameList_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetNicknameList_Request)

CPlayer_GetNicknameList_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetNicknameList_Response', (_message.Message,), {

  'PlayerNickname' : _reflection.GeneratedProtocolMessageType('PlayerNickname', (_message.Message,), {
    'DESCRIPTOR' : _CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME,
    '__module__' : 'steammessages_player_pb2'
    # @@protoc_insertion_point(class_scope:CPlayer_GetNicknameList_Response.PlayerNickname)
    })
  ,
  'DESCRIPTOR' : _CPLAYER_GETNICKNAMELIST_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetNicknameList_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetNicknameList_Response)
_sym_db.RegisterMessage(CPlayer_GetNicknameList_Response.PlayerNickname)

CPlayer_GetPerFriendPreferences_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPerFriendPreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPERFRIENDPREFERENCES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPerFriendPreferences_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPerFriendPreferences_Request)

PerFriendPreferences = _reflection.GeneratedProtocolMessageType('PerFriendPreferences', (_message.Message,), {
  'DESCRIPTOR' : _PERFRIENDPREFERENCES,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:PerFriendPreferences)
  })
_sym_db.RegisterMessage(PerFriendPreferences)

CPlayer_GetPerFriendPreferences_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPerFriendPreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPerFriendPreferences_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPerFriendPreferences_Response)

CPlayer_SetPerFriendPreferences_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetPerFriendPreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPERFRIENDPREFERENCES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetPerFriendPreferences_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetPerFriendPreferences_Request)

CPlayer_SetPerFriendPreferences_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetPerFriendPreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetPerFriendPreferences_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetPerFriendPreferences_Response)

CPlayer_AddFriend_Request = _reflection.GeneratedProtocolMessageType('CPlayer_AddFriend_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_ADDFRIEND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_AddFriend_Request)
  })
_sym_db.RegisterMessage(CPlayer_AddFriend_Request)

CPlayer_AddFriend_Response = _reflection.GeneratedProtocolMessageType('CPlayer_AddFriend_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_ADDFRIEND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_AddFriend_Response)
  })
_sym_db.RegisterMessage(CPlayer_AddFriend_Response)

CPlayer_RemoveFriend_Request = _reflection.GeneratedProtocolMessageType('CPlayer_RemoveFriend_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_REMOVEFRIEND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_RemoveFriend_Request)
  })
_sym_db.RegisterMessage(CPlayer_RemoveFriend_Request)

CPlayer_RemoveFriend_Response = _reflection.GeneratedProtocolMessageType('CPlayer_RemoveFriend_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_REMOVEFRIEND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_RemoveFriend_Response)
  })
_sym_db.RegisterMessage(CPlayer_RemoveFriend_Response)

CPlayer_IgnoreFriend_Request = _reflection.GeneratedProtocolMessageType('CPlayer_IgnoreFriend_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_IGNOREFRIEND_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_IgnoreFriend_Request)
  })
_sym_db.RegisterMessage(CPlayer_IgnoreFriend_Request)

CPlayer_IgnoreFriend_Response = _reflection.GeneratedProtocolMessageType('CPlayer_IgnoreFriend_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_IGNOREFRIEND_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_IgnoreFriend_Response)
  })
_sym_db.RegisterMessage(CPlayer_IgnoreFriend_Response)

CPlayer_GetCommunityPreferences_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetCommunityPreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetCommunityPreferences_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetCommunityPreferences_Request)

CPlayer_CommunityPreferences = _reflection.GeneratedProtocolMessageType('CPlayer_CommunityPreferences', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_COMMUNITYPREFERENCES,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_CommunityPreferences)
  })
_sym_db.RegisterMessage(CPlayer_CommunityPreferences)

CPlayer_GetCommunityPreferences_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetCommunityPreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetCommunityPreferences_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetCommunityPreferences_Response)

CPlayer_SetCommunityPreferences_Request = _reflection.GeneratedProtocolMessageType('CPlayer_SetCommunityPreferences_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetCommunityPreferences_Request)
  })
_sym_db.RegisterMessage(CPlayer_SetCommunityPreferences_Request)

CPlayer_SetCommunityPreferences_Response = _reflection.GeneratedProtocolMessageType('CPlayer_SetCommunityPreferences_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_SetCommunityPreferences_Response)
  })
_sym_db.RegisterMessage(CPlayer_SetCommunityPreferences_Response)

CPlayer_GetTextFilterWords_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetTextFilterWords_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETTEXTFILTERWORDS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetTextFilterWords_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetTextFilterWords_Request)

CPlayer_TextFilterWords = _reflection.GeneratedProtocolMessageType('CPlayer_TextFilterWords', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_TEXTFILTERWORDS,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_TextFilterWords)
  })
_sym_db.RegisterMessage(CPlayer_TextFilterWords)

CPlayer_GetTextFilterWords_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetTextFilterWords_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETTEXTFILTERWORDS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetTextFilterWords_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetTextFilterWords_Response)

CPlayer_GetNewSteamAnnouncementState_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetNewSteamAnnouncementState_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetNewSteamAnnouncementState_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetNewSteamAnnouncementState_Request)

CPlayer_GetNewSteamAnnouncementState_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetNewSteamAnnouncementState_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetNewSteamAnnouncementState_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetNewSteamAnnouncementState_Response)

CPlayer_UpdateSteamAnnouncementLastRead_Request = _reflection.GeneratedProtocolMessageType('CPlayer_UpdateSteamAnnouncementLastRead_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_UpdateSteamAnnouncementLastRead_Request)
  })
_sym_db.RegisterMessage(CPlayer_UpdateSteamAnnouncementLastRead_Request)

CPlayer_UpdateSteamAnnouncementLastRead_Response = _reflection.GeneratedProtocolMessageType('CPlayer_UpdateSteamAnnouncementLastRead_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_UpdateSteamAnnouncementLastRead_Response)
  })
_sym_db.RegisterMessage(CPlayer_UpdateSteamAnnouncementLastRead_Response)

CPlayer_GetPrivacySettings_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetPrivacySettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPRIVACYSETTINGS_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPrivacySettings_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetPrivacySettings_Request)

CPrivacySettings = _reflection.GeneratedProtocolMessageType('CPrivacySettings', (_message.Message,), {
  'DESCRIPTOR' : _CPRIVACYSETTINGS,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPrivacySettings)
  })
_sym_db.RegisterMessage(CPrivacySettings)

CPlayer_GetPrivacySettings_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetPrivacySettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETPRIVACYSETTINGS_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetPrivacySettings_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetPrivacySettings_Response)

CPlayer_GetDurationControl_Request = _reflection.GeneratedProtocolMessageType('CPlayer_GetDurationControl_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETDURATIONCONTROL_REQUEST,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetDurationControl_Request)
  })
_sym_db.RegisterMessage(CPlayer_GetDurationControl_Request)

CPlayer_GetDurationControl_Response = _reflection.GeneratedProtocolMessageType('CPlayer_GetDurationControl_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_GETDURATIONCONTROL_RESPONSE,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_GetDurationControl_Response)
  })
_sym_db.RegisterMessage(CPlayer_GetDurationControl_Response)

CPlayer_LastPlayedTimes_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_LastPlayedTimes_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_LASTPLAYEDTIMES_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_LastPlayedTimes_Notification)
  })
_sym_db.RegisterMessage(CPlayer_LastPlayedTimes_Notification)

CPlayer_FriendNicknameChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_FriendNicknameChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_FriendNicknameChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_FriendNicknameChanged_Notification)

CPlayer_FriendEquippedProfileItemsChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_FriendEquippedProfileItemsChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_FriendEquippedProfileItemsChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_FriendEquippedProfileItemsChanged_Notification)

CPlayer_NewSteamAnnouncementState_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_NewSteamAnnouncementState_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_NewSteamAnnouncementState_Notification)
  })
_sym_db.RegisterMessage(CPlayer_NewSteamAnnouncementState_Notification)

CPlayer_CommunityPreferencesChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_CommunityPreferencesChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_CommunityPreferencesChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_CommunityPreferencesChanged_Notification)

CPlayer_TextFilterWordsChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_TextFilterWordsChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_TextFilterWordsChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_TextFilterWordsChanged_Notification)

CPlayer_PerFriendPreferencesChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_PerFriendPreferencesChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_PerFriendPreferencesChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_PerFriendPreferencesChanged_Notification)

CPlayer_PrivacySettingsChanged_Notification = _reflection.GeneratedProtocolMessageType('CPlayer_PrivacySettingsChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_player_pb2'
  # @@protoc_insertion_point(class_scope:CPlayer_PrivacySettingsChanged_Notification)
  })
_sym_db.RegisterMessage(CPlayer_PrivacySettingsChanged_Notification)


DESCRIPTOR._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['include_appinfo']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['include_played_free_games']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['appids_filter']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['include_free_sub']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['skip_unvetted_apps']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['language']._options = None
_CPLAYER_GETOWNEDGAMES_REQUEST.fields_by_name['include_extended_appinfo']._options = None
_CPLAYER_GETPROFILEBACKGROUND_REQUEST.fields_by_name['steamid']._options = None
_PROFILEITEM.fields_by_name['image_small']._options = None
_PROFILEITEM.fields_by_name['image_large']._options = None
_PROFILEITEM.fields_by_name['name']._options = None
_PROFILEITEM.fields_by_name['item_title']._options = None
_PROFILEITEM.fields_by_name['item_description']._options = None
_PROFILEITEM.fields_by_name['movie_webm']._options = None
_PROFILEITEM.fields_by_name['movie_mp4']._options = None
_PROFILEITEM.fields_by_name['movie_webm_small']._options = None
_PROFILEITEM.fields_by_name['movie_mp4_small']._options = None
_PROFILEITEM.fields_by_name['equipped_flags']._options = None
_CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_GETAVATARFRAME_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_GETANIMATEDAVATAR_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST.fields_by_name['flags']._options = None
_CPLAYER_GETPOSTEDSTATUS_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_GETLASTPLAYEDTIMES_REQUEST.fields_by_name['min_last_played']._options = None
_CPLAYER_ADDFRIEND_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_ADDFRIEND_RESPONSE.fields_by_name['invite_sent']._options = None
_CPLAYER_ADDFRIEND_RESPONSE.fields_by_name['friend_relationship']._options = None
_CPLAYER_REMOVEFRIEND_REQUEST.fields_by_name['steamid']._options = None
_CPLAYER_REMOVEFRIEND_RESPONSE.fields_by_name['friend_relationship']._options = None
_CPLAYER_IGNOREFRIEND_REQUEST.fields_by_name['unignore']._options = None
_CPLAYER_IGNOREFRIEND_RESPONSE.fields_by_name['friend_relationship']._options = None

_PLAYER = _descriptor.ServiceDescriptor(
  name='Player',
  full_name='Player',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030)A service for accessing Steam player data',
  create_key=_descriptor._internal_create_key,
  serialized_start=16426,
  serialized_end=24062,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMutualFriendsForIncomingInvites',
    full_name='Player.GetMutualFriendsForIncomingInvites',
    index=0,
    containing_service=None,
    input_type=_CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST,
    output_type=_CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE,
    serialized_options=b'\202\265\030ZGet me the mutual friends for each of my pending incoming invites (individuals and clans).',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOwnedGames',
    full_name='Player.GetOwnedGames',
    index=1,
    containing_service=None,
    input_type=_CPLAYER_GETOWNEDGAMES_REQUEST,
    output_type=_CPLAYER_GETOWNEDGAMES_RESPONSE,
    serialized_options=b'\202\265\030*Return a list of games owned by the player',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlayNext',
    full_name='Player.GetPlayNext',
    index=2,
    containing_service=None,
    input_type=_CPLAYER_GETPLAYNEXT_REQUEST,
    output_type=_CPLAYER_GETPLAYNEXT_RESPONSE,
    serialized_options=b'\202\265\030/Return suggested games for player to play next.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFriendsGameplayInfo',
    full_name='Player.GetFriendsGameplayInfo',
    index=3,
    containing_service=None,
    input_type=_CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST,
    output_type=_CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE,
    serialized_options=b'\202\265\030GGet a list of friends who are playing, have played, own, or want a game',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGameBadgeLevels',
    full_name='Player.GetGameBadgeLevels',
    index=4,
    containing_service=None,
    input_type=_CPLAYER_GETGAMEBADGELEVELS_REQUEST,
    output_type=_CPLAYER_GETGAMEBADGELEVELS_RESPONSE,
    serialized_options=b'\202\265\030QReturns the Steam Level of a user, the Badge level for the game, and if it\'s foil',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileBackground',
    full_name='Player.GetProfileBackground',
    index=5,
    containing_service=None,
    input_type=_CPLAYER_GETPROFILEBACKGROUND_REQUEST,
    output_type=_CPLAYER_GETPROFILEBACKGROUND_RESPONSE,
    serialized_options=b'\202\265\030;Gets which profile background is active for a specific user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileBackground',
    full_name='Player.SetProfileBackground',
    index=6,
    containing_service=None,
    input_type=_CPLAYER_SETPROFILEBACKGROUND_REQUEST,
    output_type=_CPLAYER_SETPROFILEBACKGROUND_RESPONSE,
    serialized_options=b'\202\265\030\"Sets the user\'s profile background',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMiniProfileBackground',
    full_name='Player.GetMiniProfileBackground',
    index=7,
    containing_service=None,
    input_type=_CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST,
    output_type=_CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE,
    serialized_options=b'\202\265\030@Gets which mini profile background is active for a specific user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetMiniProfileBackground',
    full_name='Player.SetMiniProfileBackground',
    index=8,
    containing_service=None,
    input_type=_CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST,
    output_type=_CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE,
    serialized_options=b'\202\265\030\'Sets the user\'s mini profile background',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAvatarFrame',
    full_name='Player.GetAvatarFrame',
    index=9,
    containing_service=None,
    input_type=_CPLAYER_GETAVATARFRAME_REQUEST,
    output_type=_CPLAYER_GETAVATARFRAME_RESPONSE,
    serialized_options=b'\202\265\0305Gets which avatar frame is active for a specific user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAvatarFrame',
    full_name='Player.SetAvatarFrame',
    index=10,
    containing_service=None,
    input_type=_CPLAYER_SETAVATARFRAME_REQUEST,
    output_type=_CPLAYER_SETAVATARFRAME_RESPONSE,
    serialized_options=b'\202\265\030.Sets the user\'s avatar frame for their profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAnimatedAvatar',
    full_name='Player.GetAnimatedAvatar',
    index=11,
    containing_service=None,
    input_type=_CPLAYER_GETANIMATEDAVATAR_REQUEST,
    output_type=_CPLAYER_GETANIMATEDAVATAR_RESPONSE,
    serialized_options=b'\202\265\0308Gets which animated avatar is active for a specific user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAnimatedAvatar',
    full_name='Player.SetAnimatedAvatar',
    index=12,
    containing_service=None,
    input_type=_CPLAYER_SETANIMATEDAVATAR_REQUEST,
    output_type=_CPLAYER_SETANIMATEDAVATAR_RESPONSE,
    serialized_options=b'\202\265\0301Sets the user\'s animated avatar for their profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSteamDeckKeyboardSkin',
    full_name='Player.GetSteamDeckKeyboardSkin',
    index=13,
    containing_service=None,
    input_type=_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST,
    output_type=_CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE,
    serialized_options=b'\202\265\030AGets which Steam Deck keyboard skin is active for a specific user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSteamDeckKeyboardSkin',
    full_name='Player.SetSteamDeckKeyboardSkin',
    index=14,
    containing_service=None,
    input_type=_CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST,
    output_type=_CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE,
    serialized_options=b'\202\265\0300Sets the user\'s current Steam Deck keyboard skin',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileItemsOwned',
    full_name='Player.GetProfileItemsOwned',
    index=15,
    containing_service=None,
    input_type=_CPLAYER_GETPROFILEITEMSOWNED_REQUEST,
    output_type=_CPLAYER_GETPROFILEITEMSOWNED_RESPONSE,
    serialized_options=b'\202\265\0305Returns the items the user can equip on their profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileItemsEquipped',
    full_name='Player.GetProfileItemsEquipped',
    index=16,
    containing_service=None,
    input_type=_CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST,
    output_type=_CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE,
    serialized_options=b'\202\265\0308Returns the items the user has equipped on their profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEquippedProfileItemFlags',
    full_name='Player.SetEquippedProfileItemFlags',
    index=17,
    containing_service=None,
    input_type=_CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST,
    output_type=_CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE,
    serialized_options=b'\202\265\030\'Sets special flags on the equipped item',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEmoticonList',
    full_name='Player.GetEmoticonList',
    index=18,
    containing_service=None,
    input_type=_CPLAYER_GETEMOTICONLIST_REQUEST,
    output_type=_CPLAYER_GETEMOTICONLIST_RESPONSE,
    serialized_options=b'\202\265\0305Gets a list of the emoticons a user has with metadata',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAchievementsProgress',
    full_name='Player.GetAchievementsProgress',
    index=19,
    containing_service=None,
    input_type=_CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST,
    output_type=_CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE,
    serialized_options=b'\202\265\030EGets the achievement completion stats for the specified list of apps.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFavoriteBadge',
    full_name='Player.GetFavoriteBadge',
    index=20,
    containing_service=None,
    input_type=_CPLAYER_GETFAVORITEBADGE_REQUEST,
    output_type=_CPLAYER_GETFAVORITEBADGE_RESPONSE,
    serialized_options=b'\202\265\0301Gets the badge the user has set as their favorite',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFavoriteBadge',
    full_name='Player.SetFavoriteBadge',
    index=21,
    containing_service=None,
    input_type=_CPLAYER_SETFAVORITEBADGE_REQUEST,
    output_type=_CPLAYER_SETFAVORITEBADGE_RESPONSE,
    serialized_options=b'\202\265\030%Sets the badge  as the users favorite',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileCustomization',
    full_name='Player.GetProfileCustomization',
    index=22,
    containing_service=None,
    input_type=_CPLAYER_GETPROFILECUSTOMIZATION_REQUEST,
    output_type=_CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE,
    serialized_options=b'\202\265\0301Returns the customizations (if any) for a profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPurchasedProfileCustomizations',
    full_name='Player.GetPurchasedProfileCustomizations',
    index=23,
    containing_service=None,
    input_type=_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST,
    output_type=_CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE,
    serialized_options=b'\202\265\030,Returns the purchased profile customizations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPurchasedAndUpgradedProfileCustomizations',
    full_name='Player.GetPurchasedAndUpgradedProfileCustomizations',
    index=24,
    containing_service=None,
    input_type=_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST,
    output_type=_CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE,
    serialized_options=b'\202\265\0309Returns the purchased and upgraded profile customizations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileThemesAvailable',
    full_name='Player.GetProfileThemesAvailable',
    index=25,
    containing_service=None,
    input_type=_CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST,
    output_type=_CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE,
    serialized_options=b'\202\265\030#Gets themes available for the user.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileTheme',
    full_name='Player.SetProfileTheme',
    index=26,
    containing_service=None,
    input_type=_CPLAYER_SETPROFILETHEME_REQUEST,
    output_type=_CPLAYER_SETPROFILETHEME_RESPONSE,
    serialized_options=b'\202\265\030\037Selects a theme for the profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfilePreferences',
    full_name='Player.SetProfilePreferences',
    index=27,
    containing_service=None,
    input_type=_CPLAYER_SETPROFILEPREFERENCES_REQUEST,
    output_type=_CPLAYER_SETPROFILEPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030\030Sets profile preferences',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostStatusToFriends',
    full_name='Player.PostStatusToFriends',
    index=28,
    containing_service=None,
    input_type=_CPLAYER_POSTSTATUSTOFRIENDS_REQUEST,
    output_type=_CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE,
    serialized_options=b'\202\265\030)Posts custom status text into the blotter',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPostedStatus',
    full_name='Player.GetPostedStatus',
    index=29,
    containing_service=None,
    input_type=_CPLAYER_GETPOSTEDSTATUS_REQUEST,
    output_type=_CPLAYER_GETPOSTEDSTATUS_RESPONSE,
    serialized_options=b'\202\265\030*Gets a posted status text for a user by id',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePostedStatus',
    full_name='Player.DeletePostedStatus',
    index=30,
    containing_service=None,
    input_type=_CPLAYER_DELETEPOSTEDSTATUS_REQUEST,
    output_type=_CPLAYER_DELETEPOSTEDSTATUS_RESPONSE,
    serialized_options=b'\202\265\030-Deletes a posted status text for a user by id',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClientGetLastPlayedTimes',
    full_name='Player.ClientGetLastPlayedTimes',
    index=31,
    containing_service=None,
    input_type=_CPLAYER_GETLASTPLAYEDTIMES_REQUEST,
    output_type=_CPLAYER_GETLASTPLAYEDTIMES_RESPONSE,
    serialized_options=b'\202\265\030*Gets the last-played times for the account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTimeSSAAccepted',
    full_name='Player.GetTimeSSAAccepted',
    index=32,
    containing_service=None,
    input_type=_CPLAYER_GETTIMESSAACCEPTED_REQUEST,
    output_type=_CPLAYER_GETTIMESSAACCEPTED_RESPONSE,
    serialized_options=b'\202\265\030,Gets the time when the user accepted the SSA',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcceptSSA',
    full_name='Player.AcceptSSA',
    index=33,
    containing_service=None,
    input_type=_CPLAYER_ACCEPTSSA_REQUEST,
    output_type=_CPLAYER_ACCEPTSSA_RESPONSE,
    serialized_options=b'\202\265\030\031User is accepting the SSA',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNicknameList',
    full_name='Player.GetNicknameList',
    index=34,
    containing_service=None,
    input_type=_CPLAYER_GETNICKNAMELIST_REQUEST,
    output_type=_CPLAYER_GETNICKNAMELIST_RESPONSE,
    serialized_options=b'\202\265\0308Gets the list of nicknames this user has for other users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPerFriendPreferences',
    full_name='Player.GetPerFriendPreferences',
    index=35,
    containing_service=None,
    input_type=_CPLAYER_GETPERFRIENDPREFERENCES_REQUEST,
    output_type=_CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030IGets the list of per-friend preferences this user has set for other users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetPerFriendPreferences',
    full_name='Player.SetPerFriendPreferences',
    index=36,
    containing_service=None,
    input_type=_CPLAYER_SETPERFRIENDPREFERENCES_REQUEST,
    output_type=_CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030CSets the logged in user\'s per-friend preferences for the given user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddFriend',
    full_name='Player.AddFriend',
    index=37,
    containing_service=None,
    input_type=_CPLAYER_ADDFRIEND_REQUEST,
    output_type=_CPLAYER_ADDFRIEND_RESPONSE,
    serialized_options=b'\202\265\030)Invites another Steam user to be a friend',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveFriend',
    full_name='Player.RemoveFriend',
    index=38,
    containing_service=None,
    input_type=_CPLAYER_REMOVEFRIEND_REQUEST,
    output_type=_CPLAYER_REMOVEFRIEND_RESPONSE,
    serialized_options=b'\202\265\030/Removes a friend or ignores a friend suggestion',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IgnoreFriend',
    full_name='Player.IgnoreFriend',
    index=39,
    containing_service=None,
    input_type=_CPLAYER_IGNOREFRIEND_REQUEST,
    output_type=_CPLAYER_IGNOREFRIEND_RESPONSE,
    serialized_options=b'\202\265\030SBlocks or unblocks communication with the user.  Despite name, can be a non-friend.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommunityPreferences',
    full_name='Player.GetCommunityPreferences',
    index=40,
    containing_service=None,
    input_type=_CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST,
    output_type=_CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030*Returns the player\'s community preferences',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCommunityPreferences',
    full_name='Player.SetCommunityPreferences',
    index=41,
    containing_service=None,
    input_type=_CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST,
    output_type=_CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE,
    serialized_options=b'\202\265\030\'Sets the player\'s community preferences',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTextFilterWords',
    full_name='Player.GetTextFilterWords',
    index=42,
    containing_service=None,
    input_type=_CPLAYER_GETTEXTFILTERWORDS_REQUEST,
    output_type=_CPLAYER_GETTEXTFILTERWORDS_RESPONSE,
    serialized_options=b'\202\265\0306Get the custom text filtering dictionary for this user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNewSteamAnnouncementState',
    full_name='Player.GetNewSteamAnnouncementState',
    index=43,
    containing_service=None,
    input_type=_CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST,
    output_type=_CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE,
    serialized_options=b'\202\265\030[Calculates and returns what to display for UI that renders new steam announcement available',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSteamAnnouncementLastRead',
    full_name='Player.UpdateSteamAnnouncementLastRead',
    index=44,
    containing_service=None,
    input_type=_CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST,
    output_type=_CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE,
    serialized_options=b'\202\265\0300Marks latest announcement timestamp read by user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPrivacySettings',
    full_name='Player.GetPrivacySettings',
    index=45,
    containing_service=None,
    input_type=_CPLAYER_GETPRIVACYSETTINGS_REQUEST,
    output_type=_CPLAYER_GETPRIVACYSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030\035Get current privacy settings.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDurationControl',
    full_name='Player.GetDurationControl',
    index=46,
    containing_service=None,
    input_type=_CPLAYER_GETDURATIONCONTROL_REQUEST,
    output_type=_CPLAYER_GETDURATIONCONTROL_RESPONSE,
    serialized_options=b'\202\265\030\'Get gameplay duration control settings.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLAYER)

DESCRIPTOR.services_by_name['Player'] = _PLAYER


_PLAYERCLIENT = _descriptor.ServiceDescriptor(
  name='PlayerClient',
  full_name='PlayerClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030&Steam player data client notifications\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=24065,
  serialized_end=25511,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyLastPlayedTimes',
    full_name='PlayerClient.NotifyLastPlayedTimes',
    index=0,
    containing_service=None,
    input_type=_CPLAYER_LASTPLAYEDTIMES_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030;Notification from server to client of more recent play time',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyFriendNicknameChanged',
    full_name='PlayerClient.NotifyFriendNicknameChanged',
    index=1,
    containing_service=None,
    input_type=_CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030GNotification from server to client that a friend\'s nickname has changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyFriendEquippedProfileItemsChanged',
    full_name='PlayerClient.NotifyFriendEquippedProfileItemsChanged',
    index=2,
    containing_service=None,
    input_type=_CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030VNotification from server to client that a friend\'s equipped profile items have changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyNewSteamAnnouncementState',
    full_name='PlayerClient.NotifyNewSteamAnnouncementState',
    index=3,
    containing_service=None,
    input_type=_CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030?Notifies client of changes to steam announcement state for user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyCommunityPreferencesChanged',
    full_name='PlayerClient.NotifyCommunityPreferencesChanged',
    index=4,
    containing_service=None,
    input_type=_CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030PNotification from server to client that their community preferences have changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyTextFilterWordsChanged',
    full_name='PlayerClient.NotifyTextFilterWordsChanged',
    index=5,
    containing_service=None,
    input_type=_CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030SNotification from server to client that their text filtering dictionary has changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyPerFriendPreferencesChanged',
    full_name='PlayerClient.NotifyPerFriendPreferencesChanged',
    index=6,
    containing_service=None,
    input_type=_CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030ANotification from server that per-friend preferences have changed',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyPrivacyPrivacySettingsChanged',
    full_name='PlayerClient.NotifyPrivacyPrivacySettingsChanged',
    index=7,
    containing_service=None,
    input_type=_CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\0306Notification from server that privacy settings changed',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLAYERCLIENT)

DESCRIPTOR.services_by_name['PlayerClient'] = _PLAYERCLIENT

Player = service_reflection.GeneratedServiceType('Player', (_service.Service,), dict(
  DESCRIPTOR = _PLAYER,
  __module__ = 'steammessages_player_pb2'
  ))

Player_Stub = service_reflection.GeneratedServiceStubType('Player_Stub', (Player,), dict(
  DESCRIPTOR = _PLAYER,
  __module__ = 'steammessages_player_pb2'
  ))


PlayerClient = service_reflection.GeneratedServiceType('PlayerClient', (_service.Service,), dict(
  DESCRIPTOR = _PLAYERCLIENT,
  __module__ = 'steammessages_player_pb2'
  ))

PlayerClient_Stub = service_reflection.GeneratedServiceStubType('PlayerClient_Stub', (PlayerClient,), dict(
  DESCRIPTOR = _PLAYERCLIENT,
  __module__ = 'steammessages_player_pb2'
  ))


# @@protoc_insertion_point(module_scope)
