# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_webui_friends.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_clientserver_friends_pb2 as steammessages__clientserver__friends__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_webui_friends.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_webui_friends.proto\x1a steammessages_unified_base.proto\x1a\x18steammessages_base.proto\x1a(steammessages_clientserver_friends.proto\"\x82\x01\n1CHelpRequestLogs_UploadUserApplicationLog_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08log_type\x18\x02 \x01(\t\x12\x16\n\x0eversion_string\x18\x03 \x01(\t\x12\x14\n\x0clog_contents\x18\x04 \x01(\t\"@\n2CHelpRequestLogs_UploadUserApplicationLog_Response\x12\n\n\x02id\x18\x01 \x01(\x04\"n\n\x1e\x43MsgClientAppMinutesPlayedData\x12L\n\x0eminutes_played\x18\x01 \x03(\x0b\x32\x34.CMsgClientAppMinutesPlayedData_AppMinutesPlayedData\"n\n3CMsgClientAppMinutesPlayedData_AppMinutesPlayedData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0f\n\x07\x66orever\x18\x02 \x01(\x05\x12\x16\n\x0elast_two_weeks\x18\x03 \x01(\x05\">\n\x1a\x43\x43ommunity_GetApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\x05\x12\x10\n\x08language\x18\x02 \x01(\r\"B\n\x1b\x43\x43ommunity_GetApps_Response\x12#\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x15.CCDDBAppDetailCommon\"T\n1CCommunity_GetAppRichPresenceLocalization_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x10\n\x08language\x18\x02 \x01(\t\"\x97\x01\n2CCommunity_GetAppRichPresenceLocalization_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12R\n\x0btoken_lists\x18\x02 \x03(\x0b\x32=.CCommunity_GetAppRichPresenceLocalization_Response_TokenList\"W\n8CCommunity_GetAppRichPresenceLocalization_Response_Token\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9b\x01\n<CCommunity_GetAppRichPresenceLocalization_Response_TokenList\x12\x10\n\x08language\x18\x01 \x01(\t\x12I\n\x06tokens\x18\x02 \x03(\x0b\x32\x39.CCommunity_GetAppRichPresenceLocalization_Response_Token\"\x9d\x02\n#CCommunity_GetCommentThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x05 \x01(\x06\x12\r\n\x05start\x18\x06 \x01(\x05\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x10\n\x08upvoters\x18\x08 \x01(\x05\x12\x17\n\x0finclude_deleted\x18\t \x01(\x08\x12\x12\n\ngidcomment\x18\n \x01(\x06\x12\x13\n\x0btime_oldest\x18\x0b \x01(\r\x12\x14\n\x0coldest_first\x18\x0c \x01(\x08\"\xf6\x01\n\x12\x43\x43ommunity_Comment\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07upvotes\x18\x05 \x01(\x05\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x16\n\x0ehidden_by_user\x18\x07 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x08 \x01(\x08\x12!\n\tipaddress\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x14\n\x0ctotal_hidden\x18\n \x01(\x05\x12\x17\n\x0fupvoted_by_user\x18\x0b \x01(\x08\"\x88\x03\n$CCommunity_GetCommentThread_Response\x12%\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x13.CCommunity_Comment\x12-\n\x10\x64\x65leted_comments\x18\x02 \x03(\x0b\x32\x13.CCommunity_Comment\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x04 \x01(\x06\x12\r\n\x05start\x18\x05 \x01(\x05\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\x12\x13\n\x0btotal_count\x18\x07 \x01(\x05\x12\x0f\n\x07upvotes\x18\x08 \x01(\x05\x12\x10\n\x08upvoters\x18\t \x03(\r\x12\x17\n\x0fuser_subscribed\x18\n \x01(\x08\x12\x14\n\x0cuser_upvoted\x18\x0b \x01(\x08\x12\x18\n\x10\x61nswer_commentid\x18\x0c \x01(\x06\x12\x14\n\x0c\x61nswer_actor\x18\r \x01(\r\x12\x19\n\x11\x61nswer_actor_rank\x18\x0e \x01(\x05\x12\x10\n\x08\x63\x61n_post\x18\x0f \x01(\x08\"\xc7\x01\n&CCommunity_PostCommentToThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x18\n\x10gidparentcomment\x18\x07 \x01(\x06\x12\x1e\n\x16suppress_notifications\x18\x08 \x01(\x08\"v\n\'CCommunity_PostCommentToThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0f\n\x07upvotes\x18\x04 \x01(\x05\"\xa9\x01\n*CCommunity_DeleteCommentFromThread_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1b\n\x13\x63omment_thread_type\x18\x02 \x01(\r\x12\x12\n\ngidfeature\x18\x03 \x01(\x06\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x06\x12\x12\n\ngidcomment\x18\x05 \x01(\x06\x12\x10\n\x08undelete\x18\x06 \x01(\x08\"-\n+CCommunity_DeleteCommentFromThread_Response\"\xc0\x01\n$CCommunity_RateCommentThread_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x0f\n\x07rate_up\x18\x06 \x01(\x08\x12\x1e\n\x16suppress_notifications\x18\x07 \x01(\x08\"\x89\x01\n%CCommunity_RateCommentThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x04\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07upvotes\x18\x04 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x05 \x01(\x08\"\xaa\x01\n*CCommunity_GetCommentThreadRatings_Request\x12\x19\n\x11\x63ommentthreadtype\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x12\n\ngidfeature\x18\x03 \x01(\x04\x12\x13\n\x0bgidfeature2\x18\x04 \x01(\x04\x12\x12\n\ngidcomment\x18\x05 \x01(\x04\x12\x13\n\x0bmax_results\x18\x06 \x01(\r\"\x9c\x01\n+CCommunity_GetCommentThreadRatings_Response\x12\x17\n\x0f\x63ommentthreadid\x18\x01 \x01(\x04\x12\x12\n\ngidcomment\x18\x02 \x01(\x04\x12\x0f\n\x07upvotes\x18\x03 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x04 \x01(\x08\x12\x1a\n\x12upvoter_accountids\x18\x05 \x03(\r\"R\n\'CCommunity_RateClanAnnouncement_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"*\n(CCommunity_RateClanAnnouncement_Response\"K\n1CCommunity_GetClanAnnouncementVoteForUser_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\"Z\n2CCommunity_GetClanAnnouncementVoteForUser_Response\x12\x10\n\x08voted_up\x18\x01 \x01(\x08\x12\x12\n\nvoted_down\x18\x02 \x01(\x08\"/\n\x0c\x43\x41ppPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x03(\r\"\xd8\x02\n*CCommunity_GetUserPartnerEventNews_Request\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x1a\n\x12rtime32_start_time\x18\x03 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\x04 \x01(\r\x12\x1b\n\x13language_preference\x18\x05 \x03(\r\x12M\n\x11\x66ilter_event_type\x18\x06 \x03(\x05\x42\x32\x82\xb5\x18.enum; suggested type: ECommunityWordFilterType\x12\x17\n\x0f\x66ilter_to_appid\x18\x07 \x01(\x08\x12\x1f\n\x08\x61pp_list\x18\x08 \x03(\x0b\x32\r.CAppPriority\x12\x16\n\x0b\x63ount_after\x18\t \x01(\r:\x01\x30\x12\x17\n\x0c\x63ount_before\x18\n \x01(\r:\x01\x30\"W\n+CCommunity_GetUserPartnerEventNews_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CClanMatchEventByRange\"k\n\'CCommunity_GetBestEventsForUser_Request\x12\x1a\n\x12include_steam_blog\x18\x01 \x01(\x08\x12$\n\x1c\x66ilter_to_played_within_days\x18\x02 \x01(\r\"\xc3\x01\n\x1d\x43\x43ommunity_PartnerEventResult\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x19\n\x11possible_takeover\x18\x05 \x01(\x08\x12 \n\x15rtime32_last_modified\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x11user_app_priority\x18\x07 \x01(\x05\"[\n(CCommunity_GetBestEventsForUser_Response\x12/\n\x07results\x18\x01 \x03(\x0b\x32\x1e.CCommunity_PartnerEventResult\"8\n6CCommunity_ClearUserPartnerEventsAppPriorities_Request\"9\n7CCommunity_ClearUserPartnerEventsAppPriorities_Response\"O\n#CCommunity_PartnerEventsAppPriority\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11user_app_priority\x18\x02 \x01(\x05\"6\n4CCommunity_GetUserPartnerEventsAppPriorities_Request\"q\n5CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x38\n\npriorities\x18\x01 \x03(\x0b\x32$.CCommunity_PartnerEventsAppPriority\"G\n6CCommunity_ClearSinglePartnerEventsAppPriority_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"9\n7CCommunity_ClearSinglePartnerEventsAppPriority_Response\"?\n.CCommunity_PartnerEventsShowMoreForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowMoreForApp_Response\"?\n.CCommunity_PartnerEventsShowLessForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"1\n/CCommunity_PartnerEventsShowLessForApp_Response\"\x81\x01\n+CCommunity_MarkPartnerEventsForUser_Request\x12R\n\x08markings\x18\x01 \x03(\x0b\x32@.CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\"\xdd\x01\n?CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12P\n\x10\x64isplay_location\x18\x03 \x01(\x05\x42\x36\x82\xb5\x18\x32\x65num; suggested type: EPartnerEventDisplayLocation\x12\x12\n\nmark_shown\x18\x04 \x01(\x08\x12\x11\n\tmark_read\x18\x05 \x01(\x08\".\n,CCommunity_MarkPartnerEventsForUser_Response\"y\n*CProductImpressionsFromClient_Notification\x12K\n\x0bimpressions\x18\x01 \x03(\x0b\x32\x36.CProductImpressionsFromClient_Notification_Impression\"\xa9\x01\n5CProductImpressionsFromClient_Notification_Impression\x12H\n\x04type\x18\x01 \x01(\x05\x42:\x82\xb5\x18\x36\x65num; suggested type: EProductImpressionFromClientType\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fnum_impressions\x18\x03 \x01(\r\"P\n\x14\x43\x46riendsListCategory\x12\x0f\n\x07groupid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61\x63\x63ountid_members\x18\x03 \x03(\r\"$\n\"CFriendsList_GetCategories_Request\"P\n#CFriendsList_GetCategories_Response\x12)\n\ncategories\x18\x01 \x03(\x0b\x32\x15.CFriendsListCategory\"U\n\x19\x43\x46riendsListFavoriteEntry\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\r\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"#\n!CFriendsList_GetFavorites_Request\"S\n\"CFriendsList_GetFavorites_Response\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"R\n!CFriendsList_SetFavorites_Request\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"$\n\"CFriendsList_SetFavorites_Response\"[\n*CFriendsList_FavoritesChanged_Notification\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"%\n#CFriendsList_GetFriendsList_Request\"S\n$CFriendsList_GetFriendsList_Response\x12+\n\x0b\x66riendslist\x18\x01 \x01(\x0b\x32\x16.CMsgClientFriendsList\"c\n(CMsgClientUCMEnumerateUserPublishedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x12\n\nsort_order\x18\x03 \x01(\r\"\xb9\x01\n0CMsgClientUCMEnumerateUserPublishedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12Z\n\x0fpublished_files\x18\x02 \x03(\x0b\x32\x41.CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"]\n@CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\x98\x01\n)CMsgClientUCMEnumerateUserSubscribedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x14\n\tlist_type\x18\x03 \x01(\r:\x01\x31\x12\x1d\n\x12matching_file_type\x18\x04 \x01(\r:\x01\x30\x12\x11\n\x05\x63ount\x18\x05 \x01(\r:\x02\x35\x30\"\xbc\x01\n1CMsgClientUCMEnumerateUserSubscribedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\\\n\x10subscribed_files\x18\x02 \x03(\x0b\x32\x42.CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"}\nACMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x1d\n\x12rtime32_subscribed\x18\x02 \x01(\x07:\x01\x30\"N\n!CMsgClientUCMPublishedFileDeleted\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\x97\x01\n!CMsgClientWorkshopItemInfoRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12G\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32/.CMsgClientWorkshopItemInfoRequest_WorkshopItem\"a\n.CMsgClientWorkshopItemInfoRequest_WorkshopItem\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\"\xb2\x01\n\"CMsgClientWorkshopItemInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x13\n\x0bupdate_time\x18\x02 \x01(\r\x12L\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32\x34.CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo\x12\x15\n\rprivate_items\x18\x04 \x03(\x06\"\x8e\x01\n3CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\x11\n\tis_legacy\x18\x04 \x01(\x08\"\x94\x01\n%CMsgClientUCMGetPublishedFilesForUser\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x18\n\x10\x63reator_steam_id\x18\x02 \x01(\x06\x12\x15\n\rrequired_tags\x18\x03 \x03(\t\x12\x15\n\rexcluded_tags\x18\x04 \x03(\t\x12\x13\n\x0bstart_index\x18\x05 \x01(\r\"\xb3\x01\n-CMsgClientUCMGetPublishedFilesForUserResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12W\n\x0fpublished_files\x18\x02 \x03(\x0b\x32>.CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"Z\n=CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xb7\x01\n\x1e\x43MsgCREEnumeratePublishedFiles\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\nquery_type\x18\x02 \x01(\x05\x12\x13\n\x0bstart_index\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ys\x18\x04 \x01(\r\x12\r\n\x05\x63ount\x18\x05 \x01(\r\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x11\n\tuser_tags\x18\x07 \x03(\t\x12\x1e\n\x12matching_file_type\x18\x08 \x01(\r:\x02\x31\x33\"\xa5\x01\n&CMsgCREEnumeratePublishedFilesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12P\n\x0fpublished_files\x18\x02 \x03(\x0b\x32\x37.CMsgCREEnumeratePublishedFilesResponse_PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\"\x9d\x01\n6CMsgCREEnumeratePublishedFilesResponse_PublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x11\n\tvotes_for\x18\x02 \x01(\x05\x12\x15\n\rvotes_against\x18\x03 \x01(\x05\x12\x0f\n\x07reports\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"r\n\x18\x43MsgGameServerPingSample\x12\r\n\x05my_ip\x18\x01 \x01(\x07\x12\x11\n\tgs_app_id\x18\x02 \x01(\x05\x12\x34\n\ngs_samples\x18\x03 \x03(\x0b\x32 .CMsgGameServerPingSample_Sample\"^\n\x1f\x43MsgGameServerPingSample_Sample\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x13\n\x0b\x61vg_ping_ms\x18\x02 \x01(\r\x12\x1a\n\x12stddev_ping_ms_x10\x18\x03 \x01(\r\"D\n!CClan_RespondToClanInvite_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"$\n\"CClan_RespondToClanInvite_Response\"A\n&CVoiceChat_RequestOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"?\n\'CVoiceChat_RequestOneOnOneChat_Response\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\"^\n-CVoiceChat_OneOnOneChatRequested_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\"p\n%CVoiceChat_AnswerOneOnOneChat_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"(\n&CVoiceChat_AnswerOneOnOneChat_Response\"~\n3CVoiceChat_OneOnOneChatRequestResponse_Notification\x12\x14\n\x0cvoicechat_id\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"=\n\"CVoiceChat_EndOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"%\n#CVoiceChat_EndOneOnOneChat_Response\"U\n$CVoiceChat_LeaveOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x14\n\x0cvoice_chatid\x18\x02 \x01(\x06\"\'\n%CVoiceChat_LeaveOneOnOneChat_Response\"\xdd\x01\n+CVoiceChat_UserJoinedVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xe0\x01\n\'CVoiceChat_UserVoiceStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x1e\n\x16user_muted_mic_locally\x18\x03 \x01(\x08\x12!\n\x19user_muted_output_locally\x18\x04 \x01(\x08\x12#\n\x1buser_has_no_mic_for_session\x18\x05 \x01(\x08\x12!\n\x19user_webaudio_sample_rate\x18\x06 \x01(\x05\"y\n(CVoiceChat_AllMembersStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x37\n\x05users\x18\x02 \x03(\x0b\x32(.CVoiceChat_UserVoiceStatus_Notification\"\x88\x02\n,CVoiceChat_UpdateVoiceChatWebRTCData_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x18\n\x10ip_webrtc_server\x18\x02 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x03 \x01(\r\x12\x18\n\x10ip_webrtc_client\x18\x04 \x01(\r\x12\x1a\n\x12port_webrtc_client\x18\x05 \x01(\r\x12\x1e\n\x16ssrc_my_sending_stream\x18\x06 \x01(\r\x12\x12\n\nuser_agent\x18\x07 \x01(\t\x12\"\n\x1ahas_audio_worklets_support\x18\x08 \x01(\x08\"O\n-CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12\x1e\n\x16send_client_voice_logs\x18\x01 \x01(\x08\"i\n,CVoiceChat_UploadClientVoiceChatLogs_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12#\n\x1b\x63lient_voice_logs_new_lines\x18\x02 \x01(\t\"/\n-CVoiceChat_UploadClientVoiceChatLogs_Response\"9\n!CVoiceChat_LeaveVoiceChat_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\"$\n\"CVoiceChat_LeaveVoiceChat_Response\"\xdb\x01\n)CVoiceChat_UserLeftVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xaa\x01\n&CVoiceChat_VoiceChatEnded_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12 \n\x18one_on_one_steamid_lower\x18\x02 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x03 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x04 \x01(\x04\x12\x15\n\rchat_group_id\x18\x05 \x01(\x04\"=\n.CWebRTCClient_InitiateWebRTCConnection_Request\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"M\n/CWebRTCClient_InitiateWebRTCConnection_Response\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\"\x8b\x01\n+CWebRTC_WebRTCSessionConnected_Notification\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\tclient_ip\x18\x02 \x01(\r\x12\x13\n\x0b\x63lient_port\x18\x03 \x01(\r\x12\x11\n\tserver_ip\x18\x04 \x01(\r\x12\x13\n\x0bserver_port\x18\x05 \x01(\r\"\xde\x01\n2CWebRTC_WebRTCUpdateRemoteDescription_Notification\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\x12\"\n\x1aremote_description_version\x18\x02 \x01(\x04\x12h\n\x13ssrcs_to_accountids\x18\x03 \x03(\x0b\x32K.CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\"m\nJCWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\taccountid\x18\x02 \x01(\r\"\xdb\x01\n9CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x12\x18\n\x10ip_webrtc_server\x18\x01 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x02 \x01(\r\x12 \n\x18ip_webrtc_session_client\x18\x03 \x01(\r\x12\"\n\x1aport_webrtc_session_client\x18\x04 \x01(\r\x12\"\n\x1aremote_description_version\x18\x05 \x01(\x04\"<\n:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response\"\'\n%CMobilePerAccount_GetSettings_Request\"\xec\x01\n&CMobilePerAccount_GetSettings_Response\x12\x14\n\x0chas_settings\x18\x04 \x01(\x08\x12\x17\n\x0f\x61llow_sale_push\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llow_wishlist_push\x18\x03 \x01(\x08\x12\x1f\n\x17\x63hat_notification_level\x18\x05 \x01(\r\x12\x1a\n\x12notify_direct_chat\x18\x06 \x01(\x08\x12\x19\n\x11notify_group_chat\x18\x07 \x01(\x08\x12\x1e\n\x10\x61llow_event_push\x18\x08 \x01(\x08:\x04true\"\xd5\x01\n%CMobilePerAccount_SetSettings_Request\x12\x17\n\x0f\x61llow_sale_push\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llow_wishlist_push\x18\x03 \x01(\x08\x12\x1f\n\x17\x63hat_notification_level\x18\x04 \x01(\r\x12\x1a\n\x12notify_direct_chat\x18\x05 \x01(\x08\x12\x19\n\x11notify_group_chat\x18\x06 \x01(\x08\x12\x1e\n\x10\x61llow_event_push\x18\x07 \x01(\x08:\x04true\"(\n&CMobilePerAccount_SetSettings_Response\"\x84\x02\n*CMobileDevice_RegisterMobileDevice_Request\x12\x10\n\x08\x64\x65viceid\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x14\n\x0cpush_enabled\x18\x03 \x01(\x08\x12\x13\n\x0b\x61pp_version\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x06 \x01(\t\x12#\n\x1btwofactor_device_identifier\x18\x07 \x01(\t\x12\x38\n\nmobile_app\x18\x08 \x01(\x05\x42$\x82\xb5\x18 enum; suggested type: EMobileApp\"F\n+CMobileDevice_RegisterMobileDevice_Response\x12\x17\n\x0funique_deviceid\x18\x02 \x01(\r\"E\n1CMobileDevice_DeregisterMobileDevice_Notification\x12\x10\n\x08\x64\x65viceid\x18\x01 \x01(\t\"\x0e\n\x0cUnknownProto2\x97\x01\n\x0fHelpRequestLogs\x12\x83\x01\n\x18UploadUserApplicationLog\x12\x32.CHelpRequestLogs_UploadUserApplicationLog_Request\x1a\x33.CHelpRequestLogs_UploadUserApplicationLog_Response2\x9e\x10\n\tCommunity\x12\x44\n\x07GetApps\x12\x1b.CCommunity_GetApps_Request\x1a\x1c.CCommunity_GetApps_Response\x12\x89\x01\n\x1eGetAppRichPresenceLocalization\x12\x32.CCommunity_GetAppRichPresenceLocalization_Request\x1a\x33.CCommunity_GetAppRichPresenceLocalization_Response\x12_\n\x10GetCommentThread\x12$.CCommunity_GetCommentThread_Request\x1a%.CCommunity_GetCommentThread_Response\x12h\n\x13PostCommentToThread\x12\'.CCommunity_PostCommentToThread_Request\x1a(.CCommunity_PostCommentToThread_Response\x12t\n\x17\x44\x65leteCommentFromThread\x12+.CCommunity_DeleteCommentFromThread_Request\x1a,.CCommunity_DeleteCommentFromThread_Response\x12\x62\n\x11RateCommentThread\x12%.CCommunity_RateCommentThread_Request\x1a&.CCommunity_RateCommentThread_Response\x12t\n\x17GetCommentThreadRatings\x12+.CCommunity_GetCommentThreadRatings_Request\x1a,.CCommunity_GetCommentThreadRatings_Response\x12k\n\x14RateClanAnnouncement\x12(.CCommunity_RateClanAnnouncement_Request\x1a).CCommunity_RateClanAnnouncement_Response\x12\x89\x01\n\x1eGetClanAnnouncementVoteForUser\x12\x32.CCommunity_GetClanAnnouncementVoteForUser_Request\x1a\x33.CCommunity_GetClanAnnouncementVoteForUser_Response\x12t\n\x17GetUserPartnerEventNews\x12+.CCommunity_GetUserPartnerEventNews_Request\x1a,.CCommunity_GetUserPartnerEventNews_Response\x12k\n\x14GetBestEventsForUser\x12(.CCommunity_GetBestEventsForUser_Request\x1a).CCommunity_GetBestEventsForUser_Response\x12w\n\x18MarkPartnerEventsForUser\x12,.CCommunity_MarkPartnerEventsForUser_Request\x1a-.CCommunity_MarkPartnerEventsForUser_Response\x12\x80\x01\n\x1bPartnerEventsShowMoreForApp\x12/.CCommunity_PartnerEventsShowMoreForApp_Request\x1a\x30.CCommunity_PartnerEventsShowMoreForApp_Response\x12\x80\x01\n\x1bPartnerEventsShowLessForApp\x12/.CCommunity_PartnerEventsShowLessForApp_Request\x1a\x30.CCommunity_PartnerEventsShowLessForApp_Response\x12\x98\x01\n#ClearUserPartnerEventsAppPriorities\x12\x37.CCommunity_ClearUserPartnerEventsAppPriorities_Request\x1a\x38.CCommunity_ClearUserPartnerEventsAppPriorities_Response\x12\x92\x01\n!GetUserPartnerEventsAppPriorities\x12\x35.CCommunity_GetUserPartnerEventsAppPriorities_Request\x1a\x36.CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x98\x01\n#ClearSinglePartnerEventsAppPriority\x12\x37.CCommunity_ClearSinglePartnerEventsAppPriority_Request\x1a\x38.CCommunity_ClearSinglePartnerEventsAppPriority_Response2U\n\x11\x45xperimentService\x12@\n\"ReportProductImpressionsFromClient\x12\r.UnknownProto\x1a\x0b.NoResponse2\xfa\x02\n\x0b\x46riendsList\x12Z\n\rGetCategories\x12#.CFriendsList_GetCategories_Request\x1a$.CFriendsList_GetCategories_Response\x12]\n\x0eGetFriendsList\x12$.CFriendsList_GetFriendsList_Request\x1a%.CFriendsList_GetFriendsList_Response\x12W\n\x0cGetFavorites\x12\".CFriendsList_GetFavorites_Request\x1a#.CFriendsList_GetFavorites_Response\x12W\n\x0cSetFavorites\x12\".CFriendsList_SetFavorites_Request\x1a#.CFriendsList_SetFavorites_Response2a\n\x11\x46riendsListClient\x12L\n\x10\x46\x61voritesChanged\x12+.CFriendsList_FavoritesChanged_Notification\x1a\x0b.NoResponse2f\n\x04\x43lan\x12^\n\x13RespondToClanInvite\x12\".CClan_RespondToClanInvite_Request\x1a#.CClan_RespondToClanInvite_Response2\xc1\x06\n\tVoiceChat\x12z\n\x19UpdateVoiceChatWebRTCData\x12-.CVoiceChat_UpdateVoiceChatWebRTCData_Request\x1a..CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12z\n\x19UploadClientVoiceChatLogs\x12-.CVoiceChat_UploadClientVoiceChatLogs_Request\x1a..CVoiceChat_UploadClientVoiceChatLogs_Response\x12Y\n\x0eLeaveVoiceChat\x12\".CVoiceChat_LeaveVoiceChat_Request\x1a#.CVoiceChat_LeaveVoiceChat_Response\x12h\n\x13RequestOneOnOneChat\x12\'.CVoiceChat_RequestOneOnOneChat_Request\x1a(.CVoiceChat_RequestOneOnOneChat_Response\x12\x65\n\x12\x41nswerOneOnOneChat\x12&.CVoiceChat_AnswerOneOnOneChat_Request\x1a\'.CVoiceChat_AnswerOneOnOneChat_Response\x12\\\n\x0f\x45ndOneOnOneChat\x12#.CVoiceChat_EndOneOnOneChat_Request\x1a$.CVoiceChat_EndOneOnOneChat_Response\x12\x62\n\x11LeaveOneOnOneChat\x12%.CVoiceChat_LeaveOneOnOneChat_Request\x1a&.CVoiceChat_LeaveOneOnOneChat_Response2\xed\x04\n\x0fVoiceChatClient\x12V\n\x19NotifyUserJoinedVoiceChat\x12,.CVoiceChat_UserJoinedVoiceChat_Notification\x1a\x0b.NoResponse\x12R\n\x17NotifyUserLeftVoiceChat\x12*.CVoiceChat_UserLeftVoiceChat_Notification\x1a\x0b.NoResponse\x12L\n\x14NotifyVoiceChatEnded\x12\'.CVoiceChat_VoiceChatEnded_Notification\x1a\x0b.NoResponse\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12S\n\x19NotifyAllUsersVoiceStatus\x12).CVoiceChat_AllMembersStatus_Notification\x1a\x0b.NoResponse\x12Z\n\x1bNotifyOneOnOneChatRequested\x12..CVoiceChat_OneOnOneChatRequested_Notification\x1a\x0b.NoResponse\x12_\n\x1aNotifyOneOnOneChatResponse\x12\x34.CVoiceChat_OneOnOneChatRequestResponse_Notification\x1a\x0b.NoResponse2\xae\x02\n\x0cWebRTCClient\x12}\n\x18InitiateWebRTCConnection\x12/.CWebRTCClient_InitiateWebRTCConnection_Request\x1a\x30.CWebRTCClient_InitiateWebRTCConnection_Response\x12\x9e\x01\n#AcknowledgeUpdatedRemoteDescription\x12:.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x1a;.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response2\xdf\x01\n\x19WebRTCClientNotifications\x12Y\n\x1cNotifyWebRTCSessionConnected\x12,.CWebRTC_WebRTCSessionConnected_Notification\x1a\x0b.NoResponse\x12g\n#NotifyWebRTCUpdateRemoteDescription\x12\x33.CWebRTC_WebRTCUpdateRemoteDescription_Notification\x1a\x0b.NoResponse2\xd2\x01\n\x10MobilePerAccount\x12^\n\x0bGetSettings\x12&.CMobilePerAccount_GetSettings_Request\x1a\'.CMobilePerAccount_GetSettings_Response\x12^\n\x0bSetSettings\x12&.CMobilePerAccount_SetSettings_Request\x1a\'.CMobilePerAccount_SetSettings_Response2\xdc\x01\n\x0cMobileDevice\x12q\n\x14RegisterMobileDevice\x12+.CMobileDevice_RegisterMobileDevice_Request\x1a,.CMobileDevice_RegisterMobileDevice_Response\x12Y\n\x16\x44\x65registerMobileDevice\x12\x32.CMobileDevice_DeregisterMobileDevice_Notification\x1a\x0b.NoResponseB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,steammessages__base__pb2.DESCRIPTOR,steammessages__clientserver__friends__pb2.DESCRIPTOR,])




_CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST = _descriptor.Descriptor(
  name='CHelpRequestLogs_UploadUserApplicationLog_Request',
  full_name='CHelpRequestLogs_UploadUserApplicationLog_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CHelpRequestLogs_UploadUserApplicationLog_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_type', full_name='CHelpRequestLogs_UploadUserApplicationLog_Request.log_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_string', full_name='CHelpRequestLogs_UploadUserApplicationLog_Request.version_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_contents', full_name='CHelpRequestLogs_UploadUserApplicationLog_Request.log_contents', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=270,
)


_CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE = _descriptor.Descriptor(
  name='CHelpRequestLogs_UploadUserApplicationLog_Response',
  full_name='CHelpRequestLogs_UploadUserApplicationLog_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CHelpRequestLogs_UploadUserApplicationLog_Response.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=336,
)


_CMSGCLIENTAPPMINUTESPLAYEDDATA = _descriptor.Descriptor(
  name='CMsgClientAppMinutesPlayedData',
  full_name='CMsgClientAppMinutesPlayedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minutes_played', full_name='CMsgClientAppMinutesPlayedData.minutes_played', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=448,
)


_CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA = _descriptor.Descriptor(
  name='CMsgClientAppMinutesPlayedData_AppMinutesPlayedData',
  full_name='CMsgClientAppMinutesPlayedData_AppMinutesPlayedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientAppMinutesPlayedData_AppMinutesPlayedData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forever', full_name='CMsgClientAppMinutesPlayedData_AppMinutesPlayedData.forever', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_two_weeks', full_name='CMsgClientAppMinutesPlayedData_AppMinutesPlayedData.last_two_weeks', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=560,
)


_CCOMMUNITY_GETAPPS_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetApps_Request',
  full_name='CCommunity_GetApps_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CCommunity_GetApps_Request.appids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetApps_Request.language', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=624,
)


_CCOMMUNITY_GETAPPS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetApps_Response',
  full_name='CCommunity_GetApps_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CCommunity_GetApps_Response.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=692,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Request',
  full_name='CCommunity_GetAppRichPresenceLocalization_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_GetAppRichPresenceLocalization_Request.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetAppRichPresenceLocalization_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=778,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_GetAppRichPresenceLocalization_Response.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_lists', full_name='CCommunity_GetAppRichPresenceLocalization_Response.token_lists', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=932,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response_Token',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1021,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList.tokens', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1179,
)


_CCOMMUNITY_GETCOMMENTTHREAD_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetCommentThread_Request',
  full_name='CCommunity_GetCommentThread_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_GetCommentThread_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment_thread_type', full_name='CCommunity_GetCommentThread_Request.comment_thread_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature', full_name='CCommunity_GetCommentThread_Request.gidfeature', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature2', full_name='CCommunity_GetCommentThread_Request.gidfeature2', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_GetCommentThread_Request.commentthreadid', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='CCommunity_GetCommentThread_Request.start', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetCommentThread_Request.count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvoters', full_name='CCommunity_GetCommentThread_Request.upvoters', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_deleted', full_name='CCommunity_GetCommentThread_Request.include_deleted', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_GetCommentThread_Request.gidcomment', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_oldest', full_name='CCommunity_GetCommentThread_Request.time_oldest', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oldest_first', full_name='CCommunity_GetCommentThread_Request.oldest_first', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1467,
)


_CCOMMUNITY_COMMENT = _descriptor.Descriptor(
  name='CCommunity_Comment',
  full_name='CCommunity_Comment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_Comment.gidcomment', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_Comment.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CCommunity_Comment.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='CCommunity_Comment.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_Comment.upvotes', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='CCommunity_Comment.hidden', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden_by_user', full_name='CCommunity_Comment.hidden_by_user', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='CCommunity_Comment.deleted', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress', full_name='CCommunity_Comment.ipaddress', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_hidden', full_name='CCommunity_Comment.total_hidden', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvoted_by_user', full_name='CCommunity_Comment.upvoted_by_user', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1716,
)


_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetCommentThread_Response',
  full_name='CCommunity_GetCommentThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comments', full_name='CCommunity_GetCommentThread_Response.comments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_comments', full_name='CCommunity_GetCommentThread_Response.deleted_comments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_GetCommentThread_Response.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_GetCommentThread_Response.commentthreadid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='CCommunity_GetCommentThread_Response.start', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetCommentThread_Response.count', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_count', full_name='CCommunity_GetCommentThread_Response.total_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_GetCommentThread_Response.upvotes', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvoters', full_name='CCommunity_GetCommentThread_Response.upvoters', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_subscribed', full_name='CCommunity_GetCommentThread_Response.user_subscribed', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_upvoted', full_name='CCommunity_GetCommentThread_Response.user_upvoted', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_commentid', full_name='CCommunity_GetCommentThread_Response.answer_commentid', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_actor', full_name='CCommunity_GetCommentThread_Response.answer_actor', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_actor_rank', full_name='CCommunity_GetCommentThread_Response.answer_actor_rank', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_post', full_name='CCommunity_GetCommentThread_Response.can_post', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=2111,
)


_CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST = _descriptor.Descriptor(
  name='CCommunity_PostCommentToThread_Request',
  full_name='CCommunity_PostCommentToThread_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_PostCommentToThread_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment_thread_type', full_name='CCommunity_PostCommentToThread_Request.comment_thread_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature', full_name='CCommunity_PostCommentToThread_Request.gidfeature', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature2', full_name='CCommunity_PostCommentToThread_Request.gidfeature2', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='CCommunity_PostCommentToThread_Request.text', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidparentcomment', full_name='CCommunity_PostCommentToThread_Request.gidparentcomment', index=5,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suppress_notifications', full_name='CCommunity_PostCommentToThread_Request.suppress_notifications', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2114,
  serialized_end=2313,
)


_CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PostCommentToThread_Response',
  full_name='CCommunity_PostCommentToThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_PostCommentToThread_Response.gidcomment', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_PostCommentToThread_Response.commentthreadid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_PostCommentToThread_Response.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_PostCommentToThread_Response.upvotes', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2315,
  serialized_end=2433,
)


_CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST = _descriptor.Descriptor(
  name='CCommunity_DeleteCommentFromThread_Request',
  full_name='CCommunity_DeleteCommentFromThread_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_DeleteCommentFromThread_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment_thread_type', full_name='CCommunity_DeleteCommentFromThread_Request.comment_thread_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature', full_name='CCommunity_DeleteCommentFromThread_Request.gidfeature', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature2', full_name='CCommunity_DeleteCommentFromThread_Request.gidfeature2', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_DeleteCommentFromThread_Request.gidcomment', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undelete', full_name='CCommunity_DeleteCommentFromThread_Request.undelete', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2605,
)


_CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_DeleteCommentFromThread_Response',
  full_name='CCommunity_DeleteCommentFromThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2607,
  serialized_end=2652,
)


_CCOMMUNITY_RATECOMMENTTHREAD_REQUEST = _descriptor.Descriptor(
  name='CCommunity_RateCommentThread_Request',
  full_name='CCommunity_RateCommentThread_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commentthreadtype', full_name='CCommunity_RateCommentThread_Request.commentthreadtype', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_RateCommentThread_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature', full_name='CCommunity_RateCommentThread_Request.gidfeature', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature2', full_name='CCommunity_RateCommentThread_Request.gidfeature2', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_RateCommentThread_Request.gidcomment', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_up', full_name='CCommunity_RateCommentThread_Request.rate_up', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suppress_notifications', full_name='CCommunity_RateCommentThread_Request.suppress_notifications', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2655,
  serialized_end=2847,
)


_CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_RateCommentThread_Response',
  full_name='CCommunity_RateCommentThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_RateCommentThread_Response.gidcomment', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_RateCommentThread_Response.commentthreadid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_RateCommentThread_Response.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_RateCommentThread_Response.upvotes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_upvoted', full_name='CCommunity_RateCommentThread_Response.has_upvoted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2850,
  serialized_end=2987,
)


_CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetCommentThreadRatings_Request',
  full_name='CCommunity_GetCommentThreadRatings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commentthreadtype', full_name='CCommunity_GetCommentThreadRatings_Request.commentthreadtype', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_GetCommentThreadRatings_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature', full_name='CCommunity_GetCommentThreadRatings_Request.gidfeature', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidfeature2', full_name='CCommunity_GetCommentThreadRatings_Request.gidfeature2', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_GetCommentThreadRatings_Request.gidcomment', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='CCommunity_GetCommentThreadRatings_Request.max_results', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3160,
)


_CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetCommentThreadRatings_Response',
  full_name='CCommunity_GetCommentThreadRatings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_GetCommentThreadRatings_Response.commentthreadid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_GetCommentThreadRatings_Response.gidcomment', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_GetCommentThreadRatings_Response.upvotes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_upvoted', full_name='CCommunity_GetCommentThreadRatings_Response.has_upvoted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upvoter_accountids', full_name='CCommunity_GetCommentThreadRatings_Response.upvoter_accountids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3319,
)


_CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST = _descriptor.Descriptor(
  name='CCommunity_RateClanAnnouncement_Request',
  full_name='CCommunity_RateClanAnnouncement_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcementid', full_name='CCommunity_RateClanAnnouncement_Request.announcementid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_up', full_name='CCommunity_RateClanAnnouncement_Request.vote_up', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3321,
  serialized_end=3403,
)


_CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_RateClanAnnouncement_Response',
  full_name='CCommunity_RateClanAnnouncement_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3405,
  serialized_end=3447,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncementVoteForUser_Request',
  full_name='CCommunity_GetClanAnnouncementVoteForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcementid', full_name='CCommunity_GetClanAnnouncementVoteForUser_Request.announcementid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3449,
  serialized_end=3524,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncementVoteForUser_Response',
  full_name='CCommunity_GetClanAnnouncementVoteForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voted_up', full_name='CCommunity_GetClanAnnouncementVoteForUser_Response.voted_up', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voted_down', full_name='CCommunity_GetClanAnnouncementVoteForUser_Response.voted_down', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3526,
  serialized_end=3616,
)


_CAPPPRIORITY = _descriptor.Descriptor(
  name='CAppPriority',
  full_name='CAppPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='CAppPriority.priority', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CAppPriority.appid', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3665,
)


_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventNews_Request',
  full_name='CCommunity_GetUserPartnerEventNews_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetUserPartnerEventNews_Request.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='CCommunity_GetUserPartnerEventNews_Request.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_start_time', full_name='CCommunity_GetUserPartnerEventNews_Request.rtime32_start_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_end_time', full_name='CCommunity_GetUserPartnerEventNews_Request.rtime32_end_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_preference', full_name='CCommunity_GetUserPartnerEventNews_Request.language_preference', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_event_type', full_name='CCommunity_GetUserPartnerEventNews_Request.filter_event_type', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.enum; suggested type: ECommunityWordFilterType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_to_appid', full_name='CCommunity_GetUserPartnerEventNews_Request.filter_to_appid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_list', full_name='CCommunity_GetUserPartnerEventNews_Request.app_list', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_after', full_name='CCommunity_GetUserPartnerEventNews_Request.count_after', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_before', full_name='CCommunity_GetUserPartnerEventNews_Request.count_before', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3668,
  serialized_end=4012,
)


_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventNews_Response',
  full_name='CCommunity_GetUserPartnerEventNews_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CCommunity_GetUserPartnerEventNews_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4014,
  serialized_end=4101,
)


_CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetBestEventsForUser_Request',
  full_name='CCommunity_GetBestEventsForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_steam_blog', full_name='CCommunity_GetBestEventsForUser_Request.include_steam_blog', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_to_played_within_days', full_name='CCommunity_GetBestEventsForUser_Request.filter_to_played_within_days', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4103,
  serialized_end=4210,
)


_CCOMMUNITY_PARTNEREVENTRESULT = _descriptor.Descriptor(
  name='CCommunity_PartnerEventResult',
  full_name='CCommunity_PartnerEventResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CCommunity_PartnerEventResult.clanid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_gid', full_name='CCommunity_PartnerEventResult.event_gid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_gid', full_name='CCommunity_PartnerEventResult.announcement_gid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventResult.appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='possible_takeover', full_name='CCommunity_PartnerEventResult.possible_takeover', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_last_modified', full_name='CCommunity_PartnerEventResult.rtime32_last_modified', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_app_priority', full_name='CCommunity_PartnerEventResult.user_app_priority', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4213,
  serialized_end=4408,
)


_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetBestEventsForUser_Response',
  full_name='CCommunity_GetBestEventsForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CCommunity_GetBestEventsForUser_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4410,
  serialized_end=4501,
)


_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST = _descriptor.Descriptor(
  name='CCommunity_ClearUserPartnerEventsAppPriorities_Request',
  full_name='CCommunity_ClearUserPartnerEventsAppPriorities_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4503,
  serialized_end=4559,
)


_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_ClearUserPartnerEventsAppPriorities_Response',
  full_name='CCommunity_ClearUserPartnerEventsAppPriorities_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4561,
  serialized_end=4618,
)


_CCOMMUNITY_PARTNEREVENTSAPPPRIORITY = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsAppPriority',
  full_name='CCommunity_PartnerEventsAppPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventsAppPriority.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_app_priority', full_name='CCommunity_PartnerEventsAppPriority.user_app_priority', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4620,
  serialized_end=4699,
)


_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventsAppPriorities_Request',
  full_name='CCommunity_GetUserPartnerEventsAppPriorities_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4701,
  serialized_end=4755,
)


_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventsAppPriorities_Response',
  full_name='CCommunity_GetUserPartnerEventsAppPriorities_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priorities', full_name='CCommunity_GetUserPartnerEventsAppPriorities_Response.priorities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4757,
  serialized_end=4870,
)


_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST = _descriptor.Descriptor(
  name='CCommunity_ClearSinglePartnerEventsAppPriority_Request',
  full_name='CCommunity_ClearSinglePartnerEventsAppPriority_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_ClearSinglePartnerEventsAppPriority_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4872,
  serialized_end=4943,
)


_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_ClearSinglePartnerEventsAppPriority_Response',
  full_name='CCommunity_ClearSinglePartnerEventsAppPriority_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4945,
  serialized_end=5002,
)


_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowMoreForApp_Request',
  full_name='CCommunity_PartnerEventsShowMoreForApp_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventsShowMoreForApp_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5004,
  serialized_end=5067,
)


_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowMoreForApp_Response',
  full_name='CCommunity_PartnerEventsShowMoreForApp_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5069,
  serialized_end=5118,
)


_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowLessForApp_Request',
  full_name='CCommunity_PartnerEventsShowLessForApp_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventsShowLessForApp_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5120,
  serialized_end=5183,
)


_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowLessForApp_Response',
  full_name='CCommunity_PartnerEventsShowLessForApp_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5185,
  serialized_end=5234,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Request',
  full_name='CCommunity_MarkPartnerEventsForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markings', full_name='CCommunity_MarkPartnerEventsForUser_Request.markings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5237,
  serialized_end=5366,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking',
  full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.clanid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_gid', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.event_gid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_location', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.display_location', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302enum; suggested type: EPartnerEventDisplayLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_shown', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.mark_shown', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_read', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.mark_read', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5369,
  serialized_end=5590,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Response',
  full_name='CCommunity_MarkPartnerEventsForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5592,
  serialized_end=5638,
)


_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION = _descriptor.Descriptor(
  name='CProductImpressionsFromClient_Notification',
  full_name='CProductImpressionsFromClient_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='impressions', full_name='CProductImpressionsFromClient_Notification.impressions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5640,
  serialized_end=5761,
)


_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION = _descriptor.Descriptor(
  name='CProductImpressionsFromClient_Notification_Impression',
  full_name='CProductImpressionsFromClient_Notification_Impression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CProductImpressionsFromClient_Notification_Impression.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306enum; suggested type: EProductImpressionFromClientType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CProductImpressionsFromClient_Notification_Impression.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_impressions', full_name='CProductImpressionsFromClient_Notification_Impression.num_impressions', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5764,
  serialized_end=5933,
)


_CFRIENDSLISTCATEGORY = _descriptor.Descriptor(
  name='CFriendsListCategory',
  full_name='CFriendsListCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CFriendsListCategory.groupid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CFriendsListCategory.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid_members', full_name='CFriendsListCategory.accountid_members', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5935,
  serialized_end=6015,
)


_CFRIENDSLIST_GETCATEGORIES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetCategories_Request',
  full_name='CFriendsList_GetCategories_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6017,
  serialized_end=6053,
)


_CFRIENDSLIST_GETCATEGORIES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetCategories_Response',
  full_name='CFriendsList_GetCategories_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='categories', full_name='CFriendsList_GetCategories_Response.categories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6055,
  serialized_end=6135,
)


_CFRIENDSLISTFAVORITEENTRY = _descriptor.Descriptor(
  name='CFriendsListFavoriteEntry',
  full_name='CFriendsListFavoriteEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CFriendsListFavoriteEntry.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CFriendsListFavoriteEntry.clanid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CFriendsListFavoriteEntry.chat_group_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6137,
  serialized_end=6222,
)


_CFRIENDSLIST_GETFAVORITES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetFavorites_Request',
  full_name='CFriendsList_GetFavorites_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6224,
  serialized_end=6259,
)


_CFRIENDSLIST_GETFAVORITES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetFavorites_Response',
  full_name='CFriendsList_GetFavorites_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_GetFavorites_Response.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6261,
  serialized_end=6344,
)


_CFRIENDSLIST_SETFAVORITES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_SetFavorites_Request',
  full_name='CFriendsList_SetFavorites_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_SetFavorites_Request.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6346,
  serialized_end=6428,
)


_CFRIENDSLIST_SETFAVORITES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_SetFavorites_Response',
  full_name='CFriendsList_SetFavorites_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6430,
  serialized_end=6466,
)


_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CFriendsList_FavoritesChanged_Notification',
  full_name='CFriendsList_FavoritesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_FavoritesChanged_Notification.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6468,
  serialized_end=6559,
)


_CFRIENDSLIST_GETFRIENDSLIST_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetFriendsList_Request',
  full_name='CFriendsList_GetFriendsList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6561,
  serialized_end=6598,
)


_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetFriendsList_Response',
  full_name='CFriendsList_GetFriendsList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendslist', full_name='CFriendsList_GetFriendsList_Response.friendslist', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6600,
  serialized_end=6683,
)


_CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILES = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserPublishedFiles',
  full_name='CMsgClientUCMEnumerateUserPublishedFiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUCMEnumerateUserPublishedFiles.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_index', full_name='CMsgClientUCMEnumerateUserPublishedFiles.start_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='CMsgClientUCMEnumerateUserPublishedFiles.sort_order', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6685,
  serialized_end=6784,
)


_CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserPublishedFilesResponse',
  full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_files', full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse.published_files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse.total_results', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6787,
  serialized_end=6972,
)


_CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId',
  full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6974,
  serialized_end=7067,
)


_CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILES = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserSubscribedFiles',
  full_name='CMsgClientUCMEnumerateUserSubscribedFiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUCMEnumerateUserSubscribedFiles.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_index', full_name='CMsgClientUCMEnumerateUserSubscribedFiles.start_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='CMsgClientUCMEnumerateUserSubscribedFiles.list_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matching_file_type', full_name='CMsgClientUCMEnumerateUserSubscribedFiles.matching_file_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgClientUCMEnumerateUserSubscribedFiles.count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7070,
  serialized_end=7222,
)


_CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserSubscribedFilesResponse',
  full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribed_files', full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse.subscribed_files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse.total_results', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7225,
  serialized_end=7413,
)


_CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId',
  full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_subscribed', full_name='CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId.rtime32_subscribed', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7415,
  serialized_end=7540,
)


_CMSGCLIENTUCMPUBLISHEDFILEDELETED = _descriptor.Descriptor(
  name='CMsgClientUCMPublishedFileDeleted',
  full_name='CMsgClientUCMPublishedFileDeleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientUCMPublishedFileDeleted.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUCMPublishedFileDeleted.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7542,
  serialized_end=7620,
)


_CMSGCLIENTWORKSHOPITEMINFOREQUEST = _descriptor.Descriptor(
  name='CMsgClientWorkshopItemInfoRequest',
  full_name='CMsgClientWorkshopItemInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientWorkshopItemInfoRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_time_updated', full_name='CMsgClientWorkshopItemInfoRequest.last_time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_items', full_name='CMsgClientWorkshopItemInfoRequest.workshop_items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7623,
  serialized_end=7774,
)


_CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM = _descriptor.Descriptor(
  name='CMsgClientWorkshopItemInfoRequest_WorkshopItem',
  full_name='CMsgClientWorkshopItemInfoRequest_WorkshopItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientWorkshopItemInfoRequest_WorkshopItem.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CMsgClientWorkshopItemInfoRequest_WorkshopItem.time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7776,
  serialized_end=7873,
)


_CMSGCLIENTWORKSHOPITEMINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientWorkshopItemInfoResponse',
  full_name='CMsgClientWorkshopItemInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientWorkshopItemInfoResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='CMsgClientWorkshopItemInfoResponse.update_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workshop_items', full_name='CMsgClientWorkshopItemInfoResponse.workshop_items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_items', full_name='CMsgClientWorkshopItemInfoResponse.private_items', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7876,
  serialized_end=8054,
)


_CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO = _descriptor.Descriptor(
  name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo',
  full_name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo.time_updated', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo.manifest_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_legacy', full_name='CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo.is_legacy', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8057,
  serialized_end=8199,
)


_CMSGCLIENTUCMGETPUBLISHEDFILESFORUSER = _descriptor.Descriptor(
  name='CMsgClientUCMGetPublishedFilesForUser',
  full_name='CMsgClientUCMGetPublishedFilesForUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUCMGetPublishedFilesForUser.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_steam_id', full_name='CMsgClientUCMGetPublishedFilesForUser.creator_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_tags', full_name='CMsgClientUCMGetPublishedFilesForUser.required_tags', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_tags', full_name='CMsgClientUCMGetPublishedFilesForUser.excluded_tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_index', full_name='CMsgClientUCMGetPublishedFilesForUser.start_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8202,
  serialized_end=8350,
)


_CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUCMGetPublishedFilesForUserResponse',
  full_name='CMsgClientUCMGetPublishedFilesForUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUCMGetPublishedFilesForUserResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_files', full_name='CMsgClientUCMGetPublishedFilesForUserResponse.published_files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgClientUCMGetPublishedFilesForUserResponse.total_results', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8353,
  serialized_end=8532,
)


_CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId',
  full_name='CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8534,
  serialized_end=8624,
)


_CMSGCREENUMERATEPUBLISHEDFILES = _descriptor.Descriptor(
  name='CMsgCREEnumeratePublishedFiles',
  full_name='CMsgCREEnumeratePublishedFiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgCREEnumeratePublishedFiles.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_type', full_name='CMsgCREEnumeratePublishedFiles.query_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_index', full_name='CMsgCREEnumeratePublishedFiles.start_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days', full_name='CMsgCREEnumeratePublishedFiles.days', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgCREEnumeratePublishedFiles.count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CMsgCREEnumeratePublishedFiles.tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_tags', full_name='CMsgCREEnumeratePublishedFiles.user_tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matching_file_type', full_name='CMsgCREEnumeratePublishedFiles.matching_file_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=13,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8627,
  serialized_end=8810,
)


_CMSGCREENUMERATEPUBLISHEDFILESRESPONSE = _descriptor.Descriptor(
  name='CMsgCREEnumeratePublishedFilesResponse',
  full_name='CMsgCREEnumeratePublishedFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgCREEnumeratePublishedFilesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_files', full_name='CMsgCREEnumeratePublishedFilesResponse.published_files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgCREEnumeratePublishedFilesResponse.total_results', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8813,
  serialized_end=8978,
)


_CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId',
  full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_for', full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId.votes_for', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_against', full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId.votes_against', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId.reports', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgCREEnumeratePublishedFilesResponse_PublishedFileId.score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8981,
  serialized_end=9138,
)


_CMSGGAMESERVERPINGSAMPLE = _descriptor.Descriptor(
  name='CMsgGameServerPingSample',
  full_name='CMsgGameServerPingSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='my_ip', full_name='CMsgGameServerPingSample.my_ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gs_app_id', full_name='CMsgGameServerPingSample.gs_app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gs_samples', full_name='CMsgGameServerPingSample.gs_samples', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9140,
  serialized_end=9254,
)


_CMSGGAMESERVERPINGSAMPLE_SAMPLE = _descriptor.Descriptor(
  name='CMsgGameServerPingSample_Sample',
  full_name='CMsgGameServerPingSample_Sample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgGameServerPingSample_Sample.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_ping_ms', full_name='CMsgGameServerPingSample_Sample.avg_ping_ms', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_ping_ms_x10', full_name='CMsgGameServerPingSample_Sample.stddev_ping_ms_x10', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9256,
  serialized_end=9350,
)


_CCLAN_RESPONDTOCLANINVITE_REQUEST = _descriptor.Descriptor(
  name='CClan_RespondToClanInvite_Request',
  full_name='CClan_RespondToClanInvite_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CClan_RespondToClanInvite_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CClan_RespondToClanInvite_Request.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9352,
  serialized_end=9420,
)


_CCLAN_RESPONDTOCLANINVITE_RESPONSE = _descriptor.Descriptor(
  name='CClan_RespondToClanInvite_Response',
  full_name='CClan_RespondToClanInvite_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9422,
  serialized_end=9458,
)


_CVOICECHAT_REQUESTONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_RequestOneOnOneChat_Request',
  full_name='CVoiceChat_RequestOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_RequestOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9460,
  serialized_end=9525,
)


_CVOICECHAT_REQUESTONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_RequestOneOnOneChat_Response',
  full_name='CVoiceChat_RequestOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_RequestOneOnOneChat_Response.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9527,
  serialized_end=9590,
)


_CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_OneOnOneChatRequested_Notification',
  full_name='CVoiceChat_OneOnOneChatRequested_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_OneOnOneChatRequested_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_OneOnOneChatRequested_Notification.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9592,
  serialized_end=9686,
)


_CVOICECHAT_ANSWERONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_AnswerOneOnOneChat_Request',
  full_name='CVoiceChat_AnswerOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_AnswerOneOnOneChat_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_AnswerOneOnOneChat_Request.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted_request', full_name='CVoiceChat_AnswerOneOnOneChat_Request.accepted_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9688,
  serialized_end=9800,
)


_CVOICECHAT_ANSWERONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_AnswerOneOnOneChat_Response',
  full_name='CVoiceChat_AnswerOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9802,
  serialized_end=9842,
)


_CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_OneOnOneChatRequestResponse_Notification',
  full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voicechat_id', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.voicechat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepted_request', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.accepted_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9844,
  serialized_end=9970,
)


_CVOICECHAT_ENDONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_EndOneOnOneChat_Request',
  full_name='CVoiceChat_EndOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_EndOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9972,
  serialized_end=10033,
)


_CVOICECHAT_ENDONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_EndOneOnOneChat_Response',
  full_name='CVoiceChat_EndOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10035,
  serialized_end=10072,
)


_CVOICECHAT_LEAVEONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_LeaveOneOnOneChat_Request',
  full_name='CVoiceChat_LeaveOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_LeaveOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_LeaveOneOnOneChat_Request.voice_chatid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10074,
  serialized_end=10159,
)


_CVOICECHAT_LEAVEONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_LeaveOneOnOneChat_Response',
  full_name='CVoiceChat_LeaveOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10161,
  serialized_end=10200,
)


_CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserJoinedVoiceChat_Notification',
  full_name='CVoiceChat_UserJoinedVoiceChat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.chatid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.one_on_one_steamid_lower', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.one_on_one_steamid_higher', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.chat_group_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_sessionid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.user_sessionid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10203,
  serialized_end=10424,
)


_CVOICECHAT_USERVOICESTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserVoiceStatus_Notification',
  full_name='CVoiceChat_UserVoiceStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserVoiceStatus_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserVoiceStatus_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_muted_mic_locally', full_name='CVoiceChat_UserVoiceStatus_Notification.user_muted_mic_locally', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_muted_output_locally', full_name='CVoiceChat_UserVoiceStatus_Notification.user_muted_output_locally', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_has_no_mic_for_session', full_name='CVoiceChat_UserVoiceStatus_Notification.user_has_no_mic_for_session', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_webaudio_sample_rate', full_name='CVoiceChat_UserVoiceStatus_Notification.user_webaudio_sample_rate', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10427,
  serialized_end=10651,
)


_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_AllMembersStatus_Notification',
  full_name='CVoiceChat_AllMembersStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_AllMembersStatus_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='CVoiceChat_AllMembersStatus_Notification.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10653,
  serialized_end=10774,
)


_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_UpdateVoiceChatWebRTCData_Request',
  full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_server', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ip_webrtc_server', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_webrtc_server', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.port_webrtc_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_client', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ip_webrtc_client', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_webrtc_client', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.port_webrtc_client', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssrc_my_sending_stream', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ssrc_my_sending_stream', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.user_agent', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_audio_worklets_support', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.has_audio_worklets_support', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10777,
  serialized_end=11041,
)


_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_UpdateVoiceChatWebRTCData_Response',
  full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_client_voice_logs', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Response.send_client_voice_logs', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11043,
  serialized_end=11122,
)


_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_UploadClientVoiceChatLogs_Request',
  full_name='CVoiceChat_UploadClientVoiceChatLogs_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UploadClientVoiceChatLogs_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_voice_logs_new_lines', full_name='CVoiceChat_UploadClientVoiceChatLogs_Request.client_voice_logs_new_lines', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11124,
  serialized_end=11229,
)


_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_UploadClientVoiceChatLogs_Response',
  full_name='CVoiceChat_UploadClientVoiceChatLogs_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11231,
  serialized_end=11278,
)


_CVOICECHAT_LEAVEVOICECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_LeaveVoiceChat_Request',
  full_name='CVoiceChat_LeaveVoiceChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_LeaveVoiceChat_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11280,
  serialized_end=11337,
)


_CVOICECHAT_LEAVEVOICECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_LeaveVoiceChat_Response',
  full_name='CVoiceChat_LeaveVoiceChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11339,
  serialized_end=11375,
)


_CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserLeftVoiceChat_Notification',
  full_name='CVoiceChat_UserLeftVoiceChat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.chatid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_UserLeftVoiceChat_Notification.one_on_one_steamid_lower', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_UserLeftVoiceChat_Notification.one_on_one_steamid_higher', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_UserLeftVoiceChat_Notification.chat_group_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_sessionid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.user_sessionid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11378,
  serialized_end=11597,
)


_CVOICECHAT_VOICECHATENDED_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_VoiceChatEnded_Notification',
  full_name='CVoiceChat_VoiceChatEnded_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_VoiceChatEnded_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_VoiceChatEnded_Notification.one_on_one_steamid_lower', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_VoiceChatEnded_Notification.one_on_one_steamid_higher', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_VoiceChatEnded_Notification.chatid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_VoiceChatEnded_Notification.chat_group_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11600,
  serialized_end=11770,
)


_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST = _descriptor.Descriptor(
  name='CWebRTCClient_InitiateWebRTCConnection_Request',
  full_name='CWebRTCClient_InitiateWebRTCConnection_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdp', full_name='CWebRTCClient_InitiateWebRTCConnection_Request.sdp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11772,
  serialized_end=11833,
)


_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE = _descriptor.Descriptor(
  name='CWebRTCClient_InitiateWebRTCConnection_Response',
  full_name='CWebRTCClient_InitiateWebRTCConnection_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_description', full_name='CWebRTCClient_InitiateWebRTCConnection_Response.remote_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11835,
  serialized_end=11912,
)


_CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION = _descriptor.Descriptor(
  name='CWebRTC_WebRTCSessionConnected_Notification',
  full_name='CWebRTC_WebRTCSessionConnected_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssrc', full_name='CWebRTC_WebRTCSessionConnected_Notification.ssrc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='CWebRTC_WebRTCSessionConnected_Notification.client_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_port', full_name='CWebRTC_WebRTCSessionConnected_Notification.client_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CWebRTC_WebRTCSessionConnected_Notification.server_ip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CWebRTC_WebRTCSessionConnected_Notification.server_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11915,
  serialized_end=12054,
)


_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION = _descriptor.Descriptor(
  name='CWebRTC_WebRTCUpdateRemoteDescription_Notification',
  full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_description', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.remote_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_description_version', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.remote_description_version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssrcs_to_accountids', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.ssrcs_to_accountids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12057,
  serialized_end=12279,
)


_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING = _descriptor.Descriptor(
  name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping',
  full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssrc', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping.ssrc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12281,
  serialized_end=12390,
)


_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST = _descriptor.Descriptor(
  name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request',
  full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_webrtc_server', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.ip_webrtc_server', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_webrtc_server', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.port_webrtc_server', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_session_client', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.ip_webrtc_session_client', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_webrtc_session_client', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.port_webrtc_session_client', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_description_version', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.remote_description_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12393,
  serialized_end=12612,
)


_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE = _descriptor.Descriptor(
  name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response',
  full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12614,
  serialized_end=12674,
)


_CMOBILEPERACCOUNT_GETSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CMobilePerAccount_GetSettings_Request',
  full_name='CMobilePerAccount_GetSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12676,
  serialized_end=12715,
)


_CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CMobilePerAccount_GetSettings_Response',
  full_name='CMobilePerAccount_GetSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_settings', full_name='CMobilePerAccount_GetSettings_Response.has_settings', index=0,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_sale_push', full_name='CMobilePerAccount_GetSettings_Response.allow_sale_push', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_wishlist_push', full_name='CMobilePerAccount_GetSettings_Response.allow_wishlist_push', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_notification_level', full_name='CMobilePerAccount_GetSettings_Response.chat_notification_level', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_direct_chat', full_name='CMobilePerAccount_GetSettings_Response.notify_direct_chat', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_group_chat', full_name='CMobilePerAccount_GetSettings_Response.notify_group_chat', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_event_push', full_name='CMobilePerAccount_GetSettings_Response.allow_event_push', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12718,
  serialized_end=12954,
)


_CMOBILEPERACCOUNT_SETSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CMobilePerAccount_SetSettings_Request',
  full_name='CMobilePerAccount_SetSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_sale_push', full_name='CMobilePerAccount_SetSettings_Request.allow_sale_push', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_wishlist_push', full_name='CMobilePerAccount_SetSettings_Request.allow_wishlist_push', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_notification_level', full_name='CMobilePerAccount_SetSettings_Request.chat_notification_level', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_direct_chat', full_name='CMobilePerAccount_SetSettings_Request.notify_direct_chat', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify_group_chat', full_name='CMobilePerAccount_SetSettings_Request.notify_group_chat', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_event_push', full_name='CMobilePerAccount_SetSettings_Request.allow_event_push', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12957,
  serialized_end=13170,
)


_CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CMobilePerAccount_SetSettings_Response',
  full_name='CMobilePerAccount_SetSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13172,
  serialized_end=13212,
)


_CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST = _descriptor.Descriptor(
  name='CMobileDevice_RegisterMobileDevice_Request',
  full_name='CMobileDevice_RegisterMobileDevice_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceid', full_name='CMobileDevice_RegisterMobileDevice_Request.deviceid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMobileDevice_RegisterMobileDevice_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push_enabled', full_name='CMobileDevice_RegisterMobileDevice_Request.push_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='CMobileDevice_RegisterMobileDevice_Request.app_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os_version', full_name='CMobileDevice_RegisterMobileDevice_Request.os_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_model', full_name='CMobileDevice_RegisterMobileDevice_Request.device_model', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twofactor_device_identifier', full_name='CMobileDevice_RegisterMobileDevice_Request.twofactor_device_identifier', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mobile_app', full_name='CMobileDevice_RegisterMobileDevice_Request.mobile_app', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 enum; suggested type: EMobileApp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13215,
  serialized_end=13475,
)


_CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE = _descriptor.Descriptor(
  name='CMobileDevice_RegisterMobileDevice_Response',
  full_name='CMobileDevice_RegisterMobileDevice_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique_deviceid', full_name='CMobileDevice_RegisterMobileDevice_Response.unique_deviceid', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13477,
  serialized_end=13547,
)


_CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION = _descriptor.Descriptor(
  name='CMobileDevice_DeregisterMobileDevice_Notification',
  full_name='CMobileDevice_DeregisterMobileDevice_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceid', full_name='CMobileDevice_DeregisterMobileDevice_Notification.deviceid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13549,
  serialized_end=13618,
)


_UNKNOWNPROTO = _descriptor.Descriptor(
  name='UnknownProto',
  full_name='UnknownProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13620,
  serialized_end=13634,
)

_CMSGCLIENTAPPMINUTESPLAYEDDATA.fields_by_name['minutes_played'].message_type = _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA
_CCOMMUNITY_GETAPPS_RESPONSE.fields_by_name['apps'].message_type = steammessages__base__pb2._CCDDBAPPDETAILCOMMON
_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE.fields_by_name['token_lists'].message_type = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST
_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST.fields_by_name['tokens'].message_type = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN
_CCOMMUNITY_COMMENT.fields_by_name['ipaddress'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE.fields_by_name['comments'].message_type = _CCOMMUNITY_COMMENT
_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE.fields_by_name['deleted_comments'].message_type = _CCOMMUNITY_COMMENT
_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST.fields_by_name['app_list'].message_type = _CAPPPRIORITY
_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE.fields_by_name['results'].message_type = steammessages__base__pb2._CCLANMATCHEVENTBYRANGE
_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE.fields_by_name['results'].message_type = _CCOMMUNITY_PARTNEREVENTRESULT
_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE.fields_by_name['priorities'].message_type = _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY
_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST.fields_by_name['markings'].message_type = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING
_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION.fields_by_name['impressions'].message_type = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION
_CFRIENDSLIST_GETCATEGORIES_RESPONSE.fields_by_name['categories'].message_type = _CFRIENDSLISTCATEGORY
_CFRIENDSLIST_GETFAVORITES_RESPONSE.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_SETFAVORITES_REQUEST.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE.fields_by_name['friendslist'].message_type = steammessages__clientserver__friends__pb2._CMSGCLIENTFRIENDSLIST
_CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE.fields_by_name['published_files'].message_type = _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID
_CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE.fields_by_name['subscribed_files'].message_type = _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID
_CMSGCLIENTWORKSHOPITEMINFOREQUEST.fields_by_name['workshop_items'].message_type = _CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM
_CMSGCLIENTWORKSHOPITEMINFORESPONSE.fields_by_name['workshop_items'].message_type = _CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO
_CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE.fields_by_name['published_files'].message_type = _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID
_CMSGCREENUMERATEPUBLISHEDFILESRESPONSE.fields_by_name['published_files'].message_type = _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID
_CMSGGAMESERVERPINGSAMPLE.fields_by_name['gs_samples'].message_type = _CMSGGAMESERVERPINGSAMPLE_SAMPLE
_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION.fields_by_name['users'].message_type = _CVOICECHAT_USERVOICESTATUS_NOTIFICATION
_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION.fields_by_name['ssrcs_to_accountids'].message_type = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING
DESCRIPTOR.message_types_by_name['CHelpRequestLogs_UploadUserApplicationLog_Request'] = _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST
DESCRIPTOR.message_types_by_name['CHelpRequestLogs_UploadUserApplicationLog_Response'] = _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAppMinutesPlayedData'] = _CMSGCLIENTAPPMINUTESPLAYEDDATA
DESCRIPTOR.message_types_by_name['CMsgClientAppMinutesPlayedData_AppMinutesPlayedData'] = _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA
DESCRIPTOR.message_types_by_name['CCommunity_GetApps_Request'] = _CCOMMUNITY_GETAPPS_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetApps_Response'] = _CCOMMUNITY_GETAPPS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Request'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response_Token'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response_TokenList'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThread_Request'] = _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_Comment'] = _CCOMMUNITY_COMMENT
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThread_Response'] = _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PostCommentToThread_Request'] = _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_PostCommentToThread_Response'] = _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_DeleteCommentFromThread_Request'] = _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_DeleteCommentFromThread_Response'] = _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_RateCommentThread_Request'] = _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_RateCommentThread_Response'] = _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThreadRatings_Request'] = _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThreadRatings_Response'] = _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_RateClanAnnouncement_Request'] = _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_RateClanAnnouncement_Response'] = _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncementVoteForUser_Request'] = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncementVoteForUser_Response'] = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CAppPriority'] = _CAPPPRIORITY
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventNews_Request'] = _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventNews_Response'] = _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetBestEventsForUser_Request'] = _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventResult'] = _CCOMMUNITY_PARTNEREVENTRESULT
DESCRIPTOR.message_types_by_name['CCommunity_GetBestEventsForUser_Response'] = _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_ClearUserPartnerEventsAppPriorities_Request'] = _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_ClearUserPartnerEventsAppPriorities_Response'] = _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsAppPriority'] = _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventsAppPriorities_Request'] = _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventsAppPriorities_Response'] = _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_ClearSinglePartnerEventsAppPriority_Request'] = _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_ClearSinglePartnerEventsAppPriority_Response'] = _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowMoreForApp_Request'] = _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowMoreForApp_Response'] = _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowLessForApp_Request'] = _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowLessForApp_Response'] = _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Request'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Response'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CProductImpressionsFromClient_Notification'] = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CProductImpressionsFromClient_Notification_Impression'] = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION
DESCRIPTOR.message_types_by_name['CFriendsListCategory'] = _CFRIENDSLISTCATEGORY
DESCRIPTOR.message_types_by_name['CFriendsList_GetCategories_Request'] = _CFRIENDSLIST_GETCATEGORIES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetCategories_Response'] = _CFRIENDSLIST_GETCATEGORIES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsListFavoriteEntry'] = _CFRIENDSLISTFAVORITEENTRY
DESCRIPTOR.message_types_by_name['CFriendsList_GetFavorites_Request'] = _CFRIENDSLIST_GETFAVORITES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetFavorites_Response'] = _CFRIENDSLIST_GETFAVORITES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsList_SetFavorites_Request'] = _CFRIENDSLIST_SETFAVORITES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_SetFavorites_Response'] = _CFRIENDSLIST_SETFAVORITES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsList_FavoritesChanged_Notification'] = _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CFriendsList_GetFriendsList_Request'] = _CFRIENDSLIST_GETFRIENDSLIST_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetFriendsList_Response'] = _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserPublishedFiles'] = _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILES
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserPublishedFilesResponse'] = _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId'] = _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserSubscribedFiles'] = _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILES
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserSubscribedFilesResponse'] = _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId'] = _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID
DESCRIPTOR.message_types_by_name['CMsgClientUCMPublishedFileDeleted'] = _CMSGCLIENTUCMPUBLISHEDFILEDELETED
DESCRIPTOR.message_types_by_name['CMsgClientWorkshopItemInfoRequest'] = _CMSGCLIENTWORKSHOPITEMINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientWorkshopItemInfoRequest_WorkshopItem'] = _CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM
DESCRIPTOR.message_types_by_name['CMsgClientWorkshopItemInfoResponse'] = _CMSGCLIENTWORKSHOPITEMINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo'] = _CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO
DESCRIPTOR.message_types_by_name['CMsgClientUCMGetPublishedFilesForUser'] = _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSER
DESCRIPTOR.message_types_by_name['CMsgClientUCMGetPublishedFilesForUserResponse'] = _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId'] = _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID
DESCRIPTOR.message_types_by_name['CMsgCREEnumeratePublishedFiles'] = _CMSGCREENUMERATEPUBLISHEDFILES
DESCRIPTOR.message_types_by_name['CMsgCREEnumeratePublishedFilesResponse'] = _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgCREEnumeratePublishedFilesResponse_PublishedFileId'] = _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID
DESCRIPTOR.message_types_by_name['CMsgGameServerPingSample'] = _CMSGGAMESERVERPINGSAMPLE
DESCRIPTOR.message_types_by_name['CMsgGameServerPingSample_Sample'] = _CMSGGAMESERVERPINGSAMPLE_SAMPLE
DESCRIPTOR.message_types_by_name['CClan_RespondToClanInvite_Request'] = _CCLAN_RESPONDTOCLANINVITE_REQUEST
DESCRIPTOR.message_types_by_name['CClan_RespondToClanInvite_Response'] = _CCLAN_RESPONDTOCLANINVITE_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_RequestOneOnOneChat_Request'] = _CVOICECHAT_REQUESTONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_RequestOneOnOneChat_Response'] = _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_OneOnOneChatRequested_Notification'] = _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_AnswerOneOnOneChat_Request'] = _CVOICECHAT_ANSWERONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_AnswerOneOnOneChat_Response'] = _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_OneOnOneChatRequestResponse_Notification'] = _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_EndOneOnOneChat_Request'] = _CVOICECHAT_ENDONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_EndOneOnOneChat_Response'] = _CVOICECHAT_ENDONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveOneOnOneChat_Request'] = _CVOICECHAT_LEAVEONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveOneOnOneChat_Response'] = _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UserJoinedVoiceChat_Notification'] = _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_UserVoiceStatus_Notification'] = _CVOICECHAT_USERVOICESTATUS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_AllMembersStatus_Notification'] = _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_UpdateVoiceChatWebRTCData_Request'] = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_UpdateVoiceChatWebRTCData_Response'] = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UploadClientVoiceChatLogs_Request'] = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_UploadClientVoiceChatLogs_Response'] = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveVoiceChat_Request'] = _CVOICECHAT_LEAVEVOICECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveVoiceChat_Response'] = _CVOICECHAT_LEAVEVOICECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UserLeftVoiceChat_Notification'] = _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_VoiceChatEnded_Notification'] = _CVOICECHAT_VOICECHATENDED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CWebRTCClient_InitiateWebRTCConnection_Request'] = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST
DESCRIPTOR.message_types_by_name['CWebRTCClient_InitiateWebRTCConnection_Response'] = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCSessionConnected_Notification'] = _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCUpdateRemoteDescription_Notification'] = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping'] = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING
DESCRIPTOR.message_types_by_name['CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request'] = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST
DESCRIPTOR.message_types_by_name['CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response'] = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE
DESCRIPTOR.message_types_by_name['CMobilePerAccount_GetSettings_Request'] = _CMOBILEPERACCOUNT_GETSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CMobilePerAccount_GetSettings_Response'] = _CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CMobilePerAccount_SetSettings_Request'] = _CMOBILEPERACCOUNT_SETSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CMobilePerAccount_SetSettings_Response'] = _CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CMobileDevice_RegisterMobileDevice_Request'] = _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST
DESCRIPTOR.message_types_by_name['CMobileDevice_RegisterMobileDevice_Response'] = _CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE
DESCRIPTOR.message_types_by_name['CMobileDevice_DeregisterMobileDevice_Notification'] = _CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION
DESCRIPTOR.message_types_by_name['UnknownProto'] = _UNKNOWNPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CHelpRequestLogs_UploadUserApplicationLog_Request = _reflection.GeneratedProtocolMessageType('CHelpRequestLogs_UploadUserApplicationLog_Request', (_message.Message,), {
  'DESCRIPTOR' : _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CHelpRequestLogs_UploadUserApplicationLog_Request)
  })
_sym_db.RegisterMessage(CHelpRequestLogs_UploadUserApplicationLog_Request)

CHelpRequestLogs_UploadUserApplicationLog_Response = _reflection.GeneratedProtocolMessageType('CHelpRequestLogs_UploadUserApplicationLog_Response', (_message.Message,), {
  'DESCRIPTOR' : _CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CHelpRequestLogs_UploadUserApplicationLog_Response)
  })
_sym_db.RegisterMessage(CHelpRequestLogs_UploadUserApplicationLog_Response)

CMsgClientAppMinutesPlayedData = _reflection.GeneratedProtocolMessageType('CMsgClientAppMinutesPlayedData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAPPMINUTESPLAYEDDATA,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppMinutesPlayedData)
  })
_sym_db.RegisterMessage(CMsgClientAppMinutesPlayedData)

CMsgClientAppMinutesPlayedData_AppMinutesPlayedData = _reflection.GeneratedProtocolMessageType('CMsgClientAppMinutesPlayedData_AppMinutesPlayedData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppMinutesPlayedData_AppMinutesPlayedData)
  })
_sym_db.RegisterMessage(CMsgClientAppMinutesPlayedData_AppMinutesPlayedData)

CCommunity_GetApps_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetApps_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetApps_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetApps_Request)

CCommunity_GetApps_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetApps_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetApps_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetApps_Response)

CCommunity_GetAppRichPresenceLocalization_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Request)

CCommunity_GetAppRichPresenceLocalization_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response)

CCommunity_GetAppRichPresenceLocalization_Response_Token = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response_Token', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response_Token)
  })
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response_Token)

CCommunity_GetAppRichPresenceLocalization_Response_TokenList = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response_TokenList', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response_TokenList)
  })
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response_TokenList)

CCommunity_GetCommentThread_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThread_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCOMMENTTHREAD_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThread_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetCommentThread_Request)

CCommunity_Comment = _reflection.GeneratedProtocolMessageType('CCommunity_Comment', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_COMMENT,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_Comment)
  })
_sym_db.RegisterMessage(CCommunity_Comment)

CCommunity_GetCommentThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThread_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThread_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetCommentThread_Response)

CCommunity_PostCommentToThread_Request = _reflection.GeneratedProtocolMessageType('CCommunity_PostCommentToThread_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PostCommentToThread_Request)
  })
_sym_db.RegisterMessage(CCommunity_PostCommentToThread_Request)

CCommunity_PostCommentToThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PostCommentToThread_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PostCommentToThread_Response)
  })
_sym_db.RegisterMessage(CCommunity_PostCommentToThread_Response)

CCommunity_DeleteCommentFromThread_Request = _reflection.GeneratedProtocolMessageType('CCommunity_DeleteCommentFromThread_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_DeleteCommentFromThread_Request)
  })
_sym_db.RegisterMessage(CCommunity_DeleteCommentFromThread_Request)

CCommunity_DeleteCommentFromThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_DeleteCommentFromThread_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_DeleteCommentFromThread_Response)
  })
_sym_db.RegisterMessage(CCommunity_DeleteCommentFromThread_Response)

CCommunity_RateCommentThread_Request = _reflection.GeneratedProtocolMessageType('CCommunity_RateCommentThread_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_RATECOMMENTTHREAD_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateCommentThread_Request)
  })
_sym_db.RegisterMessage(CCommunity_RateCommentThread_Request)

CCommunity_RateCommentThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_RateCommentThread_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateCommentThread_Response)
  })
_sym_db.RegisterMessage(CCommunity_RateCommentThread_Response)

CCommunity_GetCommentThreadRatings_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThreadRatings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThreadRatings_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetCommentThreadRatings_Request)

CCommunity_GetCommentThreadRatings_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThreadRatings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThreadRatings_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetCommentThreadRatings_Response)

CCommunity_RateClanAnnouncement_Request = _reflection.GeneratedProtocolMessageType('CCommunity_RateClanAnnouncement_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateClanAnnouncement_Request)
  })
_sym_db.RegisterMessage(CCommunity_RateClanAnnouncement_Request)

CCommunity_RateClanAnnouncement_Response = _reflection.GeneratedProtocolMessageType('CCommunity_RateClanAnnouncement_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateClanAnnouncement_Response)
  })
_sym_db.RegisterMessage(CCommunity_RateClanAnnouncement_Response)

CCommunity_GetClanAnnouncementVoteForUser_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncementVoteForUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetClanAnnouncementVoteForUser_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncementVoteForUser_Request)

CCommunity_GetClanAnnouncementVoteForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncementVoteForUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetClanAnnouncementVoteForUser_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncementVoteForUser_Response)

CAppPriority = _reflection.GeneratedProtocolMessageType('CAppPriority', (_message.Message,), {
  'DESCRIPTOR' : _CAPPPRIORITY,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CAppPriority)
  })
_sym_db.RegisterMessage(CAppPriority)

CCommunity_GetUserPartnerEventNews_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventNews_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventNews_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventNews_Request)

CCommunity_GetUserPartnerEventNews_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventNews_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventNews_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventNews_Response)

CCommunity_GetBestEventsForUser_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetBestEventsForUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetBestEventsForUser_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetBestEventsForUser_Request)

CCommunity_PartnerEventResult = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventResult', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTRESULT,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventResult)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventResult)

CCommunity_GetBestEventsForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetBestEventsForUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetBestEventsForUser_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetBestEventsForUser_Response)

CCommunity_ClearUserPartnerEventsAppPriorities_Request = _reflection.GeneratedProtocolMessageType('CCommunity_ClearUserPartnerEventsAppPriorities_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearUserPartnerEventsAppPriorities_Request)
  })
_sym_db.RegisterMessage(CCommunity_ClearUserPartnerEventsAppPriorities_Request)

CCommunity_ClearUserPartnerEventsAppPriorities_Response = _reflection.GeneratedProtocolMessageType('CCommunity_ClearUserPartnerEventsAppPriorities_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearUserPartnerEventsAppPriorities_Response)
  })
_sym_db.RegisterMessage(CCommunity_ClearUserPartnerEventsAppPriorities_Response)

CCommunity_PartnerEventsAppPriority = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsAppPriority', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsAppPriority)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventsAppPriority)

CCommunity_GetUserPartnerEventsAppPriorities_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventsAppPriorities_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventsAppPriorities_Request)
  })
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventsAppPriorities_Request)

CCommunity_GetUserPartnerEventsAppPriorities_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventsAppPriorities_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventsAppPriorities_Response)
  })
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventsAppPriorities_Response)

CCommunity_ClearSinglePartnerEventsAppPriority_Request = _reflection.GeneratedProtocolMessageType('CCommunity_ClearSinglePartnerEventsAppPriority_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearSinglePartnerEventsAppPriority_Request)
  })
_sym_db.RegisterMessage(CCommunity_ClearSinglePartnerEventsAppPriority_Request)

CCommunity_ClearSinglePartnerEventsAppPriority_Response = _reflection.GeneratedProtocolMessageType('CCommunity_ClearSinglePartnerEventsAppPriority_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearSinglePartnerEventsAppPriority_Response)
  })
_sym_db.RegisterMessage(CCommunity_ClearSinglePartnerEventsAppPriority_Response)

CCommunity_PartnerEventsShowMoreForApp_Request = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowMoreForApp_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowMoreForApp_Request)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowMoreForApp_Request)

CCommunity_PartnerEventsShowMoreForApp_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowMoreForApp_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowMoreForApp_Response)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowMoreForApp_Response)

CCommunity_PartnerEventsShowLessForApp_Request = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowLessForApp_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowLessForApp_Request)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowLessForApp_Request)

CCommunity_PartnerEventsShowLessForApp_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowLessForApp_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowLessForApp_Response)
  })
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowLessForApp_Response)

CCommunity_MarkPartnerEventsForUser_Request = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Request)
  })
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Request)

CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking)
  })
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking)

CCommunity_MarkPartnerEventsForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Response)
  })
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Response)

CProductImpressionsFromClient_Notification = _reflection.GeneratedProtocolMessageType('CProductImpressionsFromClient_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CProductImpressionsFromClient_Notification)
  })
_sym_db.RegisterMessage(CProductImpressionsFromClient_Notification)

CProductImpressionsFromClient_Notification_Impression = _reflection.GeneratedProtocolMessageType('CProductImpressionsFromClient_Notification_Impression', (_message.Message,), {
  'DESCRIPTOR' : _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CProductImpressionsFromClient_Notification_Impression)
  })
_sym_db.RegisterMessage(CProductImpressionsFromClient_Notification_Impression)

CFriendsListCategory = _reflection.GeneratedProtocolMessageType('CFriendsListCategory', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLISTCATEGORY,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsListCategory)
  })
_sym_db.RegisterMessage(CFriendsListCategory)

CFriendsList_GetCategories_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetCategories_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETCATEGORIES_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetCategories_Request)
  })
_sym_db.RegisterMessage(CFriendsList_GetCategories_Request)

CFriendsList_GetCategories_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetCategories_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETCATEGORIES_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetCategories_Response)
  })
_sym_db.RegisterMessage(CFriendsList_GetCategories_Response)

CFriendsListFavoriteEntry = _reflection.GeneratedProtocolMessageType('CFriendsListFavoriteEntry', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLISTFAVORITEENTRY,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsListFavoriteEntry)
  })
_sym_db.RegisterMessage(CFriendsListFavoriteEntry)

CFriendsList_GetFavorites_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFavorites_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETFAVORITES_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFavorites_Request)
  })
_sym_db.RegisterMessage(CFriendsList_GetFavorites_Request)

CFriendsList_GetFavorites_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFavorites_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETFAVORITES_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFavorites_Response)
  })
_sym_db.RegisterMessage(CFriendsList_GetFavorites_Response)

CFriendsList_SetFavorites_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_SetFavorites_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_SETFAVORITES_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_SetFavorites_Request)
  })
_sym_db.RegisterMessage(CFriendsList_SetFavorites_Request)

CFriendsList_SetFavorites_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_SetFavorites_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_SETFAVORITES_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_SetFavorites_Response)
  })
_sym_db.RegisterMessage(CFriendsList_SetFavorites_Response)

CFriendsList_FavoritesChanged_Notification = _reflection.GeneratedProtocolMessageType('CFriendsList_FavoritesChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_FavoritesChanged_Notification)
  })
_sym_db.RegisterMessage(CFriendsList_FavoritesChanged_Notification)

CFriendsList_GetFriendsList_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFriendsList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETFRIENDSLIST_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFriendsList_Request)
  })
_sym_db.RegisterMessage(CFriendsList_GetFriendsList_Request)

CFriendsList_GetFriendsList_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFriendsList_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFriendsList_Response)
  })
_sym_db.RegisterMessage(CFriendsList_GetFriendsList_Response)

CMsgClientUCMEnumerateUserPublishedFiles = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserPublishedFiles', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILES,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserPublishedFiles)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserPublishedFiles)

CMsgClientUCMEnumerateUserPublishedFilesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserPublishedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserPublishedFilesResponse)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserPublishedFilesResponse)

CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserPublishedFilesResponse_PublishedFileId)

CMsgClientUCMEnumerateUserSubscribedFiles = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserSubscribedFiles', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILES,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserSubscribedFiles)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserSubscribedFiles)

CMsgClientUCMEnumerateUserSubscribedFilesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserSubscribedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserSubscribedFilesResponse)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserSubscribedFilesResponse)

CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId = _reflection.GeneratedProtocolMessageType('CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESRESPONSE_PUBLISHEDFILEID,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId)
  })
_sym_db.RegisterMessage(CMsgClientUCMEnumerateUserSubscribedFilesResponse_PublishedFileId)

CMsgClientUCMPublishedFileDeleted = _reflection.GeneratedProtocolMessageType('CMsgClientUCMPublishedFileDeleted', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMPUBLISHEDFILEDELETED,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMPublishedFileDeleted)
  })
_sym_db.RegisterMessage(CMsgClientUCMPublishedFileDeleted)

CMsgClientWorkshopItemInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgClientWorkshopItemInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTWORKSHOPITEMINFOREQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWorkshopItemInfoRequest)
  })
_sym_db.RegisterMessage(CMsgClientWorkshopItemInfoRequest)

CMsgClientWorkshopItemInfoRequest_WorkshopItem = _reflection.GeneratedProtocolMessageType('CMsgClientWorkshopItemInfoRequest_WorkshopItem', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTWORKSHOPITEMINFOREQUEST_WORKSHOPITEM,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWorkshopItemInfoRequest_WorkshopItem)
  })
_sym_db.RegisterMessage(CMsgClientWorkshopItemInfoRequest_WorkshopItem)

CMsgClientWorkshopItemInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientWorkshopItemInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTWORKSHOPITEMINFORESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWorkshopItemInfoResponse)
  })
_sym_db.RegisterMessage(CMsgClientWorkshopItemInfoResponse)

CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo = _reflection.GeneratedProtocolMessageType('CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTWORKSHOPITEMINFORESPONSE_WORKSHOPITEMINFO,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo)
  })
_sym_db.RegisterMessage(CMsgClientWorkshopItemInfoResponse_WorkshopItemInfo)

CMsgClientUCMGetPublishedFilesForUser = _reflection.GeneratedProtocolMessageType('CMsgClientUCMGetPublishedFilesForUser', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSER,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMGetPublishedFilesForUser)
  })
_sym_db.RegisterMessage(CMsgClientUCMGetPublishedFilesForUser)

CMsgClientUCMGetPublishedFilesForUserResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUCMGetPublishedFilesForUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMGetPublishedFilesForUserResponse)
  })
_sym_db.RegisterMessage(CMsgClientUCMGetPublishedFilesForUserResponse)

CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId = _reflection.GeneratedProtocolMessageType('CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUCMGETPUBLISHEDFILESFORUSERRESPONSE_PUBLISHEDFILEID,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId)
  })
_sym_db.RegisterMessage(CMsgClientUCMGetPublishedFilesForUserResponse_PublishedFileId)

CMsgCREEnumeratePublishedFiles = _reflection.GeneratedProtocolMessageType('CMsgCREEnumeratePublishedFiles', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCREENUMERATEPUBLISHEDFILES,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREEnumeratePublishedFiles)
  })
_sym_db.RegisterMessage(CMsgCREEnumeratePublishedFiles)

CMsgCREEnumeratePublishedFilesResponse = _reflection.GeneratedProtocolMessageType('CMsgCREEnumeratePublishedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREEnumeratePublishedFilesResponse)
  })
_sym_db.RegisterMessage(CMsgCREEnumeratePublishedFilesResponse)

CMsgCREEnumeratePublishedFilesResponse_PublishedFileId = _reflection.GeneratedProtocolMessageType('CMsgCREEnumeratePublishedFilesResponse_PublishedFileId', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCREENUMERATEPUBLISHEDFILESRESPONSE_PUBLISHEDFILEID,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREEnumeratePublishedFilesResponse_PublishedFileId)
  })
_sym_db.RegisterMessage(CMsgCREEnumeratePublishedFilesResponse_PublishedFileId)

CMsgGameServerPingSample = _reflection.GeneratedProtocolMessageType('CMsgGameServerPingSample', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGAMESERVERPINGSAMPLE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerPingSample)
  })
_sym_db.RegisterMessage(CMsgGameServerPingSample)

CMsgGameServerPingSample_Sample = _reflection.GeneratedProtocolMessageType('CMsgGameServerPingSample_Sample', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGAMESERVERPINGSAMPLE_SAMPLE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerPingSample_Sample)
  })
_sym_db.RegisterMessage(CMsgGameServerPingSample_Sample)

CClan_RespondToClanInvite_Request = _reflection.GeneratedProtocolMessageType('CClan_RespondToClanInvite_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCLAN_RESPONDTOCLANINVITE_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CClan_RespondToClanInvite_Request)
  })
_sym_db.RegisterMessage(CClan_RespondToClanInvite_Request)

CClan_RespondToClanInvite_Response = _reflection.GeneratedProtocolMessageType('CClan_RespondToClanInvite_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCLAN_RESPONDTOCLANINVITE_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CClan_RespondToClanInvite_Response)
  })
_sym_db.RegisterMessage(CClan_RespondToClanInvite_Response)

CVoiceChat_RequestOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_RequestOneOnOneChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_REQUESTONEONONECHAT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_RequestOneOnOneChat_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_RequestOneOnOneChat_Request)

CVoiceChat_RequestOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_RequestOneOnOneChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_RequestOneOnOneChat_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_RequestOneOnOneChat_Response)

CVoiceChat_OneOnOneChatRequested_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_OneOnOneChatRequested_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_OneOnOneChatRequested_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_OneOnOneChatRequested_Notification)

CVoiceChat_AnswerOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_AnswerOneOnOneChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ANSWERONEONONECHAT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AnswerOneOnOneChat_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_AnswerOneOnOneChat_Request)

CVoiceChat_AnswerOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_AnswerOneOnOneChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AnswerOneOnOneChat_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_AnswerOneOnOneChat_Response)

CVoiceChat_OneOnOneChatRequestResponse_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_OneOnOneChatRequestResponse_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_OneOnOneChatRequestResponse_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_OneOnOneChatRequestResponse_Notification)

CVoiceChat_EndOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_EndOneOnOneChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ENDONEONONECHAT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_EndOneOnOneChat_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_EndOneOnOneChat_Request)

CVoiceChat_EndOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_EndOneOnOneChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ENDONEONONECHAT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_EndOneOnOneChat_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_EndOneOnOneChat_Response)

CVoiceChat_LeaveOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveOneOnOneChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_LEAVEONEONONECHAT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveOneOnOneChat_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_LeaveOneOnOneChat_Request)

CVoiceChat_LeaveOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveOneOnOneChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveOneOnOneChat_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_LeaveOneOnOneChat_Response)

CVoiceChat_UserJoinedVoiceChat_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserJoinedVoiceChat_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserJoinedVoiceChat_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_UserJoinedVoiceChat_Notification)

CVoiceChat_UserVoiceStatus_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserVoiceStatus_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserVoiceStatus_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_UserVoiceStatus_Notification)

CVoiceChat_AllMembersStatus_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_AllMembersStatus_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AllMembersStatus_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_AllMembersStatus_Notification)

CVoiceChat_UpdateVoiceChatWebRTCData_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_UpdateVoiceChatWebRTCData_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UpdateVoiceChatWebRTCData_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_UpdateVoiceChatWebRTCData_Request)

CVoiceChat_UpdateVoiceChatWebRTCData_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_UpdateVoiceChatWebRTCData_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UpdateVoiceChatWebRTCData_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_UpdateVoiceChatWebRTCData_Response)

CVoiceChat_UploadClientVoiceChatLogs_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_UploadClientVoiceChatLogs_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UploadClientVoiceChatLogs_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_UploadClientVoiceChatLogs_Request)

CVoiceChat_UploadClientVoiceChatLogs_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_UploadClientVoiceChatLogs_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UploadClientVoiceChatLogs_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_UploadClientVoiceChatLogs_Response)

CVoiceChat_LeaveVoiceChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveVoiceChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_LEAVEVOICECHAT_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveVoiceChat_Request)
  })
_sym_db.RegisterMessage(CVoiceChat_LeaveVoiceChat_Request)

CVoiceChat_LeaveVoiceChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveVoiceChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_LEAVEVOICECHAT_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveVoiceChat_Response)
  })
_sym_db.RegisterMessage(CVoiceChat_LeaveVoiceChat_Response)

CVoiceChat_UserLeftVoiceChat_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserLeftVoiceChat_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserLeftVoiceChat_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_UserLeftVoiceChat_Notification)

CVoiceChat_VoiceChatEnded_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_VoiceChatEnded_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVOICECHAT_VOICECHATENDED_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_VoiceChatEnded_Notification)
  })
_sym_db.RegisterMessage(CVoiceChat_VoiceChatEnded_Notification)

CWebRTCClient_InitiateWebRTCConnection_Request = _reflection.GeneratedProtocolMessageType('CWebRTCClient_InitiateWebRTCConnection_Request', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_InitiateWebRTCConnection_Request)
  })
_sym_db.RegisterMessage(CWebRTCClient_InitiateWebRTCConnection_Request)

CWebRTCClient_InitiateWebRTCConnection_Response = _reflection.GeneratedProtocolMessageType('CWebRTCClient_InitiateWebRTCConnection_Response', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_InitiateWebRTCConnection_Response)
  })
_sym_db.RegisterMessage(CWebRTCClient_InitiateWebRTCConnection_Response)

CWebRTC_WebRTCSessionConnected_Notification = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCSessionConnected_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCSessionConnected_Notification)
  })
_sym_db.RegisterMessage(CWebRTC_WebRTCSessionConnected_Notification)

CWebRTC_WebRTCUpdateRemoteDescription_Notification = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCUpdateRemoteDescription_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCUpdateRemoteDescription_Notification)
  })
_sym_db.RegisterMessage(CWebRTC_WebRTCUpdateRemoteDescription_Notification)

CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping)
  })
_sym_db.RegisterMessage(CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping)

CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request = _reflection.GeneratedProtocolMessageType('CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request)
  })
_sym_db.RegisterMessage(CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request)

CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response = _reflection.GeneratedProtocolMessageType('CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response', (_message.Message,), {
  'DESCRIPTOR' : _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response)
  })
_sym_db.RegisterMessage(CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response)

CMobilePerAccount_GetSettings_Request = _reflection.GeneratedProtocolMessageType('CMobilePerAccount_GetSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEPERACCOUNT_GETSETTINGS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobilePerAccount_GetSettings_Request)
  })
_sym_db.RegisterMessage(CMobilePerAccount_GetSettings_Request)

CMobilePerAccount_GetSettings_Response = _reflection.GeneratedProtocolMessageType('CMobilePerAccount_GetSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobilePerAccount_GetSettings_Response)
  })
_sym_db.RegisterMessage(CMobilePerAccount_GetSettings_Response)

CMobilePerAccount_SetSettings_Request = _reflection.GeneratedProtocolMessageType('CMobilePerAccount_SetSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEPERACCOUNT_SETSETTINGS_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobilePerAccount_SetSettings_Request)
  })
_sym_db.RegisterMessage(CMobilePerAccount_SetSettings_Request)

CMobilePerAccount_SetSettings_Response = _reflection.GeneratedProtocolMessageType('CMobilePerAccount_SetSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobilePerAccount_SetSettings_Response)
  })
_sym_db.RegisterMessage(CMobilePerAccount_SetSettings_Response)

CMobileDevice_RegisterMobileDevice_Request = _reflection.GeneratedProtocolMessageType('CMobileDevice_RegisterMobileDevice_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobileDevice_RegisterMobileDevice_Request)
  })
_sym_db.RegisterMessage(CMobileDevice_RegisterMobileDevice_Request)

CMobileDevice_RegisterMobileDevice_Response = _reflection.GeneratedProtocolMessageType('CMobileDevice_RegisterMobileDevice_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobileDevice_RegisterMobileDevice_Response)
  })
_sym_db.RegisterMessage(CMobileDevice_RegisterMobileDevice_Response)

CMobileDevice_DeregisterMobileDevice_Notification = _reflection.GeneratedProtocolMessageType('CMobileDevice_DeregisterMobileDevice_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CMobileDevice_DeregisterMobileDevice_Notification)
  })
_sym_db.RegisterMessage(CMobileDevice_DeregisterMobileDevice_Notification)

UnknownProto = _reflection.GeneratedProtocolMessageType('UnknownProto', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNPROTO,
  '__module__' : 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:UnknownProto)
  })
_sym_db.RegisterMessage(UnknownProto)


DESCRIPTOR._options = None
_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST.fields_by_name['filter_event_type']._options = None
_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING.fields_by_name['display_location']._options = None
_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION.fields_by_name['type']._options = None
_CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST.fields_by_name['mobile_app']._options = None

_HELPREQUESTLOGS = _descriptor.ServiceDescriptor(
  name='HelpRequestLogs',
  full_name='HelpRequestLogs',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=13637,
  serialized_end=13788,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadUserApplicationLog',
    full_name='HelpRequestLogs.UploadUserApplicationLog',
    index=0,
    containing_service=None,
    input_type=_CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_REQUEST,
    output_type=_CHELPREQUESTLOGS_UPLOADUSERAPPLICATIONLOG_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HELPREQUESTLOGS)

DESCRIPTOR.services_by_name['HelpRequestLogs'] = _HELPREQUESTLOGS


_COMMUNITY = _descriptor.ServiceDescriptor(
  name='Community',
  full_name='Community',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=13791,
  serialized_end=15869,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetApps',
    full_name='Community.GetApps',
    index=0,
    containing_service=None,
    input_type=_CCOMMUNITY_GETAPPS_REQUEST,
    output_type=_CCOMMUNITY_GETAPPS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAppRichPresenceLocalization',
    full_name='Community.GetAppRichPresenceLocalization',
    index=1,
    containing_service=None,
    input_type=_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST,
    output_type=_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommentThread',
    full_name='Community.GetCommentThread',
    index=2,
    containing_service=None,
    input_type=_CCOMMUNITY_GETCOMMENTTHREAD_REQUEST,
    output_type=_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostCommentToThread',
    full_name='Community.PostCommentToThread',
    index=3,
    containing_service=None,
    input_type=_CCOMMUNITY_POSTCOMMENTTOTHREAD_REQUEST,
    output_type=_CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCommentFromThread',
    full_name='Community.DeleteCommentFromThread',
    index=4,
    containing_service=None,
    input_type=_CCOMMUNITY_DELETECOMMENTFROMTHREAD_REQUEST,
    output_type=_CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RateCommentThread',
    full_name='Community.RateCommentThread',
    index=5,
    containing_service=None,
    input_type=_CCOMMUNITY_RATECOMMENTTHREAD_REQUEST,
    output_type=_CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommentThreadRatings',
    full_name='Community.GetCommentThreadRatings',
    index=6,
    containing_service=None,
    input_type=_CCOMMUNITY_GETCOMMENTTHREADRATINGS_REQUEST,
    output_type=_CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RateClanAnnouncement',
    full_name='Community.RateClanAnnouncement',
    index=7,
    containing_service=None,
    input_type=_CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST,
    output_type=_CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClanAnnouncementVoteForUser',
    full_name='Community.GetClanAnnouncementVoteForUser',
    index=8,
    containing_service=None,
    input_type=_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST,
    output_type=_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPartnerEventNews',
    full_name='Community.GetUserPartnerEventNews',
    index=9,
    containing_service=None,
    input_type=_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_REQUEST,
    output_type=_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBestEventsForUser',
    full_name='Community.GetBestEventsForUser',
    index=10,
    containing_service=None,
    input_type=_CCOMMUNITY_GETBESTEVENTSFORUSER_REQUEST,
    output_type=_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarkPartnerEventsForUser',
    full_name='Community.MarkPartnerEventsForUser',
    index=11,
    containing_service=None,
    input_type=_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST,
    output_type=_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PartnerEventsShowMoreForApp',
    full_name='Community.PartnerEventsShowMoreForApp',
    index=12,
    containing_service=None,
    input_type=_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_REQUEST,
    output_type=_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PartnerEventsShowLessForApp',
    full_name='Community.PartnerEventsShowLessForApp',
    index=13,
    containing_service=None,
    input_type=_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_REQUEST,
    output_type=_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearUserPartnerEventsAppPriorities',
    full_name='Community.ClearUserPartnerEventsAppPriorities',
    index=14,
    containing_service=None,
    input_type=_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_REQUEST,
    output_type=_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPartnerEventsAppPriorities',
    full_name='Community.GetUserPartnerEventsAppPriorities',
    index=15,
    containing_service=None,
    input_type=_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_REQUEST,
    output_type=_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearSinglePartnerEventsAppPriority',
    full_name='Community.ClearSinglePartnerEventsAppPriority',
    index=16,
    containing_service=None,
    input_type=_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_REQUEST,
    output_type=_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITY)

DESCRIPTOR.services_by_name['Community'] = _COMMUNITY


_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ExperimentService',
  full_name='ExperimentService',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=15871,
  serialized_end=15956,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportProductImpressionsFromClient',
    full_name='ExperimentService.ReportProductImpressionsFromClient',
    index=0,
    containing_service=None,
    input_type=_UNKNOWNPROTO,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE


_FRIENDSLIST = _descriptor.ServiceDescriptor(
  name='FriendsList',
  full_name='FriendsList',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=15959,
  serialized_end=16337,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCategories',
    full_name='FriendsList.GetCategories',
    index=0,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETCATEGORIES_REQUEST,
    output_type=_CFRIENDSLIST_GETCATEGORIES_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFriendsList',
    full_name='FriendsList.GetFriendsList',
    index=1,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETFRIENDSLIST_REQUEST,
    output_type=_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFavorites',
    full_name='FriendsList.GetFavorites',
    index=2,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETFAVORITES_REQUEST,
    output_type=_CFRIENDSLIST_GETFAVORITES_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFavorites',
    full_name='FriendsList.SetFavorites',
    index=3,
    containing_service=None,
    input_type=_CFRIENDSLIST_SETFAVORITES_REQUEST,
    output_type=_CFRIENDSLIST_SETFAVORITES_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDSLIST)

DESCRIPTOR.services_by_name['FriendsList'] = _FRIENDSLIST


_FRIENDSLISTCLIENT = _descriptor.ServiceDescriptor(
  name='FriendsListClient',
  full_name='FriendsListClient',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=16339,
  serialized_end=16436,
  methods=[
  _descriptor.MethodDescriptor(
    name='FavoritesChanged',
    full_name='FriendsListClient.FavoritesChanged',
    index=0,
    containing_service=None,
    input_type=_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDSLISTCLIENT)

DESCRIPTOR.services_by_name['FriendsListClient'] = _FRIENDSLISTCLIENT


_CLAN = _descriptor.ServiceDescriptor(
  name='Clan',
  full_name='Clan',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=16438,
  serialized_end=16540,
  methods=[
  _descriptor.MethodDescriptor(
    name='RespondToClanInvite',
    full_name='Clan.RespondToClanInvite',
    index=0,
    containing_service=None,
    input_type=_CCLAN_RESPONDTOCLANINVITE_REQUEST,
    output_type=_CCLAN_RESPONDTOCLANINVITE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLAN)

DESCRIPTOR.services_by_name['Clan'] = _CLAN


_VOICECHAT = _descriptor.ServiceDescriptor(
  name='VoiceChat',
  full_name='VoiceChat',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=16543,
  serialized_end=17376,
  methods=[
  _descriptor.MethodDescriptor(
    name='UpdateVoiceChatWebRTCData',
    full_name='VoiceChat.UpdateVoiceChatWebRTCData',
    index=0,
    containing_service=None,
    input_type=_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST,
    output_type=_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserVoiceStatus',
    full_name='VoiceChat.NotifyUserVoiceStatus',
    index=1,
    containing_service=None,
    input_type=_CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UploadClientVoiceChatLogs',
    full_name='VoiceChat.UploadClientVoiceChatLogs',
    index=2,
    containing_service=None,
    input_type=_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST,
    output_type=_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveVoiceChat',
    full_name='VoiceChat.LeaveVoiceChat',
    index=3,
    containing_service=None,
    input_type=_CVOICECHAT_LEAVEVOICECHAT_REQUEST,
    output_type=_CVOICECHAT_LEAVEVOICECHAT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestOneOnOneChat',
    full_name='VoiceChat.RequestOneOnOneChat',
    index=4,
    containing_service=None,
    input_type=_CVOICECHAT_REQUESTONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_REQUESTONEONONECHAT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AnswerOneOnOneChat',
    full_name='VoiceChat.AnswerOneOnOneChat',
    index=5,
    containing_service=None,
    input_type=_CVOICECHAT_ANSWERONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_ANSWERONEONONECHAT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndOneOnOneChat',
    full_name='VoiceChat.EndOneOnOneChat',
    index=6,
    containing_service=None,
    input_type=_CVOICECHAT_ENDONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_ENDONEONONECHAT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveOneOnOneChat',
    full_name='VoiceChat.LeaveOneOnOneChat',
    index=7,
    containing_service=None,
    input_type=_CVOICECHAT_LEAVEONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_LEAVEONEONONECHAT_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VOICECHAT)

DESCRIPTOR.services_by_name['VoiceChat'] = _VOICECHAT


_VOICECHATCLIENT = _descriptor.ServiceDescriptor(
  name='VoiceChatClient',
  full_name='VoiceChatClient',
  file=DESCRIPTOR,
  index=7,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=17379,
  serialized_end=18000,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyUserJoinedVoiceChat',
    full_name='VoiceChatClient.NotifyUserJoinedVoiceChat',
    index=0,
    containing_service=None,
    input_type=_CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserLeftVoiceChat',
    full_name='VoiceChatClient.NotifyUserLeftVoiceChat',
    index=1,
    containing_service=None,
    input_type=_CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyVoiceChatEnded',
    full_name='VoiceChatClient.NotifyVoiceChatEnded',
    index=2,
    containing_service=None,
    input_type=_CVOICECHAT_VOICECHATENDED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserVoiceStatus',
    full_name='VoiceChatClient.NotifyUserVoiceStatus',
    index=3,
    containing_service=None,
    input_type=_CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyAllUsersVoiceStatus',
    full_name='VoiceChatClient.NotifyAllUsersVoiceStatus',
    index=4,
    containing_service=None,
    input_type=_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyOneOnOneChatRequested',
    full_name='VoiceChatClient.NotifyOneOnOneChatRequested',
    index=5,
    containing_service=None,
    input_type=_CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyOneOnOneChatResponse',
    full_name='VoiceChatClient.NotifyOneOnOneChatResponse',
    index=6,
    containing_service=None,
    input_type=_CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VOICECHATCLIENT)

DESCRIPTOR.services_by_name['VoiceChatClient'] = _VOICECHATCLIENT


_WEBRTCCLIENT = _descriptor.ServiceDescriptor(
  name='WebRTCClient',
  full_name='WebRTCClient',
  file=DESCRIPTOR,
  index=8,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=18003,
  serialized_end=18305,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitiateWebRTCConnection',
    full_name='WebRTCClient.InitiateWebRTCConnection',
    index=0,
    containing_service=None,
    input_type=_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST,
    output_type=_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcknowledgeUpdatedRemoteDescription',
    full_name='WebRTCClient.AcknowledgeUpdatedRemoteDescription',
    index=1,
    containing_service=None,
    input_type=_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST,
    output_type=_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBRTCCLIENT)

DESCRIPTOR.services_by_name['WebRTCClient'] = _WEBRTCCLIENT


_WEBRTCCLIENTNOTIFICATIONS = _descriptor.ServiceDescriptor(
  name='WebRTCClientNotifications',
  full_name='WebRTCClientNotifications',
  file=DESCRIPTOR,
  index=9,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=18308,
  serialized_end=18531,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCSessionConnected',
    full_name='WebRTCClientNotifications.NotifyWebRTCSessionConnected',
    index=0,
    containing_service=None,
    input_type=_CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCUpdateRemoteDescription',
    full_name='WebRTCClientNotifications.NotifyWebRTCUpdateRemoteDescription',
    index=1,
    containing_service=None,
    input_type=_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBRTCCLIENTNOTIFICATIONS)

DESCRIPTOR.services_by_name['WebRTCClientNotifications'] = _WEBRTCCLIENTNOTIFICATIONS


_MOBILEPERACCOUNT = _descriptor.ServiceDescriptor(
  name='MobilePerAccount',
  full_name='MobilePerAccount',
  file=DESCRIPTOR,
  index=10,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=18534,
  serialized_end=18744,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSettings',
    full_name='MobilePerAccount.GetSettings',
    index=0,
    containing_service=None,
    input_type=_CMOBILEPERACCOUNT_GETSETTINGS_REQUEST,
    output_type=_CMOBILEPERACCOUNT_GETSETTINGS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSettings',
    full_name='MobilePerAccount.SetSettings',
    index=1,
    containing_service=None,
    input_type=_CMOBILEPERACCOUNT_SETSETTINGS_REQUEST,
    output_type=_CMOBILEPERACCOUNT_SETSETTINGS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MOBILEPERACCOUNT)

DESCRIPTOR.services_by_name['MobilePerAccount'] = _MOBILEPERACCOUNT


_MOBILEDEVICE = _descriptor.ServiceDescriptor(
  name='MobileDevice',
  full_name='MobileDevice',
  file=DESCRIPTOR,
  index=11,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=18747,
  serialized_end=18967,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterMobileDevice',
    full_name='MobileDevice.RegisterMobileDevice',
    index=0,
    containing_service=None,
    input_type=_CMOBILEDEVICE_REGISTERMOBILEDEVICE_REQUEST,
    output_type=_CMOBILEDEVICE_REGISTERMOBILEDEVICE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeregisterMobileDevice',
    full_name='MobileDevice.DeregisterMobileDevice',
    index=1,
    containing_service=None,
    input_type=_CMOBILEDEVICE_DEREGISTERMOBILEDEVICE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MOBILEDEVICE)

DESCRIPTOR.services_by_name['MobileDevice'] = _MOBILEDEVICE

HelpRequestLogs = service_reflection.GeneratedServiceType('HelpRequestLogs', (_service.Service,), dict(
  DESCRIPTOR = _HELPREQUESTLOGS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

HelpRequestLogs_Stub = service_reflection.GeneratedServiceStubType('HelpRequestLogs_Stub', (HelpRequestLogs,), dict(
  DESCRIPTOR = _HELPREQUESTLOGS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


Community = service_reflection.GeneratedServiceType('Community', (_service.Service,), dict(
  DESCRIPTOR = _COMMUNITY,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

Community_Stub = service_reflection.GeneratedServiceStubType('Community_Stub', (Community,), dict(
  DESCRIPTOR = _COMMUNITY,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


ExperimentService = service_reflection.GeneratedServiceType('ExperimentService', (_service.Service,), dict(
  DESCRIPTOR = _EXPERIMENTSERVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

ExperimentService_Stub = service_reflection.GeneratedServiceStubType('ExperimentService_Stub', (ExperimentService,), dict(
  DESCRIPTOR = _EXPERIMENTSERVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


FriendsList = service_reflection.GeneratedServiceType('FriendsList', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDSLIST,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

FriendsList_Stub = service_reflection.GeneratedServiceStubType('FriendsList_Stub', (FriendsList,), dict(
  DESCRIPTOR = _FRIENDSLIST,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


FriendsListClient = service_reflection.GeneratedServiceType('FriendsListClient', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDSLISTCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

FriendsListClient_Stub = service_reflection.GeneratedServiceStubType('FriendsListClient_Stub', (FriendsListClient,), dict(
  DESCRIPTOR = _FRIENDSLISTCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


Clan = service_reflection.GeneratedServiceType('Clan', (_service.Service,), dict(
  DESCRIPTOR = _CLAN,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

Clan_Stub = service_reflection.GeneratedServiceStubType('Clan_Stub', (Clan,), dict(
  DESCRIPTOR = _CLAN,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


VoiceChat = service_reflection.GeneratedServiceType('VoiceChat', (_service.Service,), dict(
  DESCRIPTOR = _VOICECHAT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

VoiceChat_Stub = service_reflection.GeneratedServiceStubType('VoiceChat_Stub', (VoiceChat,), dict(
  DESCRIPTOR = _VOICECHAT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


VoiceChatClient = service_reflection.GeneratedServiceType('VoiceChatClient', (_service.Service,), dict(
  DESCRIPTOR = _VOICECHATCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

VoiceChatClient_Stub = service_reflection.GeneratedServiceStubType('VoiceChatClient_Stub', (VoiceChatClient,), dict(
  DESCRIPTOR = _VOICECHATCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


WebRTCClient = service_reflection.GeneratedServiceType('WebRTCClient', (_service.Service,), dict(
  DESCRIPTOR = _WEBRTCCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

WebRTCClient_Stub = service_reflection.GeneratedServiceStubType('WebRTCClient_Stub', (WebRTCClient,), dict(
  DESCRIPTOR = _WEBRTCCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


WebRTCClientNotifications = service_reflection.GeneratedServiceType('WebRTCClientNotifications', (_service.Service,), dict(
  DESCRIPTOR = _WEBRTCCLIENTNOTIFICATIONS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

WebRTCClientNotifications_Stub = service_reflection.GeneratedServiceStubType('WebRTCClientNotifications_Stub', (WebRTCClientNotifications,), dict(
  DESCRIPTOR = _WEBRTCCLIENTNOTIFICATIONS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


MobilePerAccount = service_reflection.GeneratedServiceType('MobilePerAccount', (_service.Service,), dict(
  DESCRIPTOR = _MOBILEPERACCOUNT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

MobilePerAccount_Stub = service_reflection.GeneratedServiceStubType('MobilePerAccount_Stub', (MobilePerAccount,), dict(
  DESCRIPTOR = _MOBILEPERACCOUNT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


MobileDevice = service_reflection.GeneratedServiceType('MobileDevice', (_service.Service,), dict(
  DESCRIPTOR = _MOBILEDEVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

MobileDevice_Stub = service_reflection.GeneratedServiceStubType('MobileDevice_Stub', (MobileDevice,), dict(
  DESCRIPTOR = _MOBILEDEVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


# @@protoc_insertion_point(module_scope)
