# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums_clientserver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='enums_clientserver.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65nums_clientserver.proto*\xd4\x9e\x03\n\x04\x45Msg\x12\x11\n\rk_EMsgInvalid\x10\x00\x12\x0f\n\x0bk_EMsgMulti\x10\x01\x12\x19\n\x15k_EMsgProtobufWrapped\x10\x02\x12\x15\n\x11k_EMsgBaseGeneral\x10\x64\x12\x16\n\x12k_EMsgGenericReply\x10\x64\x12\x17\n\x13k_EMsgDestJobFailed\x10q\x12\x0f\n\x0bk_EMsgAlert\x10s\x12\x15\n\x11k_EMsgSCIDRequest\x10x\x12\x16\n\x12k_EMsgSCIDResponse\x10y\x12\x16\n\x12k_EMsgJobHeartbeat\x10{\x12\x14\n\x10k_EMsgHubConnect\x10|\x12\x13\n\x0fk_EMsgSubscribe\x10~\x12\x14\n\x10k_EMRouteMessage\x10\x7f\x12\x14\n\x0fk_EMsgWGRequest\x10\x82\x01\x12\x15\n\x10k_EMsgWGResponse\x10\x83\x01\x12\x14\n\x0fk_EMsgKeepAlive\x10\x84\x01\x12\x1b\n\x16k_EMsgWebAPIJobRequest\x10\x85\x01\x12\x1c\n\x17k_EMsgWebAPIJobResponse\x10\x86\x01\x12\x1d\n\x18k_EMsgClientSessionStart\x10\x87\x01\x12\x1b\n\x16k_EMsgClientSessionEnd\x10\x88\x01\x12\x1e\n\x19k_EMsgClientSessionUpdate\x10\x89\x01\x12\x1a\n\x15k_EMsgStatsDeprecated\x10\x8a\x01\x12\x0f\n\nk_EMsgPing\x10\x8b\x01\x12\x17\n\x12k_EMsgPingResponse\x10\x8c\x01\x12\x10\n\x0bk_EMsgStats\x10\x8d\x01\x12 \n\x1bk_EMsgRequestFullStatsBlock\x10\x8e\x01\x12\x1b\n\x16k_EMsgLoadDBOCacheItem\x10\x8f\x01\x12#\n\x1ek_EMsgLoadDBOCacheItemResponse\x10\x90\x01\x12\"\n\x1dk_EMsgInvalidateDBOCacheItems\x10\x91\x01\x12\x18\n\x13k_EMsgServiceMethod\x10\x92\x01\x12 \n\x1bk_EMsgServiceMethodResponse\x10\x93\x01\x12 \n\x1bk_EMsgClientPackageVersions\x10\x94\x01\x12\x1b\n\x16k_EMsgTimestampRequest\x10\x95\x01\x12\x1c\n\x17k_EMsgTimestampResponse\x10\x96\x01\x12&\n!k_EMsgServiceMethodCallFromClient\x10\x97\x01\x12$\n\x1fk_EMsgServiceMethodSendToClient\x10\x98\x01\x12\x14\n\x0fk_EMsgBaseShell\x10\xc8\x01\x12\x16\n\x11k_EMsgAssignSysID\x10\xc8\x01\x12\x0f\n\nk_EMsgExit\x10\xc9\x01\x12\x15\n\x10k_EMsgDirRequest\x10\xca\x01\x12\x16\n\x11k_EMsgDirResponse\x10\xcb\x01\x12\x15\n\x10k_EMsgZipRequest\x10\xcc\x01\x12\x16\n\x11k_EMsgZipResponse\x10\xcd\x01\x12\x1f\n\x1ak_EMsgUpdateRecordResponse\x10\xd7\x01\x12\"\n\x1dk_EMsgUpdateCreditCardRequest\x10\xdd\x01\x12 \n\x1bk_EMsgUpdateUserBanResponse\x10\xe1\x01\x12\x18\n\x13k_EMsgPrepareToExit\x10\xe2\x01\x12#\n\x1ek_EMsgContentDescriptionUpdate\x10\xe3\x01\x12\x1a\n\x15k_EMsgTestResetServer\x10\xe4\x01\x12\x1a\n\x15k_EMsgUniverseChanged\x10\xe5\x01\x12 \n\x1bk_EMsgShellConfigInfoUpdate\x10\xe6\x01\x12(\n#k_EMsgRequestWindowsEventLogEntries\x10\xe9\x01\x12(\n#k_EMsgProvideWindowsEventLogEntries\x10\xea\x01\x12\x1a\n\x15k_EMsgShellSearchLogs\x10\xeb\x01\x12\"\n\x1dk_EMsgShellSearchLogsResponse\x10\xec\x01\x12#\n\x1ek_EMsgShellCheckWindowsUpdates\x10\xed\x01\x12+\n&k_EMsgShellCheckWindowsUpdatesResponse\x10\xee\x01\x12\x1e\n\x19k_EMsgTestFlushDelayedSQL\x10\xf0\x01\x12&\n!k_EMsgTestFlushDelayedSQLResponse\x10\xf1\x01\x12*\n%k_EMsgEnsureExecuteScheduledTask_TEST\x10\xf2\x01\x12\x32\n-k_EMsgEnsureExecuteScheduledTaskResponse_TEST\x10\xf3\x01\x12.\n)k_EMsgUpdateScheduledTaskEnableState_TEST\x10\xf4\x01\x12\x36\n1k_EMsgUpdateScheduledTaskEnableStateResponse_TEST\x10\xf5\x01\x12(\n#k_EMsgContentDescriptionDeltaUpdate\x10\xf6\x01\x12)\n$k_EMsgGMShellAndServerAddressUpdates\x10\xf7\x01\x12\x11\n\x0ck_EMsgBaseGM\x10\xac\x02\x12\x14\n\x0fk_EMsgHeartbeat\x10\xac\x02\x12\x16\n\x11k_EMsgShellFailed\x10\xad\x02\x12\x15\n\x10k_EMsgExitShells\x10\xb3\x02\x12\x14\n\x0fk_EMsgExitShell\x10\xb4\x02\x12\x1c\n\x17k_EMsgGracefulExitShell\x10\xb5\x02\x12$\n\x1fk_EMsgLicenseProcessingComplete\x10\xbc\x02\x12\x16\n\x11k_EMsgSetTestFlag\x10\xbd\x02\x12\x1f\n\x1ak_EMsgQueuedEmailsComplete\x10\xbe\x02\x12\x1b\n\x16k_EMsgGMReportPHPError\x10\xbf\x02\x12\x14\n\x0fk_EMsgGMDRMSync\x10\xc0\x02\x12\x1f\n\x1ak_EMsgPhysicalBoxInventory\x10\xc1\x02\x12\x1b\n\x16k_EMsgUpdateConfigFile\x10\xc2\x02\x12\x15\n\x10k_EMsgTestInitDB\x10\xc3\x02\x12\x1d\n\x18k_EMsgGMWriteConfigToSQL\x10\xc4\x02\x12 \n\x1bk_EMsgGMLoadActivationCodes\x10\xc5\x02\x12\x18\n\x13k_EMsgGMQueueForFBS\x10\xc6\x02\x12$\n\x1fk_EMsgGMSchemaConversionResults\x10\xc7\x02\x12#\n\x1ek_EMsgGMWriteShellFailureToSQL\x10\xc9\x02\x12\x1c\n\x17k_EMsgGMWriteStatsToSOS\x10\xca\x02\x12$\n\x1fk_EMsgGMGetServiceMethodRouting\x10\xcb\x02\x12,\n\'k_EMsgGMGetServiceMethodRoutingResponse\x10\xcc\x02\x12*\n%k_EMsgGMTestNextBuildSchemaConversion\x10\xce\x02\x12\x32\n-k_EMsgGMTestNextBuildSchemaConversionResponse\x10\xcf\x02\x12\x1d\n\x18k_EMsgExpectShellRestart\x10\xd0\x02\x12\x19\n\x14k_EMsgHotFixProgress\x10\xd1\x02\x12+\n&k_EMsgGMStatsForwardToAdminConnections\x10\xd2\x02\x12\x12\n\rk_EMsgBaseAIS\x10\x90\x03\x12\'\n\"k_EMsgAISRequestContentDescription\x10\x92\x03\x12\x1b\n\x16k_EMsgAISUpdateAppInfo\x10\x93\x03\x12$\n\x1fk_EMsgAISGetPackageChangeNumber\x10\x95\x03\x12,\n\'k_EMsgAISGetPackageChangeNumberResponse\x10\x96\x03\x12\x1a\n\x15k_EMsgAIGetAppGCFlags\x10\xa7\x03\x12\"\n\x1dk_EMsgAIGetAppGCFlagsResponse\x10\xa8\x03\x12\x17\n\x12k_EMsgAIGetAppList\x10\xa9\x03\x12\x1f\n\x1ak_EMsgAIGetAppListResponse\x10\xaa\x03\x12!\n\x1ck_EMsgAISGetCouponDefinition\x10\xad\x03\x12)\n$k_EMsgAISGetCouponDefinitionResponse\x10\xae\x03\x12\x31\n,k_EMsgAISUpdateSubordinateContentDescription\x10\xaf\x03\x12\x39\n4k_EMsgAISUpdateSubordinateContentDescriptionResponse\x10\xb0\x03\x12\x1a\n\x15k_EMsgAISTestEnableGC\x10\xb1\x03\x12\x11\n\x0ck_EMsgBaseAM\x10\xf4\x03\x12!\n\x1ck_EMsgAMUpdateUserBanRequest\x10\xf8\x03\x12\x17\n\x12k_EMsgAMAddLicense\x10\xf9\x03\x12\x1f\n\x1ak_EMsgAMSendSystemIMToUser\x10\xfc\x03\x12\x1a\n\x15k_EMsgAMExtendLicense\x10\xfd\x03\x12 \n\x1bk_EMsgAMAddMinutesToLicense\x10\xfe\x03\x12\x1a\n\x15k_EMsgAMCancelLicense\x10\xff\x03\x12\x19\n\x14k_EMsgAMInitPurchase\x10\x80\x04\x12\x1d\n\x18k_EMsgAMPurchaseResponse\x10\x81\x04\x12\x1a\n\x15k_EMsgAMGetFinalPrice\x10\x82\x04\x12\"\n\x1dk_EMsgAMGetFinalPriceResponse\x10\x83\x04\x12\x1d\n\x18k_EMsgAMGetLegacyGameKey\x10\x84\x04\x12%\n k_EMsgAMGetLegacyGameKeyResponse\x10\x85\x04\x12!\n\x1ck_EMsgAMFindHungTransactions\x10\x86\x04\x12%\n k_EMsgAMSetAccountTrustedRequest\x10\x87\x04\x12\x1b\n\x16k_EMsgAMCancelPurchase\x10\x8a\x04\x12\x19\n\x14k_EMsgAMNewChallenge\x10\x8b\x04\x12\x1b\n\x16k_EMsgAMLoadOEMTickets\x10\x8c\x04\x12\x1f\n\x1ak_EMsgAMFixPendingPurchase\x10\x8d\x04\x12\'\n\"k_EMsgAMFixPendingPurchaseResponse\x10\x8e\x04\x12\x19\n\x14k_EMsgAMIsUserBanned\x10\x8f\x04\x12\x18\n\x13k_EMsgAMRegisterKey\x10\x90\x04\x12 \n\x1bk_EMsgAMLoadActivationCodes\x10\x91\x04\x12(\n#k_EMsgAMLoadActivationCodesResponse\x10\x92\x04\x12\x1e\n\x19k_EMsgAMLookupKeyResponse\x10\x93\x04\x12\x16\n\x11k_EMsgAMLookupKey\x10\x94\x04\x12\x18\n\x13k_EMsgAMChatCleanup\x10\x95\x04\x12\x18\n\x13k_EMsgAMClanCleanup\x10\x96\x04\x12\x1d\n\x18k_EMsgAMFixPendingRefund\x10\x97\x04\x12\x1e\n\x19k_EMsgAMReverseChargeback\x10\x98\x04\x12&\n!k_EMsgAMReverseChargebackResponse\x10\x99\x04\x12\x1c\n\x17k_EMsgAMClanCleanupList\x10\x9a\x04\x12\x18\n\x13k_EMsgAMGetLicenses\x10\x9b\x04\x12 \n\x1bk_EMsgAMGetLicensesResponse\x10\x9c\x04\x12\x1f\n\x1ak_EMsgAMSendCartRepurchase\x10\x9d\x04\x12\'\n\"k_EMsgAMSendCartRepurchaseResponse\x10\x9e\x04\x12\x1f\n\x1ak_EMsgAllowUserToPlayQuery\x10\xa6\x04\x12\"\n\x1dk_EMsgAllowUserToPlayResponse\x10\xa7\x04\x12\x17\n\x12k_EMsgAMVerfiyUser\x10\xa8\x04\x12\x1d\n\x18k_EMsgAMClientNotPlaying\x10\xa9\x04\x12$\n\x1fk_EMsgAMClientRequestFriendship\x10\xaa\x04\x12\x1f\n\x1ak_EMsgAMRelayPublishStatus\x10\xab\x04\x12!\n\x1ck_EMsgAMInitPurchaseResponse\x10\xb0\x04\x12#\n\x1ek_EMsgAMRevokePurchaseResponse\x10\xb1\x04\x12\x1f\n\x1ak_EMsgAMRefreshGuestPasses\x10\xb3\x04\x12\x1d\n\x18k_EMsgAMGrantGuestPasses\x10\xb6\x04\x12\x1c\n\x17k_EMsgAMClanDataUpdated\x10\xb7\x04\x12\x1a\n\x15k_EMsgAMReloadAccount\x10\xb8\x04\x12\x1f\n\x1ak_EMsgAMClientChatMsgRelay\x10\xb9\x04\x12\x16\n\x11k_EMsgAMChatMulti\x10\xba\x04\x12\"\n\x1dk_EMsgAMClientChatInviteRelay\x10\xbb\x04\x12\x17\n\x12k_EMsgAMChatInvite\x10\xbc\x04\x12 \n\x1bk_EMsgAMClientJoinChatRelay\x10\xbd\x04\x12&\n!k_EMsgAMClientChatMemberInfoRelay\x10\xbe\x04\x12\"\n\x1dk_EMsgAMPublishChatMemberInfo\x10\xbf\x04\x12%\n k_EMsgAMClientAcceptFriendInvite\x10\xc0\x04\x12\x16\n\x11k_EMsgAMChatEnter\x10\xc1\x04\x12+\n&k_EMsgAMClientPublishRemovalFromSource\x10\xc2\x04\x12\x1d\n\x18k_EMsgAMChatActionResult\x10\xc3\x04\x12\x19\n\x14k_EMsgAMFindAccounts\x10\xc4\x04\x12!\n\x1ck_EMsgAMFindAccountsResponse\x10\xc5\x04\x12\x1f\n\x1ak_EMsgAMIsAccountNameInUse\x10\xc6\x04\x12\'\n\"k_EMsgAMIsAccountNameInUseResponse\x10\xc7\x04\x12\x1c\n\x17k_EMsgAMSetAccountFlags\x10\xc8\x04\x12\x17\n\x12k_EMsgAMCreateClan\x10\xca\x04\x12\x1f\n\x1ak_EMsgAMCreateClanResponse\x10\xcb\x04\x12\x1b\n\x16k_EMsgAMGetClanDetails\x10\xcc\x04\x12#\n\x1ek_EMsgAMGetClanDetailsResponse\x10\xcd\x04\x12\x1b\n\x16k_EMsgAMSetPersonaName\x10\xce\x04\x12\x16\n\x11k_EMsgAMSetAvatar\x10\xcf\x04\x12\x1d\n\x18k_EMsgAMAuthenticateUser\x10\xd0\x04\x12%\n k_EMsgAMAuthenticateUserResponse\x10\xd1\x04\x12!\n\x1ck_EMsgAMP2PIntroducerMessage\x10\xd4\x04\x12\x1b\n\x16k_EMsgClientChatAction\x10\xd5\x04\x12\"\n\x1dk_EMsgAMClientChatActionRelay\x10\xd6\x04\x12\x11\n\x0ck_EMsgBaseVS\x10\xd8\x04\x12\x17\n\x12k_EMsgReqChallenge\x10\xd8\x04\x12\x16\n\x11k_EMsgVACResponse\x10\xd9\x04\x12\x1b\n\x16k_EMsgReqChallengeTest\x10\xda\x04\x12\x16\n\x11k_EMsgVSMarkCheat\x10\xdc\x04\x12\x15\n\x10k_EMsgVSAddCheat\x10\xdd\x04\x12\x1b\n\x16k_EMsgVSPurgeCodeModDB\x10\xde\x04\x12 \n\x1bk_EMsgVSGetChallengeResults\x10\xdf\x04\x12 \n\x1bk_EMsgVSChallengeResultText\x10\xe0\x04\x12\x1b\n\x16k_EMsgVSReportLingerer\x10\xe1\x04\x12$\n\x1fk_EMsgVSRequestManagedChallenge\x10\xe2\x04\x12\x1b\n\x16k_EMsgVSLoadDBFinished\x10\xe3\x04\x12\x13\n\x0ek_EMsgBaseDRMS\x10\xf1\x04\x12\x1e\n\x19k_EMsgDRMBuildBlobRequest\x10\xf4\x04\x12\x1f\n\x1ak_EMsgDRMBuildBlobResponse\x10\xf5\x04\x12 \n\x1bk_EMsgDRMResolveGuidRequest\x10\xf6\x04\x12!\n\x1ck_EMsgDRMResolveGuidResponse\x10\xf7\x04\x12\x1f\n\x1ak_EMsgDRMVariabilityReport\x10\xf9\x04\x12\'\n\"k_EMsgDRMVariabilityReportResponse\x10\xfa\x04\x12\x1d\n\x18k_EMsgDRMStabilityReport\x10\xfb\x04\x12%\n k_EMsgDRMStabilityReportResponse\x10\xfc\x04\x12\"\n\x1dk_EMsgDRMDetailsReportRequest\x10\xfd\x04\x12#\n\x1ek_EMsgDRMDetailsReportResponse\x10\xfe\x04\x12\x19\n\x14k_EMsgDRMProcessFile\x10\xff\x04\x12\x19\n\x14k_EMsgDRMAdminUpdate\x10\x80\x05\x12!\n\x1ck_EMsgDRMAdminUpdateResponse\x10\x81\x05\x12\x12\n\rk_EMsgDRMSync\x10\x82\x05\x12\x1a\n\x15k_EMsgDRMSyncResponse\x10\x83\x05\x12!\n\x1ck_EMsgDRMProcessFileResponse\x10\x84\x05\x12\x1c\n\x17k_EMsgDRMEmptyGuidCache\x10\x85\x05\x12$\n\x1fk_EMsgDRMEmptyGuidCacheResponse\x10\x86\x05\x12\x11\n\x0ck_EMsgBaseCS\x10\x8a\x05\x12\x15\n\x10k_EMsgBaseClient\x10\xbc\x05\x12!\n\x1ck_EMsgClientLogOn_Deprecated\x10\xbd\x05\x12%\n k_EMsgClientAnonLogOn_Deprecated\x10\xbe\x05\x12\x1a\n\x15k_EMsgClientHeartBeat\x10\xbf\x05\x12\x1c\n\x17k_EMsgClientVACResponse\x10\xc0\x05\x12%\n k_EMsgClientGamesPlayed_obsolete\x10\xc1\x05\x12\x17\n\x12k_EMsgClientLogOff\x10\xc2\x05\x12\"\n\x1dk_EMsgClientNoUDPConnectivity\x10\xc3\x05\x12 \n\x1bk_EMsgClientConnectionStats\x10\xc6\x05\x12\x1d\n\x18k_EMsgClientPingResponse\x10\xc8\x05\x12\x1d\n\x18k_EMsgClientRemoveFriend\x10\xca\x05\x12&\n!k_EMsgClientGamesPlayedNoDataBlob\x10\xcb\x05\x12\x1d\n\x18k_EMsgClientChangeStatus\x10\xcc\x05\x12\"\n\x1dk_EMsgClientVacStatusResponse\x10\xcd\x05\x12\x1a\n\x15k_EMsgClientFriendMsg\x10\xce\x05\x12%\n k_EMsgClientGameConnect_obsolete\x10\xcf\x05\x12&\n!k_EMsgClientGamesPlayed2_obsolete\x10\xd0\x05\x12#\n\x1ek_EMsgClientGameEnded_obsolete\x10\xd1\x05\x12\x19\n\x14k_EMsgClientSystemIM\x10\xd6\x05\x12\x1c\n\x17k_EMsgClientSystemIMAck\x10\xd7\x05\x12\x1c\n\x17k_EMsgClientGetLicenses\x10\xd8\x05\x12!\n\x1ck_EMsgClientGetLegacyGameKey\x10\xda\x05\x12.\n)k_EMsgClientContentServerLogOn_Deprecated\x10\xdb\x05\x12\x1b\n\x16k_EMsgClientAckVACBan2\x10\xdc\x05\x12$\n\x1fk_EMsgClientGetPurchaseReceipts\x10\xe0\x05\x12&\n!k_EMsgClientGamesPlayed3_obsolete\x10\xe2\x05\x12\x1d\n\x18k_EMsgClientAckGuestPass\x10\xe4\x05\x12 \n\x1bk_EMsgClientRedeemGuestPass\x10\xe5\x05\x12\x1c\n\x17k_EMsgClientGamesPlayed\x10\xe6\x05\x12\x1c\n\x17k_EMsgClientRegisterKey\x10\xe7\x05\x12!\n\x1ck_EMsgClientInviteUserToClan\x10\xe8\x05\x12&\n!k_EMsgClientAcknowledgeClanInvite\x10\xe9\x05\x12&\n!k_EMsgClientPurchaseWithMachineID\x10\xea\x05\x12\x1e\n\x19k_EMsgClientAppUsageEvent\x10\xeb\x05\x12\x1e\n\x19k_EMsgClientLogOnResponse\x10\xef\x05\x12!\n\x1ck_EMsgClientSetHeartbeatRate\x10\xf3\x05\x12&\n!k_EMsgClientNotLoggedOnDeprecated\x10\xf4\x05\x12\x1a\n\x15k_EMsgClientLoggedOff\x10\xf5\x05\x12\x14\n\x0fk_EMsgGSApprove\x10\xf6\x05\x12\x11\n\x0ck_EMsgGSDeny\x10\xf7\x05\x12\x11\n\x0ck_EMsgGSKick\x10\xf8\x05\x12!\n\x1ck_EMsgClientPurchaseResponse\x10\xfb\x05\x12\x15\n\x10k_EMsgClientPing\x10\xfc\x05\x12\x14\n\x0fk_EMsgClientNOP\x10\xfd\x05\x12\x1d\n\x18k_EMsgClientPersonaState\x10\xfe\x05\x12\x1c\n\x17k_EMsgClientFriendsList\x10\xff\x05\x12\x1c\n\x17k_EMsgClientAccountInfo\x10\x80\x06\x12\x1b\n\x16k_EMsgClientNewsUpdate\x10\x83\x06\x12 \n\x1bk_EMsgClientGameConnectDeny\x10\x85\x06\x12\x18\n\x13k_EMsgGSStatusReply\x10\x86\x06\x12\"\n\x1dk_EMsgClientGameConnectTokens\x10\x8b\x06\x12\x1c\n\x17k_EMsgClientLicenseList\x10\x8c\x06\x12\x1d\n\x18k_EMsgClientVACBanStatus\x10\x8e\x06\x12\x17\n\x12k_EMsgClientCMList\x10\x8f\x06\x12\x1b\n\x16k_EMsgClientEncryptPct\x10\x90\x06\x12)\n$k_EMsgClientGetLegacyGameKeyResponse\x10\x91\x06\x12\x1a\n\x15k_EMsgClientAddFriend\x10\x97\x06\x12\"\n\x1dk_EMsgClientAddFriendResponse\x10\x98\x06\x12%\n k_EMsgClientAckGuestPassResponse\x10\x9c\x06\x12(\n#k_EMsgClientRedeemGuestPassResponse\x10\x9d\x06\x12&\n!k_EMsgClientUpdateGuestPassesList\x10\x9e\x06\x12\x18\n\x13k_EMsgClientChatMsg\x10\x9f\x06\x12\x1b\n\x16k_EMsgClientChatInvite\x10\xa0\x06\x12\x19\n\x14k_EMsgClientJoinChat\x10\xa1\x06\x12\x1f\n\x1ak_EMsgClientChatMemberInfo\x10\xa2\x06\x12\x30\n+k_EMsgClientLogOnWithCredentials_Deprecated\x10\xa3\x06\x12\'\n\"k_EMsgClientPasswordChangeResponse\x10\xa5\x06\x12\x1a\n\x15k_EMsgClientChatEnter\x10\xa7\x06\x12(\n#k_EMsgClientFriendRemovedFromSource\x10\xa8\x06\x12\x1b\n\x16k_EMsgClientCreateChat\x10\xa9\x06\x12#\n\x1ek_EMsgClientCreateChatResponse\x10\xaa\x06\x12%\n k_EMsgClientP2PIntroducerMessage\x10\xad\x06\x12!\n\x1ck_EMsgClientChatActionResult\x10\xae\x06\x12\"\n\x1dk_EMsgClientRequestFriendData\x10\xaf\x06\x12\x1d\n\x18k_EMsgClientGetUserStats\x10\xb2\x06\x12%\n k_EMsgClientGetUserStatsResponse\x10\xb3\x06\x12\x1f\n\x1ak_EMsgClientStoreUserStats\x10\xb4\x06\x12\'\n\"k_EMsgClientStoreUserStatsResponse\x10\xb5\x06\x12\x1a\n\x15k_EMsgClientClanState\x10\xb6\x06\x12\x1e\n\x19k_EMsgClientServiceModule\x10\xbe\x06\x12\x1c\n\x17k_EMsgClientServiceCall\x10\xbf\x06\x12$\n\x1fk_EMsgClientServiceCallResponse\x10\xc0\x06\x12&\n!k_EMsgClientNatTraversalStatEvent\x10\xc7\x06\x12 \n\x1bk_EMsgClientSteamUsageEvent\x10\xca\x06\x12\x1e\n\x19k_EMsgClientCheckPassword\x10\xcd\x06\x12\x1e\n\x19k_EMsgClientResetPassword\x10\xce\x06\x12&\n!k_EMsgClientCheckPasswordResponse\x10\xd0\x06\x12&\n!k_EMsgClientResetPasswordResponse\x10\xd1\x06\x12\x1d\n\x18k_EMsgClientSessionToken\x10\xd2\x06\x12!\n\x1ck_EMsgClientDRMProblemReport\x10\xd3\x06\x12 \n\x1bk_EMsgClientSetIgnoreFriend\x10\xd7\x06\x12(\n#k_EMsgClientSetIgnoreFriendResponse\x10\xd8\x06\x12&\n!k_EMsgClientGetAppOwnershipTicket\x10\xd9\x06\x12.\n)k_EMsgClientGetAppOwnershipTicketResponse\x10\xda\x06\x12%\n k_EMsgClientGetLobbyListResponse\x10\xdc\x06\x12\x1b\n\x16k_EMsgClientServerList\x10\xf0\x06\x12\x1f\n\x1ak_EMsgClientDRMBlobRequest\x10\x80\x07\x12 \n\x1bk_EMsgClientDRMBlobResponse\x10\x81\x07\x12\x19\n\x14k_EMsgBaseGameServer\x10\x84\x07\x12\x1d\n\x18k_EMsgGSDisconnectNotice\x10\x85\x07\x12\x13\n\x0ek_EMsgGSStatus\x10\x87\x07\x12\x18\n\x13k_EMsgGSUserPlaying\x10\x89\x07\x12\x14\n\x0fk_EMsgGSStatus2\x10\x8a\x07\x12 \n\x1bk_EMsgGSStatusUpdate_Unused\x10\x8b\x07\x12\x17\n\x12k_EMsgGSServerType\x10\x8c\x07\x12\x17\n\x12k_EMsgGSPlayerList\x10\x8d\x07\x12%\n k_EMsgGSGetUserAchievementStatus\x10\x8e\x07\x12-\n(k_EMsgGSGetUserAchievementStatusResponse\x10\x8f\x07\x12\x19\n\x14k_EMsgGSGetPlayStats\x10\x96\x07\x12!\n\x1ck_EMsgGSGetPlayStatsResponse\x10\x97\x07\x12\x1f\n\x1ak_EMsgGSGetUserGroupStatus\x10\x98\x07\x12\x1f\n\x1ak_EMsgAMGetUserGroupStatus\x10\x99\x07\x12\'\n\"k_EMsgAMGetUserGroupStatusResponse\x10\x9a\x07\x12\'\n\"k_EMsgGSGetUserGroupStatusResponse\x10\x9b\x07\x12\x1a\n\x15k_EMsgGSGetReputation\x10\xa8\x07\x12\"\n\x1dk_EMsgGSGetReputationResponse\x10\xa9\x07\x12\x1e\n\x19k_EMsgGSAssociateWithClan\x10\xaa\x07\x12&\n!k_EMsgGSAssociateWithClanResponse\x10\xab\x07\x12*\n%k_EMsgGSComputeNewPlayerCompatibility\x10\xac\x07\x12\x32\n-k_EMsgGSComputeNewPlayerCompatibilityResponse\x10\xad\x07\x12\x14\n\x0fk_EMsgBaseAdmin\x10\xe8\x07\x12\x13\n\x0ek_EMsgAdminCmd\x10\xe8\x07\x12\x1b\n\x16k_EMsgAdminCmdResponse\x10\xec\x07\x12 \n\x1bk_EMsgAdminLogListenRequest\x10\xed\x07\x12\x18\n\x13k_EMsgAdminLogEvent\x10\xee\x07\x12\x17\n\x12k_EMsgUniverseData\x10\xf2\x07\x12\x14\n\x0fk_EMsgAdminSpew\x10\xfb\x07\x12\x1c\n\x17k_EMsgAdminConsoleTitle\x10\xfc\x07\x12\x16\n\x11k_EMsgAdminGCSpew\x10\xff\x07\x12\x19\n\x14k_EMsgAdminGCCommand\x10\x80\x08\x12 \n\x1bk_EMsgAdminGCGetCommandList\x10\x81\x08\x12(\n#k_EMsgAdminGCGetCommandListResponse\x10\x82\x08\x12\x1c\n\x17k_EMsgFBSConnectionData\x10\x83\x08\x12\x17\n\x12k_EMsgAdminMsgSpew\x10\x84\x08\x12\x12\n\rk_EMsgBaseFBS\x10\xcc\x08\x12\x18\n\x13k_EMsgFBSReqVersion\x10\xcc\x08\x12\x19\n\x14k_EMsgFBSVersionInfo\x10\xcd\x08\x12\x1a\n\x15k_EMsgFBSForceRefresh\x10\xce\x08\x12\x19\n\x14k_EMsgFBSForceBounce\x10\xcf\x08\x12\x1b\n\x16k_EMsgFBSDeployPackage\x10\xd0\x08\x12\x1c\n\x17k_EMsgFBSDeployResponse\x10\xd1\x08\x12 \n\x1bk_EMsgFBSUpdateBootstrapper\x10\xd2\x08\x12\x16\n\x11k_EMsgFBSSetState\x10\xd3\x08\x12\x1c\n\x17k_EMsgFBSApplyOSUpdates\x10\xd4\x08\x12\x1a\n\x15k_EMsgFBSRunCMDScript\x10\xd5\x08\x12\x17\n\x12k_EMsgFBSRebootBox\x10\xd6\x08\x12\x1f\n\x1ak_EMsgFBSSetBigBrotherMode\x10\xd7\x08\x12\x1c\n\x17k_EMsgFBSMinidumpServer\x10\xd8\x08\x12!\n\x1ck_EMsgFBSDeployHotFixPackage\x10\xda\x08\x12\"\n\x1dk_EMsgFBSDeployHotFixResponse\x10\xdb\x08\x12\x1c\n\x17k_EMsgFBSDownloadHotFix\x10\xdc\x08\x12$\n\x1fk_EMsgFBSDownloadHotFixResponse\x10\xdd\x08\x12$\n\x1fk_EMsgFBSUpdateTargetConfigFile\x10\xde\x08\x12\x1e\n\x19k_EMsgFBSApplyAccountCred\x10\xdf\x08\x12&\n!k_EMsgFBSApplyAccountCredResponse\x10\xe0\x08\x12\x1b\n\x16k_EMsgFBSSetShellCount\x10\xe1\x08\x12\x1c\n\x17k_EMsgFBSTerminateShell\x10\xe2\x08\x12\x1f\n\x1ak_EMsgFBSQueryGMForRequest\x10\xe3\x08\x12\x1d\n\x18k_EMsgFBSQueryGMResponse\x10\xe4\x08\x12\x1e\n\x19k_EMsgFBSTerminateZombies\x10\xe5\x08\x12\"\n\x1dk_EMsgFBSInfoFromBootstrapper\x10\xe6\x08\x12\x1f\n\x1ak_EMsgFBSRebootBoxResponse\x10\xe7\x08\x12(\n#k_EMsgFBSBootstrapperPackageRequest\x10\xe8\x08\x12)\n$k_EMsgFBSBootstrapperPackageResponse\x10\xe9\x08\x12)\n$k_EMsgFBSBootstrapperGetPackageChunk\x10\xea\x08\x12\x31\n,k_EMsgFBSBootstrapperGetPackageChunkResponse\x10\xeb\x08\x12\x31\n,k_EMsgFBSBootstrapperPackageTransferProgress\x10\xec\x08\x12!\n\x1ck_EMsgFBSRestartBootstrapper\x10\xed\x08\x12\x1e\n\x19k_EMsgFBSPauseFrozenDumps\x10\xee\x08\x12\x17\n\x12k_EMsgBaseFileXfer\x10\xb0\t\x12\x1a\n\x15k_EMsgFileXferRequest\x10\xb0\t\x12\x1b\n\x16k_EMsgFileXferResponse\x10\xb1\t\x12\x17\n\x12k_EMsgFileXferData\x10\xb2\t\x12\x16\n\x11k_EMsgFileXferEnd\x10\xb3\t\x12\x1a\n\x15k_EMsgFileXferDataAck\x10\xb4\t\x12\x1a\n\x15k_EMsgBaseChannelAuth\x10\x94\n\x12\x1f\n\x1ak_EMsgChannelAuthChallenge\x10\x94\n\x12\x1e\n\x19k_EMsgChannelAuthResponse\x10\x95\n\x12\x1c\n\x17k_EMsgChannelAuthResult\x10\x96\n\x12 \n\x1bk_EMsgChannelEncryptRequest\x10\x97\n\x12!\n\x1ck_EMsgChannelEncryptResponse\x10\x98\n\x12\x1f\n\x1ak_EMsgChannelEncryptResult\x10\x99\n\x12\x11\n\x0ck_EMsgBaseBS\x10\xf8\n\x12\x1a\n\x15k_EMsgBSPurchaseStart\x10\xf9\n\x12\x1d\n\x18k_EMsgBSPurchaseResponse\x10\xfa\n\x12 \n\x1bk_EMsgBSAuthenticateCCTrans\x10\xfb\n\x12(\n#k_EMsgBSAuthenticateCCTransResponse\x10\xfc\n\x12\x1b\n\x16k_EMsgBSSettleComplete\x10\xfe\n\x12\x1a\n\x15k_EMsgBSInitPayPalTxn\x10\x80\x0b\x12\"\n\x1dk_EMsgBSInitPayPalTxnResponse\x10\x81\x0b\x12\x1e\n\x19k_EMsgBSGetPayPalUserInfo\x10\x82\x0b\x12&\n!k_EMsgBSGetPayPalUserInfoResponse\x10\x83\x0b\x12\x1c\n\x17k_EMsgBSPaymentInstrBan\x10\x89\x0b\x12$\n\x1fk_EMsgBSPaymentInstrBanResponse\x10\x8a\x0b\x12\x1e\n\x19k_EMsgBSInitGCBankXferTxn\x10\x8d\x0b\x12&\n!k_EMsgBSInitGCBankXferTxnResponse\x10\x8e\x0b\x12\x18\n\x13k_EMsgBSCommitGCTxn\x10\x91\x0b\x12#\n\x1ek_EMsgBSQueryTransactionStatus\x10\x92\x0b\x12+\n&k_EMsgBSQueryTransactionStatusResponse\x10\x93\x0b\x12!\n\x1ck_EMsgBSQueryTxnExtendedInfo\x10\x99\x0b\x12)\n$k_EMsgBSQueryTxnExtendedInfoResponse\x10\x9a\x0b\x12\"\n\x1dk_EMsgBSUpdateConversionRates\x10\x9b\x0b\x12#\n\x1ek_EMsgBSPurchaseRunFraudChecks\x10\x9d\x0b\x12+\n&k_EMsgBSPurchaseRunFraudChecksResponse\x10\x9e\x0b\x12!\n\x1ck_EMsgBSQueryBankInformation\x10\xa0\x0b\x12)\n$k_EMsgBSQueryBankInformationResponse\x10\xa1\x0b\x12$\n\x1fk_EMsgBSValidateXsollaSignature\x10\xa5\x0b\x12,\n\'k_EMsgBSValidateXsollaSignatureResponse\x10\xa6\x0b\x12\x1e\n\x19k_EMsgBSQiwiWalletInvoice\x10\xa8\x0b\x12&\n!k_EMsgBSQiwiWalletInvoiceResponse\x10\xa9\x0b\x12\'\n\"k_EMsgBSUpdateInventoryFromProPack\x10\xaa\x0b\x12/\n*k_EMsgBSUpdateInventoryFromProPackResponse\x10\xab\x0b\x12 \n\x1bk_EMsgBSSendShippingRequest\x10\xac\x0b\x12(\n#k_EMsgBSSendShippingRequestResponse\x10\xad\x0b\x12\"\n\x1dk_EMsgBSGetProPackOrderStatus\x10\xae\x0b\x12*\n%k_EMsgBSGetProPackOrderStatusResponse\x10\xaf\x0b\x12\x1c\n\x17k_EMsgBSCheckJobRunning\x10\xb0\x0b\x12$\n\x1fk_EMsgBSCheckJobRunningResponse\x10\xb1\x0b\x12*\n%k_EMsgBSResetPackagePurchaseRateLimit\x10\xb2\x0b\x12\x32\n-k_EMsgBSResetPackagePurchaseRateLimitResponse\x10\xb3\x0b\x12\x1e\n\x19k_EMsgBSUpdatePaymentData\x10\xb4\x0b\x12&\n!k_EMsgBSUpdatePaymentDataResponse\x10\xb5\x0b\x12\x1e\n\x19k_EMsgBSGetBillingAddress\x10\xb6\x0b\x12&\n!k_EMsgBSGetBillingAddressResponse\x10\xb7\x0b\x12\x1e\n\x19k_EMsgBSGetCreditCardInfo\x10\xb8\x0b\x12&\n!k_EMsgBSGetCreditCardInfoResponse\x10\xb9\x0b\x12%\n k_EMsgBSRemoveExpiredPaymentData\x10\xbc\x0b\x12-\n(k_EMsgBSRemoveExpiredPaymentDataResponse\x10\xbd\x0b\x12!\n\x1ck_EMsgBSConvertToCurrentKeys\x10\xbe\x0b\x12)\n$k_EMsgBSConvertToCurrentKeysResponse\x10\xbf\x0b\x12\x19\n\x14k_EMsgBSInitPurchase\x10\xc0\x0b\x12!\n\x1ck_EMsgBSInitPurchaseResponse\x10\xc1\x0b\x12\x1d\n\x18k_EMsgBSCompletePurchase\x10\xc2\x0b\x12%\n k_EMsgBSCompletePurchaseResponse\x10\xc3\x0b\x12 \n\x1bk_EMsgBSPruneCardUsageStats\x10\xc4\x0b\x12(\n#k_EMsgBSPruneCardUsageStatsResponse\x10\xc5\x0b\x12!\n\x1ck_EMsgBSStoreBankInformation\x10\xc6\x0b\x12)\n$k_EMsgBSStoreBankInformationResponse\x10\xc7\x0b\x12\x1a\n\x15k_EMsgBSVerifyPOSAKey\x10\xc8\x0b\x12\"\n\x1dk_EMsgBSVerifyPOSAKeyResponse\x10\xc9\x0b\x12!\n\x1ck_EMsgBSReverseRedeemPOSAKey\x10\xca\x0b\x12)\n$k_EMsgBSReverseRedeemPOSAKeyResponse\x10\xcb\x0b\x12 \n\x1bk_EMsgBSQueryFindCreditCard\x10\xcc\x0b\x12(\n#k_EMsgBSQueryFindCreditCardResponse\x10\xcd\x0b\x12!\n\x1ck_EMsgBSStatusInquiryPOSAKey\x10\xce\x0b\x12)\n$k_EMsgBSStatusInquiryPOSAKeyResponse\x10\xcf\x0b\x12,\n\'k_EMsgBSBoaCompraConfirmProductDelivery\x10\xd6\x0b\x12\x34\n/k_EMsgBSBoaCompraConfirmProductDeliveryResponse\x10\xd7\x0b\x12!\n\x1ck_EMsgBSGenerateBoaCompraMD5\x10\xd8\x0b\x12)\n$k_EMsgBSGenerateBoaCompraMD5Response\x10\xd9\x0b\x12\x18\n\x13k_EMsgBSCommitWPTxn\x10\xda\x0b\x12\x1b\n\x16k_EMsgBSCommitAdyenTxn\x10\xdb\x0b\x12\x12\n\rk_EMsgBaseATS\x10\xdc\x0b\x12\x1d\n\x18k_EMsgATSStartStressTest\x10\xdd\x0b\x12\x1c\n\x17k_EMsgATSStopStressTest\x10\xde\x0b\x12\x1f\n\x1ak_EMsgATSRunFailServerTest\x10\xdf\x0b\x12\x1d\n\x18k_EMsgATSUFSPerfTestTask\x10\xe0\x0b\x12!\n\x1ck_EMsgATSUFSPerfTestResponse\x10\xe1\x0b\x12\x16\n\x11k_EMsgATSCycleTCM\x10\xe2\x0b\x12 \n\x1bk_EMsgATSInitDRMSStressTest\x10\xe3\x0b\x12\x16\n\x11k_EMsgATSCallTest\x10\xe4\x0b\x12\x1b\n\x16k_EMsgATSCallTestReply\x10\xe5\x0b\x12!\n\x1ck_EMsgATSStartExternalStress\x10\xe6\x0b\x12$\n\x1fk_EMsgATSExternalStressJobStart\x10\xe7\x0b\x12%\n k_EMsgATSExternalStressJobQueued\x10\xe8\x0b\x12&\n!k_EMsgATSExternalStressJobRunning\x10\xe9\x0b\x12&\n!k_EMsgATSExternalStressJobStopped\x10\xea\x0b\x12&\n!k_EMsgATSExternalStressJobStopAll\x10\xeb\x0b\x12(\n#k_EMsgATSExternalStressActionResult\x10\xec\x0b\x12\x15\n\x10k_EMsgATSStarted\x10\xed\x0b\x12\x1c\n\x17k_EMsgATSCSPerfTestTask\x10\xee\x0b\x12 \n\x1bk_EMsgATSCSPerfTestResponse\x10\xef\x0b\x12\x11\n\x0ck_EMsgBaseDP\x10\xc0\x0c\x12\x1f\n\x1ak_EMsgDPSetPublishingState\x10\xc1\x0c\x12\x1e\n\x19k_EMsgDPUniquePlayersStat\x10\xc3\x0c\x12\'\n\"k_EMsgDPStreamingUniquePlayersStat\x10\xc4\x0c\x12\x1a\n\x15k_EMsgDPBlockingStats\x10\xc7\x0c\x12\x1e\n\x19k_EMsgDPNatTraversalStats\x10\xc8\x0c\x12\x17\n\x12k_EMsgDPCloudStats\x10\xcc\x0c\x12\x1b\n\x16k_EMsgDPGetPlayerCount\x10\xcf\x0c\x12#\n\x1ek_EMsgDPGetPlayerCountResponse\x10\xd0\x0c\x12$\n\x1fk_EMsgDPGameServersPlayersStats\x10\xd1\x0c\x12%\n k_EMsgClientDPCheckSpecialSurvey\x10\xd4\x0c\x12-\n(k_EMsgClientDPCheckSpecialSurveyResponse\x10\xd5\x0c\x12,\n\'k_EMsgClientDPSendSpecialSurveyResponse\x10\xd6\x0c\x12\x31\n,k_EMsgClientDPSendSpecialSurveyResponseReply\x10\xd7\x0c\x12 \n\x1bk_EMsgDPStoreSaleStatistics\x10\xd8\x0c\x12%\n k_EMsgClientDPUpdateAppJobReport\x10\xd9\x0c\x12(\n#k_EMsgClientDPUnsignedInstallScript\x10\xdb\x0c\x12\x1d\n\x18k_EMsgDPPartnerMicroTxns\x10\xdc\x0c\x12%\n k_EMsgDPPartnerMicroTxnsResponse\x10\xdd\x0c\x12%\n k_EMsgClientDPContentStatsReport\x10\xde\x0c\x12 \n\x1bk_EMsgDPVRUniquePlayersStat\x10\xdf\x0c\x12\x11\n\x0ck_EMsgBaseCM\x10\xa4\r\x12\x1a\n\x15k_EMsgCMSetAllowState\x10\xa5\r\x12\x1b\n\x16k_EMsgCMSpewAllowState\x10\xa6\r\x12\x1c\n\x17k_EMsgCMSessionRejected\x10\xa7\r\x12\x17\n\x12k_EMsgCMSetSecrets\x10\xa8\r\x12\x17\n\x12k_EMsgCMGetSecrets\x10\xa9\r\x12\x11\n\x0ck_EMsgBaseGC\x10\x98\x11\x12\x16\n\x11k_EMsgGCCmdRevive\x10\x9b\x11\x12\x14\n\x0fk_EMsgGCCmdDown\x10\x9e\x11\x12\x16\n\x11k_EMsgGCCmdDeploy\x10\x9f\x11\x12\x1e\n\x19k_EMsgGCCmdDeployResponse\x10\xa0\x11\x12\x16\n\x11k_EMsgGCCmdSwitch\x10\xa1\x11\x12\x1c\n\x17k_EMsgAMRefreshSessions\x10\xa2\x11\x12\x1f\n\x1ak_EMsgGCAchievementAwarded\x10\xa4\x11\x12\x1a\n\x15k_EMsgGCSystemMessage\x10\xa5\x11\x12\x16\n\x11k_EMsgGCCmdStatus\x10\xa8\x11\x12-\n(k_EMsgGCRegisterWebInterfaces_Deprecated\x10\xa9\x11\x12)\n$k_EMsgGCGetAccountDetails_DEPRECATED\x10\xaa\x11\x12\x1c\n\x17k_EMsgGCInterAppMessage\x10\xab\x11\x12\x1d\n\x18k_EMsgGCGetEmailTemplate\x10\xac\x11\x12%\n k_EMsgGCGetEmailTemplateResponse\x10\xad\x11\x12\x13\n\x0ek_EMsgGCHRelay\x10\xae\x11\x12\x1b\n\x16k_EMsgGCHRelayToClient\x10\xaf\x11\x12\x1b\n\x16k_EMsgGCHUpdateSession\x10\xb0\x11\x12\"\n\x1dk_EMsgGCHRequestUpdateSession\x10\xb1\x11\x12\x1b\n\x16k_EMsgGCHRequestStatus\x10\xb2\x11\x12#\n\x1ek_EMsgGCHRequestStatusResponse\x10\xb3\x11\x12$\n\x1fk_EMsgGCHAccountVacStatusChange\x10\xb4\x11\x12\x15\n\x10k_EMsgGCHSpawnGC\x10\xb5\x11\x12\x1d\n\x18k_EMsgGCHSpawnGCResponse\x10\xb6\x11\x12\x14\n\x0fk_EMsgGCHKillGC\x10\xb7\x11\x12\x1c\n\x17k_EMsgGCHKillGCResponse\x10\xb8\x11\x12)\n$k_EMsgGCHAccountTradeBanStatusChange\x10\xb9\x11\x12%\n k_EMsgGCHAccountLockStatusChange\x10\xba\x11\x12#\n\x1ek_EMsgGCHVacVerificationChange\x10\xbb\x11\x12&\n!k_EMsgGCHAccountPhoneNumberChange\x10\xbc\x11\x12$\n\x1fk_EMsgGCHAccountTwoFactorChange\x10\xbd\x11\x12\x1f\n\x1ak_EMsgGCHInviteUserToLobby\x10\xbe\x11\x12$\n\x1fk_EMsgGCHUpdateMultipleSessions\x10\xbf\x11\x12*\n%k_EMsgGCHMarkAppSessionsAuthoritative\x10\xc0\x11\x12/\n*k_EMsgGCHRecurringSubscriptionStatusChange\x10\xc1\x11\x12\x1f\n\x1ak_EMsgGCHAppCheersReceived\x10\xc2\x11\x12&\n!k_EMsgGCHAppCheersGetAllowedTypes\x10\xc3\x11\x12.\n)k_EMsgGCHAppCheersGetAllowedTypesResponse\x10\xc4\x11\x12\x12\n\rk_EMsgBaseP2P\x10\xc4\x13\x12\x1f\n\x1ak_EMsgP2PIntroducerMessage\x10\xc6\x13\x12\x11\n\x0ck_EMsgBaseSM\x10\xd4\x16\x12\x1c\n\x17k_EMsgSMExpensiveReport\x10\xd6\x16\x12\x19\n\x14k_EMsgSMHourlyReport\x10\xd7\x16\x12\x1d\n\x18k_EMsgSMPartitionRenames\x10\xd9\x16\x12\x19\n\x14k_EMsgSMMonitorSpace\x10\xda\x16\x12*\n%k_EMsgSMTestNextBuildSchemaConversion\x10\xdb\x16\x12\x32\n-k_EMsgSMTestNextBuildSchemaConversionResponse\x10\xdc\x16\x12\x13\n\x0ek_EMsgBaseTest\x10\xb8\x17\x12\x15\n\x10k_EMsgFailServer\x10\xb8\x17\x12\x1b\n\x16k_EMsgJobHeartbeatTest\x10\xb9\x17\x12#\n\x1ek_EMsgJobHeartbeatTestResponse\x10\xba\x17\x12\x17\n\x12k_EMsgBaseFTSRange\x10\x9c\x18\x12\x17\n\x12k_EMsgBaseCCSRange\x10\xce\x18\x12\'\n\"k_EMsgCCSDeleteAllCommentsByAuthor\x10\xd9\x18\x12/\n*k_EMsgCCSDeleteAllCommentsByAuthorResponse\x10\xda\x18\x12\x17\n\x12k_EMsgBaseLBSRange\x10\x80\x19\x12\x16\n\x11k_EMsgLBSSetScore\x10\x81\x19\x12\x1e\n\x19k_EMsgLBSSetScoreResponse\x10\x82\x19\x12\x1c\n\x17k_EMsgLBSFindOrCreateLB\x10\x83\x19\x12$\n\x1fk_EMsgLBSFindOrCreateLBResponse\x10\x84\x19\x12\x1a\n\x15k_EMsgLBSGetLBEntries\x10\x85\x19\x12\"\n\x1dk_EMsgLBSGetLBEntriesResponse\x10\x86\x19\x12\x17\n\x12k_EMsgLBSGetLBList\x10\x87\x19\x12\x1f\n\x1ak_EMsgLBSGetLBListResponse\x10\x88\x19\x12\x1a\n\x15k_EMsgLBSSetLBDetails\x10\x89\x19\x12\x16\n\x11k_EMsgLBSDeleteLB\x10\x8a\x19\x12\x1b\n\x16k_EMsgLBSDeleteLBEntry\x10\x8b\x19\x12\x15\n\x10k_EMsgLBSResetLB\x10\x8c\x19\x12\x1d\n\x18k_EMsgLBSResetLBResponse\x10\x8d\x19\x12\x1e\n\x19k_EMsgLBSDeleteLBResponse\x10\x8e\x19\x12\x12\n\rk_EMsgBaseOGS\x10\xc8\x1a\x12\x1a\n\x15k_EMsgOGSBeginSession\x10\xc9\x1a\x12\"\n\x1dk_EMsgOGSBeginSessionResponse\x10\xca\x1a\x12\x18\n\x13k_EMsgOGSEndSession\x10\xcb\x1a\x12 \n\x1bk_EMsgOGSEndSessionResponse\x10\xcc\x1a\x12 \n\x1bk_EMsgOGSWriteAppSessionRow\x10\xce\x1a\x12\x12\n\rk_EMsgBaseBRP\x10\x90\x1c\x12 \n\x1bk_EMsgBRPPostTransactionTax\x10\xad\x1c\x12(\n#k_EMsgBRPPostTransactionTaxResponse\x10\xae\x1c\x12\x17\n\x12k_EMsgBaseAMRange2\x10\xa0\x1f\x12\x17\n\x12k_EMsgAMCreateChat\x10\xa1\x1f\x12\x1f\n\x1ak_EMsgAMCreateChatResponse\x10\xa2\x1f\x12\x1a\n\x15k_EMsgAMSetProfileURL\x10\xa5\x1f\x12#\n\x1ek_EMsgAMGetAccountEmailAddress\x10\xa6\x1f\x12+\n&k_EMsgAMGetAccountEmailAddressResponse\x10\xa7\x1f\x12\x1c\n\x17k_EMsgAMRequestClanData\x10\xa8\x1f\x12\x1b\n\x16k_EMsgAMRouteToClients\x10\xa9\x1f\x12\x16\n\x11k_EMsgAMLeaveClan\x10\xaa\x1f\x12\x1c\n\x17k_EMsgAMClanPermissions\x10\xab\x1f\x12$\n\x1fk_EMsgAMClanPermissionsResponse\x10\xac\x1f\x12\x30\n+k_EMsgAMCreateClanEventDummyForRateLimiting\x10\xad\x1f\x12\x30\n+k_EMsgAMUpdateClanEventDummyForRateLimiting\x10\xaf\x1f\x12&\n!k_EMsgAMSetClanPermissionSettings\x10\xb5\x1f\x12.\n)k_EMsgAMSetClanPermissionSettingsResponse\x10\xb6\x1f\x12&\n!k_EMsgAMGetClanPermissionSettings\x10\xb7\x1f\x12.\n)k_EMsgAMGetClanPermissionSettingsResponse\x10\xb8\x1f\x12 \n\x1bk_EMsgAMPublishChatRoomInfo\x10\xb9\x1f\x12\x1d\n\x18k_EMsgClientChatRoomInfo\x10\xba\x1f\x12\x1b\n\x16k_EMsgAMGetClanHistory\x10\xc7\x1f\x12#\n\x1ek_EMsgAMGetClanHistoryResponse\x10\xc8\x1f\x12\"\n\x1dk_EMsgAMGetClanPermissionBits\x10\xc9\x1f\x12*\n%k_EMsgAMGetClanPermissionBitsResponse\x10\xca\x1f\x12\"\n\x1dk_EMsgAMSetClanPermissionBits\x10\xcb\x1f\x12*\n%k_EMsgAMSetClanPermissionBitsResponse\x10\xcc\x1f\x12\x1f\n\x1ak_EMsgAMSessionInfoRequest\x10\xcd\x1f\x12 \n\x1bk_EMsgAMSessionInfoResponse\x10\xce\x1f\x12\x1c\n\x17k_EMsgAMValidateWGToken\x10\xcf\x1f\x12\x18\n\x13k_EMsgAMGetClanRank\x10\xd2\x1f\x12 \n\x1bk_EMsgAMGetClanRankResponse\x10\xd3\x1f\x12\x18\n\x13k_EMsgAMSetClanRank\x10\xd4\x1f\x12 \n\x1bk_EMsgAMSetClanRankResponse\x10\xd5\x1f\x12\x18\n\x13k_EMsgAMGetClanPOTW\x10\xd6\x1f\x12 \n\x1bk_EMsgAMGetClanPOTWResponse\x10\xd7\x1f\x12\x18\n\x13k_EMsgAMSetClanPOTW\x10\xd8\x1f\x12 \n\x1bk_EMsgAMSetClanPOTWResponse\x10\xd9\x1f\x12\x15\n\x10k_EMsgAMDumpUser\x10\xdb\x1f\x12\x1d\n\x18k_EMsgAMKickUserFromClan\x10\xdc\x1f\x12\x1d\n\x18k_EMsgAMAddFounderToClan\x10\xdd\x1f\x12$\n\x1fk_EMsgAMValidateWGTokenResponse\x10\xde\x1f\x12\x1e\n\x19k_EMsgAMSetAccountDetails\x10\xe0\x1f\x12\x1b\n\x16k_EMsgAMGetChatBanList\x10\xe1\x1f\x12#\n\x1ek_EMsgAMGetChatBanListResponse\x10\xe2\x1f\x12\x1a\n\x15k_EMsgAMUnBanFromChat\x10\xe3\x1f\x12\x1b\n\x16k_EMsgAMSetClanDetails\x10\xe4\x1f\x12\x1e\n\x19k_EMsgUGSGetUserGameStats\x10\xe9\x1f\x12&\n!k_EMsgUGSGetUserGameStatsResponse\x10\xea\x1f\x12 \n\x1bk_EMsgAMCheckClanMembership\x10\xeb\x1f\x12\x1b\n\x16k_EMsgAMGetClanMembers\x10\xec\x1f\x12#\n\x1ek_EMsgAMGetClanMembersResponse\x10\xed\x1f\x12#\n\x1ek_EMsgAMNotifyChatOfClanChange\x10\xef\x1f\x12\x1d\n\x18k_EMsgAMResubmitPurchase\x10\xf0\x1f\x12\x16\n\x11k_EMsgAMAddFriend\x10\xf1\x1f\x12\x1e\n\x19k_EMsgAMAddFriendResponse\x10\xf2\x1f\x12\x19\n\x14k_EMsgAMRemoveFriend\x10\xf3\x1f\x12\x15\n\x10k_EMsgAMDumpClan\x10\xf4\x1f\x12\x1c\n\x17k_EMsgAMChangeClanOwner\x10\xf5\x1f\x12\x1e\n\x19k_EMsgAMCancelEasyCollect\x10\xf6\x1f\x12&\n!k_EMsgAMCancelEasyCollectResponse\x10\xf7\x1f\x12\x1a\n\x15k_EMsgAMClansInCommon\x10\xfa\x1f\x12\"\n\x1dk_EMsgAMClansInCommonResponse\x10\xfb\x1f\x12\x1d\n\x18k_EMsgAMIsValidAccountID\x10\xfc\x1f\x12\x1c\n\x17k_EMsgAMWipeFriendsList\x10\xff\x1f\x12\x17\n\x12k_EMsgAMSetIgnored\x10\x80 \x12\'\n\"k_EMsgAMClansInCommonCountResponse\x10\x81 \x12\x18\n\x13k_EMsgAMFriendsList\x10\x82 \x12 \n\x1bk_EMsgAMFriendsListResponse\x10\x83 \x12\x1c\n\x17k_EMsgAMFriendsInCommon\x10\x84 \x12$\n\x1fk_EMsgAMFriendsInCommonResponse\x10\x85 \x12)\n$k_EMsgAMFriendsInCommonCountResponse\x10\x86 \x12\x1f\n\x1ak_EMsgAMClansInCommonCount\x10\x87 \x12\x1d\n\x18k_EMsgAMChallengeVerdict\x10\x88 \x12\"\n\x1dk_EMsgAMChallengeNotification\x10\x89 \x12\x17\n\x12k_EMsgAMFindGSByIP\x10\x8a \x12\x18\n\x13k_EMsgAMFoundGSByIP\x10\x8b \x12\x18\n\x13k_EMsgAMGiftRevoked\x10\x8c \x12\x19\n\x14k_EMsgAMUserClanList\x10\x8e \x12!\n\x1ck_EMsgAMUserClanListResponse\x10\x8f \x12\x1f\n\x1ak_EMsgAMGetAccountDetails2\x10\x90 \x12\'\n\"k_EMsgAMGetAccountDetailsResponse2\x10\x91 \x12(\n#k_EMsgAMSetCommunityProfileSettings\x10\x92 \x12\x30\n+k_EMsgAMSetCommunityProfileSettingsResponse\x10\x93 \x12%\n k_EMsgAMGetCommunityPrivacyState\x10\x94 \x12-\n(k_EMsgAMGetCommunityPrivacyStateResponse\x10\x95 \x12(\n#k_EMsgAMCheckClanInviteRateLimiting\x10\x96 \x12&\n!k_EMsgUGSGetUserAchievementStatus\x10\x97 \x12\x17\n\x12k_EMsgAMGetIgnored\x10\x98 \x12\x1f\n\x1ak_EMsgAMGetIgnoredResponse\x10\x99 \x12\x1f\n\x1ak_EMsgAMSetIgnoredResponse\x10\x9a \x12&\n!k_EMsgAMSetFriendRelationshipNone\x10\x9b \x12\"\n\x1dk_EMsgAMGetFriendRelationship\x10\x9c \x12*\n%k_EMsgAMGetFriendRelationshipResponse\x10\x9d \x12 \n\x1bk_EMsgAMServiceModulesCache\x10\x9e \x12\x1f\n\x1ak_EMsgAMServiceModulesCall\x10\x9f \x12\'\n\"k_EMsgAMServiceModulesCallResponse\x10\xa0 \x12!\n\x1ck_EMsgCommunityAddFriendNews\x10\xac \x12\x19\n\x14k_EMsgAMFindClanUser\x10\xaf \x12!\n\x1ck_EMsgAMFindClanUserResponse\x10\xb0 \x12\x18\n\x13k_EMsgAMBanFromChat\x10\xb1 \x12%\n k_EMsgAMGetUserNewsSubscriptions\x10\xb3 \x12-\n(k_EMsgAMGetUserNewsSubscriptionsResponse\x10\xb4 \x12%\n k_EMsgAMSetUserNewsSubscriptions\x10\xb5 \x12\x1d\n\x18k_EMsgAMSendQueuedEmails\x10\xb8 \x12\x1c\n\x17k_EMsgAMSetLicenseFlags\x10\xb9 \x12\"\n\x1dk_EMsgCommunityDeleteUserNews\x10\xbb \x12\"\n\x1dk_EMsgAMAllowUserFilesRequest\x10\xbc \x12#\n\x1ek_EMsgAMAllowUserFilesResponse\x10\xbd \x12\x1d\n\x18k_EMsgAMGetAccountStatus\x10\xbe \x12%\n k_EMsgAMGetAccountStatusResponse\x10\xbf \x12\x1a\n\x15k_EMsgAMEditBanReason\x10\xc0 \x12(\n#k_EMsgAMCheckClanMembershipResponse\x10\xc1 \x12$\n\x1fk_EMsgAMProbeClanMembershipList\x10\xc2 \x12,\n\'k_EMsgAMProbeClanMembershipListResponse\x10\xc3 \x12.\n)k_EMsgUGSGetUserAchievementStatusResponse\x10\xc4 \x12\x1e\n\x19k_EMsgAMGetFriendsLobbies\x10\xc5 \x12&\n!k_EMsgAMGetFriendsLobbiesResponse\x10\xc6 \x12&\n!k_EMsgAMGetUserFriendNewsResponse\x10\xcc \x12%\n k_EMsgCommunityGetUserFriendNews\x10\xcd \x12%\n k_EMsgAMGetUserClansNewsResponse\x10\xce \x12\x1d\n\x18k_EMsgAMGetUserClansNews\x10\xcf \x12!\n\x1ck_EMsgAMGetPreviousCBAccount\x10\xd8 \x12)\n$k_EMsgAMGetPreviousCBAccountResponse\x10\xd9 \x12\"\n\x1dk_EMsgAMGetUserLicenseHistory\x10\xde \x12*\n%k_EMsgAMGetUserLicenseHistoryResponse\x10\xdf \x12\"\n\x1dk_EMsgAMSupportChangePassword\x10\xe2 \x12\x1f\n\x1ak_EMsgAMSupportChangeEmail\x10\xe3 \x12(\n#k_EMsgAMResetUserVerificationGSByIP\x10\xe5 \x12\x1e\n\x19k_EMsgAMUpdateGSPlayStats\x10\xe6 \x12#\n\x1ek_EMsgAMSupportEnableOrDisable\x10\xe7 \x12\x1e\n\x19k_EMsgAMGetPurchaseStatus\x10\xee \x12$\n\x1fk_EMsgAMSupportIsAccountEnabled\x10\xf1 \x12,\n\'k_EMsgAMSupportIsAccountEnabledResponse\x10\xf2 \x12\x1a\n\x15k_EMsgUGSGetUserStats\x10\xf3 \x12\x15\n\x10k_EMsgAMGSSearch\x10\xf5 \x12!\n\x1ck_EMsgMarketingMessageUpdate\x10\xf8 \x12#\n\x1ek_EMsgChatServerRouteFriendMsg\x10\xfb \x12(\n#k_EMsgAMTicketAuthRequestOrResponse\x10\xfc \x12\x1b\n\x16k_EMsgAMAddFreeLicense\x10\x80!\x12\x1e\n\x19k_EMsgAMValidateEmailLink\x10\x87!\x12&\n!k_EMsgAMValidateEmailLinkResponse\x10\x88!\x12\x1c\n\x17k_EMsgUGSStoreUserStats\x10\x8c!\x12\x1d\n\x18k_EMsgAMDeleteStoredCard\x10\x91!\x12!\n\x1ck_EMsgAMRevokeLegacyGameKeys\x10\x92!\x12\x1d\n\x18k_EMsgAMGetWalletDetails\x10\x94!\x12%\n k_EMsgAMGetWalletDetailsResponse\x10\x95!\x12$\n\x1fk_EMsgAMDeleteStoredPaymentInfo\x10\x96!\x12$\n\x1fk_EMsgAMGetStoredPaymentSummary\x10\x97!\x12,\n\'k_EMsgAMGetStoredPaymentSummaryResponse\x10\x98!\x12$\n\x1fk_EMsgAMGetWalletConversionRate\x10\x99!\x12,\n\'k_EMsgAMGetWalletConversionRateResponse\x10\x9a!\x12\x1a\n\x15k_EMsgAMConvertWallet\x10\x9b!\x12\"\n\x1dk_EMsgAMConvertWalletResponse\x10\x9c!\x12\x1b\n\x16k_EMsgAMSetPreApproval\x10\x9f!\x12#\n\x1ek_EMsgAMSetPreApprovalResponse\x10\xa0!\x12\x19\n\x14k_EMsgAMCreateRefund\x10\xa2!\x12\x1d\n\x18k_EMsgAMCreateChargeback\x10\xa4!\x12\x1a\n\x15k_EMsgAMCreateDispute\x10\xa6!\x12\x19\n\x14k_EMsgAMClearDispute\x10\xa8!\x12&\n!k_EMsgAMCreateFinancialAdjustment\x10\xa9!\x12\x1f\n\x1ak_EMsgAMPlayerNicknameList\x10\xaa!\x12\'\n\"k_EMsgAMPlayerNicknameListResponse\x10\xab!\x12\x1d\n\x18k_EMsgAMSetDRMTestConfig\x10\xac!\x12#\n\x1ek_EMsgAMGetUserCurrentGameInfo\x10\xad!\x12+\n&k_EMsgAMGetUserCurrentGameInfoResponse\x10\xae!\x12\x1c\n\x17k_EMsgAMGetGSPlayerList\x10\xaf!\x12$\n\x1fk_EMsgAMGetGSPlayerListResponse\x10\xb0!\x12\"\n\x1dk_EMsgAMGetSteamIDForMicroTxn\x10\xb6!\x12*\n%k_EMsgAMGetSteamIDForMicroTxnResponse\x10\xb7!\x12\x1d\n\x18k_EMsgAMSetPartnerMember\x10\xb8!\x12 \n\x1bk_EMsgAMRemovePublisherUser\x10\xb9!\x12\x1f\n\x1ak_EMsgAMGetUserLicenseList\x10\xba!\x12\'\n\"k_EMsgAMGetUserLicenseListResponse\x10\xbb!\x12\"\n\x1dk_EMsgAMReloadGameGroupPolicy\x10\xbc!\x12#\n\x1ek_EMsgAMAddFreeLicenseResponse\x10\xbd!\x12\x1c\n\x17k_EMsgAMVACStatusUpdate\x10\xbe!\x12\x1e\n\x19k_EMsgAMGetAccountDetails\x10\xbf!\x12&\n!k_EMsgAMGetAccountDetailsResponse\x10\xc0!\x12!\n\x1ck_EMsgAMGetPlayerLinkDetails\x10\xc1!\x12)\n$k_EMsgAMGetPlayerLinkDetailsResponse\x10\xc2!\x12)\n$k_EMsgAMGetAccountFlagsForWGSpoofing\x10\xc6!\x12\x31\n,k_EMsgAMGetAccountFlagsForWGSpoofingResponse\x10\xc7!\x12\x1c\n\x17k_EMsgAMGetClanOfficers\x10\xca!\x12$\n\x1fk_EMsgAMGetClanOfficersResponse\x10\xcb!\x12\x17\n\x12k_EMsgAMNameChange\x10\xcc!\x12\x1b\n\x16k_EMsgAMGetNameHistory\x10\xcd!\x12#\n\x1ek_EMsgAMGetNameHistoryResponse\x10\xce!\x12!\n\x1ck_EMsgAMUpdateProviderStatus\x10\xd1!\x12)\n$k_EMsgAMSupportRemoveAccountSecurity\x10\xd3!\x12*\n%k_EMsgAMIsAccountInCaptchaGracePeriod\x10\xd4!\x12\x32\n-k_EMsgAMIsAccountInCaptchaGracePeriodResponse\x10\xd5!\x12\x1d\n\x18k_EMsgAMAccountPS3Unlink\x10\xd6!\x12%\n k_EMsgAMAccountPS3UnlinkResponse\x10\xd7!\x12$\n\x1fk_EMsgUGSStoreUserStatsResponse\x10\xd8!\x12\x1e\n\x19k_EMsgAMGetAccountPSNInfo\x10\xd9!\x12&\n!k_EMsgAMGetAccountPSNInfoResponse\x10\xda!\x12$\n\x1fk_EMsgAMAuthenticatedPlayerList\x10\xdb!\x12\x19\n\x14k_EMsgAMGetUserGifts\x10\xdc!\x12!\n\x1ck_EMsgAMGetUserGiftsResponse\x10\xdd!\x12 \n\x1bk_EMsgAMTransferLockedGifts\x10\xe0!\x12(\n#k_EMsgAMTransferLockedGiftsResponse\x10\xe1!\x12%\n k_EMsgAMPlayerHostedOnGameServer\x10\xe2!\x12\x1e\n\x19k_EMsgAMGetAccountBanInfo\x10\xe3!\x12&\n!k_EMsgAMGetAccountBanInfoResponse\x10\xe4!\x12!\n\x1ck_EMsgAMRecordBanEnforcement\x10\xe5!\x12!\n\x1ck_EMsgAMRollbackGiftTransfer\x10\xe6!\x12)\n$k_EMsgAMRollbackGiftTransferResponse\x10\xe7!\x12%\n k_EMsgAMHandlePendingTransaction\x10\xe8!\x12\x1f\n\x1ak_EMsgAMRequestClanDetails\x10\xe9!\x12(\n#k_EMsgAMDeleteStoredPaypalAgreement\x10\xea!\x12\x1d\n\x18k_EMsgAMGameServerUpdate\x10\xeb!\x12\x1d\n\x18k_EMsgAMGameServerRemove\x10\xec!\x12 \n\x1bk_EMsgAMGetPaypalAgreements\x10\xed!\x12(\n#k_EMsgAMGetPaypalAgreementsResponse\x10\xee!\x12/\n*k_EMsgAMGameServerPlayerCompatibilityCheck\x10\xef!\x12\x37\n2k_EMsgAMGameServerPlayerCompatibilityCheckResponse\x10\xf0!\x12\x19\n\x14k_EMsgAMRenewLicense\x10\xf1!\x12\'\n\"k_EMsgAMGetAccountCommunityBanInfo\x10\xf2!\x12/\n*k_EMsgAMGetAccountCommunityBanInfoResponse\x10\xf3!\x12,\n\'k_EMsgAMGameServerAccountChangePassword\x10\xf4!\x12+\n&k_EMsgAMGameServerAccountDeleteAccount\x10\xf5!\x12\x1b\n\x16k_EMsgAMRenewAgreement\x10\xf6!\x12\x1a\n\x15k_EMsgAMXsollaPayment\x10\xf8!\x12\"\n\x1dk_EMsgAMXsollaPaymentResponse\x10\xf9!\x12\"\n\x1dk_EMsgAMAcctAllowedToPurchase\x10\xfa!\x12*\n%k_EMsgAMAcctAllowedToPurchaseResponse\x10\xfb!\x12\x1d\n\x18k_EMsgAMSwapKioskDeposit\x10\xfc!\x12%\n k_EMsgAMSwapKioskDepositResponse\x10\xfd!\x12\x1f\n\x1ak_EMsgAMSetUserGiftUnowned\x10\xfe!\x12\'\n\"k_EMsgAMSetUserGiftUnownedResponse\x10\xff!\x12!\n\x1ck_EMsgAMClaimUnownedUserGift\x10\x80\"\x12)\n$k_EMsgAMClaimUnownedUserGiftResponse\x10\x81\"\x12\x18\n\x13k_EMsgAMSetClanName\x10\x82\"\x12 \n\x1bk_EMsgAMSetClanNameResponse\x10\x83\"\x12\x18\n\x13k_EMsgAMGrantCoupon\x10\x84\"\x12 \n\x1bk_EMsgAMGrantCouponResponse\x10\x85\"\x12-\n(k_EMsgAMIsPackageRestrictedInUserCountry\x10\x86\"\x12\x35\n0k_EMsgAMIsPackageRestrictedInUserCountryResponse\x10\x87\"\x12-\n(k_EMsgAMHandlePendingTransactionResponse\x10\x88\"\x12\x1e\n\x19k_EMsgAMGrantGuestPasses2\x10\x89\"\x12&\n!k_EMsgAMGrantGuestPasses2Response\x10\x8a\"\x12 \n\x1bk_EMsgAMGetPlayerBanDetails\x10\x8d\"\x12(\n#k_EMsgAMGetPlayerBanDetailsResponse\x10\x8e\"\x12\x1d\n\x18k_EMsgAMFinalizePurchase\x10\x8f\"\x12%\n k_EMsgAMFinalizePurchaseResponse\x10\x90\"\x12\"\n\x1dk_EMsgAMPersonaChangeResponse\x10\x94\"\x12+\n&k_EMsgAMGetClanDetailsForForumCreation\x10\x95\"\x12\x33\n.k_EMsgAMGetClanDetailsForForumCreationResponse\x10\x96\"\x12(\n#k_EMsgAMGetPendingNotificationCount\x10\x97\"\x12\x30\n+k_EMsgAMGetPendingNotificationCountResponse\x10\x98\"\x12 \n\x1bk_EMsgAMPasswordHashUpgrade\x10\x99\"\x12\x1d\n\x18k_EMsgAMBoaCompraPayment\x10\x9c\"\x12%\n k_EMsgAMBoaCompraPaymentResponse\x10\x9d\"\x12%\n k_EMsgAMCompleteExternalPurchase\x10\x9f\"\x12-\n(k_EMsgAMCompleteExternalPurchaseResponse\x10\xa0\"\x12)\n$k_EMsgAMResolveNegativeWalletCredits\x10\xa1\"\x12\x31\n,k_EMsgAMResolveNegativeWalletCreditsResponse\x10\xa2\"\x12&\n!k_EMsgAMPlayerGetClanBasicDetails\x10\xa5\"\x12.\n)k_EMsgAMPlayerGetClanBasicDetailsResponse\x10\xa6\"\x12\x17\n\x12k_EMsgAMMOLPayment\x10\xa7\"\x12\x1f\n\x1ak_EMsgAMMOLPaymentResponse\x10\xa8\"\x12\x1b\n\x16k_EMsgGetUserIPCountry\x10\xa9\"\x12#\n\x1ek_EMsgGetUserIPCountryResponse\x10\xaa\"\x12+\n&k_EMsgNotificationOfSuspiciousActivity\x10\xab\"\x12\x1a\n\x15k_EMsgAMDegicaPayment\x10\xac\"\x12\"\n\x1dk_EMsgAMDegicaPaymentResponse\x10\xad\"\x12\x19\n\x14k_EMsgAMEClubPayment\x10\xae\"\x12!\n\x1ck_EMsgAMEClubPaymentResponse\x10\xaf\"\x12%\n k_EMsgAMPayPalPaymentsHubPayment\x10\xb0\"\x12-\n(k_EMsgAMPayPalPaymentsHubPaymentResponse\x10\xb1\"\x12\x31\n,k_EMsgAMTwoFactorRecoverAuthenticatorRequest\x10\xb2\"\x12\x32\n-k_EMsgAMTwoFactorRecoverAuthenticatorResponse\x10\xb3\"\x12\x1d\n\x18k_EMsgAMSmart2PayPayment\x10\xb4\"\x12%\n k_EMsgAMSmart2PayPaymentResponse\x10\xb5\"\x12\x37\n2k_EMsgAMValidatePasswordResetCodeAndSendSmsRequest\x10\xb6\"\x12\x38\n3k_EMsgAMValidatePasswordResetCodeAndSendSmsResponse\x10\xb7\"\x12*\n%k_EMsgAMGetAccountResetDetailsRequest\x10\xb8\"\x12+\n&k_EMsgAMGetAccountResetDetailsResponse\x10\xb9\"\x12\x1a\n\x15k_EMsgAMBitPayPayment\x10\xba\"\x12\"\n\x1dk_EMsgAMBitPayPaymentResponse\x10\xbb\"\x12\"\n\x1dk_EMsgAMSendAccountInfoUpdate\x10\xbc\"\x12\x1e\n\x19k_EMsgAMSendScheduledGift\x10\xbd\"\x12\x1a\n\x15k_EMsgAMNodwinPayment\x10\xbe\"\x12\"\n\x1dk_EMsgAMNodwinPaymentResponse\x10\xbf\"\x12 \n\x1bk_EMsgAMResolveWalletRevoke\x10\xc0\"\x12\'\n\"k_EMsgAMResolveWalletReverseRevoke\x10\xc1\"\x12\x1a\n\x15k_EMsgAMFundedPayment\x10\xc2\"\x12\"\n\x1dk_EMsgAMFundedPaymentResponse\x10\xc3\"\x12.\n)k_EMsgAMRequestPersonaUpdateForChatServer\x10\xc4\"\x12 \n\x1bk_EMsgAMPerfectWorldPayment\x10\xc5\"\x12(\n#k_EMsgAMPerfectWorldPaymentResponse\x10\xc6\"\x12\x1c\n\x17k_EMsgAMECommPayPayment\x10\xc7\"\x12$\n\x1fk_EMsgAMECommPayPaymentResponse\x10\xc8\"\x12\x16\n\x11k_EMsgBasePSRange\x10\x88\'\x12\x1f\n\x1ak_EMsgPSCreateShoppingCart\x10\x89\'\x12\'\n\"k_EMsgPSCreateShoppingCartResponse\x10\x8a\'\x12 \n\x1bk_EMsgPSIsValidShoppingCart\x10\x8b\'\x12(\n#k_EMsgPSIsValidShoppingCartResponse\x10\x8c\'\x12+\n&k_EMsgPSRemoveLineItemFromShoppingCart\x10\x8f\'\x12\x33\n.k_EMsgPSRemoveLineItemFromShoppingCartResponse\x10\x90\'\x12$\n\x1fk_EMsgPSGetShoppingCartContents\x10\x91\'\x12,\n\'k_EMsgPSGetShoppingCartContentsResponse\x10\x92\'\x12*\n%k_EMsgPSAddWalletCreditToShoppingCart\x10\x93\'\x12\x32\n-k_EMsgPSAddWalletCreditToShoppingCartResponse\x10\x94\'\x12\x17\n\x12k_EMsgBaseUFSRange\x10\xd0(\x12%\n k_EMsgClientUFSUploadFileRequest\x10\xd2(\x12&\n!k_EMsgClientUFSUploadFileResponse\x10\xd3(\x12#\n\x1ek_EMsgClientUFSUploadFileChunk\x10\xd4(\x12&\n!k_EMsgClientUFSUploadFileFinished\x10\xd5(\x12%\n k_EMsgClientUFSGetFileListForApp\x10\xd6(\x12-\n(k_EMsgClientUFSGetFileListForAppResponse\x10\xd7(\x12#\n\x1ek_EMsgClientUFSDownloadRequest\x10\xda(\x12$\n\x1fk_EMsgClientUFSDownloadResponse\x10\xdb(\x12!\n\x1ck_EMsgClientUFSDownloadChunk\x10\xdc(\x12 \n\x1bk_EMsgClientUFSLoginRequest\x10\xdd(\x12!\n\x1ck_EMsgClientUFSLoginResponse\x10\xde(\x12!\n\x1ck_EMsgUFSReloadPartitionInfo\x10\xdf(\x12%\n k_EMsgClientUFSTransferHeartbeat\x10\xe0(\x12\x1d\n\x18k_EMsgUFSSynchronizeFile\x10\xe1(\x12%\n k_EMsgUFSSynchronizeFileResponse\x10\xe2(\x12%\n k_EMsgClientUFSDeleteFileRequest\x10\xe3(\x12&\n!k_EMsgClientUFSDeleteFileResponse\x10\xe4(\x12!\n\x1ck_EMsgClientUFSGetUGCDetails\x10\xea(\x12)\n$k_EMsgClientUFSGetUGCDetailsResponse\x10\xeb(\x12\x1d\n\x18k_EMsgUFSUpdateFileFlags\x10\xec(\x12%\n k_EMsgUFSUpdateFileFlagsResponse\x10\xed(\x12%\n k_EMsgClientUFSGetSingleFileInfo\x10\xee(\x12-\n(k_EMsgClientUFSGetSingleFileInfoResponse\x10\xef(\x12\x1d\n\x18k_EMsgClientUFSShareFile\x10\xf0(\x12%\n k_EMsgClientUFSShareFileResponse\x10\xf1(\x12\x1b\n\x16k_EMsgUFSReloadAccount\x10\xf2(\x12#\n\x1ek_EMsgUFSReloadAccountResponse\x10\xf3(\x12!\n\x1ck_EMsgUFSUpdateRecordBatched\x10\xf4(\x12)\n$k_EMsgUFSUpdateRecordBatchedResponse\x10\xf5(\x12\x19\n\x14k_EMsgUFSMigrateFile\x10\xf6(\x12!\n\x1ck_EMsgUFSMigrateFileResponse\x10\xf7(\x12\x18\n\x13k_EMsgUFSGetUGCURLs\x10\xf8(\x12 \n\x1bk_EMsgUFSGetUGCURLsResponse\x10\xf9(\x12)\n$k_EMsgUFSHttpUploadFileFinishRequest\x10\xfa(\x12*\n%k_EMsgUFSHttpUploadFileFinishResponse\x10\xfb(\x12\"\n\x1dk_EMsgUFSDownloadStartRequest\x10\xfc(\x12#\n\x1ek_EMsgUFSDownloadStartResponse\x10\xfd(\x12\"\n\x1dk_EMsgUFSDownloadChunkRequest\x10\xfe(\x12#\n\x1ek_EMsgUFSDownloadChunkResponse\x10\xff(\x12#\n\x1ek_EMsgUFSDownloadFinishRequest\x10\x80)\x12$\n\x1fk_EMsgUFSDownloadFinishResponse\x10\x81)\x12\x1b\n\x16k_EMsgUFSFlushURLCache\x10\x82)\x12 \n\x1bk_EMsgClientUFSUploadCommit\x10\x83)\x12(\n#k_EMsgClientUFSUploadCommitResponse\x10\x84)\x12\x1e\n\x19k_EMsgUFSMigrateFileAppID\x10\x85)\x12&\n!k_EMsgUFSMigrateFileAppIDResponse\x10\x86)\x12\x16\n\x11k_EMsgBaseClient2\x10\x98*\x12.\n)k_EMsgClientRequestForgottenPasswordEmail\x10\x99*\x12\x36\n1k_EMsgClientRequestForgottenPasswordEmailResponse\x10\x9a*\x12&\n!k_EMsgClientCreateAccountResponse\x10\x9b*\x12\'\n\"k_EMsgClientResetForgottenPassword\x10\x9c*\x12/\n*k_EMsgClientResetForgottenPasswordResponse\x10\x9d*\x12/\n*k_EMsgClientInformOfResetForgottenPassword\x10\x9f*\x12\x37\n2k_EMsgClientInformOfResetForgottenPasswordResponse\x10\xa0*\x12)\n$k_EMsgClientAnonUserLogOn_Deprecated\x10\xa1*\x12(\n#k_EMsgClientGamesPlayedWithDataBlob\x10\xa2*\x12#\n\x1ek_EMsgClientUpdateUserGameInfo\x10\xa3*\x12\x1f\n\x1ak_EMsgClientFileToDownload\x10\xa4*\x12\'\n\"k_EMsgClientFileToDownloadResponse\x10\xa5*\x12\x1c\n\x17k_EMsgClientLBSSetScore\x10\xa6*\x12$\n\x1fk_EMsgClientLBSSetScoreResponse\x10\xa7*\x12\"\n\x1dk_EMsgClientLBSFindOrCreateLB\x10\xa8*\x12*\n%k_EMsgClientLBSFindOrCreateLBResponse\x10\xa9*\x12 \n\x1bk_EMsgClientLBSGetLBEntries\x10\xaa*\x12(\n#k_EMsgClientLBSGetLBEntriesResponse\x10\xab*\x12\x1d\n\x18k_EMsgClientChatDeclined\x10\xb2*\x12\"\n\x1dk_EMsgClientFriendMsgIncoming\x10\xb3*\x12$\n\x1fk_EMsgClientAuthList_Deprecated\x10\xb4*\x12#\n\x1ek_EMsgClientTicketAuthComplete\x10\xb5*\x12!\n\x1ck_EMsgClientIsLimitedAccount\x10\xb6*\x12 \n\x1bk_EMsgClientRequestAuthList\x10\xb7*\x12\x19\n\x14k_EMsgClientAuthList\x10\xb8*\x12\x15\n\x10k_EMsgClientStat\x10\xb9*\x12\"\n\x1dk_EMsgClientP2PConnectionInfo\x10\xba*\x12&\n!k_EMsgClientP2PConnectionFailInfo\x10\xbb*\x12&\n!k_EMsgClientGetDepotDecryptionKey\x10\xbe*\x12.\n)k_EMsgClientGetDepotDecryptionKeyResponse\x10\xbf*\x12\"\n\x1dk_EMsgGSPerformHardwareSurvey\x10\xc0*\x12\"\n\x1dk_EMsgClientEnableTestLicense\x10\xc3*\x12*\n%k_EMsgClientEnableTestLicenseResponse\x10\xc4*\x12#\n\x1ek_EMsgClientDisableTestLicense\x10\xc5*\x12+\n&k_EMsgClientDisableTestLicenseResponse\x10\xc6*\x12&\n!k_EMsgClientRequestValidationMail\x10\xc8*\x12.\n)k_EMsgClientRequestValidationMailResponse\x10\xc9*\x12%\n k_EMsgClientCheckAppBetaPassword\x10\xca*\x12-\n(k_EMsgClientCheckAppBetaPasswordResponse\x10\xcb*\x12\x15\n\x10k_EMsgClientToGC\x10\xcc*\x12\x17\n\x12k_EMsgClientFromGC\x10\xcd*\x12\x1e\n\x19k_EMsgClientEmailAddrInfo\x10\xd0*\x12 \n\x1bk_EMsgClientPasswordChange3\x10\xd1*\x12\x1d\n\x18k_EMsgClientEmailChange3\x10\xd2*\x12\"\n\x1dk_EMsgClientPersonalQAChange3\x10\xd3*\x12(\n#k_EMsgClientResetForgottenPassword3\x10\xd4*\x12/\n*k_EMsgClientRequestForgottenPasswordEmail3\x10\xd5*\x12\x1c\n\x17k_EMsgClientNewLoginKey\x10\xd7*\x12$\n\x1fk_EMsgClientNewLoginKeyAccepted\x10\xd8*\x12)\n$k_EMsgClientLogOnWithHash_Deprecated\x10\xd9*\x12 \n\x1bk_EMsgClientStoreUserStats2\x10\xda*\x12\x1d\n\x18k_EMsgClientStatsUpdated\x10\xdb*\x12#\n\x1ek_EMsgClientActivateOEMLicense\x10\xdc*\x12#\n\x1ek_EMsgClientRegisterOEMMachine\x10\xdd*\x12+\n&k_EMsgClientRegisterOEMMachineResponse\x10\xde*\x12%\n k_EMsgClientRequestedClientStats\x10\xe8*\x12\x1b\n\x16k_EMsgClientStat2Int32\x10\xe9*\x12\x16\n\x11k_EMsgClientStat2\x10\xea*\x12\x1f\n\x1ak_EMsgClientVerifyPassword\x10\xeb*\x12\'\n\"k_EMsgClientVerifyPasswordResponse\x10\xec*\x12#\n\x1ek_EMsgClientDRMDownloadRequest\x10\xed*\x12$\n\x1fk_EMsgClientDRMDownloadResponse\x10\xee*\x12\x1f\n\x1ak_EMsgClientDRMFinalResult\x10\xef*\x12&\n!k_EMsgClientGetFriendsWhoPlayGame\x10\xf0*\x12.\n)k_EMsgClientGetFriendsWhoPlayGameResponse\x10\xf1*\x12 \n\x1bk_EMsgClientOGSBeginSession\x10\xf2*\x12(\n#k_EMsgClientOGSBeginSessionResponse\x10\xf3*\x12\x1e\n\x19k_EMsgClientOGSEndSession\x10\xf4*\x12&\n!k_EMsgClientOGSEndSessionResponse\x10\xf5*\x12\x1c\n\x17k_EMsgClientOGSWriteRow\x10\xf6*\x12\x18\n\x13k_EMsgClientDRMTest\x10\xf7*\x12\x1e\n\x19k_EMsgClientDRMTestResult\x10\xf8*\x12\"\n\x1dk_EMsgClientServerUnavailable\x10\xfc*\x12!\n\x1ck_EMsgClientServersAvailable\x10\xfd*\x12)\n$k_EMsgClientRegisterAuthTicketWithCM\x10\xfe*\x12\x1c\n\x17k_EMsgClientGCMsgFailed\x10\xff*\x12$\n\x1fk_EMsgClientMicroTxnAuthRequest\x10\x80+\x12\"\n\x1dk_EMsgClientMicroTxnAuthorize\x10\x81+\x12*\n%k_EMsgClientMicroTxnAuthorizeResponse\x10\x82+\x12 \n\x1bk_EMsgClientGetMicroTxnInfo\x10\x84+\x12(\n#k_EMsgClientGetMicroTxnInfoResponse\x10\x85+\x12(\n#k_EMsgClientMarketingMessageUpdate2\x10\x86+\x12%\n k_EMsgClientDeregisterWithServer\x10\x87+\x12\'\n\"k_EMsgClientSubscribeToPersonaFeed\x10\x88+\x12\x16\n\x11k_EMsgClientLogon\x10\x8a+\x12!\n\x1ck_EMsgClientGetClientDetails\x10\x8b+\x12)\n$k_EMsgClientGetClientDetailsResponse\x10\x8c+\x12+\n&k_EMsgClientReportOverlayDetourFailure\x10\x8d+\x12!\n\x1ck_EMsgClientGetClientAppList\x10\x8e+\x12)\n$k_EMsgClientGetClientAppListResponse\x10\x8f+\x12!\n\x1ck_EMsgClientInstallClientApp\x10\x90+\x12)\n$k_EMsgClientInstallClientAppResponse\x10\x91+\x12#\n\x1ek_EMsgClientUninstallClientApp\x10\x92+\x12+\n&k_EMsgClientUninstallClientAppResponse\x10\x93+\x12(\n#k_EMsgClientSetClientAppUpdateState\x10\x94+\x12\x30\n+k_EMsgClientSetClientAppUpdateStateResponse\x10\x95+\x12*\n%k_EMsgClientRequestEncryptedAppTicket\x10\x96+\x12\x32\n-k_EMsgClientRequestEncryptedAppTicketResponse\x10\x97+\x12!\n\x1ck_EMsgClientWalletInfoUpdate\x10\x98+\x12\x1a\n\x15k_EMsgClientLBSSetUGC\x10\x99+\x12\"\n\x1dk_EMsgClientLBSSetUGCResponse\x10\x9a+\x12\"\n\x1dk_EMsgClientAMGetClanOfficers\x10\x9b+\x12*\n%k_EMsgClientAMGetClanOfficersResponse\x10\x9c+\x12\"\n\x1dk_EMsgClientFriendProfileInfo\x10\x9f+\x12*\n%k_EMsgClientFriendProfileInfoResponse\x10\xa0+\x12\"\n\x1dk_EMsgClientUpdateMachineAuth\x10\xa1+\x12*\n%k_EMsgClientUpdateMachineAuthResponse\x10\xa2+\x12 \n\x1bk_EMsgClientReadMachineAuth\x10\xa3+\x12(\n#k_EMsgClientReadMachineAuthResponse\x10\xa4+\x12#\n\x1ek_EMsgClientRequestMachineAuth\x10\xa5+\x12+\n&k_EMsgClientRequestMachineAuthResponse\x10\xa6+\x12#\n\x1ek_EMsgClientScreenshotsChanged\x10\xa7+\x12 \n\x1bk_EMsgClientGetCDNAuthToken\x10\xaa+\x12(\n#k_EMsgClientGetCDNAuthTokenResponse\x10\xab+\x12\'\n\"k_EMsgClientDownloadRateStatistics\x10\xac+\x12#\n\x1ek_EMsgClientRequestAccountData\x10\xad+\x12+\n&k_EMsgClientRequestAccountDataResponse\x10\xae+\x12(\n#k_EMsgClientResetForgottenPassword4\x10\xaf+\x12\x1b\n\x16k_EMsgClientHideFriend\x10\xb0+\x12\"\n\x1dk_EMsgClientFriendsGroupsList\x10\xb1+\x12&\n!k_EMsgClientGetClanActivityCounts\x10\xb2+\x12.\n)k_EMsgClientGetClanActivityCountsResponse\x10\xb3+\x12 \n\x1bk_EMsgClientOGSReportString\x10\xb4+\x12\x1d\n\x18k_EMsgClientOGSReportBug\x10\xb5+\x12\x19\n\x14k_EMsgClientSentLogs\x10\xb6+\x12 \n\x1bk_EMsgClientLogonGameServer\x10\xb7+\x12%\n k_EMsgAMClientCreateFriendsGroup\x10\xb8+\x12-\n(k_EMsgAMClientCreateFriendsGroupResponse\x10\xb9+\x12%\n k_EMsgAMClientDeleteFriendsGroup\x10\xba+\x12-\n(k_EMsgAMClientDeleteFriendsGroupResponse\x10\xbb+\x12%\n k_EMsgAMClientManageFriendsGroup\x10\xbc+\x12-\n(k_EMsgAMClientManageFriendsGroupResponse\x10\xbd+\x12#\n\x1ek_EMsgAMClientAddFriendToGroup\x10\xbe+\x12+\n&k_EMsgAMClientAddFriendToGroupResponse\x10\xbf+\x12(\n#k_EMsgAMClientRemoveFriendFromGroup\x10\xc0+\x12\x30\n+k_EMsgAMClientRemoveFriendFromGroupResponse\x10\xc1+\x12(\n#k_EMsgClientAMGetPersonaNameHistory\x10\xc2+\x12\x30\n+k_EMsgClientAMGetPersonaNameHistoryResponse\x10\xc3+\x12#\n\x1ek_EMsgClientRequestFreeLicense\x10\xc4+\x12+\n&k_EMsgClientRequestFreeLicenseResponse\x10\xc5+\x12\x30\n+k_EMsgClientDRMDownloadRequestWithCrashData\x10\xc6+\x12\x1c\n\x17k_EMsgClientAuthListAck\x10\xc7+\x12\"\n\x1dk_EMsgClientItemAnnouncements\x10\xc8+\x12)\n$k_EMsgClientRequestItemAnnouncements\x10\xc9+\x12&\n!k_EMsgClientFriendMsgEchoToSender\x10\xca+\x12%\n k_EMsgClientCommentNotifications\x10\xce+\x12,\n\'k_EMsgClientRequestCommentNotifications\x10\xcf+\x12&\n!k_EMsgClientPersonaChangeResponse\x10\xd0+\x12\x33\n.k_EMsgClientRequestWebAPIAuthenticateUserNonce\x10\xd1+\x12;\n6k_EMsgClientRequestWebAPIAuthenticateUserNonceResponse\x10\xd2+\x12#\n\x1ek_EMsgClientPlayerNicknameList\x10\xd3+\x12$\n\x1fk_EMsgAMClientSetPlayerNickname\x10\xd4+\x12,\n\'k_EMsgAMClientSetPlayerNicknameResponse\x10\xd5+\x12,\n\'k_EMsgClientGetNumberOfCurrentPlayersDP\x10\xd8+\x12\x34\n/k_EMsgClientGetNumberOfCurrentPlayersDPResponse\x10\xd9+\x12$\n\x1fk_EMsgClientServiceMethodLegacy\x10\xda+\x12,\n\'k_EMsgClientServiceMethodLegacyResponse\x10\xdb+\x12*\n%k_EMsgClientFriendUserStatusPublished\x10\xdc+\x12\x1e\n\x19k_EMsgClientCurrentUIMode\x10\xdd+\x12-\n(k_EMsgClientVanityURLChangedNotification\x10\xde+\x12\"\n\x1dk_EMsgClientUserNotifications\x10\xdf+\x12\x12\n\rk_EMsgBaseDFS\x10\xe0+\x12\x15\n\x10k_EMsgDFSGetFile\x10\xe1+\x12\x1e\n\x19k_EMsgDFSInstallLocalFile\x10\xe2+\x12\x18\n\x13k_EMsgDFSConnection\x10\xe3+\x12\x1d\n\x18k_EMsgDFSConnectionReply\x10\xe4+\x12\'\n\"k_EMsgClientDFSAuthenticateRequest\x10\xe5+\x12(\n#k_EMsgClientDFSAuthenticateResponse\x10\xe6+\x12\x1e\n\x19k_EMsgClientDFSEndSession\x10\xe7+\x12\x17\n\x12k_EMsgDFSPurgeFile\x10\xe8+\x12\x17\n\x12k_EMsgDFSRouteFile\x10\xe9+\x12\x1f\n\x1ak_EMsgDFSGetFileFromServer\x10\xea+\x12\x1e\n\x19k_EMsgDFSAcceptedResponse\x10\xeb+\x12\x1d\n\x18k_EMsgDFSRequestPingback\x10\xec+\x12\x1e\n\x19k_EMsgDFSRecvTransmitFile\x10\xed+\x12\x1e\n\x19k_EMsgDFSSendTransmitFile\x10\xee+\x12\x1e\n\x19k_EMsgDFSRequestPingback2\x10\xef+\x12\x1f\n\x1ak_EMsgDFSResponsePingback2\x10\xf0+\x12\"\n\x1dk_EMsgClientDFSDownloadStatus\x10\xf1+\x12\x1b\n\x16k_EMsgDFSStartTransfer\x10\xf2+\x12\x1e\n\x19k_EMsgDFSTransferComplete\x10\xf3+\x12\x1f\n\x1ak_EMsgDFSRouteFileResponse\x10\xf4+\x12&\n!k_EMsgClientNetworkingCertRequest\x10\xf5+\x12.\n)k_EMsgClientNetworkingCertRequestResponse\x10\xf6+\x12!\n\x1ck_EMsgClientChallengeRequest\x10\xf7+\x12\"\n\x1dk_EMsgClientChallengeResponse\x10\xf8+\x12#\n\x1ek_EMsgBadgeCraftedNotification\x10\xf9+\x12,\n\'k_EMsgClientNetworkingMobileCertRequest\x10\xfa+\x12\x34\n/k_EMsgClientNetworkingMobileCertRequestResponse\x10\xfb+\x12\x12\n\rk_EMsgBaseMDS\x10\xa8-\x12#\n\x1ek_EMsgMDSGetDepotDecryptionKey\x10\xb4-\x12+\n&k_EMsgMDSGetDepotDecryptionKeyResponse\x10\xb5-\x12(\n#k_EMsgMDSContentServerConfigRequest\x10\xc3-\x12!\n\x1ck_EMsgMDSContentServerConfig\x10\xc4-\x12\x1e\n\x19k_EMsgMDSGetDepotManifest\x10\xc5-\x12&\n!k_EMsgMDSGetDepotManifestResponse\x10\xc6-\x12#\n\x1ek_EMsgMDSGetDepotManifestChunk\x10\xc7-\x12\x1b\n\x16k_EMsgMDSGetDepotChunk\x10\xc8-\x12#\n\x1ek_EMsgMDSGetDepotChunkResponse\x10\xc9-\x12 \n\x1bk_EMsgMDSGetDepotChunkChunk\x10\xca-\x12\x1c\n\x17k_EMsgMDSToCSFlushChunk\x10\xd4-\x12\x1a\n\x15k_EMsgMDSMigrateChunk\x10\xd7-\x12\"\n\x1dk_EMsgMDSMigrateChunkResponse\x10\xd8-\x12\x1f\n\x1ak_EMsgMDSToCSFlushManifest\x10\xd9-\x12\x11\n\x0ck_EMsgCSBase\x10\xb8\x30\x12\x11\n\x0ck_EMsgCSPing\x10\xb9\x30\x12\x19\n\x14k_EMsgCSPingResponse\x10\xba\x30\x12\x12\n\rk_EMsgGMSBase\x10\x80\x32\x12!\n\x1ck_EMsgGMSGameServerReplicate\x10\x81\x32\x12\x1f\n\x1ak_EMsgClientGMSServerQuery\x10\x83\x32\x12\'\n\"k_EMsgGMSClientServerQueryResponse\x10\x84\x32\x12 \n\x1bk_EMsgAMGMSGameServerUpdate\x10\x85\x32\x12 \n\x1bk_EMsgAMGMSGameServerRemove\x10\x86\x32\x12\x1e\n\x19k_EMsgGameServerOutOfDate\x10\x87\x32\x12\"\n\x1dk_EMsgDeviceAuthorizationBase\x10\xe4\x32\x12,\n\'k_EMsgClientAuthorizeLocalDeviceRequest\x10\xe5\x32\x12-\n(k_EMsgClientAuthorizeLocalDeviceResponse\x10\xe6\x32\x12)\n$k_EMsgClientDeauthorizeDeviceRequest\x10\xe7\x32\x12\"\n\x1dk_EMsgClientDeauthorizeDevice\x10\xe8\x32\x12-\n(k_EMsgClientUseLocalDeviceAuthorizations\x10\xe9\x32\x12%\n k_EMsgClientGetAuthorizedDevices\x10\xea\x32\x12-\n(k_EMsgClientGetAuthorizedDevicesResponse\x10\xeb\x32\x12*\n%k_EMsgAMNotifySessionDeviceAuthorized\x10\xec\x32\x12\x31\n,k_EMsgClientAuthorizeLocalDeviceNotification\x10\xed\x32\x12\x12\n\rk_EMsgMMSBase\x10\xc8\x33\x12\x1f\n\x1ak_EMsgClientMMSCreateLobby\x10\xc9\x33\x12\'\n\"k_EMsgClientMMSCreateLobbyResponse\x10\xca\x33\x12\x1d\n\x18k_EMsgClientMMSJoinLobby\x10\xcb\x33\x12%\n k_EMsgClientMMSJoinLobbyResponse\x10\xcc\x33\x12\x1e\n\x19k_EMsgClientMMSLeaveLobby\x10\xcd\x33\x12&\n!k_EMsgClientMMSLeaveLobbyResponse\x10\xce\x33\x12 \n\x1bk_EMsgClientMMSGetLobbyList\x10\xcf\x33\x12(\n#k_EMsgClientMMSGetLobbyListResponse\x10\xd0\x33\x12 \n\x1bk_EMsgClientMMSSetLobbyData\x10\xd1\x33\x12(\n#k_EMsgClientMMSSetLobbyDataResponse\x10\xd2\x33\x12 \n\x1bk_EMsgClientMMSGetLobbyData\x10\xd3\x33\x12\x1d\n\x18k_EMsgClientMMSLobbyData\x10\xd4\x33\x12$\n\x1fk_EMsgClientMMSSendLobbyChatMsg\x10\xd5\x33\x12 \n\x1bk_EMsgClientMMSLobbyChatMsg\x10\xd6\x33\x12!\n\x1ck_EMsgClientMMSSetLobbyOwner\x10\xd7\x33\x12)\n$k_EMsgClientMMSSetLobbyOwnerResponse\x10\xd8\x33\x12&\n!k_EMsgClientMMSSetLobbyGameServer\x10\xd9\x33\x12&\n!k_EMsgClientMMSLobbyGameServerSet\x10\xda\x33\x12#\n\x1ek_EMsgClientMMSUserJoinedLobby\x10\xdb\x33\x12!\n\x1ck_EMsgClientMMSUserLeftLobby\x10\xdc\x33\x12!\n\x1ck_EMsgClientMMSInviteToLobby\x10\xdd\x33\x12)\n$k_EMsgClientMMSFlushFrenemyListCache\x10\xde\x33\x12\x31\n,k_EMsgClientMMSFlushFrenemyListCacheResponse\x10\xdf\x33\x12\"\n\x1dk_EMsgClientMMSSetLobbyLinked\x10\xe0\x33\x12.\n)k_EMsgClientMMSSetRatelimitPolicyOnClient\x10\xe1\x33\x12\"\n\x1dk_EMsgClientMMSGetLobbyStatus\x10\xe2\x33\x12*\n%k_EMsgClientMMSGetLobbyStatusResponse\x10\xe3\x33\x12\x1a\n\x15k_EMsgMMSGetLobbyList\x10\xe4\x33\x12\"\n\x1dk_EMsgMMSGetLobbyListResponse\x10\xe5\x33\x12\x18\n\x13k_EMsgNonStdMsgBase\x10\x90\x35\x12\x1d\n\x18k_EMsgNonStdMsgMemcached\x10\x91\x35\x12\x1e\n\x19k_EMsgNonStdMsgHTTPServer\x10\x92\x35\x12\x1e\n\x19k_EMsgNonStdMsgHTTPClient\x10\x93\x35\x12\x1e\n\x19k_EMsgNonStdMsgWGResponse\x10\x94\x35\x12 \n\x1bk_EMsgNonStdMsgPHPSimulator\x10\x95\x35\x12\x19\n\x14k_EMsgNonStdMsgChase\x10\x96\x35\x12\x1f\n\x1ak_EMsgNonStdMsgDFSTransfer\x10\x97\x35\x12\x19\n\x14k_EMsgNonStdMsgTests\x10\x98\x35\x12\x1f\n\x1ak_EMsgNonStdMsgUMQpipeAAPL\x10\x99\x35\x12\x1a\n\x15k_EMSgNonStdMsgSyslog\x10\x9a\x35\x12\x1b\n\x16k_EMsgNonStdMsgLogsink\x10\x9b\x35\x12\"\n\x1dk_EMsgNonStdMsgSteam2Emulator\x10\x9c\x35\x12\x1e\n\x19k_EMsgNonStdMsgRTMPServer\x10\x9d\x35\x12\x1d\n\x18k_EMsgNonStdMsgWebSocket\x10\x9e\x35\x12\x19\n\x14k_EMsgNonStdMsgRedis\x10\x9f\x35\x12\x12\n\rk_EMsgUDSBase\x10\xd8\x36\x12%\n k_EMsgClientUDSP2PSessionStarted\x10\xd9\x36\x12#\n\x1ek_EMsgClientUDSP2PSessionEnded\x10\xda\x36\x12\x1c\n\x17k_EMsgUDSRenderUserAuth\x10\xdb\x36\x12$\n\x1fk_EMsgUDSRenderUserAuthResponse\x10\xdc\x36\x12\x1d\n\x18k_EMsgClientInviteToGame\x10\xdd\x36\x12\x18\n\x13k_EMsgUDSHasSession\x10\xde\x36\x12 \n\x1bk_EMsgUDSHasSessionResponse\x10\xdf\x36\x12\x13\n\x0ek_EMsgMPASBase\x10\xbc\x37\x12\x1a\n\x15k_EMsgMPASVacBanReset\x10\xbd\x37\x12\x12\n\rk_EMsgKGSBase\x10\xa0\x38\x12\x12\n\rk_EMsgUCMBase\x10\x84\x39\x12!\n\x1ck_EMsgClientUCMAddScreenshot\x10\x85\x39\x12)\n$k_EMsgClientUCMAddScreenshotResponse\x10\x86\x39\x12#\n\x1ek_EMsgUCMResetCommunityContent\x10\x8b\x39\x12+\n&k_EMsgUCMResetCommunityContentResponse\x10\x8c\x39\x12$\n\x1fk_EMsgClientUCMDeleteScreenshot\x10\x8d\x39\x12,\n\'k_EMsgClientUCMDeleteScreenshotResponse\x10\x8e\x39\x12\x1f\n\x1ak_EMsgClientUCMPublishFile\x10\x8f\x39\x12\'\n\"k_EMsgClientUCMPublishFileResponse\x10\x90\x39\x12\'\n\"k_EMsgClientUCMDeletePublishedFile\x10\x93\x39\x12/\n*k_EMsgClientUCMDeletePublishedFileResponse\x10\x94\x39\x12\'\n\"k_EMsgClientUCMUpdatePublishedFile\x10\x9d\x39\x12/\n*k_EMsgClientUCMUpdatePublishedFileResponse\x10\x9e\x39\x12!\n\x1ck_EMsgUCMUpdatePublishedFile\x10\x9f\x39\x12)\n$k_EMsgUCMUpdatePublishedFileResponse\x10\xa0\x39\x12!\n\x1ck_EMsgUCMDeletePublishedFile\x10\xa1\x39\x12)\n$k_EMsgUCMDeletePublishedFileResponse\x10\xa2\x39\x12%\n k_EMsgUCMUpdatePublishedFileStat\x10\xa3\x39\x12!\n\x1ck_EMsgUCMReloadPublishedFile\x10\xa9\x39\x12&\n!k_EMsgUCMReloadUserFileListCaches\x10\xaa\x39\x12#\n\x1ek_EMsgUCMPublishedFileReported\x10\xab\x39\x12%\n k_EMsgUCMPublishedFilePreviewAdd\x10\xad\x39\x12-\n(k_EMsgUCMPublishedFilePreviewAddResponse\x10\xae\x39\x12(\n#k_EMsgUCMPublishedFilePreviewRemove\x10\xaf\x39\x12\x30\n+k_EMsgUCMPublishedFilePreviewRemoveResponse\x10\xb0\x39\x12%\n k_EMsgUCMPublishedFileSubscribed\x10\xb5\x39\x12\'\n\"k_EMsgUCMPublishedFileUnsubscribed\x10\xb6\x39\x12\x19\n\x14k_EMsgUCMPublishFile\x10\xb7\x39\x12!\n\x1ck_EMsgUCMPublishFileResponse\x10\xb8\x39\x12#\n\x1ek_EMsgUCMPublishedFileChildAdd\x10\xb9\x39\x12+\n&k_EMsgUCMPublishedFileChildAddResponse\x10\xba\x39\x12&\n!k_EMsgUCMPublishedFileChildRemove\x10\xbb\x39\x12.\n)k_EMsgUCMPublishedFileChildRemoveResponse\x10\xbc\x39\x12(\n#k_EMsgUCMPublishedFileParentChanged\x10\xbf\x39\x12.\n)k_EMsgClientUCMSetUserPublishedFileAction\x10\xc4\x39\x12\x36\n1k_EMsgClientUCMSetUserPublishedFileActionResponse\x10\xc5\x39\x12\x37\n2k_EMsgClientUCMEnumeratePublishedFilesByUserAction\x10\xc6\x39\x12?\n:k_EMsgClientUCMEnumeratePublishedFilesByUserActionResponse\x10\xc7\x39\x12$\n\x1fk_EMsgUCMGetUserSubscribedFiles\x10\xc9\x39\x12,\n\'k_EMsgUCMGetUserSubscribedFilesResponse\x10\xca\x39\x12#\n\x1ek_EMsgUCMFixStatsPublishedFile\x10\xcb\x39\x12;\n6k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdates\x10\xd2\x39\x12\x43\n>k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse\x10\xd3\x39\x12)\n$k_EMsgUCMPublishedFileContentUpdated\x10\xd4\x39\x12(\n#k_EMsgClientUCMPublishedFileUpdated\x10\xd5\x39\x12+\n&k_EMsgClientWorkshopItemChangesRequest\x10\xd6\x39\x12,\n\'k_EMsgClientWorkshopItemChangesResponse\x10\xd7\x39\x12\x11\n\x0ck_EMsgFSBase\x10\xcc:\x12#\n\x1ek_EMsgClientRichPresenceUpload\x10\xcd:\x12$\n\x1fk_EMsgClientRichPresenceRequest\x10\xce:\x12!\n\x1ck_EMsgClientRichPresenceInfo\x10\xcf:\x12 \n\x1bk_EMsgFSRichPresenceRequest\x10\xd0:\x12!\n\x1ck_EMsgFSRichPresenceResponse\x10\xd1:\x12\x1f\n\x1ak_EMsgFSComputeFrenematrix\x10\xd2:\x12\'\n\"k_EMsgFSComputeFrenematrixResponse\x10\xd3:\x12#\n\x1ek_EMsgFSPlayStatusNotification\x10\xd4:\x12 \n\x1bk_EMsgFSAddOrRemoveFollower\x10\xd6:\x12(\n#k_EMsgFSAddOrRemoveFollowerResponse\x10\xd7:\x12 \n\x1bk_EMsgFSUpdateFollowingList\x10\xd8:\x12 \n\x1bk_EMsgFSCommentNotification\x10\xd9:\x12&\n!k_EMsgFSCommentNotificationViewed\x10\xda:\x12#\n\x1ek_EMsgClientFSGetFollowerCount\x10\xdb:\x12+\n&k_EMsgClientFSGetFollowerCountResponse\x10\xdc:\x12!\n\x1ck_EMsgClientFSGetIsFollowing\x10\xdd:\x12)\n$k_EMsgClientFSGetIsFollowingResponse\x10\xde:\x12)\n$k_EMsgClientFSEnumerateFollowingList\x10\xdf:\x12\x31\n,k_EMsgClientFSEnumerateFollowingListResponse\x10\xe0:\x12(\n#k_EMsgFSGetPendingNotificationCount\x10\xe1:\x12\x30\n+k_EMsgFSGetPendingNotificationCountResponse\x10\xe2:\x12/\n*k_EMsgClientChatOfflineMessageNotification\x10\xe3:\x12/\n*k_EMsgClientChatRequestOfflineMessageCount\x10\xe4:\x12,\n\'k_EMsgClientChatGetFriendMessageHistory\x10\xe5:\x12\x34\n/k_EMsgClientChatGetFriendMessageHistoryResponse\x10\xe6:\x12>\n9k_EMsgClientChatGetFriendMessageHistoryForOfflineMessages\x10\xe7:\x12(\n#k_EMsgClientFSGetFriendsSteamLevels\x10\xe8:\x12\x30\n+k_EMsgClientFSGetFriendsSteamLevelsResponse\x10\xe9:\x12\x1e\n\x19k_EMsgAMRequestFriendData\x10\xea:\x12\x14\n\x0fk_EMsgDRMRange2\x10\xb0;\x12,\n\'k_EMsgCEGVersionSetEnableDisableRequest\x10\xb0;\x12-\n(k_EMsgCEGVersionSetEnableDisableResponse\x10\xb1;\x12#\n\x1ek_EMsgCEGPropStatusDRMSRequest\x10\xb2;\x12$\n\x1fk_EMsgCEGPropStatusDRMSResponse\x10\xb3;\x12\'\n\"k_EMsgCEGWhackFailureReportRequest\x10\xb4;\x12(\n#k_EMsgCEGWhackFailureReportResponse\x10\xb5;\x12\x1e\n\x19k_EMsgDRMSFetchVersionSet\x10\xb6;\x12&\n!k_EMsgDRMSFetchVersionSetResponse\x10\xb7;\x12\x13\n\x0ek_EMsgEconBase\x10\x94<\x12+\n&k_EMsgEconTrading_InitiateTradeRequest\x10\x95<\x12,\n\'k_EMsgEconTrading_InitiateTradeProposed\x10\x96<\x12,\n\'k_EMsgEconTrading_InitiateTradeResponse\x10\x97<\x12*\n%k_EMsgEconTrading_InitiateTradeResult\x10\x98<\x12#\n\x1ek_EMsgEconTrading_StartSession\x10\x99<\x12)\n$k_EMsgEconTrading_CancelTradeRequest\x10\x9a<\x12\"\n\x1dk_EMsgEconFlushInventoryCache\x10\x9b<\x12*\n%k_EMsgEconFlushInventoryCacheResponse\x10\x9c<\x12&\n!k_EMsgEconCDKeyProcessTransaction\x10\x9f<\x12.\n)k_EMsgEconCDKeyProcessTransactionResponse\x10\xa0<\x12\x1b\n\x16k_EMsgEconGetErrorLogs\x10\xa1<\x12#\n\x1ek_EMsgEconGetErrorLogsResponse\x10\xa2<\x12\x12\n\rk_EMsgRMRange\x10\xf8<\x12\x1c\n\x17k_EMsgRMTestVerisignOTP\x10\xf8<\x12$\n\x1fk_EMsgRMTestVerisignOTPResponse\x10\xf9<\x12 \n\x1bk_EMsgRMDeleteMemcachedKeys\x10\xfb<\x12\x19\n\x14k_EMsgRMRemoteInvoke\x10\xfc<\x12\x19\n\x14k_EMsgBadLoginIPList\x10\xfd<\x12\x1f\n\x1ak_EMsgRMMsgTraceAddTrigger\x10\xfe<\x12\"\n\x1dk_EMsgRMMsgTraceRemoveTrigger\x10\xff<\x12\x1a\n\x15k_EMsgRMMsgTraceEvent\x10\x80=\x12\x12\n\rk_EMsgUGSBase\x10\xdc=\x12\x1f\n\x1ak_EMsgUGSUpdateGlobalStats\x10\xdc=\x12\"\n\x1dk_EMsgClientUGSGetGlobalStats\x10\xdd=\x12*\n%k_EMsgClientUGSGetGlobalStatsResponse\x10\xde=\x12\x14\n\x0fk_EMsgStoreBase\x10\xc0>\x12\x12\n\rk_EMsgUMQBase\x10\xa4?\x12\x1a\n\x15k_EMsgUMQLogonRequest\x10\xa4?\x12\x1b\n\x16k_EMsgUMQLogonResponse\x10\xa5?\x12\x1b\n\x16k_EMsgUMQLogoffRequest\x10\xa6?\x12\x1c\n\x17k_EMsgUMQLogoffResponse\x10\xa7?\x12\x1d\n\x18k_EMsgUMQSendChatMessage\x10\xa8?\x12!\n\x1ck_EMsgUMQIncomingChatMessage\x10\xa9?\x12\x12\n\rk_EMsgUMQPoll\x10\xaa?\x12\x19\n\x14k_EMsgUMQPollResults\x10\xab?\x12 \n\x1bk_EMsgUMQ2AM_ClientMsgBatch\x10\xac?\x12\x17\n\x12k_EMsgWorkshopBase\x10\x88@\x12\x15\n\x10k_EMsgWebAPIBase\x10\xec@\x12$\n\x1fk_EMsgWebAPIValidateOAuth2Token\x10\xec@\x12,\n\'k_EMsgWebAPIValidateOAuth2TokenResponse\x10\xed@\x12%\n k_EMsgWebAPIRegisterGCInterfaces\x10\xef@\x12+\n&k_EMsgWebAPIInvalidateOAuthClientCache\x10\xf0@\x12*\n%k_EMsgWebAPIInvalidateOAuthTokenCache\x10\xf1@\x12\x1b\n\x16k_EMsgWebAPISetSecrets\x10\xf2@\x12\x17\n\x12k_EMsgBackpackBase\x10\xd0\x41\x12 \n\x1bk_EMsgBackpackAddToCurrency\x10\xd1\x41\x12(\n#k_EMsgBackpackAddToCurrencyResponse\x10\xd2\x41\x12\x12\n\rk_EMsgCREBase\x10\xb4\x42\x12\x1d\n\x18k_EMsgCREItemVoteSummary\x10\xb7\x42\x12%\n k_EMsgCREItemVoteSummaryResponse\x10\xb8\x42\x12)\n$k_EMsgCREUpdateUserPublishedItemVote\x10\xbb\x42\x12\x31\n,k_EMsgCREUpdateUserPublishedItemVoteResponse\x10\xbc\x42\x12-\n(k_EMsgCREGetUserPublishedItemVoteDetails\x10\xbd\x42\x12\x35\n0k_EMsgCREGetUserPublishedItemVoteDetailsResponse\x10\xbe\x42\x12\x16\n\x11k_EMsgSecretsBase\x10\x98\x43\x12\'\n\"k_EMsgSecretsRequestCredentialPair\x10\x98\x43\x12(\n#k_EMsgSecretsCredentialPairResponse\x10\x99\x43\x12\x19\n\x14k_EMsgBoxMonitorBase\x10\xfc\x43\x12\"\n\x1dk_EMsgBoxMonitorReportRequest\x10\xfc\x43\x12#\n\x1ek_EMsgBoxMonitorReportResponse\x10\xfd\x43\x12\x16\n\x11k_EMsgLogsinkBase\x10\xe0\x44\x12\x1d\n\x18k_EMsgLogsinkWriteReport\x10\xe0\x44\x12\x13\n\x0ek_EMsgPICSBase\x10\xc4\x45\x12(\n#k_EMsgClientPICSChangesSinceRequest\x10\xc5\x45\x12)\n$k_EMsgClientPICSChangesSinceResponse\x10\xc6\x45\x12\'\n\"k_EMsgClientPICSProductInfoRequest\x10\xc7\x45\x12(\n#k_EMsgClientPICSProductInfoResponse\x10\xc8\x45\x12\'\n\"k_EMsgClientPICSAccessTokenRequest\x10\xc9\x45\x12(\n#k_EMsgClientPICSAccessTokenResponse\x10\xca\x45\x12\x18\n\x13k_EMsgWorkerProcess\x10\xa8\x46\x12#\n\x1ek_EMsgWorkerProcessPingRequest\x10\xa8\x46\x12$\n\x1fk_EMsgWorkerProcessPingResponse\x10\xa9\x46\x12 \n\x1bk_EMsgWorkerProcessShutdown\x10\xaa\x46\x12\x1b\n\x16k_EMsgDRMWorkerProcess\x10\x8cG\x12%\n k_EMsgDRMWorkerProcessDRMAndSign\x10\x8cG\x12-\n(k_EMsgDRMWorkerProcessDRMAndSignResponse\x10\x8dG\x12\x30\n+k_EMsgDRMWorkerProcessSteamworksInfoRequest\x10\x8eG\x12\x31\n,k_EMsgDRMWorkerProcessSteamworksInfoResponse\x10\x8fG\x12/\n*k_EMsgDRMWorkerProcessInstallDRMDLLRequest\x10\x90G\x12\x30\n+k_EMsgDRMWorkerProcessInstallDRMDLLResponse\x10\x91G\x12\x30\n+k_EMsgDRMWorkerProcessSecretIdStringRequest\x10\x92G\x12\x31\n,k_EMsgDRMWorkerProcessSecretIdStringResponse\x10\x93G\x12\x37\n2k_EMsgDRMWorkerProcessInstallProcessedFilesRequest\x10\x96G\x12\x38\n3k_EMsgDRMWorkerProcessInstallProcessedFilesResponse\x10\x97G\x12-\n(k_EMsgDRMWorkerProcessExamineBlobRequest\x10\x98G\x12.\n)k_EMsgDRMWorkerProcessExamineBlobResponse\x10\x99G\x12\x30\n+k_EMsgDRMWorkerProcessDescribeSecretRequest\x10\x9aG\x12\x31\n,k_EMsgDRMWorkerProcessDescribeSecretResponse\x10\x9bG\x12\x32\n-k_EMsgDRMWorkerProcessBackfillOriginalRequest\x10\x9cG\x12\x33\n.k_EMsgDRMWorkerProcessBackfillOriginalResponse\x10\x9dG\x12\x30\n+k_EMsgDRMWorkerProcessValidateDRMDLLRequest\x10\x9eG\x12\x31\n,k_EMsgDRMWorkerProcessValidateDRMDLLResponse\x10\x9fG\x12.\n)k_EMsgDRMWorkerProcessValidateFileRequest\x10\xa0G\x12/\n*k_EMsgDRMWorkerProcessValidateFileResponse\x10\xa1G\x12\x31\n,k_EMsgDRMWorkerProcessSplitAndInstallRequest\x10\xa2G\x12\x32\n-k_EMsgDRMWorkerProcessSplitAndInstallResponse\x10\xa3G\x12)\n$k_EMsgDRMWorkerProcessGetBlobRequest\x10\xa4G\x12*\n%k_EMsgDRMWorkerProcessGetBlobResponse\x10\xa5G\x12/\n*k_EMsgDRMWorkerProcessEvaluateCrashRequest\x10\xa6G\x12\x30\n+k_EMsgDRMWorkerProcessEvaluateCrashResponse\x10\xa7G\x12-\n(k_EMsgDRMWorkerProcessAnalyzeFileRequest\x10\xa8G\x12.\n)k_EMsgDRMWorkerProcessAnalyzeFileResponse\x10\xa9G\x12,\n\'k_EMsgDRMWorkerProcessUnpackBlobRequest\x10\xaaG\x12-\n(k_EMsgDRMWorkerProcessUnpackBlobResponse\x10\xabG\x12,\n\'k_EMsgDRMWorkerProcessInstallAllRequest\x10\xacG\x12-\n(k_EMsgDRMWorkerProcessInstallAllResponse\x10\xadG\x12\x1c\n\x17k_EMsgTestWorkerProcess\x10\xf0G\x12\x33\n.k_EMsgTestWorkerProcessLoadUnloadModuleRequest\x10\xf0G\x12\x34\n/k_EMsgTestWorkerProcessLoadUnloadModuleResponse\x10\xf1G\x12\x34\n/k_EMsgTestWorkerProcessServiceModuleCallRequest\x10\xf2G\x12\x35\n0k_EMsgTestWorkerProcessServiceModuleCallResponse\x10\xf3G\x12\x1a\n\x15k_EMsgQuestServerBase\x10\xd4H\x12 \n\x1bk_EMsgClientGetEmoticonList\x10\xf2H\x12\x1d\n\x18k_EMsgClientEmoticonList\x10\xf3H\x12\x12\n\rk_EMsgSLCBase\x10\xb8I\x12\x1f\n\x1ak_EMsgSLCUserSessionStatus\x10\xb8I\x12&\n!k_EMsgSLCRequestUserSessionStatus\x10\xb9I\x12&\n!k_EMsgSLCSharedLicensesLockStatus\x10\xbaI\x12(\n#k_EMsgClientSharedLibraryLockStatus\x10\xbdI\x12)\n$k_EMsgClientSharedLibraryStopPlaying\x10\xbeI\x12!\n\x1ck_EMsgSLCOwnerLibraryChanged\x10\xbfI\x12\"\n\x1dk_EMsgSLCSharedLibraryChanged\x10\xc0I\x12\x1b\n\x16k_EMsgRemoteClientBase\x10\x9cJ\x12$\n\x1fk_EMsgRemoteClientAuth_OBSOLETE\x10\x9cJ\x12,\n\'k_EMsgRemoteClientAuthResponse_OBSOLETE\x10\x9dJ\x12 \n\x1bk_EMsgRemoteClientAppStatus\x10\x9eJ\x12\"\n\x1dk_EMsgRemoteClientStartStream\x10\x9fJ\x12*\n%k_EMsgRemoteClientStartStreamResponse\x10\xa0J\x12\x1b\n\x16k_EMsgRemoteClientPing\x10\xa1J\x12#\n\x1ek_EMsgRemoteClientPingResponse\x10\xa2J\x12 \n\x1bk_EMsgClientUnlockStreaming\x10\xa3J\x12(\n#k_EMsgClientUnlockStreamingResponse\x10\xa4J\x12!\n\x1ck_EMsgRemoteClientAcceptEULA\x10\xa5J\x12*\n%k_EMsgRemoteClientGetControllerConfig\x10\xa6J\x12\x32\n-k_EMsgRemoteClientGetControllerConfigResponse\x10\xa7J\x12\'\n\"k_EMsgRemoteClientStreamingEnabled\x10\xa8J\x12\x1b\n\x16k_EMsgClientUnlockHEVC\x10\xa9J\x12#\n\x1ek_EMsgClientUnlockHEVCResponse\x10\xaaJ\x12$\n\x1fk_EMsgRemoteClientStatusRequest\x10\xabJ\x12%\n k_EMsgRemoteClientStatusResponse\x10\xacJ\x12\'\n\"k_EMsgClientConcurrentSessionsBase\x10\x80K\x12$\n\x1fk_EMsgClientPlayingSessionState\x10\x80K\x12#\n\x1ek_EMsgClientKickPlayingSession\x10\x81K\x12\x1e\n\x19k_EMsgClientBroadcastBase\x10\xe4K\x12\x1e\n\x19k_EMsgClientBroadcastInit\x10\xe4K\x12 \n\x1bk_EMsgClientBroadcastFrames\x10\xe5K\x12$\n\x1fk_EMsgClientBroadcastDisconnect\x10\xe6K\x12$\n\x1fk_EMsgClientBroadcastScreenshot\x10\xe7K\x12&\n!k_EMsgClientBroadcastUploadConfig\x10\xe8K\x12\x16\n\x11k_EMsgBaseClient3\x10\xc8L\x12&\n!k_EMsgClientVoiceCallPreAuthorize\x10\xc8L\x12.\n)k_EMsgClientVoiceCallPreAuthorizeResponse\x10\xc9L\x12\'\n\"k_EMsgClientServerTimestampRequest\x10\xcaL\x12(\n#k_EMsgClientServerTimestampResponse\x10\xcbL\x12/\n*k_EMsgServiceMethodCallFromClientNonAuthed\x10\xccL\x12\x16\n\x11k_EMsgClientHello\x10\xcdL\x12)\n$k_EMsgClientEnableOrDisableDownloads\x10\xceL\x12\x31\n,k_EMsgClientEnableOrDisableDownloadsResponse\x10\xcfL\x12\x1b\n\x16k_EMsgClientLANP2PBase\x10\xacM\x12#\n\x1ek_EMsgClientLANP2PRequestChunk\x10\xacM\x12+\n&k_EMsgClientLANP2PRequestChunkResponse\x10\xadM\x12\x1a\n\x15k_EMsgClientLANP2PMax\x10\x8fN\x12\x1d\n\x18k_EMsgBaseWatchdogServer\x10\x90N\x12\x19\n\x14k_EMsgNotifyWatchdog\x10\x90N\x12 \n\x1bk_EMsgClientSiteLicenseBase\x10\xf4N\x12\x30\n+k_EMsgClientSiteLicenseSiteInfoNotification\x10\xf4N\x12$\n\x1fk_EMsgClientSiteLicenseCheckout\x10\xf5N\x12,\n\'k_EMsgClientSiteLicenseCheckoutResponse\x10\xf6N\x12-\n(k_EMsgClientSiteLicenseGetAvailableSeats\x10\xf7N\x12\x35\n0k_EMsgClientSiteLicenseGetAvailableSeatsResponse\x10\xf8N\x12/\n*k_EMsgClientSiteLicenseGetContentCacheInfo\x10\xf9N\x12\x37\n2k_EMsgClientSiteLicenseGetContentCacheInfoResponse\x10\xfaN\x12\x19\n\x14k_EMsgBaseChatServer\x10\xe0]\x12\x30\n+k_EMsgChatServerGetPendingNotificationCount\x10\xe0]\x12\x38\n3k_EMsgChatServerGetPendingNotificationCountResponse\x10\xe1]\x12\x1b\n\x16k_EMsgBaseSecretServer\x10\xc4^\x12\x1e\n\x19k_EMsgServerSecretChanged\x10\xc4^\x1a\x02\x10\x01*\xcf\x04\n\x17\x45\x43lientPersonaStateFlag\x12#\n\x1fk_EClientPersonaStateFlagStatus\x10\x01\x12\'\n#k_EClientPersonaStateFlagPlayerName\x10\x02\x12&\n\"k_EClientPersonaStateFlagQueryPort\x10\x04\x12%\n!k_EClientPersonaStateFlagSourceID\x10\x08\x12%\n!k_EClientPersonaStateFlagPresence\x10\x10\x12%\n!k_EClientPersonaStateFlagLastSeen\x10@\x12*\n%k_EClientPersonaStateFlagUserClanRank\x10\x80\x01\x12\'\n\"k_EClientPersonaStateGameExtraInfo\x10\x80\x02\x12&\n!k_EClientPersonaStateGameDataBlob\x10\x80\x04\x12&\n!k_EClientPersonaStateFlagClanData\x10\x80\x08\x12&\n!k_EClientPersonaStateFlagFacebook\x10\x80\x10\x12*\n%k_EClientPersonaStateFlagRichPresence\x10\x80 \x12\'\n\"k_EClientPersonaStateFlagBroadcast\x10\x80@\x12\'\n!k_EClientPersonaStateFlagWatching\x10\x80\x80\x01*\xb9\x01\n\x14\x45MsgClanAccountFlags\x12\x1f\n\x1bk_EMsgClanAccountFlagPublic\x10\x01\x12\x1e\n\x1ak_EMsgClanAccountFlagLarge\x10\x02\x12\x1f\n\x1bk_EMsgClanAccountFlagLocked\x10\x04\x12!\n\x1dk_EMsgClanAccountFlagDisabled\x10\x08\x12\x1c\n\x18k_EMsgClanAccountFlagOGG\x10\x10*\x90\x03\n\x11\x45SteamReviewScore\x12.\n*k_ESteamReviewScore_OverwhelminglyPositive\x10\t\x12$\n k_ESteamReviewScore_VeryPositive\x10\x08\x12 \n\x1ck_ESteamReviewScore_Positive\x10\x07\x12&\n\"k_ESteamReviewScore_MostlyPositive\x10\x06\x12\x1d\n\x19k_ESteamReviewScore_Mixed\x10\x05\x12&\n\"k_ESteamReviewScore_MostlyNegative\x10\x04\x12 \n\x1ck_ESteamReviewScore_Negative\x10\x03\x12$\n k_ESteamReviewScore_VeryNegative\x10\x02\x12.\n*k_ESteamReviewScore_OverwhelminglyNegative\x10\x01\x12\x1c\n\x18k_ESteamReviewScore_None\x10\x00\x42\x05H\x01\x90\x01\x00'
)

_EMSG = _descriptor.EnumDescriptor(
  name='EMsg',
  full_name='EMsg',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgInvalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMulti', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgProtobufWrapped', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseGeneral', index=3, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGenericReply', index=4, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDestJobFailed', index=5, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAlert', index=6, number=115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSCIDRequest', index=7, number=120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSCIDResponse', index=8, number=121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgJobHeartbeat', index=9, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgHubConnect', index=10, number=124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSubscribe', index=11, number=126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMRouteMessage', index=12, number=127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWGRequest', index=13, number=130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWGResponse', index=14, number=131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgKeepAlive', index=15, number=132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIJobRequest', index=16, number=133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIJobResponse', index=17, number=134,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSessionStart', index=18, number=135,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSessionEnd', index=19, number=136,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSessionUpdate', index=20, number=137,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgStatsDeprecated', index=21, number=138,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPing', index=22, number=139,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPingResponse', index=23, number=140,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgStats', index=24, number=141,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRequestFullStatsBlock', index=25, number=142,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLoadDBOCacheItem', index=26, number=143,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLoadDBOCacheItemResponse', index=27, number=144,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgInvalidateDBOCacheItems', index=28, number=145,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServiceMethod', index=29, number=146,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServiceMethodResponse', index=30, number=147,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPackageVersions', index=31, number=148,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTimestampRequest', index=32, number=149,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTimestampResponse', index=33, number=150,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServiceMethodCallFromClient', index=34, number=151,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServiceMethodSendToClient', index=35, number=152,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseShell', index=36, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAssignSysID', index=37, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgExit', index=38, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDirRequest', index=39, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDirResponse', index=40, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgZipRequest', index=41, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgZipResponse', index=42, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateRecordResponse', index=43, number=215,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateCreditCardRequest', index=44, number=221,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateUserBanResponse', index=45, number=225,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPrepareToExit', index=46, number=226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgContentDescriptionUpdate', index=47, number=227,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestResetServer', index=48, number=228,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUniverseChanged', index=49, number=229,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellConfigInfoUpdate', index=50, number=230,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRequestWindowsEventLogEntries', index=51, number=233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgProvideWindowsEventLogEntries', index=52, number=234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellSearchLogs', index=53, number=235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellSearchLogsResponse', index=54, number=236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellCheckWindowsUpdates', index=55, number=237,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellCheckWindowsUpdatesResponse', index=56, number=238,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestFlushDelayedSQL', index=57, number=240,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestFlushDelayedSQLResponse', index=58, number=241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEnsureExecuteScheduledTask_TEST', index=59, number=242,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEnsureExecuteScheduledTaskResponse_TEST', index=60, number=243,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateScheduledTaskEnableState_TEST', index=61, number=244,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateScheduledTaskEnableStateResponse_TEST', index=62, number=245,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgContentDescriptionDeltaUpdate', index=63, number=246,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMShellAndServerAddressUpdates', index=64, number=247,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseGM', index=65, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgHeartbeat', index=66, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgShellFailed', index=67, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgExitShells', index=68, number=307,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgExitShell', index=69, number=308,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGracefulExitShell', index=70, number=309,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLicenseProcessingComplete', index=71, number=316,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSetTestFlag', index=72, number=317,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgQueuedEmailsComplete', index=73, number=318,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMReportPHPError', index=74, number=319,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMDRMSync', index=75, number=320,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPhysicalBoxInventory', index=76, number=321,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateConfigFile', index=77, number=322,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestInitDB', index=78, number=323,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMWriteConfigToSQL', index=79, number=324,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMLoadActivationCodes', index=80, number=325,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMQueueForFBS', index=81, number=326,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMSchemaConversionResults', index=82, number=327,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMWriteShellFailureToSQL', index=83, number=329,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMWriteStatsToSOS', index=84, number=330,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMGetServiceMethodRouting', index=85, number=331,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMGetServiceMethodRoutingResponse', index=86, number=332,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMTestNextBuildSchemaConversion', index=87, number=334,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMTestNextBuildSchemaConversionResponse', index=88, number=335,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgExpectShellRestart', index=89, number=336,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgHotFixProgress', index=90, number=337,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMStatsForwardToAdminConnections', index=91, number=338,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseAIS', index=92, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISRequestContentDescription', index=93, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISUpdateAppInfo', index=94, number=403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISGetPackageChangeNumber', index=95, number=405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISGetPackageChangeNumberResponse', index=96, number=406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAIGetAppGCFlags', index=97, number=423,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAIGetAppGCFlagsResponse', index=98, number=424,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAIGetAppList', index=99, number=425,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAIGetAppListResponse', index=100, number=426,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISGetCouponDefinition', index=101, number=429,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISGetCouponDefinitionResponse', index=102, number=430,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISUpdateSubordinateContentDescription', index=103, number=431,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISUpdateSubordinateContentDescriptionResponse', index=104, number=432,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAISTestEnableGC', index=105, number=433,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseAM', index=106, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUpdateUserBanRequest', index=107, number=504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddLicense', index=108, number=505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendSystemIMToUser', index=109, number=508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMExtendLicense', index=110, number=509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddMinutesToLicense', index=111, number=510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCancelLicense', index=112, number=511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMInitPurchase', index=113, number=512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPurchaseResponse', index=114, number=513,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFinalPrice', index=115, number=514,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFinalPriceResponse', index=116, number=515,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetLegacyGameKey', index=117, number=516,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetLegacyGameKeyResponse', index=118, number=517,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindHungTransactions', index=119, number=518,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetAccountTrustedRequest', index=120, number=519,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCancelPurchase', index=121, number=522,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNewChallenge', index=122, number=523,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLoadOEMTickets', index=123, number=524,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFixPendingPurchase', index=124, number=525,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFixPendingPurchaseResponse', index=125, number=526,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsUserBanned', index=126, number=527,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRegisterKey', index=127, number=528,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLoadActivationCodes', index=128, number=529,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLoadActivationCodesResponse', index=129, number=530,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLookupKeyResponse', index=130, number=531,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLookupKey', index=131, number=532,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChatCleanup', index=132, number=533,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClanCleanup', index=133, number=534,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFixPendingRefund', index=134, number=535,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMReverseChargeback', index=135, number=536,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMReverseChargebackResponse', index=136, number=537,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClanCleanupList', index=137, number=538,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetLicenses', index=138, number=539,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetLicensesResponse', index=139, number=540,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendCartRepurchase', index=140, number=541,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendCartRepurchaseResponse', index=141, number=542,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAllowUserToPlayQuery', index=142, number=550,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAllowUserToPlayResponse', index=143, number=551,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMVerfiyUser', index=144, number=552,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientNotPlaying', index=145, number=553,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientRequestFriendship', index=146, number=554,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRelayPublishStatus', index=147, number=555,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMInitPurchaseResponse', index=148, number=560,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRevokePurchaseResponse', index=149, number=561,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRefreshGuestPasses', index=150, number=563,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGrantGuestPasses', index=151, number=566,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClanDataUpdated', index=152, number=567,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMReloadAccount', index=153, number=568,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientChatMsgRelay', index=154, number=569,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChatMulti', index=155, number=570,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientChatInviteRelay', index=156, number=571,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChatInvite', index=157, number=572,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientJoinChatRelay', index=158, number=573,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientChatMemberInfoRelay', index=159, number=574,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPublishChatMemberInfo', index=160, number=575,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientAcceptFriendInvite', index=161, number=576,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChatEnter', index=162, number=577,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientPublishRemovalFromSource', index=163, number=578,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChatActionResult', index=164, number=579,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindAccounts', index=165, number=580,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindAccountsResponse', index=166, number=581,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsAccountNameInUse', index=167, number=582,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsAccountNameInUseResponse', index=168, number=583,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetAccountFlags', index=169, number=584,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateClan', index=170, number=586,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateClanResponse', index=171, number=587,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanDetails', index=172, number=588,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanDetailsResponse', index=173, number=589,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetPersonaName', index=174, number=590,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetAvatar', index=175, number=591,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAuthenticateUser', index=176, number=592,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAuthenticateUserResponse', index=177, number=593,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMP2PIntroducerMessage', index=178, number=596,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatAction', index=179, number=597,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientChatActionRelay', index=180, number=598,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseVS', index=181, number=600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgReqChallenge', index=182, number=600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVACResponse', index=183, number=601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgReqChallengeTest', index=184, number=602,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSMarkCheat', index=185, number=604,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSAddCheat', index=186, number=605,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSPurgeCodeModDB', index=187, number=606,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSGetChallengeResults', index=188, number=607,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSChallengeResultText', index=189, number=608,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSReportLingerer', index=190, number=609,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSRequestManagedChallenge', index=191, number=610,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgVSLoadDBFinished', index=192, number=611,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseDRMS', index=193, number=625,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMBuildBlobRequest', index=194, number=628,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMBuildBlobResponse', index=195, number=629,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMResolveGuidRequest', index=196, number=630,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMResolveGuidResponse', index=197, number=631,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMVariabilityReport', index=198, number=633,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMVariabilityReportResponse', index=199, number=634,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMStabilityReport', index=200, number=635,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMStabilityReportResponse', index=201, number=636,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMDetailsReportRequest', index=202, number=637,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMDetailsReportResponse', index=203, number=638,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMProcessFile', index=204, number=639,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMAdminUpdate', index=205, number=640,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMAdminUpdateResponse', index=206, number=641,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMSync', index=207, number=642,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMSyncResponse', index=208, number=643,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMProcessFileResponse', index=209, number=644,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMEmptyGuidCache', index=210, number=645,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMEmptyGuidCacheResponse', index=211, number=646,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseCS', index=212, number=650,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseClient', index=213, number=700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogOn_Deprecated', index=214, number=701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAnonLogOn_Deprecated', index=215, number=702,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientHeartBeat', index=216, number=703,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVACResponse', index=217, number=704,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayed_obsolete', index=218, number=705,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogOff', index=219, number=706,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNoUDPConnectivity', index=220, number=707,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientConnectionStats', index=221, number=710,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPingResponse', index=222, number=712,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRemoveFriend', index=223, number=714,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayedNoDataBlob', index=224, number=715,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChangeStatus', index=225, number=716,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVacStatusResponse', index=226, number=717,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendMsg', index=227, number=718,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGameConnect_obsolete', index=228, number=719,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayed2_obsolete', index=229, number=720,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGameEnded_obsolete', index=230, number=721,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSystemIM', index=231, number=726,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSystemIMAck', index=232, number=727,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetLicenses', index=233, number=728,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetLegacyGameKey', index=234, number=730,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientContentServerLogOn_Deprecated', index=235, number=731,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAckVACBan2', index=236, number=732,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetPurchaseReceipts', index=237, number=736,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayed3_obsolete', index=238, number=738,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAckGuestPass', index=239, number=740,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRedeemGuestPass', index=240, number=741,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayed', index=241, number=742,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRegisterKey', index=242, number=743,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInviteUserToClan', index=243, number=744,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAcknowledgeClanInvite', index=244, number=745,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPurchaseWithMachineID', index=245, number=746,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAppUsageEvent', index=246, number=747,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogOnResponse', index=247, number=751,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSetHeartbeatRate', index=248, number=755,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNotLoggedOnDeprecated', index=249, number=756,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLoggedOff', index=250, number=757,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSApprove', index=251, number=758,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSDeny', index=252, number=759,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSKick', index=253, number=760,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPurchaseResponse', index=254, number=763,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPing', index=255, number=764,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNOP', index=256, number=765,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPersonaState', index=257, number=766,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendsList', index=258, number=767,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAccountInfo', index=259, number=768,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNewsUpdate', index=260, number=771,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGameConnectDeny', index=261, number=773,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSStatusReply', index=262, number=774,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGameConnectTokens', index=263, number=779,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLicenseList', index=264, number=780,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVACBanStatus', index=265, number=782,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCMList', index=266, number=783,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEncryptPct', index=267, number=784,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetLegacyGameKeyResponse', index=268, number=785,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAddFriend', index=269, number=791,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAddFriendResponse', index=270, number=792,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAckGuestPassResponse', index=271, number=796,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRedeemGuestPassResponse', index=272, number=797,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUpdateGuestPassesList', index=273, number=798,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatMsg', index=274, number=799,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatInvite', index=275, number=800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientJoinChat', index=276, number=801,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatMemberInfo', index=277, number=802,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogOnWithCredentials_Deprecated', index=278, number=803,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPasswordChangeResponse', index=279, number=805,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatEnter', index=280, number=807,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendRemovedFromSource', index=281, number=808,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCreateChat', index=282, number=809,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCreateChatResponse', index=283, number=810,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientP2PIntroducerMessage', index=284, number=813,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatActionResult', index=285, number=814,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestFriendData', index=286, number=815,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetUserStats', index=287, number=818,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetUserStatsResponse', index=288, number=819,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStoreUserStats', index=289, number=820,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStoreUserStatsResponse', index=290, number=821,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientClanState', index=291, number=822,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServiceModule', index=292, number=830,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServiceCall', index=293, number=831,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServiceCallResponse', index=294, number=832,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNatTraversalStatEvent', index=295, number=839,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSteamUsageEvent', index=296, number=842,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCheckPassword', index=297, number=845,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetPassword', index=298, number=846,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCheckPasswordResponse', index=299, number=848,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetPasswordResponse', index=300, number=849,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSessionToken', index=301, number=850,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMProblemReport', index=302, number=851,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSetIgnoreFriend', index=303, number=855,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSetIgnoreFriendResponse', index=304, number=856,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetAppOwnershipTicket', index=305, number=857,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetAppOwnershipTicketResponse', index=306, number=858,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetLobbyListResponse', index=307, number=860,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServerList', index=308, number=880,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMBlobRequest', index=309, number=896,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMBlobResponse', index=310, number=897,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseGameServer', index=311, number=900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSDisconnectNotice', index=312, number=901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSStatus', index=313, number=903,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSUserPlaying', index=314, number=905,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSStatus2', index=315, number=906,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSStatusUpdate_Unused', index=316, number=907,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSServerType', index=317, number=908,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSPlayerList', index=318, number=909,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetUserAchievementStatus', index=319, number=910,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetUserAchievementStatusResponse', index=320, number=911,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetPlayStats', index=321, number=918,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetPlayStatsResponse', index=322, number=919,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetUserGroupStatus', index=323, number=920,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserGroupStatus', index=324, number=921,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserGroupStatusResponse', index=325, number=922,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetUserGroupStatusResponse', index=326, number=923,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetReputation', index=327, number=936,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSGetReputationResponse', index=328, number=937,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSAssociateWithClan', index=329, number=938,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSAssociateWithClanResponse', index=330, number=939,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSComputeNewPlayerCompatibility', index=331, number=940,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSComputeNewPlayerCompatibilityResponse', index=332, number=941,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseAdmin', index=333, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminCmd', index=334, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminCmdResponse', index=335, number=1004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminLogListenRequest', index=336, number=1005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminLogEvent', index=337, number=1006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUniverseData', index=338, number=1010,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminSpew', index=339, number=1019,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminConsoleTitle', index=340, number=1020,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminGCSpew', index=341, number=1023,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminGCCommand', index=342, number=1024,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminGCGetCommandList', index=343, number=1025,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminGCGetCommandListResponse', index=344, number=1026,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSConnectionData', index=345, number=1027,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAdminMsgSpew', index=346, number=1028,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseFBS', index=347, number=1100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSReqVersion', index=348, number=1100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSVersionInfo', index=349, number=1101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSForceRefresh', index=350, number=1102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSForceBounce', index=351, number=1103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDeployPackage', index=352, number=1104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDeployResponse', index=353, number=1105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSUpdateBootstrapper', index=354, number=1106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSSetState', index=355, number=1107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSApplyOSUpdates', index=356, number=1108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSRunCMDScript', index=357, number=1109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSRebootBox', index=358, number=1110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSSetBigBrotherMode', index=359, number=1111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSMinidumpServer', index=360, number=1112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDeployHotFixPackage', index=361, number=1114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDeployHotFixResponse', index=362, number=1115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDownloadHotFix', index=363, number=1116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSDownloadHotFixResponse', index=364, number=1117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSUpdateTargetConfigFile', index=365, number=1118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSApplyAccountCred', index=366, number=1119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSApplyAccountCredResponse', index=367, number=1120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSSetShellCount', index=368, number=1121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSTerminateShell', index=369, number=1122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSQueryGMForRequest', index=370, number=1123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSQueryGMResponse', index=371, number=1124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSTerminateZombies', index=372, number=1125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSInfoFromBootstrapper', index=373, number=1126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSRebootBoxResponse', index=374, number=1127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSBootstrapperPackageRequest', index=375, number=1128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSBootstrapperPackageResponse', index=376, number=1129,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSBootstrapperGetPackageChunk', index=377, number=1130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSBootstrapperGetPackageChunkResponse', index=378, number=1131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSBootstrapperPackageTransferProgress', index=379, number=1132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSRestartBootstrapper', index=380, number=1133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFBSPauseFrozenDumps', index=381, number=1134,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseFileXfer', index=382, number=1200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFileXferRequest', index=383, number=1200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFileXferResponse', index=384, number=1201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFileXferData', index=385, number=1202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFileXferEnd', index=386, number=1203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFileXferDataAck', index=387, number=1204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseChannelAuth', index=388, number=1300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelAuthChallenge', index=389, number=1300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelAuthResponse', index=390, number=1301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelAuthResult', index=391, number=1302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelEncryptRequest', index=392, number=1303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelEncryptResponse', index=393, number=1304,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChannelEncryptResult', index=394, number=1305,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseBS', index=395, number=1400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPurchaseStart', index=396, number=1401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPurchaseResponse', index=397, number=1402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSAuthenticateCCTrans', index=398, number=1403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSAuthenticateCCTransResponse', index=399, number=1404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSSettleComplete', index=400, number=1406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitPayPalTxn', index=401, number=1408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitPayPalTxnResponse', index=402, number=1409,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetPayPalUserInfo', index=403, number=1410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetPayPalUserInfoResponse', index=404, number=1411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPaymentInstrBan', index=405, number=1417,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPaymentInstrBanResponse', index=406, number=1418,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitGCBankXferTxn', index=407, number=1421,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitGCBankXferTxnResponse', index=408, number=1422,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCommitGCTxn', index=409, number=1425,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryTransactionStatus', index=410, number=1426,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryTransactionStatusResponse', index=411, number=1427,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryTxnExtendedInfo', index=412, number=1433,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryTxnExtendedInfoResponse', index=413, number=1434,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSUpdateConversionRates', index=414, number=1435,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPurchaseRunFraudChecks', index=415, number=1437,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPurchaseRunFraudChecksResponse', index=416, number=1438,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryBankInformation', index=417, number=1440,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryBankInformationResponse', index=418, number=1441,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSValidateXsollaSignature', index=419, number=1445,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSValidateXsollaSignatureResponse', index=420, number=1446,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQiwiWalletInvoice', index=421, number=1448,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQiwiWalletInvoiceResponse', index=422, number=1449,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSUpdateInventoryFromProPack', index=423, number=1450,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSUpdateInventoryFromProPackResponse', index=424, number=1451,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSSendShippingRequest', index=425, number=1452,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSSendShippingRequestResponse', index=426, number=1453,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetProPackOrderStatus', index=427, number=1454,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetProPackOrderStatusResponse', index=428, number=1455,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCheckJobRunning', index=429, number=1456,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCheckJobRunningResponse', index=430, number=1457,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSResetPackagePurchaseRateLimit', index=431, number=1458,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSResetPackagePurchaseRateLimitResponse', index=432, number=1459,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSUpdatePaymentData', index=433, number=1460,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSUpdatePaymentDataResponse', index=434, number=1461,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetBillingAddress', index=435, number=1462,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetBillingAddressResponse', index=436, number=1463,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetCreditCardInfo', index=437, number=1464,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGetCreditCardInfoResponse', index=438, number=1465,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSRemoveExpiredPaymentData', index=439, number=1468,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSRemoveExpiredPaymentDataResponse', index=440, number=1469,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSConvertToCurrentKeys', index=441, number=1470,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSConvertToCurrentKeysResponse', index=442, number=1471,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitPurchase', index=443, number=1472,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSInitPurchaseResponse', index=444, number=1473,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCompletePurchase', index=445, number=1474,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCompletePurchaseResponse', index=446, number=1475,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPruneCardUsageStats', index=447, number=1476,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSPruneCardUsageStatsResponse', index=448, number=1477,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSStoreBankInformation', index=449, number=1478,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSStoreBankInformationResponse', index=450, number=1479,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSVerifyPOSAKey', index=451, number=1480,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSVerifyPOSAKeyResponse', index=452, number=1481,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSReverseRedeemPOSAKey', index=453, number=1482,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSReverseRedeemPOSAKeyResponse', index=454, number=1483,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryFindCreditCard', index=455, number=1484,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSQueryFindCreditCardResponse', index=456, number=1485,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSStatusInquiryPOSAKey', index=457, number=1486,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSStatusInquiryPOSAKeyResponse', index=458, number=1487,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSBoaCompraConfirmProductDelivery', index=459, number=1494,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSBoaCompraConfirmProductDeliveryResponse', index=460, number=1495,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGenerateBoaCompraMD5', index=461, number=1496,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSGenerateBoaCompraMD5Response', index=462, number=1497,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCommitWPTxn', index=463, number=1498,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBSCommitAdyenTxn', index=464, number=1499,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseATS', index=465, number=1500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSStartStressTest', index=466, number=1501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSStopStressTest', index=467, number=1502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSRunFailServerTest', index=468, number=1503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSUFSPerfTestTask', index=469, number=1504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSUFSPerfTestResponse', index=470, number=1505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSCycleTCM', index=471, number=1506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSInitDRMSStressTest', index=472, number=1507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSCallTest', index=473, number=1508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSCallTestReply', index=474, number=1509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSStartExternalStress', index=475, number=1510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressJobStart', index=476, number=1511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressJobQueued', index=477, number=1512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressJobRunning', index=478, number=1513,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressJobStopped', index=479, number=1514,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressJobStopAll', index=480, number=1515,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSExternalStressActionResult', index=481, number=1516,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSStarted', index=482, number=1517,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSCSPerfTestTask', index=483, number=1518,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgATSCSPerfTestResponse', index=484, number=1519,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseDP', index=485, number=1600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPSetPublishingState', index=486, number=1601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPUniquePlayersStat', index=487, number=1603,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPStreamingUniquePlayersStat', index=488, number=1604,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPBlockingStats', index=489, number=1607,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPNatTraversalStats', index=490, number=1608,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPCloudStats', index=491, number=1612,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPGetPlayerCount', index=492, number=1615,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPGetPlayerCountResponse', index=493, number=1616,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPGameServersPlayersStats', index=494, number=1617,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPCheckSpecialSurvey', index=495, number=1620,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPCheckSpecialSurveyResponse', index=496, number=1621,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPSendSpecialSurveyResponse', index=497, number=1622,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPSendSpecialSurveyResponseReply', index=498, number=1623,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPStoreSaleStatistics', index=499, number=1624,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPUpdateAppJobReport', index=500, number=1625,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPUnsignedInstallScript', index=501, number=1627,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPPartnerMicroTxns', index=502, number=1628,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPPartnerMicroTxnsResponse', index=503, number=1629,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDPContentStatsReport', index=504, number=1630,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDPVRUniquePlayersStat', index=505, number=1631,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseCM', index=506, number=1700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCMSetAllowState', index=507, number=1701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCMSpewAllowState', index=508, number=1702,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCMSessionRejected', index=509, number=1703,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCMSetSecrets', index=510, number=1704,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCMGetSecrets', index=511, number=1705,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseGC', index=512, number=2200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdRevive', index=513, number=2203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdDown', index=514, number=2206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdDeploy', index=515, number=2207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdDeployResponse', index=516, number=2208,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdSwitch', index=517, number=2209,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRefreshSessions', index=518, number=2210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAchievementAwarded', index=519, number=2212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSystemMessage', index=520, number=2213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCmdStatus', index=521, number=2216,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRegisterWebInterfaces_Deprecated', index=522, number=2217,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetAccountDetails_DEPRECATED', index=523, number=2218,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInterAppMessage', index=524, number=2219,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetEmailTemplate', index=525, number=2220,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetEmailTemplateResponse', index=526, number=2221,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRelay', index=527, number=2222,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRelayToClient', index=528, number=2223,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHUpdateSession', index=529, number=2224,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRequestUpdateSession', index=530, number=2225,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRequestStatus', index=531, number=2226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRequestStatusResponse', index=532, number=2227,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAccountVacStatusChange', index=533, number=2228,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHSpawnGC', index=534, number=2229,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHSpawnGCResponse', index=535, number=2230,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHKillGC', index=536, number=2231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHKillGCResponse', index=537, number=2232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAccountTradeBanStatusChange', index=538, number=2233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAccountLockStatusChange', index=539, number=2234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHVacVerificationChange', index=540, number=2235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAccountPhoneNumberChange', index=541, number=2236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAccountTwoFactorChange', index=542, number=2237,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHInviteUserToLobby', index=543, number=2238,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHUpdateMultipleSessions', index=544, number=2239,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHMarkAppSessionsAuthoritative', index=545, number=2240,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHRecurringSubscriptionStatusChange', index=546, number=2241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAppCheersReceived', index=547, number=2242,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAppCheersGetAllowedTypes', index=548, number=2243,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHAppCheersGetAllowedTypesResponse', index=549, number=2244,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseP2P', index=550, number=2500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgP2PIntroducerMessage', index=551, number=2502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseSM', index=552, number=2900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMExpensiveReport', index=553, number=2902,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMHourlyReport', index=554, number=2903,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMPartitionRenames', index=555, number=2905,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMMonitorSpace', index=556, number=2906,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMTestNextBuildSchemaConversion', index=557, number=2907,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSMTestNextBuildSchemaConversionResponse', index=558, number=2908,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseTest', index=559, number=3000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFailServer', index=560, number=3000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgJobHeartbeatTest', index=561, number=3001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgJobHeartbeatTestResponse', index=562, number=3002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseFTSRange', index=563, number=3100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseCCSRange', index=564, number=3150,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCCSDeleteAllCommentsByAuthor', index=565, number=3161,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCCSDeleteAllCommentsByAuthorResponse', index=566, number=3162,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseLBSRange', index=567, number=3200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSSetScore', index=568, number=3201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSSetScoreResponse', index=569, number=3202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSFindOrCreateLB', index=570, number=3203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSFindOrCreateLBResponse', index=571, number=3204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSGetLBEntries', index=572, number=3205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSGetLBEntriesResponse', index=573, number=3206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSGetLBList', index=574, number=3207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSGetLBListResponse', index=575, number=3208,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSSetLBDetails', index=576, number=3209,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSDeleteLB', index=577, number=3210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSDeleteLBEntry', index=578, number=3211,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSResetLB', index=579, number=3212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSResetLBResponse', index=580, number=3213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLBSDeleteLBResponse', index=581, number=3214,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseOGS', index=582, number=3400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgOGSBeginSession', index=583, number=3401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgOGSBeginSessionResponse', index=584, number=3402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgOGSEndSession', index=585, number=3403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgOGSEndSessionResponse', index=586, number=3404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgOGSWriteAppSessionRow', index=587, number=3406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseBRP', index=588, number=3600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBRPPostTransactionTax', index=589, number=3629,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBRPPostTransactionTaxResponse', index=590, number=3630,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseAMRange2', index=591, number=4000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateChat', index=592, number=4001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateChatResponse', index=593, number=4002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetProfileURL', index=594, number=4005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountEmailAddress', index=595, number=4006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountEmailAddressResponse', index=596, number=4007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRequestClanData', index=597, number=4008,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRouteToClients', index=598, number=4009,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMLeaveClan', index=599, number=4010,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClanPermissions', index=600, number=4011,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClanPermissionsResponse', index=601, number=4012,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateClanEventDummyForRateLimiting', index=602, number=4013,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUpdateClanEventDummyForRateLimiting', index=603, number=4015,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPermissionSettings', index=604, number=4021,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPermissionSettingsResponse', index=605, number=4022,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPermissionSettings', index=606, number=4023,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPermissionSettingsResponse', index=607, number=4024,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPublishChatRoomInfo', index=608, number=4025,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatRoomInfo', index=609, number=4026,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanHistory', index=610, number=4039,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanHistoryResponse', index=611, number=4040,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPermissionBits', index=612, number=4041,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPermissionBitsResponse', index=613, number=4042,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPermissionBits', index=614, number=4043,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPermissionBitsResponse', index=615, number=4044,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSessionInfoRequest', index=616, number=4045,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSessionInfoResponse', index=617, number=4046,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidateWGToken', index=618, number=4047,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanRank', index=619, number=4050,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanRankResponse', index=620, number=4051,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanRank', index=621, number=4052,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanRankResponse', index=622, number=4053,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPOTW', index=623, number=4054,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanPOTWResponse', index=624, number=4055,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPOTW', index=625, number=4056,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanPOTWResponse', index=626, number=4057,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDumpUser', index=627, number=4059,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMKickUserFromClan', index=628, number=4060,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddFounderToClan', index=629, number=4061,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidateWGTokenResponse', index=630, number=4062,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetAccountDetails', index=631, number=4064,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetChatBanList', index=632, number=4065,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetChatBanListResponse', index=633, number=4066,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUnBanFromChat', index=634, number=4067,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanDetails', index=635, number=4068,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSGetUserGameStats', index=636, number=4073,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSGetUserGameStatsResponse', index=637, number=4074,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCheckClanMembership', index=638, number=4075,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanMembers', index=639, number=4076,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanMembersResponse', index=640, number=4077,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNotifyChatOfClanChange', index=641, number=4079,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResubmitPurchase', index=642, number=4080,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddFriend', index=643, number=4081,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddFriendResponse', index=644, number=4082,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRemoveFriend', index=645, number=4083,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDumpClan', index=646, number=4084,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChangeClanOwner', index=647, number=4085,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCancelEasyCollect', index=648, number=4086,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCancelEasyCollectResponse', index=649, number=4087,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClansInCommon', index=650, number=4090,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClansInCommonResponse', index=651, number=4091,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsValidAccountID', index=652, number=4092,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMWipeFriendsList', index=653, number=4095,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetIgnored', index=654, number=4096,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClansInCommonCountResponse', index=655, number=4097,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFriendsList', index=656, number=4098,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFriendsListResponse', index=657, number=4099,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFriendsInCommon', index=658, number=4100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFriendsInCommonResponse', index=659, number=4101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFriendsInCommonCountResponse', index=660, number=4102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClansInCommonCount', index=661, number=4103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChallengeVerdict', index=662, number=4104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMChallengeNotification', index=663, number=4105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindGSByIP', index=664, number=4106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFoundGSByIP', index=665, number=4107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGiftRevoked', index=666, number=4108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUserClanList', index=667, number=4110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUserClanListResponse', index=668, number=4111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountDetails2', index=669, number=4112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountDetailsResponse2', index=670, number=4113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetCommunityProfileSettings', index=671, number=4114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetCommunityProfileSettingsResponse', index=672, number=4115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetCommunityPrivacyState', index=673, number=4116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetCommunityPrivacyStateResponse', index=674, number=4117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCheckClanInviteRateLimiting', index=675, number=4118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSGetUserAchievementStatus', index=676, number=4119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetIgnored', index=677, number=4120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetIgnoredResponse', index=678, number=4121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetIgnoredResponse', index=679, number=4122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetFriendRelationshipNone', index=680, number=4123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFriendRelationship', index=681, number=4124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFriendRelationshipResponse', index=682, number=4125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMServiceModulesCache', index=683, number=4126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMServiceModulesCall', index=684, number=4127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMServiceModulesCallResponse', index=685, number=4128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCommunityAddFriendNews', index=686, number=4140,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindClanUser', index=687, number=4143,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFindClanUserResponse', index=688, number=4144,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMBanFromChat', index=689, number=4145,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserNewsSubscriptions', index=690, number=4147,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserNewsSubscriptionsResponse', index=691, number=4148,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetUserNewsSubscriptions', index=692, number=4149,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendQueuedEmails', index=693, number=4152,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetLicenseFlags', index=694, number=4153,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCommunityDeleteUserNews', index=695, number=4155,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAllowUserFilesRequest', index=696, number=4156,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAllowUserFilesResponse', index=697, number=4157,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountStatus', index=698, number=4158,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountStatusResponse', index=699, number=4159,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMEditBanReason', index=700, number=4160,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCheckClanMembershipResponse', index=701, number=4161,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMProbeClanMembershipList', index=702, number=4162,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMProbeClanMembershipListResponse', index=703, number=4163,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSGetUserAchievementStatusResponse', index=704, number=4164,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFriendsLobbies', index=705, number=4165,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetFriendsLobbiesResponse', index=706, number=4166,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserFriendNewsResponse', index=707, number=4172,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCommunityGetUserFriendNews', index=708, number=4173,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserClansNewsResponse', index=709, number=4174,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserClansNews', index=710, number=4175,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPreviousCBAccount', index=711, number=4184,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPreviousCBAccountResponse', index=712, number=4185,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserLicenseHistory', index=713, number=4190,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserLicenseHistoryResponse', index=714, number=4191,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportChangePassword', index=715, number=4194,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportChangeEmail', index=716, number=4195,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResetUserVerificationGSByIP', index=717, number=4197,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUpdateGSPlayStats', index=718, number=4198,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportEnableOrDisable', index=719, number=4199,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPurchaseStatus', index=720, number=4206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportIsAccountEnabled', index=721, number=4209,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportIsAccountEnabledResponse', index=722, number=4210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSGetUserStats', index=723, number=4211,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGSSearch', index=724, number=4213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMarketingMessageUpdate', index=725, number=4216,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChatServerRouteFriendMsg', index=726, number=4219,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMTicketAuthRequestOrResponse', index=727, number=4220,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddFreeLicense', index=728, number=4224,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidateEmailLink', index=729, number=4231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidateEmailLinkResponse', index=730, number=4232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSStoreUserStats', index=731, number=4236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDeleteStoredCard', index=732, number=4241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRevokeLegacyGameKeys', index=733, number=4242,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetWalletDetails', index=734, number=4244,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetWalletDetailsResponse', index=735, number=4245,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDeleteStoredPaymentInfo', index=736, number=4246,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetStoredPaymentSummary', index=737, number=4247,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetStoredPaymentSummaryResponse', index=738, number=4248,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetWalletConversionRate', index=739, number=4249,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetWalletConversionRateResponse', index=740, number=4250,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMConvertWallet', index=741, number=4251,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMConvertWalletResponse', index=742, number=4252,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetPreApproval', index=743, number=4255,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetPreApprovalResponse', index=744, number=4256,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateRefund', index=745, number=4258,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateChargeback', index=746, number=4260,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateDispute', index=747, number=4262,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClearDispute', index=748, number=4264,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCreateFinancialAdjustment', index=749, number=4265,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPlayerNicknameList', index=750, number=4266,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPlayerNicknameListResponse', index=751, number=4267,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetDRMTestConfig', index=752, number=4268,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserCurrentGameInfo', index=753, number=4269,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserCurrentGameInfoResponse', index=754, number=4270,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetGSPlayerList', index=755, number=4271,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetGSPlayerListResponse', index=756, number=4272,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetSteamIDForMicroTxn', index=757, number=4278,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetSteamIDForMicroTxnResponse', index=758, number=4279,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetPartnerMember', index=759, number=4280,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRemovePublisherUser', index=760, number=4281,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserLicenseList', index=761, number=4282,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserLicenseListResponse', index=762, number=4283,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMReloadGameGroupPolicy', index=763, number=4284,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAddFreeLicenseResponse', index=764, number=4285,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMVACStatusUpdate', index=765, number=4286,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountDetails', index=766, number=4287,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountDetailsResponse', index=767, number=4288,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPlayerLinkDetails', index=768, number=4289,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPlayerLinkDetailsResponse', index=769, number=4290,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountFlagsForWGSpoofing', index=770, number=4294,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountFlagsForWGSpoofingResponse', index=771, number=4295,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanOfficers', index=772, number=4298,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanOfficersResponse', index=773, number=4299,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNameChange', index=774, number=4300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetNameHistory', index=775, number=4301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetNameHistoryResponse', index=776, number=4302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMUpdateProviderStatus', index=777, number=4305,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSupportRemoveAccountSecurity', index=778, number=4307,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsAccountInCaptchaGracePeriod', index=779, number=4308,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsAccountInCaptchaGracePeriodResponse', index=780, number=4309,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAccountPS3Unlink', index=781, number=4310,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAccountPS3UnlinkResponse', index=782, number=4311,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSStoreUserStatsResponse', index=783, number=4312,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountPSNInfo', index=784, number=4313,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountPSNInfoResponse', index=785, number=4314,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAuthenticatedPlayerList', index=786, number=4315,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserGifts', index=787, number=4316,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetUserGiftsResponse', index=788, number=4317,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMTransferLockedGifts', index=789, number=4320,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMTransferLockedGiftsResponse', index=790, number=4321,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPlayerHostedOnGameServer', index=791, number=4322,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountBanInfo', index=792, number=4323,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountBanInfoResponse', index=793, number=4324,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRecordBanEnforcement', index=794, number=4325,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRollbackGiftTransfer', index=795, number=4326,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRollbackGiftTransferResponse', index=796, number=4327,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMHandlePendingTransaction', index=797, number=4328,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRequestClanDetails', index=798, number=4329,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDeleteStoredPaypalAgreement', index=799, number=4330,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerUpdate', index=800, number=4331,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerRemove', index=801, number=4332,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPaypalAgreements', index=802, number=4333,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPaypalAgreementsResponse', index=803, number=4334,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerPlayerCompatibilityCheck', index=804, number=4335,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerPlayerCompatibilityCheckResponse', index=805, number=4336,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRenewLicense', index=806, number=4337,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountCommunityBanInfo', index=807, number=4338,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountCommunityBanInfoResponse', index=808, number=4339,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerAccountChangePassword', index=809, number=4340,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGameServerAccountDeleteAccount', index=810, number=4341,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRenewAgreement', index=811, number=4342,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMXsollaPayment', index=812, number=4344,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMXsollaPaymentResponse', index=813, number=4345,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAcctAllowedToPurchase', index=814, number=4346,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMAcctAllowedToPurchaseResponse', index=815, number=4347,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSwapKioskDeposit', index=816, number=4348,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSwapKioskDepositResponse', index=817, number=4349,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetUserGiftUnowned', index=818, number=4350,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetUserGiftUnownedResponse', index=819, number=4351,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClaimUnownedUserGift', index=820, number=4352,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClaimUnownedUserGiftResponse', index=821, number=4353,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanName', index=822, number=4354,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSetClanNameResponse', index=823, number=4355,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGrantCoupon', index=824, number=4356,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGrantCouponResponse', index=825, number=4357,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsPackageRestrictedInUserCountry', index=826, number=4358,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMIsPackageRestrictedInUserCountryResponse', index=827, number=4359,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMHandlePendingTransactionResponse', index=828, number=4360,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGrantGuestPasses2', index=829, number=4361,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGrantGuestPasses2Response', index=830, number=4362,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPlayerBanDetails', index=831, number=4365,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPlayerBanDetailsResponse', index=832, number=4366,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFinalizePurchase', index=833, number=4367,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFinalizePurchaseResponse', index=834, number=4368,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPersonaChangeResponse', index=835, number=4372,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanDetailsForForumCreation', index=836, number=4373,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetClanDetailsForForumCreationResponse', index=837, number=4374,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPendingNotificationCount', index=838, number=4375,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetPendingNotificationCountResponse', index=839, number=4376,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPasswordHashUpgrade', index=840, number=4377,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMBoaCompraPayment', index=841, number=4380,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMBoaCompraPaymentResponse', index=842, number=4381,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCompleteExternalPurchase', index=843, number=4383,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMCompleteExternalPurchaseResponse', index=844, number=4384,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResolveNegativeWalletCredits', index=845, number=4385,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResolveNegativeWalletCreditsResponse', index=846, number=4386,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPlayerGetClanBasicDetails', index=847, number=4389,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPlayerGetClanBasicDetailsResponse', index=848, number=4390,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMMOLPayment', index=849, number=4391,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMMOLPaymentResponse', index=850, number=4392,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGetUserIPCountry', index=851, number=4393,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGetUserIPCountryResponse', index=852, number=4394,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNotificationOfSuspiciousActivity', index=853, number=4395,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDegicaPayment', index=854, number=4396,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMDegicaPaymentResponse', index=855, number=4397,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMEClubPayment', index=856, number=4398,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMEClubPaymentResponse', index=857, number=4399,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPayPalPaymentsHubPayment', index=858, number=4400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPayPalPaymentsHubPaymentResponse', index=859, number=4401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMTwoFactorRecoverAuthenticatorRequest', index=860, number=4402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMTwoFactorRecoverAuthenticatorResponse', index=861, number=4403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSmart2PayPayment', index=862, number=4404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSmart2PayPaymentResponse', index=863, number=4405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidatePasswordResetCodeAndSendSmsRequest', index=864, number=4406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMValidatePasswordResetCodeAndSendSmsResponse', index=865, number=4407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountResetDetailsRequest', index=866, number=4408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGetAccountResetDetailsResponse', index=867, number=4409,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMBitPayPayment', index=868, number=4410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMBitPayPaymentResponse', index=869, number=4411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendAccountInfoUpdate', index=870, number=4412,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMSendScheduledGift', index=871, number=4413,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNodwinPayment', index=872, number=4414,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNodwinPaymentResponse', index=873, number=4415,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResolveWalletRevoke', index=874, number=4416,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMResolveWalletReverseRevoke', index=875, number=4417,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFundedPayment', index=876, number=4418,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMFundedPaymentResponse', index=877, number=4419,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRequestPersonaUpdateForChatServer', index=878, number=4420,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPerfectWorldPayment', index=879, number=4421,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMPerfectWorldPaymentResponse', index=880, number=4422,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMECommPayPayment', index=881, number=4423,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMECommPayPaymentResponse', index=882, number=4424,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBasePSRange', index=883, number=5000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSCreateShoppingCart', index=884, number=5001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSCreateShoppingCartResponse', index=885, number=5002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSIsValidShoppingCart', index=886, number=5003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSIsValidShoppingCartResponse', index=887, number=5004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSRemoveLineItemFromShoppingCart', index=888, number=5007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSRemoveLineItemFromShoppingCartResponse', index=889, number=5008,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSGetShoppingCartContents', index=890, number=5009,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSGetShoppingCartContentsResponse', index=891, number=5010,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSAddWalletCreditToShoppingCart', index=892, number=5011,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPSAddWalletCreditToShoppingCartResponse', index=893, number=5012,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseUFSRange', index=894, number=5200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadFileRequest', index=895, number=5202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadFileResponse', index=896, number=5203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadFileChunk', index=897, number=5204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadFileFinished', index=898, number=5205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetFileListForApp', index=899, number=5206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetFileListForAppResponse', index=900, number=5207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSDownloadRequest', index=901, number=5210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSDownloadResponse', index=902, number=5211,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSDownloadChunk', index=903, number=5212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSLoginRequest', index=904, number=5213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSLoginResponse', index=905, number=5214,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSReloadPartitionInfo', index=906, number=5215,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSTransferHeartbeat', index=907, number=5216,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSSynchronizeFile', index=908, number=5217,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSSynchronizeFileResponse', index=909, number=5218,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSDeleteFileRequest', index=910, number=5219,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSDeleteFileResponse', index=911, number=5220,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetUGCDetails', index=912, number=5226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetUGCDetailsResponse', index=913, number=5227,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSUpdateFileFlags', index=914, number=5228,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSUpdateFileFlagsResponse', index=915, number=5229,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetSingleFileInfo', index=916, number=5230,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSGetSingleFileInfoResponse', index=917, number=5231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSShareFile', index=918, number=5232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSShareFileResponse', index=919, number=5233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSReloadAccount', index=920, number=5234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSReloadAccountResponse', index=921, number=5235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSUpdateRecordBatched', index=922, number=5236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSUpdateRecordBatchedResponse', index=923, number=5237,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSMigrateFile', index=924, number=5238,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSMigrateFileResponse', index=925, number=5239,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSGetUGCURLs', index=926, number=5240,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSGetUGCURLsResponse', index=927, number=5241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSHttpUploadFileFinishRequest', index=928, number=5242,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSHttpUploadFileFinishResponse', index=929, number=5243,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadStartRequest', index=930, number=5244,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadStartResponse', index=931, number=5245,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadChunkRequest', index=932, number=5246,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadChunkResponse', index=933, number=5247,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadFinishRequest', index=934, number=5248,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSDownloadFinishResponse', index=935, number=5249,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSFlushURLCache', index=936, number=5250,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadCommit', index=937, number=5251,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUFSUploadCommitResponse', index=938, number=5252,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSMigrateFileAppID', index=939, number=5253,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUFSMigrateFileAppIDResponse', index=940, number=5254,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseClient2', index=941, number=5400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestForgottenPasswordEmail', index=942, number=5401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestForgottenPasswordEmailResponse', index=943, number=5402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCreateAccountResponse', index=944, number=5403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetForgottenPassword', index=945, number=5404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetForgottenPasswordResponse', index=946, number=5405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInformOfResetForgottenPassword', index=947, number=5407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInformOfResetForgottenPasswordResponse', index=948, number=5408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAnonUserLogOn_Deprecated', index=949, number=5409,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGamesPlayedWithDataBlob', index=950, number=5410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUpdateUserGameInfo', index=951, number=5411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFileToDownload', index=952, number=5412,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFileToDownloadResponse', index=953, number=5413,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSSetScore', index=954, number=5414,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSSetScoreResponse', index=955, number=5415,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSFindOrCreateLB', index=956, number=5416,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSFindOrCreateLBResponse', index=957, number=5417,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSGetLBEntries', index=958, number=5418,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSGetLBEntriesResponse', index=959, number=5419,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatDeclined', index=960, number=5426,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendMsgIncoming', index=961, number=5427,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthList_Deprecated', index=962, number=5428,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientTicketAuthComplete', index=963, number=5429,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientIsLimitedAccount', index=964, number=5430,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestAuthList', index=965, number=5431,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthList', index=966, number=5432,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStat', index=967, number=5433,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientP2PConnectionInfo', index=968, number=5434,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientP2PConnectionFailInfo', index=969, number=5435,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetDepotDecryptionKey', index=970, number=5438,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetDepotDecryptionKeyResponse', index=971, number=5439,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGSPerformHardwareSurvey', index=972, number=5440,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEnableTestLicense', index=973, number=5443,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEnableTestLicenseResponse', index=974, number=5444,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDisableTestLicense', index=975, number=5445,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDisableTestLicenseResponse', index=976, number=5446,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestValidationMail', index=977, number=5448,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestValidationMailResponse', index=978, number=5449,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCheckAppBetaPassword', index=979, number=5450,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCheckAppBetaPasswordResponse', index=980, number=5451,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGC', index=981, number=5452,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFromGC', index=982, number=5453,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEmailAddrInfo', index=983, number=5456,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPasswordChange3', index=984, number=5457,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEmailChange3', index=985, number=5458,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPersonalQAChange3', index=986, number=5459,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetForgottenPassword3', index=987, number=5460,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestForgottenPasswordEmail3', index=988, number=5461,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNewLoginKey', index=989, number=5463,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNewLoginKeyAccepted', index=990, number=5464,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogOnWithHash_Deprecated', index=991, number=5465,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStoreUserStats2', index=992, number=5466,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStatsUpdated', index=993, number=5467,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientActivateOEMLicense', index=994, number=5468,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRegisterOEMMachine', index=995, number=5469,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRegisterOEMMachineResponse', index=996, number=5470,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestedClientStats', index=997, number=5480,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStat2Int32', index=998, number=5481,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientStat2', index=999, number=5482,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVerifyPassword', index=1000, number=5483,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVerifyPasswordResponse', index=1001, number=5484,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMDownloadRequest', index=1002, number=5485,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMDownloadResponse', index=1003, number=5486,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMFinalResult', index=1004, number=5487,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetFriendsWhoPlayGame', index=1005, number=5488,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetFriendsWhoPlayGameResponse', index=1006, number=5489,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSBeginSession', index=1007, number=5490,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSBeginSessionResponse', index=1008, number=5491,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSEndSession', index=1009, number=5492,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSEndSessionResponse', index=1010, number=5493,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSWriteRow', index=1011, number=5494,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMTest', index=1012, number=5495,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMTestResult', index=1013, number=5496,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServerUnavailable', index=1014, number=5500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServersAvailable', index=1015, number=5501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRegisterAuthTicketWithCM', index=1016, number=5502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGCMsgFailed', index=1017, number=5503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMicroTxnAuthRequest', index=1018, number=5504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMicroTxnAuthorize', index=1019, number=5505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMicroTxnAuthorizeResponse', index=1020, number=5506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetMicroTxnInfo', index=1021, number=5508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetMicroTxnInfoResponse', index=1022, number=5509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMarketingMessageUpdate2', index=1023, number=5510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDeregisterWithServer', index=1024, number=5511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSubscribeToPersonaFeed', index=1025, number=5512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogon', index=1026, number=5514,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClientDetails', index=1027, number=5515,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClientDetailsResponse', index=1028, number=5516,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientReportOverlayDetourFailure', index=1029, number=5517,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClientAppList', index=1030, number=5518,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClientAppListResponse', index=1031, number=5519,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInstallClientApp', index=1032, number=5520,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInstallClientAppResponse', index=1033, number=5521,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUninstallClientApp', index=1034, number=5522,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUninstallClientAppResponse', index=1035, number=5523,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSetClientAppUpdateState', index=1036, number=5524,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSetClientAppUpdateStateResponse', index=1037, number=5525,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestEncryptedAppTicket', index=1038, number=5526,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestEncryptedAppTicketResponse', index=1039, number=5527,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientWalletInfoUpdate', index=1040, number=5528,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSSetUGC', index=1041, number=5529,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLBSSetUGCResponse', index=1042, number=5530,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAMGetClanOfficers', index=1043, number=5531,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAMGetClanOfficersResponse', index=1044, number=5532,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendProfileInfo', index=1045, number=5535,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendProfileInfoResponse', index=1046, number=5536,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUpdateMachineAuth', index=1047, number=5537,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUpdateMachineAuthResponse', index=1048, number=5538,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientReadMachineAuth', index=1049, number=5539,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientReadMachineAuthResponse', index=1050, number=5540,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestMachineAuth', index=1051, number=5541,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestMachineAuthResponse', index=1052, number=5542,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientScreenshotsChanged', index=1053, number=5543,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetCDNAuthToken', index=1054, number=5546,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetCDNAuthTokenResponse', index=1055, number=5547,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDownloadRateStatistics', index=1056, number=5548,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestAccountData', index=1057, number=5549,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestAccountDataResponse', index=1058, number=5550,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientResetForgottenPassword4', index=1059, number=5551,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientHideFriend', index=1060, number=5552,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendsGroupsList', index=1061, number=5553,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClanActivityCounts', index=1062, number=5554,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetClanActivityCountsResponse', index=1063, number=5555,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSReportString', index=1064, number=5556,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientOGSReportBug', index=1065, number=5557,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSentLogs', index=1066, number=5558,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLogonGameServer', index=1067, number=5559,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientCreateFriendsGroup', index=1068, number=5560,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientCreateFriendsGroupResponse', index=1069, number=5561,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientDeleteFriendsGroup', index=1070, number=5562,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientDeleteFriendsGroupResponse', index=1071, number=5563,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientManageFriendsGroup', index=1072, number=5564,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientManageFriendsGroupResponse', index=1073, number=5565,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientAddFriendToGroup', index=1074, number=5566,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientAddFriendToGroupResponse', index=1075, number=5567,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientRemoveFriendFromGroup', index=1076, number=5568,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientRemoveFriendFromGroupResponse', index=1077, number=5569,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAMGetPersonaNameHistory', index=1078, number=5570,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAMGetPersonaNameHistoryResponse', index=1079, number=5571,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestFreeLicense', index=1080, number=5572,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestFreeLicenseResponse', index=1081, number=5573,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDRMDownloadRequestWithCrashData', index=1082, number=5574,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthListAck', index=1083, number=5575,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientItemAnnouncements', index=1084, number=5576,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestItemAnnouncements', index=1085, number=5577,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendMsgEchoToSender', index=1086, number=5578,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCommentNotifications', index=1087, number=5582,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestCommentNotifications', index=1088, number=5583,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPersonaChangeResponse', index=1089, number=5584,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestWebAPIAuthenticateUserNonce', index=1090, number=5585,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRequestWebAPIAuthenticateUserNonceResponse', index=1091, number=5586,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPlayerNicknameList', index=1092, number=5587,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientSetPlayerNickname', index=1093, number=5588,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMClientSetPlayerNicknameResponse', index=1094, number=5589,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetNumberOfCurrentPlayersDP', index=1095, number=5592,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetNumberOfCurrentPlayersDPResponse', index=1096, number=5593,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServiceMethodLegacy', index=1097, number=5594,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServiceMethodLegacyResponse', index=1098, number=5595,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFriendUserStatusPublished', index=1099, number=5596,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientCurrentUIMode', index=1100, number=5597,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVanityURLChangedNotification', index=1101, number=5598,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUserNotifications', index=1102, number=5599,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseDFS', index=1103, number=5600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSGetFile', index=1104, number=5601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSInstallLocalFile', index=1105, number=5602,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSConnection', index=1106, number=5603,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSConnectionReply', index=1107, number=5604,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDFSAuthenticateRequest', index=1108, number=5605,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDFSAuthenticateResponse', index=1109, number=5606,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDFSEndSession', index=1110, number=5607,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSPurgeFile', index=1111, number=5608,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSRouteFile', index=1112, number=5609,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSGetFileFromServer', index=1113, number=5610,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSAcceptedResponse', index=1114, number=5611,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSRequestPingback', index=1115, number=5612,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSRecvTransmitFile', index=1116, number=5613,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSSendTransmitFile', index=1117, number=5614,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSRequestPingback2', index=1118, number=5615,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSResponsePingback2', index=1119, number=5616,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDFSDownloadStatus', index=1120, number=5617,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSStartTransfer', index=1121, number=5618,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSTransferComplete', index=1122, number=5619,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDFSRouteFileResponse', index=1123, number=5620,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNetworkingCertRequest', index=1124, number=5621,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNetworkingCertRequestResponse', index=1125, number=5622,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChallengeRequest', index=1126, number=5623,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChallengeResponse', index=1127, number=5624,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBadgeCraftedNotification', index=1128, number=5625,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNetworkingMobileCertRequest', index=1129, number=5626,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientNetworkingMobileCertRequestResponse', index=1130, number=5627,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseMDS', index=1131, number=5800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotDecryptionKey', index=1132, number=5812,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotDecryptionKeyResponse', index=1133, number=5813,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSContentServerConfigRequest', index=1134, number=5827,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSContentServerConfig', index=1135, number=5828,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotManifest', index=1136, number=5829,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotManifestResponse', index=1137, number=5830,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotManifestChunk', index=1138, number=5831,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotChunk', index=1139, number=5832,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotChunkResponse', index=1140, number=5833,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSGetDepotChunkChunk', index=1141, number=5834,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSToCSFlushChunk', index=1142, number=5844,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSMigrateChunk', index=1143, number=5847,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSMigrateChunkResponse', index=1144, number=5848,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMDSToCSFlushManifest', index=1145, number=5849,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCSBase', index=1146, number=6200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCSPing', index=1147, number=6201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCSPingResponse', index=1148, number=6202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMSBase', index=1149, number=6400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMSGameServerReplicate', index=1150, number=6401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGMSServerQuery', index=1151, number=6403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGMSClientServerQueryResponse', index=1152, number=6404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGMSGameServerUpdate', index=1153, number=6405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMGMSGameServerRemove', index=1154, number=6406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGameServerOutOfDate', index=1155, number=6407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDeviceAuthorizationBase', index=1156, number=6500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthorizeLocalDeviceRequest', index=1157, number=6501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthorizeLocalDeviceResponse', index=1158, number=6502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDeauthorizeDeviceRequest', index=1159, number=6503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientDeauthorizeDevice', index=1160, number=6504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUseLocalDeviceAuthorizations', index=1161, number=6505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetAuthorizedDevices', index=1162, number=6506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetAuthorizedDevicesResponse', index=1163, number=6507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMNotifySessionDeviceAuthorized', index=1164, number=6508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientAuthorizeLocalDeviceNotification', index=1165, number=6509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMMSBase', index=1166, number=6600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSCreateLobby', index=1167, number=6601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSCreateLobbyResponse', index=1168, number=6602,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSJoinLobby', index=1169, number=6603,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSJoinLobbyResponse', index=1170, number=6604,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSLeaveLobby', index=1171, number=6605,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSLeaveLobbyResponse', index=1172, number=6606,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSGetLobbyList', index=1173, number=6607,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSGetLobbyListResponse', index=1174, number=6608,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyData', index=1175, number=6609,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyDataResponse', index=1176, number=6610,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSGetLobbyData', index=1177, number=6611,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSLobbyData', index=1178, number=6612,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSendLobbyChatMsg', index=1179, number=6613,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSLobbyChatMsg', index=1180, number=6614,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyOwner', index=1181, number=6615,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyOwnerResponse', index=1182, number=6616,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyGameServer', index=1183, number=6617,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSLobbyGameServerSet', index=1184, number=6618,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSUserJoinedLobby', index=1185, number=6619,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSUserLeftLobby', index=1186, number=6620,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSInviteToLobby', index=1187, number=6621,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSFlushFrenemyListCache', index=1188, number=6622,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSFlushFrenemyListCacheResponse', index=1189, number=6623,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetLobbyLinked', index=1190, number=6624,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSSetRatelimitPolicyOnClient', index=1191, number=6625,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSGetLobbyStatus', index=1192, number=6626,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientMMSGetLobbyStatusResponse', index=1193, number=6627,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMMSGetLobbyList', index=1194, number=6628,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMMSGetLobbyListResponse', index=1195, number=6629,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgBase', index=1196, number=6800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgMemcached', index=1197, number=6801,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgHTTPServer', index=1198, number=6802,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgHTTPClient', index=1199, number=6803,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgWGResponse', index=1200, number=6804,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgPHPSimulator', index=1201, number=6805,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgChase', index=1202, number=6806,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgDFSTransfer', index=1203, number=6807,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgTests', index=1204, number=6808,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgUMQpipeAAPL', index=1205, number=6809,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMSgNonStdMsgSyslog', index=1206, number=6810,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgLogsink', index=1207, number=6811,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgSteam2Emulator', index=1208, number=6812,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgRTMPServer', index=1209, number=6813,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgWebSocket', index=1210, number=6814,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNonStdMsgRedis', index=1211, number=6815,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUDSBase', index=1212, number=7000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUDSP2PSessionStarted', index=1213, number=7001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUDSP2PSessionEnded', index=1214, number=7002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUDSRenderUserAuth', index=1215, number=7003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUDSRenderUserAuthResponse', index=1216, number=7004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientInviteToGame', index=1217, number=7005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUDSHasSession', index=1218, number=7006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUDSHasSessionResponse', index=1219, number=7007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMPASBase', index=1220, number=7100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgMPASVacBanReset', index=1221, number=7101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgKGSBase', index=1222, number=7200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMBase', index=1223, number=7300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMAddScreenshot', index=1224, number=7301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMAddScreenshotResponse', index=1225, number=7302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMResetCommunityContent', index=1226, number=7307,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMResetCommunityContentResponse', index=1227, number=7308,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMDeleteScreenshot', index=1228, number=7309,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMDeleteScreenshotResponse', index=1229, number=7310,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMPublishFile', index=1230, number=7311,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMPublishFileResponse', index=1231, number=7312,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMDeletePublishedFile', index=1232, number=7315,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMDeletePublishedFileResponse', index=1233, number=7316,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMUpdatePublishedFile', index=1234, number=7325,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMUpdatePublishedFileResponse', index=1235, number=7326,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMUpdatePublishedFile', index=1236, number=7327,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMUpdatePublishedFileResponse', index=1237, number=7328,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMDeletePublishedFile', index=1238, number=7329,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMDeletePublishedFileResponse', index=1239, number=7330,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMUpdatePublishedFileStat', index=1240, number=7331,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMReloadPublishedFile', index=1241, number=7337,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMReloadUserFileListCaches', index=1242, number=7338,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileReported', index=1243, number=7339,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFilePreviewAdd', index=1244, number=7341,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFilePreviewAddResponse', index=1245, number=7342,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFilePreviewRemove', index=1246, number=7343,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFilePreviewRemoveResponse', index=1247, number=7344,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileSubscribed', index=1248, number=7349,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileUnsubscribed', index=1249, number=7350,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishFile', index=1250, number=7351,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishFileResponse', index=1251, number=7352,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileChildAdd', index=1252, number=7353,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileChildAddResponse', index=1253, number=7354,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileChildRemove', index=1254, number=7355,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileChildRemoveResponse', index=1255, number=7356,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileParentChanged', index=1256, number=7359,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMSetUserPublishedFileAction', index=1257, number=7364,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMSetUserPublishedFileActionResponse', index=1258, number=7365,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMEnumeratePublishedFilesByUserAction', index=1259, number=7366,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMEnumeratePublishedFilesByUserActionResponse', index=1260, number=7367,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMGetUserSubscribedFiles', index=1261, number=7369,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMGetUserSubscribedFilesResponse', index=1262, number=7370,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMFixStatsPublishedFile', index=1263, number=7371,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdates', index=1264, number=7378,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse', index=1265, number=7379,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUCMPublishedFileContentUpdated', index=1266, number=7380,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUCMPublishedFileUpdated', index=1267, number=7381,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientWorkshopItemChangesRequest', index=1268, number=7382,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientWorkshopItemChangesResponse', index=1269, number=7383,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSBase', index=1270, number=7500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRichPresenceUpload', index=1271, number=7501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRichPresenceRequest', index=1272, number=7502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientRichPresenceInfo', index=1273, number=7503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSRichPresenceRequest', index=1274, number=7504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSRichPresenceResponse', index=1275, number=7505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSComputeFrenematrix', index=1276, number=7506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSComputeFrenematrixResponse', index=1277, number=7507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSPlayStatusNotification', index=1278, number=7508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSAddOrRemoveFollower', index=1279, number=7510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSAddOrRemoveFollowerResponse', index=1280, number=7511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSUpdateFollowingList', index=1281, number=7512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSCommentNotification', index=1282, number=7513,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSCommentNotificationViewed', index=1283, number=7514,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetFollowerCount', index=1284, number=7515,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetFollowerCountResponse', index=1285, number=7516,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetIsFollowing', index=1286, number=7517,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetIsFollowingResponse', index=1287, number=7518,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSEnumerateFollowingList', index=1288, number=7519,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSEnumerateFollowingListResponse', index=1289, number=7520,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSGetPendingNotificationCount', index=1290, number=7521,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgFSGetPendingNotificationCountResponse', index=1291, number=7522,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatOfflineMessageNotification', index=1292, number=7523,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatRequestOfflineMessageCount', index=1293, number=7524,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatGetFriendMessageHistory', index=1294, number=7525,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatGetFriendMessageHistoryResponse', index=1295, number=7526,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientChatGetFriendMessageHistoryForOfflineMessages', index=1296, number=7527,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetFriendsSteamLevels', index=1297, number=7528,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientFSGetFriendsSteamLevelsResponse', index=1298, number=7529,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgAMRequestFriendData', index=1299, number=7530,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMRange2', index=1300, number=7600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGVersionSetEnableDisableRequest', index=1301, number=7600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGVersionSetEnableDisableResponse', index=1302, number=7601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGPropStatusDRMSRequest', index=1303, number=7602,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGPropStatusDRMSResponse', index=1304, number=7603,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGWhackFailureReportRequest', index=1305, number=7604,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCEGWhackFailureReportResponse', index=1306, number=7605,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMSFetchVersionSet', index=1307, number=7606,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMSFetchVersionSetResponse', index=1308, number=7607,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconBase', index=1309, number=7700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_InitiateTradeRequest', index=1310, number=7701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_InitiateTradeProposed', index=1311, number=7702,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_InitiateTradeResponse', index=1312, number=7703,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_InitiateTradeResult', index=1313, number=7704,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_StartSession', index=1314, number=7705,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconTrading_CancelTradeRequest', index=1315, number=7706,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconFlushInventoryCache', index=1316, number=7707,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconFlushInventoryCacheResponse', index=1317, number=7708,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconCDKeyProcessTransaction', index=1318, number=7711,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconCDKeyProcessTransactionResponse', index=1319, number=7712,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconGetErrorLogs', index=1320, number=7713,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgEconGetErrorLogsResponse', index=1321, number=7714,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMRange', index=1322, number=7800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMTestVerisignOTP', index=1323, number=7800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMTestVerisignOTPResponse', index=1324, number=7801,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMDeleteMemcachedKeys', index=1325, number=7803,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMRemoteInvoke', index=1326, number=7804,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBadLoginIPList', index=1327, number=7805,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMMsgTraceAddTrigger', index=1328, number=7806,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMMsgTraceRemoveTrigger', index=1329, number=7807,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRMMsgTraceEvent', index=1330, number=7808,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSBase', index=1331, number=7900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUGSUpdateGlobalStats', index=1332, number=7900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUGSGetGlobalStats', index=1333, number=7901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUGSGetGlobalStatsResponse', index=1334, number=7902,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgStoreBase', index=1335, number=8000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQBase', index=1336, number=8100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQLogonRequest', index=1337, number=8100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQLogonResponse', index=1338, number=8101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQLogoffRequest', index=1339, number=8102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQLogoffResponse', index=1340, number=8103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQSendChatMessage', index=1341, number=8104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQIncomingChatMessage', index=1342, number=8105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQPoll', index=1343, number=8106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQPollResults', index=1344, number=8107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUMQ2AM_ClientMsgBatch', index=1345, number=8108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWorkshopBase', index=1346, number=8200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIBase', index=1347, number=8300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIValidateOAuth2Token', index=1348, number=8300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIValidateOAuth2TokenResponse', index=1349, number=8301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIRegisterGCInterfaces', index=1350, number=8303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIInvalidateOAuthClientCache', index=1351, number=8304,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPIInvalidateOAuthTokenCache', index=1352, number=8305,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWebAPISetSecrets', index=1353, number=8306,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBackpackBase', index=1354, number=8400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBackpackAddToCurrency', index=1355, number=8401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBackpackAddToCurrencyResponse', index=1356, number=8402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREBase', index=1357, number=8500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREItemVoteSummary', index=1358, number=8503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREItemVoteSummaryResponse', index=1359, number=8504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREUpdateUserPublishedItemVote', index=1360, number=8507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREUpdateUserPublishedItemVoteResponse', index=1361, number=8508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREGetUserPublishedItemVoteDetails', index=1362, number=8509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCREGetUserPublishedItemVoteDetailsResponse', index=1363, number=8510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSecretsBase', index=1364, number=8600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSecretsRequestCredentialPair', index=1365, number=8600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSecretsCredentialPairResponse', index=1366, number=8601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBoxMonitorBase', index=1367, number=8700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBoxMonitorReportRequest', index=1368, number=8700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBoxMonitorReportResponse', index=1369, number=8701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLogsinkBase', index=1370, number=8800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLogsinkWriteReport', index=1371, number=8800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPICSBase', index=1372, number=8900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSChangesSinceRequest', index=1373, number=8901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSChangesSinceResponse', index=1374, number=8902,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSProductInfoRequest', index=1375, number=8903,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSProductInfoResponse', index=1376, number=8904,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSAccessTokenRequest', index=1377, number=8905,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPICSAccessTokenResponse', index=1378, number=8906,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWorkerProcess', index=1379, number=9000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWorkerProcessPingRequest', index=1380, number=9000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWorkerProcessPingResponse', index=1381, number=9001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgWorkerProcessShutdown', index=1382, number=9002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcess', index=1383, number=9100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessDRMAndSign', index=1384, number=9100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessDRMAndSignResponse', index=1385, number=9101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSteamworksInfoRequest', index=1386, number=9102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSteamworksInfoResponse', index=1387, number=9103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallDRMDLLRequest', index=1388, number=9104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallDRMDLLResponse', index=1389, number=9105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSecretIdStringRequest', index=1390, number=9106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSecretIdStringResponse', index=1391, number=9107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallProcessedFilesRequest', index=1392, number=9110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallProcessedFilesResponse', index=1393, number=9111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessExamineBlobRequest', index=1394, number=9112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessExamineBlobResponse', index=1395, number=9113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessDescribeSecretRequest', index=1396, number=9114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessDescribeSecretResponse', index=1397, number=9115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessBackfillOriginalRequest', index=1398, number=9116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessBackfillOriginalResponse', index=1399, number=9117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessValidateDRMDLLRequest', index=1400, number=9118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessValidateDRMDLLResponse', index=1401, number=9119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessValidateFileRequest', index=1402, number=9120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessValidateFileResponse', index=1403, number=9121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSplitAndInstallRequest', index=1404, number=9122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessSplitAndInstallResponse', index=1405, number=9123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessGetBlobRequest', index=1406, number=9124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessGetBlobResponse', index=1407, number=9125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessEvaluateCrashRequest', index=1408, number=9126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessEvaluateCrashResponse', index=1409, number=9127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessAnalyzeFileRequest', index=1410, number=9128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessAnalyzeFileResponse', index=1411, number=9129,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessUnpackBlobRequest', index=1412, number=9130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessUnpackBlobResponse', index=1413, number=9131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallAllRequest', index=1414, number=9132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDRMWorkerProcessInstallAllResponse', index=1415, number=9133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestWorkerProcess', index=1416, number=9200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestWorkerProcessLoadUnloadModuleRequest', index=1417, number=9200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestWorkerProcessLoadUnloadModuleResponse', index=1418, number=9201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestWorkerProcessServiceModuleCallRequest', index=1419, number=9202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTestWorkerProcessServiceModuleCallResponse', index=1420, number=9203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgQuestServerBase', index=1421, number=9300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientGetEmoticonList', index=1422, number=9330,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEmoticonList', index=1423, number=9331,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCBase', index=1424, number=9400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCUserSessionStatus', index=1425, number=9400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCRequestUserSessionStatus', index=1426, number=9401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCSharedLicensesLockStatus', index=1427, number=9402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSharedLibraryLockStatus', index=1428, number=9405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSharedLibraryStopPlaying', index=1429, number=9406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCOwnerLibraryChanged', index=1430, number=9407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSLCSharedLibraryChanged', index=1431, number=9408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientBase', index=1432, number=9500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientAuth_OBSOLETE', index=1433, number=9500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientAuthResponse_OBSOLETE', index=1434, number=9501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientAppStatus', index=1435, number=9502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientStartStream', index=1436, number=9503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientStartStreamResponse', index=1437, number=9504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientPing', index=1438, number=9505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientPingResponse', index=1439, number=9506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUnlockStreaming', index=1440, number=9507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUnlockStreamingResponse', index=1441, number=9508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientAcceptEULA', index=1442, number=9509,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientGetControllerConfig', index=1443, number=9510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientGetControllerConfigResponse', index=1444, number=9511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientStreamingEnabled', index=1445, number=9512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUnlockHEVC', index=1446, number=9513,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientUnlockHEVCResponse', index=1447, number=9514,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientStatusRequest', index=1448, number=9515,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRemoteClientStatusResponse', index=1449, number=9516,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientConcurrentSessionsBase', index=1450, number=9600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientPlayingSessionState', index=1451, number=9600,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientKickPlayingSession', index=1452, number=9601,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastBase', index=1453, number=9700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastInit', index=1454, number=9700,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastFrames', index=1455, number=9701,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastDisconnect', index=1456, number=9702,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastScreenshot', index=1457, number=9703,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientBroadcastUploadConfig', index=1458, number=9704,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseClient3', index=1459, number=9800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVoiceCallPreAuthorize', index=1460, number=9800,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientVoiceCallPreAuthorizeResponse', index=1461, number=9801,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServerTimestampRequest', index=1462, number=9802,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientServerTimestampResponse', index=1463, number=9803,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServiceMethodCallFromClientNonAuthed', index=1464, number=9804,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientHello', index=1465, number=9805,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEnableOrDisableDownloads', index=1466, number=9806,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEnableOrDisableDownloadsResponse', index=1467, number=9807,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLANP2PBase', index=1468, number=9900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLANP2PRequestChunk', index=1469, number=9900,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLANP2PRequestChunkResponse', index=1470, number=9901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientLANP2PMax', index=1471, number=9999,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseWatchdogServer', index=1472, number=10000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgNotifyWatchdog', index=1473, number=10000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseBase', index=1474, number=10100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseSiteInfoNotification', index=1475, number=10100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseCheckout', index=1476, number=10101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseCheckoutResponse', index=1477, number=10102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseGetAvailableSeats', index=1478, number=10103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseGetAvailableSeatsResponse', index=1479, number=10104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseGetContentCacheInfo', index=1480, number=10105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientSiteLicenseGetContentCacheInfoResponse', index=1481, number=10106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseChatServer', index=1482, number=12000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChatServerGetPendingNotificationCount', index=1483, number=12000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgChatServerGetPendingNotificationCountResponse', index=1484, number=12001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgBaseSecretServer', index=1485, number=12100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerSecretChanged', index=1486, number=12100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=30,
  serialized_end=53106,
)
_sym_db.RegisterEnumDescriptor(_EMSG)

EMsg = enum_type_wrapper.EnumTypeWrapper(_EMSG)
_ECLIENTPERSONASTATEFLAG = _descriptor.EnumDescriptor(
  name='EClientPersonaStateFlag',
  full_name='EClientPersonaStateFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagStatus', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagPlayerName', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagQueryPort', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagSourceID', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagPresence', index=4, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagLastSeen', index=5, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagUserClanRank', index=6, number=128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateGameExtraInfo', index=7, number=256,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateGameDataBlob', index=8, number=512,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagClanData', index=9, number=1024,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagFacebook', index=10, number=2048,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagRichPresence', index=11, number=4096,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagBroadcast', index=12, number=8192,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EClientPersonaStateFlagWatching', index=13, number=16384,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=53109,
  serialized_end=53700,
)
_sym_db.RegisterEnumDescriptor(_ECLIENTPERSONASTATEFLAG)

EClientPersonaStateFlag = enum_type_wrapper.EnumTypeWrapper(_ECLIENTPERSONASTATEFLAG)
_EMSGCLANACCOUNTFLAGS = _descriptor.EnumDescriptor(
  name='EMsgClanAccountFlags',
  full_name='EMsgClanAccountFlags',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClanAccountFlagPublic', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClanAccountFlagLarge', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClanAccountFlagLocked', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClanAccountFlagDisabled', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClanAccountFlagOGG', index=4, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=53703,
  serialized_end=53888,
)
_sym_db.RegisterEnumDescriptor(_EMSGCLANACCOUNTFLAGS)

EMsgClanAccountFlags = enum_type_wrapper.EnumTypeWrapper(_EMSGCLANACCOUNTFLAGS)
_ESTEAMREVIEWSCORE = _descriptor.EnumDescriptor(
  name='ESteamReviewScore',
  full_name='ESteamReviewScore',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_OverwhelminglyPositive', index=0, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_VeryPositive', index=1, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_Positive', index=2, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_MostlyPositive', index=3, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_Mixed', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_MostlyNegative', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_Negative', index=6, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_VeryNegative', index=7, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_OverwhelminglyNegative', index=8, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamReviewScore_None', index=9, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=53891,
  serialized_end=54291,
)
_sym_db.RegisterEnumDescriptor(_ESTEAMREVIEWSCORE)

ESteamReviewScore = enum_type_wrapper.EnumTypeWrapper(_ESTEAMREVIEWSCORE)
k_EMsgInvalid = 0
k_EMsgMulti = 1
k_EMsgProtobufWrapped = 2
k_EMsgBaseGeneral = 100
k_EMsgGenericReply = 100
k_EMsgDestJobFailed = 113
k_EMsgAlert = 115
k_EMsgSCIDRequest = 120
k_EMsgSCIDResponse = 121
k_EMsgJobHeartbeat = 123
k_EMsgHubConnect = 124
k_EMsgSubscribe = 126
k_EMRouteMessage = 127
k_EMsgWGRequest = 130
k_EMsgWGResponse = 131
k_EMsgKeepAlive = 132
k_EMsgWebAPIJobRequest = 133
k_EMsgWebAPIJobResponse = 134
k_EMsgClientSessionStart = 135
k_EMsgClientSessionEnd = 136
k_EMsgClientSessionUpdate = 137
k_EMsgStatsDeprecated = 138
k_EMsgPing = 139
k_EMsgPingResponse = 140
k_EMsgStats = 141
k_EMsgRequestFullStatsBlock = 142
k_EMsgLoadDBOCacheItem = 143
k_EMsgLoadDBOCacheItemResponse = 144
k_EMsgInvalidateDBOCacheItems = 145
k_EMsgServiceMethod = 146
k_EMsgServiceMethodResponse = 147
k_EMsgClientPackageVersions = 148
k_EMsgTimestampRequest = 149
k_EMsgTimestampResponse = 150
k_EMsgServiceMethodCallFromClient = 151
k_EMsgServiceMethodSendToClient = 152
k_EMsgBaseShell = 200
k_EMsgAssignSysID = 200
k_EMsgExit = 201
k_EMsgDirRequest = 202
k_EMsgDirResponse = 203
k_EMsgZipRequest = 204
k_EMsgZipResponse = 205
k_EMsgUpdateRecordResponse = 215
k_EMsgUpdateCreditCardRequest = 221
k_EMsgUpdateUserBanResponse = 225
k_EMsgPrepareToExit = 226
k_EMsgContentDescriptionUpdate = 227
k_EMsgTestResetServer = 228
k_EMsgUniverseChanged = 229
k_EMsgShellConfigInfoUpdate = 230
k_EMsgRequestWindowsEventLogEntries = 233
k_EMsgProvideWindowsEventLogEntries = 234
k_EMsgShellSearchLogs = 235
k_EMsgShellSearchLogsResponse = 236
k_EMsgShellCheckWindowsUpdates = 237
k_EMsgShellCheckWindowsUpdatesResponse = 238
k_EMsgTestFlushDelayedSQL = 240
k_EMsgTestFlushDelayedSQLResponse = 241
k_EMsgEnsureExecuteScheduledTask_TEST = 242
k_EMsgEnsureExecuteScheduledTaskResponse_TEST = 243
k_EMsgUpdateScheduledTaskEnableState_TEST = 244
k_EMsgUpdateScheduledTaskEnableStateResponse_TEST = 245
k_EMsgContentDescriptionDeltaUpdate = 246
k_EMsgGMShellAndServerAddressUpdates = 247
k_EMsgBaseGM = 300
k_EMsgHeartbeat = 300
k_EMsgShellFailed = 301
k_EMsgExitShells = 307
k_EMsgExitShell = 308
k_EMsgGracefulExitShell = 309
k_EMsgLicenseProcessingComplete = 316
k_EMsgSetTestFlag = 317
k_EMsgQueuedEmailsComplete = 318
k_EMsgGMReportPHPError = 319
k_EMsgGMDRMSync = 320
k_EMsgPhysicalBoxInventory = 321
k_EMsgUpdateConfigFile = 322
k_EMsgTestInitDB = 323
k_EMsgGMWriteConfigToSQL = 324
k_EMsgGMLoadActivationCodes = 325
k_EMsgGMQueueForFBS = 326
k_EMsgGMSchemaConversionResults = 327
k_EMsgGMWriteShellFailureToSQL = 329
k_EMsgGMWriteStatsToSOS = 330
k_EMsgGMGetServiceMethodRouting = 331
k_EMsgGMGetServiceMethodRoutingResponse = 332
k_EMsgGMTestNextBuildSchemaConversion = 334
k_EMsgGMTestNextBuildSchemaConversionResponse = 335
k_EMsgExpectShellRestart = 336
k_EMsgHotFixProgress = 337
k_EMsgGMStatsForwardToAdminConnections = 338
k_EMsgBaseAIS = 400
k_EMsgAISRequestContentDescription = 402
k_EMsgAISUpdateAppInfo = 403
k_EMsgAISGetPackageChangeNumber = 405
k_EMsgAISGetPackageChangeNumberResponse = 406
k_EMsgAIGetAppGCFlags = 423
k_EMsgAIGetAppGCFlagsResponse = 424
k_EMsgAIGetAppList = 425
k_EMsgAIGetAppListResponse = 426
k_EMsgAISGetCouponDefinition = 429
k_EMsgAISGetCouponDefinitionResponse = 430
k_EMsgAISUpdateSubordinateContentDescription = 431
k_EMsgAISUpdateSubordinateContentDescriptionResponse = 432
k_EMsgAISTestEnableGC = 433
k_EMsgBaseAM = 500
k_EMsgAMUpdateUserBanRequest = 504
k_EMsgAMAddLicense = 505
k_EMsgAMSendSystemIMToUser = 508
k_EMsgAMExtendLicense = 509
k_EMsgAMAddMinutesToLicense = 510
k_EMsgAMCancelLicense = 511
k_EMsgAMInitPurchase = 512
k_EMsgAMPurchaseResponse = 513
k_EMsgAMGetFinalPrice = 514
k_EMsgAMGetFinalPriceResponse = 515
k_EMsgAMGetLegacyGameKey = 516
k_EMsgAMGetLegacyGameKeyResponse = 517
k_EMsgAMFindHungTransactions = 518
k_EMsgAMSetAccountTrustedRequest = 519
k_EMsgAMCancelPurchase = 522
k_EMsgAMNewChallenge = 523
k_EMsgAMLoadOEMTickets = 524
k_EMsgAMFixPendingPurchase = 525
k_EMsgAMFixPendingPurchaseResponse = 526
k_EMsgAMIsUserBanned = 527
k_EMsgAMRegisterKey = 528
k_EMsgAMLoadActivationCodes = 529
k_EMsgAMLoadActivationCodesResponse = 530
k_EMsgAMLookupKeyResponse = 531
k_EMsgAMLookupKey = 532
k_EMsgAMChatCleanup = 533
k_EMsgAMClanCleanup = 534
k_EMsgAMFixPendingRefund = 535
k_EMsgAMReverseChargeback = 536
k_EMsgAMReverseChargebackResponse = 537
k_EMsgAMClanCleanupList = 538
k_EMsgAMGetLicenses = 539
k_EMsgAMGetLicensesResponse = 540
k_EMsgAMSendCartRepurchase = 541
k_EMsgAMSendCartRepurchaseResponse = 542
k_EMsgAllowUserToPlayQuery = 550
k_EMsgAllowUserToPlayResponse = 551
k_EMsgAMVerfiyUser = 552
k_EMsgAMClientNotPlaying = 553
k_EMsgAMClientRequestFriendship = 554
k_EMsgAMRelayPublishStatus = 555
k_EMsgAMInitPurchaseResponse = 560
k_EMsgAMRevokePurchaseResponse = 561
k_EMsgAMRefreshGuestPasses = 563
k_EMsgAMGrantGuestPasses = 566
k_EMsgAMClanDataUpdated = 567
k_EMsgAMReloadAccount = 568
k_EMsgAMClientChatMsgRelay = 569
k_EMsgAMChatMulti = 570
k_EMsgAMClientChatInviteRelay = 571
k_EMsgAMChatInvite = 572
k_EMsgAMClientJoinChatRelay = 573
k_EMsgAMClientChatMemberInfoRelay = 574
k_EMsgAMPublishChatMemberInfo = 575
k_EMsgAMClientAcceptFriendInvite = 576
k_EMsgAMChatEnter = 577
k_EMsgAMClientPublishRemovalFromSource = 578
k_EMsgAMChatActionResult = 579
k_EMsgAMFindAccounts = 580
k_EMsgAMFindAccountsResponse = 581
k_EMsgAMIsAccountNameInUse = 582
k_EMsgAMIsAccountNameInUseResponse = 583
k_EMsgAMSetAccountFlags = 584
k_EMsgAMCreateClan = 586
k_EMsgAMCreateClanResponse = 587
k_EMsgAMGetClanDetails = 588
k_EMsgAMGetClanDetailsResponse = 589
k_EMsgAMSetPersonaName = 590
k_EMsgAMSetAvatar = 591
k_EMsgAMAuthenticateUser = 592
k_EMsgAMAuthenticateUserResponse = 593
k_EMsgAMP2PIntroducerMessage = 596
k_EMsgClientChatAction = 597
k_EMsgAMClientChatActionRelay = 598
k_EMsgBaseVS = 600
k_EMsgReqChallenge = 600
k_EMsgVACResponse = 601
k_EMsgReqChallengeTest = 602
k_EMsgVSMarkCheat = 604
k_EMsgVSAddCheat = 605
k_EMsgVSPurgeCodeModDB = 606
k_EMsgVSGetChallengeResults = 607
k_EMsgVSChallengeResultText = 608
k_EMsgVSReportLingerer = 609
k_EMsgVSRequestManagedChallenge = 610
k_EMsgVSLoadDBFinished = 611
k_EMsgBaseDRMS = 625
k_EMsgDRMBuildBlobRequest = 628
k_EMsgDRMBuildBlobResponse = 629
k_EMsgDRMResolveGuidRequest = 630
k_EMsgDRMResolveGuidResponse = 631
k_EMsgDRMVariabilityReport = 633
k_EMsgDRMVariabilityReportResponse = 634
k_EMsgDRMStabilityReport = 635
k_EMsgDRMStabilityReportResponse = 636
k_EMsgDRMDetailsReportRequest = 637
k_EMsgDRMDetailsReportResponse = 638
k_EMsgDRMProcessFile = 639
k_EMsgDRMAdminUpdate = 640
k_EMsgDRMAdminUpdateResponse = 641
k_EMsgDRMSync = 642
k_EMsgDRMSyncResponse = 643
k_EMsgDRMProcessFileResponse = 644
k_EMsgDRMEmptyGuidCache = 645
k_EMsgDRMEmptyGuidCacheResponse = 646
k_EMsgBaseCS = 650
k_EMsgBaseClient = 700
k_EMsgClientLogOn_Deprecated = 701
k_EMsgClientAnonLogOn_Deprecated = 702
k_EMsgClientHeartBeat = 703
k_EMsgClientVACResponse = 704
k_EMsgClientGamesPlayed_obsolete = 705
k_EMsgClientLogOff = 706
k_EMsgClientNoUDPConnectivity = 707
k_EMsgClientConnectionStats = 710
k_EMsgClientPingResponse = 712
k_EMsgClientRemoveFriend = 714
k_EMsgClientGamesPlayedNoDataBlob = 715
k_EMsgClientChangeStatus = 716
k_EMsgClientVacStatusResponse = 717
k_EMsgClientFriendMsg = 718
k_EMsgClientGameConnect_obsolete = 719
k_EMsgClientGamesPlayed2_obsolete = 720
k_EMsgClientGameEnded_obsolete = 721
k_EMsgClientSystemIM = 726
k_EMsgClientSystemIMAck = 727
k_EMsgClientGetLicenses = 728
k_EMsgClientGetLegacyGameKey = 730
k_EMsgClientContentServerLogOn_Deprecated = 731
k_EMsgClientAckVACBan2 = 732
k_EMsgClientGetPurchaseReceipts = 736
k_EMsgClientGamesPlayed3_obsolete = 738
k_EMsgClientAckGuestPass = 740
k_EMsgClientRedeemGuestPass = 741
k_EMsgClientGamesPlayed = 742
k_EMsgClientRegisterKey = 743
k_EMsgClientInviteUserToClan = 744
k_EMsgClientAcknowledgeClanInvite = 745
k_EMsgClientPurchaseWithMachineID = 746
k_EMsgClientAppUsageEvent = 747
k_EMsgClientLogOnResponse = 751
k_EMsgClientSetHeartbeatRate = 755
k_EMsgClientNotLoggedOnDeprecated = 756
k_EMsgClientLoggedOff = 757
k_EMsgGSApprove = 758
k_EMsgGSDeny = 759
k_EMsgGSKick = 760
k_EMsgClientPurchaseResponse = 763
k_EMsgClientPing = 764
k_EMsgClientNOP = 765
k_EMsgClientPersonaState = 766
k_EMsgClientFriendsList = 767
k_EMsgClientAccountInfo = 768
k_EMsgClientNewsUpdate = 771
k_EMsgClientGameConnectDeny = 773
k_EMsgGSStatusReply = 774
k_EMsgClientGameConnectTokens = 779
k_EMsgClientLicenseList = 780
k_EMsgClientVACBanStatus = 782
k_EMsgClientCMList = 783
k_EMsgClientEncryptPct = 784
k_EMsgClientGetLegacyGameKeyResponse = 785
k_EMsgClientAddFriend = 791
k_EMsgClientAddFriendResponse = 792
k_EMsgClientAckGuestPassResponse = 796
k_EMsgClientRedeemGuestPassResponse = 797
k_EMsgClientUpdateGuestPassesList = 798
k_EMsgClientChatMsg = 799
k_EMsgClientChatInvite = 800
k_EMsgClientJoinChat = 801
k_EMsgClientChatMemberInfo = 802
k_EMsgClientLogOnWithCredentials_Deprecated = 803
k_EMsgClientPasswordChangeResponse = 805
k_EMsgClientChatEnter = 807
k_EMsgClientFriendRemovedFromSource = 808
k_EMsgClientCreateChat = 809
k_EMsgClientCreateChatResponse = 810
k_EMsgClientP2PIntroducerMessage = 813
k_EMsgClientChatActionResult = 814
k_EMsgClientRequestFriendData = 815
k_EMsgClientGetUserStats = 818
k_EMsgClientGetUserStatsResponse = 819
k_EMsgClientStoreUserStats = 820
k_EMsgClientStoreUserStatsResponse = 821
k_EMsgClientClanState = 822
k_EMsgClientServiceModule = 830
k_EMsgClientServiceCall = 831
k_EMsgClientServiceCallResponse = 832
k_EMsgClientNatTraversalStatEvent = 839
k_EMsgClientSteamUsageEvent = 842
k_EMsgClientCheckPassword = 845
k_EMsgClientResetPassword = 846
k_EMsgClientCheckPasswordResponse = 848
k_EMsgClientResetPasswordResponse = 849
k_EMsgClientSessionToken = 850
k_EMsgClientDRMProblemReport = 851
k_EMsgClientSetIgnoreFriend = 855
k_EMsgClientSetIgnoreFriendResponse = 856
k_EMsgClientGetAppOwnershipTicket = 857
k_EMsgClientGetAppOwnershipTicketResponse = 858
k_EMsgClientGetLobbyListResponse = 860
k_EMsgClientServerList = 880
k_EMsgClientDRMBlobRequest = 896
k_EMsgClientDRMBlobResponse = 897
k_EMsgBaseGameServer = 900
k_EMsgGSDisconnectNotice = 901
k_EMsgGSStatus = 903
k_EMsgGSUserPlaying = 905
k_EMsgGSStatus2 = 906
k_EMsgGSStatusUpdate_Unused = 907
k_EMsgGSServerType = 908
k_EMsgGSPlayerList = 909
k_EMsgGSGetUserAchievementStatus = 910
k_EMsgGSGetUserAchievementStatusResponse = 911
k_EMsgGSGetPlayStats = 918
k_EMsgGSGetPlayStatsResponse = 919
k_EMsgGSGetUserGroupStatus = 920
k_EMsgAMGetUserGroupStatus = 921
k_EMsgAMGetUserGroupStatusResponse = 922
k_EMsgGSGetUserGroupStatusResponse = 923
k_EMsgGSGetReputation = 936
k_EMsgGSGetReputationResponse = 937
k_EMsgGSAssociateWithClan = 938
k_EMsgGSAssociateWithClanResponse = 939
k_EMsgGSComputeNewPlayerCompatibility = 940
k_EMsgGSComputeNewPlayerCompatibilityResponse = 941
k_EMsgBaseAdmin = 1000
k_EMsgAdminCmd = 1000
k_EMsgAdminCmdResponse = 1004
k_EMsgAdminLogListenRequest = 1005
k_EMsgAdminLogEvent = 1006
k_EMsgUniverseData = 1010
k_EMsgAdminSpew = 1019
k_EMsgAdminConsoleTitle = 1020
k_EMsgAdminGCSpew = 1023
k_EMsgAdminGCCommand = 1024
k_EMsgAdminGCGetCommandList = 1025
k_EMsgAdminGCGetCommandListResponse = 1026
k_EMsgFBSConnectionData = 1027
k_EMsgAdminMsgSpew = 1028
k_EMsgBaseFBS = 1100
k_EMsgFBSReqVersion = 1100
k_EMsgFBSVersionInfo = 1101
k_EMsgFBSForceRefresh = 1102
k_EMsgFBSForceBounce = 1103
k_EMsgFBSDeployPackage = 1104
k_EMsgFBSDeployResponse = 1105
k_EMsgFBSUpdateBootstrapper = 1106
k_EMsgFBSSetState = 1107
k_EMsgFBSApplyOSUpdates = 1108
k_EMsgFBSRunCMDScript = 1109
k_EMsgFBSRebootBox = 1110
k_EMsgFBSSetBigBrotherMode = 1111
k_EMsgFBSMinidumpServer = 1112
k_EMsgFBSDeployHotFixPackage = 1114
k_EMsgFBSDeployHotFixResponse = 1115
k_EMsgFBSDownloadHotFix = 1116
k_EMsgFBSDownloadHotFixResponse = 1117
k_EMsgFBSUpdateTargetConfigFile = 1118
k_EMsgFBSApplyAccountCred = 1119
k_EMsgFBSApplyAccountCredResponse = 1120
k_EMsgFBSSetShellCount = 1121
k_EMsgFBSTerminateShell = 1122
k_EMsgFBSQueryGMForRequest = 1123
k_EMsgFBSQueryGMResponse = 1124
k_EMsgFBSTerminateZombies = 1125
k_EMsgFBSInfoFromBootstrapper = 1126
k_EMsgFBSRebootBoxResponse = 1127
k_EMsgFBSBootstrapperPackageRequest = 1128
k_EMsgFBSBootstrapperPackageResponse = 1129
k_EMsgFBSBootstrapperGetPackageChunk = 1130
k_EMsgFBSBootstrapperGetPackageChunkResponse = 1131
k_EMsgFBSBootstrapperPackageTransferProgress = 1132
k_EMsgFBSRestartBootstrapper = 1133
k_EMsgFBSPauseFrozenDumps = 1134
k_EMsgBaseFileXfer = 1200
k_EMsgFileXferRequest = 1200
k_EMsgFileXferResponse = 1201
k_EMsgFileXferData = 1202
k_EMsgFileXferEnd = 1203
k_EMsgFileXferDataAck = 1204
k_EMsgBaseChannelAuth = 1300
k_EMsgChannelAuthChallenge = 1300
k_EMsgChannelAuthResponse = 1301
k_EMsgChannelAuthResult = 1302
k_EMsgChannelEncryptRequest = 1303
k_EMsgChannelEncryptResponse = 1304
k_EMsgChannelEncryptResult = 1305
k_EMsgBaseBS = 1400
k_EMsgBSPurchaseStart = 1401
k_EMsgBSPurchaseResponse = 1402
k_EMsgBSAuthenticateCCTrans = 1403
k_EMsgBSAuthenticateCCTransResponse = 1404
k_EMsgBSSettleComplete = 1406
k_EMsgBSInitPayPalTxn = 1408
k_EMsgBSInitPayPalTxnResponse = 1409
k_EMsgBSGetPayPalUserInfo = 1410
k_EMsgBSGetPayPalUserInfoResponse = 1411
k_EMsgBSPaymentInstrBan = 1417
k_EMsgBSPaymentInstrBanResponse = 1418
k_EMsgBSInitGCBankXferTxn = 1421
k_EMsgBSInitGCBankXferTxnResponse = 1422
k_EMsgBSCommitGCTxn = 1425
k_EMsgBSQueryTransactionStatus = 1426
k_EMsgBSQueryTransactionStatusResponse = 1427
k_EMsgBSQueryTxnExtendedInfo = 1433
k_EMsgBSQueryTxnExtendedInfoResponse = 1434
k_EMsgBSUpdateConversionRates = 1435
k_EMsgBSPurchaseRunFraudChecks = 1437
k_EMsgBSPurchaseRunFraudChecksResponse = 1438
k_EMsgBSQueryBankInformation = 1440
k_EMsgBSQueryBankInformationResponse = 1441
k_EMsgBSValidateXsollaSignature = 1445
k_EMsgBSValidateXsollaSignatureResponse = 1446
k_EMsgBSQiwiWalletInvoice = 1448
k_EMsgBSQiwiWalletInvoiceResponse = 1449
k_EMsgBSUpdateInventoryFromProPack = 1450
k_EMsgBSUpdateInventoryFromProPackResponse = 1451
k_EMsgBSSendShippingRequest = 1452
k_EMsgBSSendShippingRequestResponse = 1453
k_EMsgBSGetProPackOrderStatus = 1454
k_EMsgBSGetProPackOrderStatusResponse = 1455
k_EMsgBSCheckJobRunning = 1456
k_EMsgBSCheckJobRunningResponse = 1457
k_EMsgBSResetPackagePurchaseRateLimit = 1458
k_EMsgBSResetPackagePurchaseRateLimitResponse = 1459
k_EMsgBSUpdatePaymentData = 1460
k_EMsgBSUpdatePaymentDataResponse = 1461
k_EMsgBSGetBillingAddress = 1462
k_EMsgBSGetBillingAddressResponse = 1463
k_EMsgBSGetCreditCardInfo = 1464
k_EMsgBSGetCreditCardInfoResponse = 1465
k_EMsgBSRemoveExpiredPaymentData = 1468
k_EMsgBSRemoveExpiredPaymentDataResponse = 1469
k_EMsgBSConvertToCurrentKeys = 1470
k_EMsgBSConvertToCurrentKeysResponse = 1471
k_EMsgBSInitPurchase = 1472
k_EMsgBSInitPurchaseResponse = 1473
k_EMsgBSCompletePurchase = 1474
k_EMsgBSCompletePurchaseResponse = 1475
k_EMsgBSPruneCardUsageStats = 1476
k_EMsgBSPruneCardUsageStatsResponse = 1477
k_EMsgBSStoreBankInformation = 1478
k_EMsgBSStoreBankInformationResponse = 1479
k_EMsgBSVerifyPOSAKey = 1480
k_EMsgBSVerifyPOSAKeyResponse = 1481
k_EMsgBSReverseRedeemPOSAKey = 1482
k_EMsgBSReverseRedeemPOSAKeyResponse = 1483
k_EMsgBSQueryFindCreditCard = 1484
k_EMsgBSQueryFindCreditCardResponse = 1485
k_EMsgBSStatusInquiryPOSAKey = 1486
k_EMsgBSStatusInquiryPOSAKeyResponse = 1487
k_EMsgBSBoaCompraConfirmProductDelivery = 1494
k_EMsgBSBoaCompraConfirmProductDeliveryResponse = 1495
k_EMsgBSGenerateBoaCompraMD5 = 1496
k_EMsgBSGenerateBoaCompraMD5Response = 1497
k_EMsgBSCommitWPTxn = 1498
k_EMsgBSCommitAdyenTxn = 1499
k_EMsgBaseATS = 1500
k_EMsgATSStartStressTest = 1501
k_EMsgATSStopStressTest = 1502
k_EMsgATSRunFailServerTest = 1503
k_EMsgATSUFSPerfTestTask = 1504
k_EMsgATSUFSPerfTestResponse = 1505
k_EMsgATSCycleTCM = 1506
k_EMsgATSInitDRMSStressTest = 1507
k_EMsgATSCallTest = 1508
k_EMsgATSCallTestReply = 1509
k_EMsgATSStartExternalStress = 1510
k_EMsgATSExternalStressJobStart = 1511
k_EMsgATSExternalStressJobQueued = 1512
k_EMsgATSExternalStressJobRunning = 1513
k_EMsgATSExternalStressJobStopped = 1514
k_EMsgATSExternalStressJobStopAll = 1515
k_EMsgATSExternalStressActionResult = 1516
k_EMsgATSStarted = 1517
k_EMsgATSCSPerfTestTask = 1518
k_EMsgATSCSPerfTestResponse = 1519
k_EMsgBaseDP = 1600
k_EMsgDPSetPublishingState = 1601
k_EMsgDPUniquePlayersStat = 1603
k_EMsgDPStreamingUniquePlayersStat = 1604
k_EMsgDPBlockingStats = 1607
k_EMsgDPNatTraversalStats = 1608
k_EMsgDPCloudStats = 1612
k_EMsgDPGetPlayerCount = 1615
k_EMsgDPGetPlayerCountResponse = 1616
k_EMsgDPGameServersPlayersStats = 1617
k_EMsgClientDPCheckSpecialSurvey = 1620
k_EMsgClientDPCheckSpecialSurveyResponse = 1621
k_EMsgClientDPSendSpecialSurveyResponse = 1622
k_EMsgClientDPSendSpecialSurveyResponseReply = 1623
k_EMsgDPStoreSaleStatistics = 1624
k_EMsgClientDPUpdateAppJobReport = 1625
k_EMsgClientDPUnsignedInstallScript = 1627
k_EMsgDPPartnerMicroTxns = 1628
k_EMsgDPPartnerMicroTxnsResponse = 1629
k_EMsgClientDPContentStatsReport = 1630
k_EMsgDPVRUniquePlayersStat = 1631
k_EMsgBaseCM = 1700
k_EMsgCMSetAllowState = 1701
k_EMsgCMSpewAllowState = 1702
k_EMsgCMSessionRejected = 1703
k_EMsgCMSetSecrets = 1704
k_EMsgCMGetSecrets = 1705
k_EMsgBaseGC = 2200
k_EMsgGCCmdRevive = 2203
k_EMsgGCCmdDown = 2206
k_EMsgGCCmdDeploy = 2207
k_EMsgGCCmdDeployResponse = 2208
k_EMsgGCCmdSwitch = 2209
k_EMsgAMRefreshSessions = 2210
k_EMsgGCAchievementAwarded = 2212
k_EMsgGCSystemMessage = 2213
k_EMsgGCCmdStatus = 2216
k_EMsgGCRegisterWebInterfaces_Deprecated = 2217
k_EMsgGCGetAccountDetails_DEPRECATED = 2218
k_EMsgGCInterAppMessage = 2219
k_EMsgGCGetEmailTemplate = 2220
k_EMsgGCGetEmailTemplateResponse = 2221
k_EMsgGCHRelay = 2222
k_EMsgGCHRelayToClient = 2223
k_EMsgGCHUpdateSession = 2224
k_EMsgGCHRequestUpdateSession = 2225
k_EMsgGCHRequestStatus = 2226
k_EMsgGCHRequestStatusResponse = 2227
k_EMsgGCHAccountVacStatusChange = 2228
k_EMsgGCHSpawnGC = 2229
k_EMsgGCHSpawnGCResponse = 2230
k_EMsgGCHKillGC = 2231
k_EMsgGCHKillGCResponse = 2232
k_EMsgGCHAccountTradeBanStatusChange = 2233
k_EMsgGCHAccountLockStatusChange = 2234
k_EMsgGCHVacVerificationChange = 2235
k_EMsgGCHAccountPhoneNumberChange = 2236
k_EMsgGCHAccountTwoFactorChange = 2237
k_EMsgGCHInviteUserToLobby = 2238
k_EMsgGCHUpdateMultipleSessions = 2239
k_EMsgGCHMarkAppSessionsAuthoritative = 2240
k_EMsgGCHRecurringSubscriptionStatusChange = 2241
k_EMsgGCHAppCheersReceived = 2242
k_EMsgGCHAppCheersGetAllowedTypes = 2243
k_EMsgGCHAppCheersGetAllowedTypesResponse = 2244
k_EMsgBaseP2P = 2500
k_EMsgP2PIntroducerMessage = 2502
k_EMsgBaseSM = 2900
k_EMsgSMExpensiveReport = 2902
k_EMsgSMHourlyReport = 2903
k_EMsgSMPartitionRenames = 2905
k_EMsgSMMonitorSpace = 2906
k_EMsgSMTestNextBuildSchemaConversion = 2907
k_EMsgSMTestNextBuildSchemaConversionResponse = 2908
k_EMsgBaseTest = 3000
k_EMsgFailServer = 3000
k_EMsgJobHeartbeatTest = 3001
k_EMsgJobHeartbeatTestResponse = 3002
k_EMsgBaseFTSRange = 3100
k_EMsgBaseCCSRange = 3150
k_EMsgCCSDeleteAllCommentsByAuthor = 3161
k_EMsgCCSDeleteAllCommentsByAuthorResponse = 3162
k_EMsgBaseLBSRange = 3200
k_EMsgLBSSetScore = 3201
k_EMsgLBSSetScoreResponse = 3202
k_EMsgLBSFindOrCreateLB = 3203
k_EMsgLBSFindOrCreateLBResponse = 3204
k_EMsgLBSGetLBEntries = 3205
k_EMsgLBSGetLBEntriesResponse = 3206
k_EMsgLBSGetLBList = 3207
k_EMsgLBSGetLBListResponse = 3208
k_EMsgLBSSetLBDetails = 3209
k_EMsgLBSDeleteLB = 3210
k_EMsgLBSDeleteLBEntry = 3211
k_EMsgLBSResetLB = 3212
k_EMsgLBSResetLBResponse = 3213
k_EMsgLBSDeleteLBResponse = 3214
k_EMsgBaseOGS = 3400
k_EMsgOGSBeginSession = 3401
k_EMsgOGSBeginSessionResponse = 3402
k_EMsgOGSEndSession = 3403
k_EMsgOGSEndSessionResponse = 3404
k_EMsgOGSWriteAppSessionRow = 3406
k_EMsgBaseBRP = 3600
k_EMsgBRPPostTransactionTax = 3629
k_EMsgBRPPostTransactionTaxResponse = 3630
k_EMsgBaseAMRange2 = 4000
k_EMsgAMCreateChat = 4001
k_EMsgAMCreateChatResponse = 4002
k_EMsgAMSetProfileURL = 4005
k_EMsgAMGetAccountEmailAddress = 4006
k_EMsgAMGetAccountEmailAddressResponse = 4007
k_EMsgAMRequestClanData = 4008
k_EMsgAMRouteToClients = 4009
k_EMsgAMLeaveClan = 4010
k_EMsgAMClanPermissions = 4011
k_EMsgAMClanPermissionsResponse = 4012
k_EMsgAMCreateClanEventDummyForRateLimiting = 4013
k_EMsgAMUpdateClanEventDummyForRateLimiting = 4015
k_EMsgAMSetClanPermissionSettings = 4021
k_EMsgAMSetClanPermissionSettingsResponse = 4022
k_EMsgAMGetClanPermissionSettings = 4023
k_EMsgAMGetClanPermissionSettingsResponse = 4024
k_EMsgAMPublishChatRoomInfo = 4025
k_EMsgClientChatRoomInfo = 4026
k_EMsgAMGetClanHistory = 4039
k_EMsgAMGetClanHistoryResponse = 4040
k_EMsgAMGetClanPermissionBits = 4041
k_EMsgAMGetClanPermissionBitsResponse = 4042
k_EMsgAMSetClanPermissionBits = 4043
k_EMsgAMSetClanPermissionBitsResponse = 4044
k_EMsgAMSessionInfoRequest = 4045
k_EMsgAMSessionInfoResponse = 4046
k_EMsgAMValidateWGToken = 4047
k_EMsgAMGetClanRank = 4050
k_EMsgAMGetClanRankResponse = 4051
k_EMsgAMSetClanRank = 4052
k_EMsgAMSetClanRankResponse = 4053
k_EMsgAMGetClanPOTW = 4054
k_EMsgAMGetClanPOTWResponse = 4055
k_EMsgAMSetClanPOTW = 4056
k_EMsgAMSetClanPOTWResponse = 4057
k_EMsgAMDumpUser = 4059
k_EMsgAMKickUserFromClan = 4060
k_EMsgAMAddFounderToClan = 4061
k_EMsgAMValidateWGTokenResponse = 4062
k_EMsgAMSetAccountDetails = 4064
k_EMsgAMGetChatBanList = 4065
k_EMsgAMGetChatBanListResponse = 4066
k_EMsgAMUnBanFromChat = 4067
k_EMsgAMSetClanDetails = 4068
k_EMsgUGSGetUserGameStats = 4073
k_EMsgUGSGetUserGameStatsResponse = 4074
k_EMsgAMCheckClanMembership = 4075
k_EMsgAMGetClanMembers = 4076
k_EMsgAMGetClanMembersResponse = 4077
k_EMsgAMNotifyChatOfClanChange = 4079
k_EMsgAMResubmitPurchase = 4080
k_EMsgAMAddFriend = 4081
k_EMsgAMAddFriendResponse = 4082
k_EMsgAMRemoveFriend = 4083
k_EMsgAMDumpClan = 4084
k_EMsgAMChangeClanOwner = 4085
k_EMsgAMCancelEasyCollect = 4086
k_EMsgAMCancelEasyCollectResponse = 4087
k_EMsgAMClansInCommon = 4090
k_EMsgAMClansInCommonResponse = 4091
k_EMsgAMIsValidAccountID = 4092
k_EMsgAMWipeFriendsList = 4095
k_EMsgAMSetIgnored = 4096
k_EMsgAMClansInCommonCountResponse = 4097
k_EMsgAMFriendsList = 4098
k_EMsgAMFriendsListResponse = 4099
k_EMsgAMFriendsInCommon = 4100
k_EMsgAMFriendsInCommonResponse = 4101
k_EMsgAMFriendsInCommonCountResponse = 4102
k_EMsgAMClansInCommonCount = 4103
k_EMsgAMChallengeVerdict = 4104
k_EMsgAMChallengeNotification = 4105
k_EMsgAMFindGSByIP = 4106
k_EMsgAMFoundGSByIP = 4107
k_EMsgAMGiftRevoked = 4108
k_EMsgAMUserClanList = 4110
k_EMsgAMUserClanListResponse = 4111
k_EMsgAMGetAccountDetails2 = 4112
k_EMsgAMGetAccountDetailsResponse2 = 4113
k_EMsgAMSetCommunityProfileSettings = 4114
k_EMsgAMSetCommunityProfileSettingsResponse = 4115
k_EMsgAMGetCommunityPrivacyState = 4116
k_EMsgAMGetCommunityPrivacyStateResponse = 4117
k_EMsgAMCheckClanInviteRateLimiting = 4118
k_EMsgUGSGetUserAchievementStatus = 4119
k_EMsgAMGetIgnored = 4120
k_EMsgAMGetIgnoredResponse = 4121
k_EMsgAMSetIgnoredResponse = 4122
k_EMsgAMSetFriendRelationshipNone = 4123
k_EMsgAMGetFriendRelationship = 4124
k_EMsgAMGetFriendRelationshipResponse = 4125
k_EMsgAMServiceModulesCache = 4126
k_EMsgAMServiceModulesCall = 4127
k_EMsgAMServiceModulesCallResponse = 4128
k_EMsgCommunityAddFriendNews = 4140
k_EMsgAMFindClanUser = 4143
k_EMsgAMFindClanUserResponse = 4144
k_EMsgAMBanFromChat = 4145
k_EMsgAMGetUserNewsSubscriptions = 4147
k_EMsgAMGetUserNewsSubscriptionsResponse = 4148
k_EMsgAMSetUserNewsSubscriptions = 4149
k_EMsgAMSendQueuedEmails = 4152
k_EMsgAMSetLicenseFlags = 4153
k_EMsgCommunityDeleteUserNews = 4155
k_EMsgAMAllowUserFilesRequest = 4156
k_EMsgAMAllowUserFilesResponse = 4157
k_EMsgAMGetAccountStatus = 4158
k_EMsgAMGetAccountStatusResponse = 4159
k_EMsgAMEditBanReason = 4160
k_EMsgAMCheckClanMembershipResponse = 4161
k_EMsgAMProbeClanMembershipList = 4162
k_EMsgAMProbeClanMembershipListResponse = 4163
k_EMsgUGSGetUserAchievementStatusResponse = 4164
k_EMsgAMGetFriendsLobbies = 4165
k_EMsgAMGetFriendsLobbiesResponse = 4166
k_EMsgAMGetUserFriendNewsResponse = 4172
k_EMsgCommunityGetUserFriendNews = 4173
k_EMsgAMGetUserClansNewsResponse = 4174
k_EMsgAMGetUserClansNews = 4175
k_EMsgAMGetPreviousCBAccount = 4184
k_EMsgAMGetPreviousCBAccountResponse = 4185
k_EMsgAMGetUserLicenseHistory = 4190
k_EMsgAMGetUserLicenseHistoryResponse = 4191
k_EMsgAMSupportChangePassword = 4194
k_EMsgAMSupportChangeEmail = 4195
k_EMsgAMResetUserVerificationGSByIP = 4197
k_EMsgAMUpdateGSPlayStats = 4198
k_EMsgAMSupportEnableOrDisable = 4199
k_EMsgAMGetPurchaseStatus = 4206
k_EMsgAMSupportIsAccountEnabled = 4209
k_EMsgAMSupportIsAccountEnabledResponse = 4210
k_EMsgUGSGetUserStats = 4211
k_EMsgAMGSSearch = 4213
k_EMsgMarketingMessageUpdate = 4216
k_EMsgChatServerRouteFriendMsg = 4219
k_EMsgAMTicketAuthRequestOrResponse = 4220
k_EMsgAMAddFreeLicense = 4224
k_EMsgAMValidateEmailLink = 4231
k_EMsgAMValidateEmailLinkResponse = 4232
k_EMsgUGSStoreUserStats = 4236
k_EMsgAMDeleteStoredCard = 4241
k_EMsgAMRevokeLegacyGameKeys = 4242
k_EMsgAMGetWalletDetails = 4244
k_EMsgAMGetWalletDetailsResponse = 4245
k_EMsgAMDeleteStoredPaymentInfo = 4246
k_EMsgAMGetStoredPaymentSummary = 4247
k_EMsgAMGetStoredPaymentSummaryResponse = 4248
k_EMsgAMGetWalletConversionRate = 4249
k_EMsgAMGetWalletConversionRateResponse = 4250
k_EMsgAMConvertWallet = 4251
k_EMsgAMConvertWalletResponse = 4252
k_EMsgAMSetPreApproval = 4255
k_EMsgAMSetPreApprovalResponse = 4256
k_EMsgAMCreateRefund = 4258
k_EMsgAMCreateChargeback = 4260
k_EMsgAMCreateDispute = 4262
k_EMsgAMClearDispute = 4264
k_EMsgAMCreateFinancialAdjustment = 4265
k_EMsgAMPlayerNicknameList = 4266
k_EMsgAMPlayerNicknameListResponse = 4267
k_EMsgAMSetDRMTestConfig = 4268
k_EMsgAMGetUserCurrentGameInfo = 4269
k_EMsgAMGetUserCurrentGameInfoResponse = 4270
k_EMsgAMGetGSPlayerList = 4271
k_EMsgAMGetGSPlayerListResponse = 4272
k_EMsgAMGetSteamIDForMicroTxn = 4278
k_EMsgAMGetSteamIDForMicroTxnResponse = 4279
k_EMsgAMSetPartnerMember = 4280
k_EMsgAMRemovePublisherUser = 4281
k_EMsgAMGetUserLicenseList = 4282
k_EMsgAMGetUserLicenseListResponse = 4283
k_EMsgAMReloadGameGroupPolicy = 4284
k_EMsgAMAddFreeLicenseResponse = 4285
k_EMsgAMVACStatusUpdate = 4286
k_EMsgAMGetAccountDetails = 4287
k_EMsgAMGetAccountDetailsResponse = 4288
k_EMsgAMGetPlayerLinkDetails = 4289
k_EMsgAMGetPlayerLinkDetailsResponse = 4290
k_EMsgAMGetAccountFlagsForWGSpoofing = 4294
k_EMsgAMGetAccountFlagsForWGSpoofingResponse = 4295
k_EMsgAMGetClanOfficers = 4298
k_EMsgAMGetClanOfficersResponse = 4299
k_EMsgAMNameChange = 4300
k_EMsgAMGetNameHistory = 4301
k_EMsgAMGetNameHistoryResponse = 4302
k_EMsgAMUpdateProviderStatus = 4305
k_EMsgAMSupportRemoveAccountSecurity = 4307
k_EMsgAMIsAccountInCaptchaGracePeriod = 4308
k_EMsgAMIsAccountInCaptchaGracePeriodResponse = 4309
k_EMsgAMAccountPS3Unlink = 4310
k_EMsgAMAccountPS3UnlinkResponse = 4311
k_EMsgUGSStoreUserStatsResponse = 4312
k_EMsgAMGetAccountPSNInfo = 4313
k_EMsgAMGetAccountPSNInfoResponse = 4314
k_EMsgAMAuthenticatedPlayerList = 4315
k_EMsgAMGetUserGifts = 4316
k_EMsgAMGetUserGiftsResponse = 4317
k_EMsgAMTransferLockedGifts = 4320
k_EMsgAMTransferLockedGiftsResponse = 4321
k_EMsgAMPlayerHostedOnGameServer = 4322
k_EMsgAMGetAccountBanInfo = 4323
k_EMsgAMGetAccountBanInfoResponse = 4324
k_EMsgAMRecordBanEnforcement = 4325
k_EMsgAMRollbackGiftTransfer = 4326
k_EMsgAMRollbackGiftTransferResponse = 4327
k_EMsgAMHandlePendingTransaction = 4328
k_EMsgAMRequestClanDetails = 4329
k_EMsgAMDeleteStoredPaypalAgreement = 4330
k_EMsgAMGameServerUpdate = 4331
k_EMsgAMGameServerRemove = 4332
k_EMsgAMGetPaypalAgreements = 4333
k_EMsgAMGetPaypalAgreementsResponse = 4334
k_EMsgAMGameServerPlayerCompatibilityCheck = 4335
k_EMsgAMGameServerPlayerCompatibilityCheckResponse = 4336
k_EMsgAMRenewLicense = 4337
k_EMsgAMGetAccountCommunityBanInfo = 4338
k_EMsgAMGetAccountCommunityBanInfoResponse = 4339
k_EMsgAMGameServerAccountChangePassword = 4340
k_EMsgAMGameServerAccountDeleteAccount = 4341
k_EMsgAMRenewAgreement = 4342
k_EMsgAMXsollaPayment = 4344
k_EMsgAMXsollaPaymentResponse = 4345
k_EMsgAMAcctAllowedToPurchase = 4346
k_EMsgAMAcctAllowedToPurchaseResponse = 4347
k_EMsgAMSwapKioskDeposit = 4348
k_EMsgAMSwapKioskDepositResponse = 4349
k_EMsgAMSetUserGiftUnowned = 4350
k_EMsgAMSetUserGiftUnownedResponse = 4351
k_EMsgAMClaimUnownedUserGift = 4352
k_EMsgAMClaimUnownedUserGiftResponse = 4353
k_EMsgAMSetClanName = 4354
k_EMsgAMSetClanNameResponse = 4355
k_EMsgAMGrantCoupon = 4356
k_EMsgAMGrantCouponResponse = 4357
k_EMsgAMIsPackageRestrictedInUserCountry = 4358
k_EMsgAMIsPackageRestrictedInUserCountryResponse = 4359
k_EMsgAMHandlePendingTransactionResponse = 4360
k_EMsgAMGrantGuestPasses2 = 4361
k_EMsgAMGrantGuestPasses2Response = 4362
k_EMsgAMGetPlayerBanDetails = 4365
k_EMsgAMGetPlayerBanDetailsResponse = 4366
k_EMsgAMFinalizePurchase = 4367
k_EMsgAMFinalizePurchaseResponse = 4368
k_EMsgAMPersonaChangeResponse = 4372
k_EMsgAMGetClanDetailsForForumCreation = 4373
k_EMsgAMGetClanDetailsForForumCreationResponse = 4374
k_EMsgAMGetPendingNotificationCount = 4375
k_EMsgAMGetPendingNotificationCountResponse = 4376
k_EMsgAMPasswordHashUpgrade = 4377
k_EMsgAMBoaCompraPayment = 4380
k_EMsgAMBoaCompraPaymentResponse = 4381
k_EMsgAMCompleteExternalPurchase = 4383
k_EMsgAMCompleteExternalPurchaseResponse = 4384
k_EMsgAMResolveNegativeWalletCredits = 4385
k_EMsgAMResolveNegativeWalletCreditsResponse = 4386
k_EMsgAMPlayerGetClanBasicDetails = 4389
k_EMsgAMPlayerGetClanBasicDetailsResponse = 4390
k_EMsgAMMOLPayment = 4391
k_EMsgAMMOLPaymentResponse = 4392
k_EMsgGetUserIPCountry = 4393
k_EMsgGetUserIPCountryResponse = 4394
k_EMsgNotificationOfSuspiciousActivity = 4395
k_EMsgAMDegicaPayment = 4396
k_EMsgAMDegicaPaymentResponse = 4397
k_EMsgAMEClubPayment = 4398
k_EMsgAMEClubPaymentResponse = 4399
k_EMsgAMPayPalPaymentsHubPayment = 4400
k_EMsgAMPayPalPaymentsHubPaymentResponse = 4401
k_EMsgAMTwoFactorRecoverAuthenticatorRequest = 4402
k_EMsgAMTwoFactorRecoverAuthenticatorResponse = 4403
k_EMsgAMSmart2PayPayment = 4404
k_EMsgAMSmart2PayPaymentResponse = 4405
k_EMsgAMValidatePasswordResetCodeAndSendSmsRequest = 4406
k_EMsgAMValidatePasswordResetCodeAndSendSmsResponse = 4407
k_EMsgAMGetAccountResetDetailsRequest = 4408
k_EMsgAMGetAccountResetDetailsResponse = 4409
k_EMsgAMBitPayPayment = 4410
k_EMsgAMBitPayPaymentResponse = 4411
k_EMsgAMSendAccountInfoUpdate = 4412
k_EMsgAMSendScheduledGift = 4413
k_EMsgAMNodwinPayment = 4414
k_EMsgAMNodwinPaymentResponse = 4415
k_EMsgAMResolveWalletRevoke = 4416
k_EMsgAMResolveWalletReverseRevoke = 4417
k_EMsgAMFundedPayment = 4418
k_EMsgAMFundedPaymentResponse = 4419
k_EMsgAMRequestPersonaUpdateForChatServer = 4420
k_EMsgAMPerfectWorldPayment = 4421
k_EMsgAMPerfectWorldPaymentResponse = 4422
k_EMsgAMECommPayPayment = 4423
k_EMsgAMECommPayPaymentResponse = 4424
k_EMsgBasePSRange = 5000
k_EMsgPSCreateShoppingCart = 5001
k_EMsgPSCreateShoppingCartResponse = 5002
k_EMsgPSIsValidShoppingCart = 5003
k_EMsgPSIsValidShoppingCartResponse = 5004
k_EMsgPSRemoveLineItemFromShoppingCart = 5007
k_EMsgPSRemoveLineItemFromShoppingCartResponse = 5008
k_EMsgPSGetShoppingCartContents = 5009
k_EMsgPSGetShoppingCartContentsResponse = 5010
k_EMsgPSAddWalletCreditToShoppingCart = 5011
k_EMsgPSAddWalletCreditToShoppingCartResponse = 5012
k_EMsgBaseUFSRange = 5200
k_EMsgClientUFSUploadFileRequest = 5202
k_EMsgClientUFSUploadFileResponse = 5203
k_EMsgClientUFSUploadFileChunk = 5204
k_EMsgClientUFSUploadFileFinished = 5205
k_EMsgClientUFSGetFileListForApp = 5206
k_EMsgClientUFSGetFileListForAppResponse = 5207
k_EMsgClientUFSDownloadRequest = 5210
k_EMsgClientUFSDownloadResponse = 5211
k_EMsgClientUFSDownloadChunk = 5212
k_EMsgClientUFSLoginRequest = 5213
k_EMsgClientUFSLoginResponse = 5214
k_EMsgUFSReloadPartitionInfo = 5215
k_EMsgClientUFSTransferHeartbeat = 5216
k_EMsgUFSSynchronizeFile = 5217
k_EMsgUFSSynchronizeFileResponse = 5218
k_EMsgClientUFSDeleteFileRequest = 5219
k_EMsgClientUFSDeleteFileResponse = 5220
k_EMsgClientUFSGetUGCDetails = 5226
k_EMsgClientUFSGetUGCDetailsResponse = 5227
k_EMsgUFSUpdateFileFlags = 5228
k_EMsgUFSUpdateFileFlagsResponse = 5229
k_EMsgClientUFSGetSingleFileInfo = 5230
k_EMsgClientUFSGetSingleFileInfoResponse = 5231
k_EMsgClientUFSShareFile = 5232
k_EMsgClientUFSShareFileResponse = 5233
k_EMsgUFSReloadAccount = 5234
k_EMsgUFSReloadAccountResponse = 5235
k_EMsgUFSUpdateRecordBatched = 5236
k_EMsgUFSUpdateRecordBatchedResponse = 5237
k_EMsgUFSMigrateFile = 5238
k_EMsgUFSMigrateFileResponse = 5239
k_EMsgUFSGetUGCURLs = 5240
k_EMsgUFSGetUGCURLsResponse = 5241
k_EMsgUFSHttpUploadFileFinishRequest = 5242
k_EMsgUFSHttpUploadFileFinishResponse = 5243
k_EMsgUFSDownloadStartRequest = 5244
k_EMsgUFSDownloadStartResponse = 5245
k_EMsgUFSDownloadChunkRequest = 5246
k_EMsgUFSDownloadChunkResponse = 5247
k_EMsgUFSDownloadFinishRequest = 5248
k_EMsgUFSDownloadFinishResponse = 5249
k_EMsgUFSFlushURLCache = 5250
k_EMsgClientUFSUploadCommit = 5251
k_EMsgClientUFSUploadCommitResponse = 5252
k_EMsgUFSMigrateFileAppID = 5253
k_EMsgUFSMigrateFileAppIDResponse = 5254
k_EMsgBaseClient2 = 5400
k_EMsgClientRequestForgottenPasswordEmail = 5401
k_EMsgClientRequestForgottenPasswordEmailResponse = 5402
k_EMsgClientCreateAccountResponse = 5403
k_EMsgClientResetForgottenPassword = 5404
k_EMsgClientResetForgottenPasswordResponse = 5405
k_EMsgClientInformOfResetForgottenPassword = 5407
k_EMsgClientInformOfResetForgottenPasswordResponse = 5408
k_EMsgClientAnonUserLogOn_Deprecated = 5409
k_EMsgClientGamesPlayedWithDataBlob = 5410
k_EMsgClientUpdateUserGameInfo = 5411
k_EMsgClientFileToDownload = 5412
k_EMsgClientFileToDownloadResponse = 5413
k_EMsgClientLBSSetScore = 5414
k_EMsgClientLBSSetScoreResponse = 5415
k_EMsgClientLBSFindOrCreateLB = 5416
k_EMsgClientLBSFindOrCreateLBResponse = 5417
k_EMsgClientLBSGetLBEntries = 5418
k_EMsgClientLBSGetLBEntriesResponse = 5419
k_EMsgClientChatDeclined = 5426
k_EMsgClientFriendMsgIncoming = 5427
k_EMsgClientAuthList_Deprecated = 5428
k_EMsgClientTicketAuthComplete = 5429
k_EMsgClientIsLimitedAccount = 5430
k_EMsgClientRequestAuthList = 5431
k_EMsgClientAuthList = 5432
k_EMsgClientStat = 5433
k_EMsgClientP2PConnectionInfo = 5434
k_EMsgClientP2PConnectionFailInfo = 5435
k_EMsgClientGetDepotDecryptionKey = 5438
k_EMsgClientGetDepotDecryptionKeyResponse = 5439
k_EMsgGSPerformHardwareSurvey = 5440
k_EMsgClientEnableTestLicense = 5443
k_EMsgClientEnableTestLicenseResponse = 5444
k_EMsgClientDisableTestLicense = 5445
k_EMsgClientDisableTestLicenseResponse = 5446
k_EMsgClientRequestValidationMail = 5448
k_EMsgClientRequestValidationMailResponse = 5449
k_EMsgClientCheckAppBetaPassword = 5450
k_EMsgClientCheckAppBetaPasswordResponse = 5451
k_EMsgClientToGC = 5452
k_EMsgClientFromGC = 5453
k_EMsgClientEmailAddrInfo = 5456
k_EMsgClientPasswordChange3 = 5457
k_EMsgClientEmailChange3 = 5458
k_EMsgClientPersonalQAChange3 = 5459
k_EMsgClientResetForgottenPassword3 = 5460
k_EMsgClientRequestForgottenPasswordEmail3 = 5461
k_EMsgClientNewLoginKey = 5463
k_EMsgClientNewLoginKeyAccepted = 5464
k_EMsgClientLogOnWithHash_Deprecated = 5465
k_EMsgClientStoreUserStats2 = 5466
k_EMsgClientStatsUpdated = 5467
k_EMsgClientActivateOEMLicense = 5468
k_EMsgClientRegisterOEMMachine = 5469
k_EMsgClientRegisterOEMMachineResponse = 5470
k_EMsgClientRequestedClientStats = 5480
k_EMsgClientStat2Int32 = 5481
k_EMsgClientStat2 = 5482
k_EMsgClientVerifyPassword = 5483
k_EMsgClientVerifyPasswordResponse = 5484
k_EMsgClientDRMDownloadRequest = 5485
k_EMsgClientDRMDownloadResponse = 5486
k_EMsgClientDRMFinalResult = 5487
k_EMsgClientGetFriendsWhoPlayGame = 5488
k_EMsgClientGetFriendsWhoPlayGameResponse = 5489
k_EMsgClientOGSBeginSession = 5490
k_EMsgClientOGSBeginSessionResponse = 5491
k_EMsgClientOGSEndSession = 5492
k_EMsgClientOGSEndSessionResponse = 5493
k_EMsgClientOGSWriteRow = 5494
k_EMsgClientDRMTest = 5495
k_EMsgClientDRMTestResult = 5496
k_EMsgClientServerUnavailable = 5500
k_EMsgClientServersAvailable = 5501
k_EMsgClientRegisterAuthTicketWithCM = 5502
k_EMsgClientGCMsgFailed = 5503
k_EMsgClientMicroTxnAuthRequest = 5504
k_EMsgClientMicroTxnAuthorize = 5505
k_EMsgClientMicroTxnAuthorizeResponse = 5506
k_EMsgClientGetMicroTxnInfo = 5508
k_EMsgClientGetMicroTxnInfoResponse = 5509
k_EMsgClientMarketingMessageUpdate2 = 5510
k_EMsgClientDeregisterWithServer = 5511
k_EMsgClientSubscribeToPersonaFeed = 5512
k_EMsgClientLogon = 5514
k_EMsgClientGetClientDetails = 5515
k_EMsgClientGetClientDetailsResponse = 5516
k_EMsgClientReportOverlayDetourFailure = 5517
k_EMsgClientGetClientAppList = 5518
k_EMsgClientGetClientAppListResponse = 5519
k_EMsgClientInstallClientApp = 5520
k_EMsgClientInstallClientAppResponse = 5521
k_EMsgClientUninstallClientApp = 5522
k_EMsgClientUninstallClientAppResponse = 5523
k_EMsgClientSetClientAppUpdateState = 5524
k_EMsgClientSetClientAppUpdateStateResponse = 5525
k_EMsgClientRequestEncryptedAppTicket = 5526
k_EMsgClientRequestEncryptedAppTicketResponse = 5527
k_EMsgClientWalletInfoUpdate = 5528
k_EMsgClientLBSSetUGC = 5529
k_EMsgClientLBSSetUGCResponse = 5530
k_EMsgClientAMGetClanOfficers = 5531
k_EMsgClientAMGetClanOfficersResponse = 5532
k_EMsgClientFriendProfileInfo = 5535
k_EMsgClientFriendProfileInfoResponse = 5536
k_EMsgClientUpdateMachineAuth = 5537
k_EMsgClientUpdateMachineAuthResponse = 5538
k_EMsgClientReadMachineAuth = 5539
k_EMsgClientReadMachineAuthResponse = 5540
k_EMsgClientRequestMachineAuth = 5541
k_EMsgClientRequestMachineAuthResponse = 5542
k_EMsgClientScreenshotsChanged = 5543
k_EMsgClientGetCDNAuthToken = 5546
k_EMsgClientGetCDNAuthTokenResponse = 5547
k_EMsgClientDownloadRateStatistics = 5548
k_EMsgClientRequestAccountData = 5549
k_EMsgClientRequestAccountDataResponse = 5550
k_EMsgClientResetForgottenPassword4 = 5551
k_EMsgClientHideFriend = 5552
k_EMsgClientFriendsGroupsList = 5553
k_EMsgClientGetClanActivityCounts = 5554
k_EMsgClientGetClanActivityCountsResponse = 5555
k_EMsgClientOGSReportString = 5556
k_EMsgClientOGSReportBug = 5557
k_EMsgClientSentLogs = 5558
k_EMsgClientLogonGameServer = 5559
k_EMsgAMClientCreateFriendsGroup = 5560
k_EMsgAMClientCreateFriendsGroupResponse = 5561
k_EMsgAMClientDeleteFriendsGroup = 5562
k_EMsgAMClientDeleteFriendsGroupResponse = 5563
k_EMsgAMClientManageFriendsGroup = 5564
k_EMsgAMClientManageFriendsGroupResponse = 5565
k_EMsgAMClientAddFriendToGroup = 5566
k_EMsgAMClientAddFriendToGroupResponse = 5567
k_EMsgAMClientRemoveFriendFromGroup = 5568
k_EMsgAMClientRemoveFriendFromGroupResponse = 5569
k_EMsgClientAMGetPersonaNameHistory = 5570
k_EMsgClientAMGetPersonaNameHistoryResponse = 5571
k_EMsgClientRequestFreeLicense = 5572
k_EMsgClientRequestFreeLicenseResponse = 5573
k_EMsgClientDRMDownloadRequestWithCrashData = 5574
k_EMsgClientAuthListAck = 5575
k_EMsgClientItemAnnouncements = 5576
k_EMsgClientRequestItemAnnouncements = 5577
k_EMsgClientFriendMsgEchoToSender = 5578
k_EMsgClientCommentNotifications = 5582
k_EMsgClientRequestCommentNotifications = 5583
k_EMsgClientPersonaChangeResponse = 5584
k_EMsgClientRequestWebAPIAuthenticateUserNonce = 5585
k_EMsgClientRequestWebAPIAuthenticateUserNonceResponse = 5586
k_EMsgClientPlayerNicknameList = 5587
k_EMsgAMClientSetPlayerNickname = 5588
k_EMsgAMClientSetPlayerNicknameResponse = 5589
k_EMsgClientGetNumberOfCurrentPlayersDP = 5592
k_EMsgClientGetNumberOfCurrentPlayersDPResponse = 5593
k_EMsgClientServiceMethodLegacy = 5594
k_EMsgClientServiceMethodLegacyResponse = 5595
k_EMsgClientFriendUserStatusPublished = 5596
k_EMsgClientCurrentUIMode = 5597
k_EMsgClientVanityURLChangedNotification = 5598
k_EMsgClientUserNotifications = 5599
k_EMsgBaseDFS = 5600
k_EMsgDFSGetFile = 5601
k_EMsgDFSInstallLocalFile = 5602
k_EMsgDFSConnection = 5603
k_EMsgDFSConnectionReply = 5604
k_EMsgClientDFSAuthenticateRequest = 5605
k_EMsgClientDFSAuthenticateResponse = 5606
k_EMsgClientDFSEndSession = 5607
k_EMsgDFSPurgeFile = 5608
k_EMsgDFSRouteFile = 5609
k_EMsgDFSGetFileFromServer = 5610
k_EMsgDFSAcceptedResponse = 5611
k_EMsgDFSRequestPingback = 5612
k_EMsgDFSRecvTransmitFile = 5613
k_EMsgDFSSendTransmitFile = 5614
k_EMsgDFSRequestPingback2 = 5615
k_EMsgDFSResponsePingback2 = 5616
k_EMsgClientDFSDownloadStatus = 5617
k_EMsgDFSStartTransfer = 5618
k_EMsgDFSTransferComplete = 5619
k_EMsgDFSRouteFileResponse = 5620
k_EMsgClientNetworkingCertRequest = 5621
k_EMsgClientNetworkingCertRequestResponse = 5622
k_EMsgClientChallengeRequest = 5623
k_EMsgClientChallengeResponse = 5624
k_EMsgBadgeCraftedNotification = 5625
k_EMsgClientNetworkingMobileCertRequest = 5626
k_EMsgClientNetworkingMobileCertRequestResponse = 5627
k_EMsgBaseMDS = 5800
k_EMsgMDSGetDepotDecryptionKey = 5812
k_EMsgMDSGetDepotDecryptionKeyResponse = 5813
k_EMsgMDSContentServerConfigRequest = 5827
k_EMsgMDSContentServerConfig = 5828
k_EMsgMDSGetDepotManifest = 5829
k_EMsgMDSGetDepotManifestResponse = 5830
k_EMsgMDSGetDepotManifestChunk = 5831
k_EMsgMDSGetDepotChunk = 5832
k_EMsgMDSGetDepotChunkResponse = 5833
k_EMsgMDSGetDepotChunkChunk = 5834
k_EMsgMDSToCSFlushChunk = 5844
k_EMsgMDSMigrateChunk = 5847
k_EMsgMDSMigrateChunkResponse = 5848
k_EMsgMDSToCSFlushManifest = 5849
k_EMsgCSBase = 6200
k_EMsgCSPing = 6201
k_EMsgCSPingResponse = 6202
k_EMsgGMSBase = 6400
k_EMsgGMSGameServerReplicate = 6401
k_EMsgClientGMSServerQuery = 6403
k_EMsgGMSClientServerQueryResponse = 6404
k_EMsgAMGMSGameServerUpdate = 6405
k_EMsgAMGMSGameServerRemove = 6406
k_EMsgGameServerOutOfDate = 6407
k_EMsgDeviceAuthorizationBase = 6500
k_EMsgClientAuthorizeLocalDeviceRequest = 6501
k_EMsgClientAuthorizeLocalDeviceResponse = 6502
k_EMsgClientDeauthorizeDeviceRequest = 6503
k_EMsgClientDeauthorizeDevice = 6504
k_EMsgClientUseLocalDeviceAuthorizations = 6505
k_EMsgClientGetAuthorizedDevices = 6506
k_EMsgClientGetAuthorizedDevicesResponse = 6507
k_EMsgAMNotifySessionDeviceAuthorized = 6508
k_EMsgClientAuthorizeLocalDeviceNotification = 6509
k_EMsgMMSBase = 6600
k_EMsgClientMMSCreateLobby = 6601
k_EMsgClientMMSCreateLobbyResponse = 6602
k_EMsgClientMMSJoinLobby = 6603
k_EMsgClientMMSJoinLobbyResponse = 6604
k_EMsgClientMMSLeaveLobby = 6605
k_EMsgClientMMSLeaveLobbyResponse = 6606
k_EMsgClientMMSGetLobbyList = 6607
k_EMsgClientMMSGetLobbyListResponse = 6608
k_EMsgClientMMSSetLobbyData = 6609
k_EMsgClientMMSSetLobbyDataResponse = 6610
k_EMsgClientMMSGetLobbyData = 6611
k_EMsgClientMMSLobbyData = 6612
k_EMsgClientMMSSendLobbyChatMsg = 6613
k_EMsgClientMMSLobbyChatMsg = 6614
k_EMsgClientMMSSetLobbyOwner = 6615
k_EMsgClientMMSSetLobbyOwnerResponse = 6616
k_EMsgClientMMSSetLobbyGameServer = 6617
k_EMsgClientMMSLobbyGameServerSet = 6618
k_EMsgClientMMSUserJoinedLobby = 6619
k_EMsgClientMMSUserLeftLobby = 6620
k_EMsgClientMMSInviteToLobby = 6621
k_EMsgClientMMSFlushFrenemyListCache = 6622
k_EMsgClientMMSFlushFrenemyListCacheResponse = 6623
k_EMsgClientMMSSetLobbyLinked = 6624
k_EMsgClientMMSSetRatelimitPolicyOnClient = 6625
k_EMsgClientMMSGetLobbyStatus = 6626
k_EMsgClientMMSGetLobbyStatusResponse = 6627
k_EMsgMMSGetLobbyList = 6628
k_EMsgMMSGetLobbyListResponse = 6629
k_EMsgNonStdMsgBase = 6800
k_EMsgNonStdMsgMemcached = 6801
k_EMsgNonStdMsgHTTPServer = 6802
k_EMsgNonStdMsgHTTPClient = 6803
k_EMsgNonStdMsgWGResponse = 6804
k_EMsgNonStdMsgPHPSimulator = 6805
k_EMsgNonStdMsgChase = 6806
k_EMsgNonStdMsgDFSTransfer = 6807
k_EMsgNonStdMsgTests = 6808
k_EMsgNonStdMsgUMQpipeAAPL = 6809
k_EMSgNonStdMsgSyslog = 6810
k_EMsgNonStdMsgLogsink = 6811
k_EMsgNonStdMsgSteam2Emulator = 6812
k_EMsgNonStdMsgRTMPServer = 6813
k_EMsgNonStdMsgWebSocket = 6814
k_EMsgNonStdMsgRedis = 6815
k_EMsgUDSBase = 7000
k_EMsgClientUDSP2PSessionStarted = 7001
k_EMsgClientUDSP2PSessionEnded = 7002
k_EMsgUDSRenderUserAuth = 7003
k_EMsgUDSRenderUserAuthResponse = 7004
k_EMsgClientInviteToGame = 7005
k_EMsgUDSHasSession = 7006
k_EMsgUDSHasSessionResponse = 7007
k_EMsgMPASBase = 7100
k_EMsgMPASVacBanReset = 7101
k_EMsgKGSBase = 7200
k_EMsgUCMBase = 7300
k_EMsgClientUCMAddScreenshot = 7301
k_EMsgClientUCMAddScreenshotResponse = 7302
k_EMsgUCMResetCommunityContent = 7307
k_EMsgUCMResetCommunityContentResponse = 7308
k_EMsgClientUCMDeleteScreenshot = 7309
k_EMsgClientUCMDeleteScreenshotResponse = 7310
k_EMsgClientUCMPublishFile = 7311
k_EMsgClientUCMPublishFileResponse = 7312
k_EMsgClientUCMDeletePublishedFile = 7315
k_EMsgClientUCMDeletePublishedFileResponse = 7316
k_EMsgClientUCMUpdatePublishedFile = 7325
k_EMsgClientUCMUpdatePublishedFileResponse = 7326
k_EMsgUCMUpdatePublishedFile = 7327
k_EMsgUCMUpdatePublishedFileResponse = 7328
k_EMsgUCMDeletePublishedFile = 7329
k_EMsgUCMDeletePublishedFileResponse = 7330
k_EMsgUCMUpdatePublishedFileStat = 7331
k_EMsgUCMReloadPublishedFile = 7337
k_EMsgUCMReloadUserFileListCaches = 7338
k_EMsgUCMPublishedFileReported = 7339
k_EMsgUCMPublishedFilePreviewAdd = 7341
k_EMsgUCMPublishedFilePreviewAddResponse = 7342
k_EMsgUCMPublishedFilePreviewRemove = 7343
k_EMsgUCMPublishedFilePreviewRemoveResponse = 7344
k_EMsgUCMPublishedFileSubscribed = 7349
k_EMsgUCMPublishedFileUnsubscribed = 7350
k_EMsgUCMPublishFile = 7351
k_EMsgUCMPublishFileResponse = 7352
k_EMsgUCMPublishedFileChildAdd = 7353
k_EMsgUCMPublishedFileChildAddResponse = 7354
k_EMsgUCMPublishedFileChildRemove = 7355
k_EMsgUCMPublishedFileChildRemoveResponse = 7356
k_EMsgUCMPublishedFileParentChanged = 7359
k_EMsgClientUCMSetUserPublishedFileAction = 7364
k_EMsgClientUCMSetUserPublishedFileActionResponse = 7365
k_EMsgClientUCMEnumeratePublishedFilesByUserAction = 7366
k_EMsgClientUCMEnumeratePublishedFilesByUserActionResponse = 7367
k_EMsgUCMGetUserSubscribedFiles = 7369
k_EMsgUCMGetUserSubscribedFilesResponse = 7370
k_EMsgUCMFixStatsPublishedFile = 7371
k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdates = 7378
k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse = 7379
k_EMsgUCMPublishedFileContentUpdated = 7380
k_EMsgClientUCMPublishedFileUpdated = 7381
k_EMsgClientWorkshopItemChangesRequest = 7382
k_EMsgClientWorkshopItemChangesResponse = 7383
k_EMsgFSBase = 7500
k_EMsgClientRichPresenceUpload = 7501
k_EMsgClientRichPresenceRequest = 7502
k_EMsgClientRichPresenceInfo = 7503
k_EMsgFSRichPresenceRequest = 7504
k_EMsgFSRichPresenceResponse = 7505
k_EMsgFSComputeFrenematrix = 7506
k_EMsgFSComputeFrenematrixResponse = 7507
k_EMsgFSPlayStatusNotification = 7508
k_EMsgFSAddOrRemoveFollower = 7510
k_EMsgFSAddOrRemoveFollowerResponse = 7511
k_EMsgFSUpdateFollowingList = 7512
k_EMsgFSCommentNotification = 7513
k_EMsgFSCommentNotificationViewed = 7514
k_EMsgClientFSGetFollowerCount = 7515
k_EMsgClientFSGetFollowerCountResponse = 7516
k_EMsgClientFSGetIsFollowing = 7517
k_EMsgClientFSGetIsFollowingResponse = 7518
k_EMsgClientFSEnumerateFollowingList = 7519
k_EMsgClientFSEnumerateFollowingListResponse = 7520
k_EMsgFSGetPendingNotificationCount = 7521
k_EMsgFSGetPendingNotificationCountResponse = 7522
k_EMsgClientChatOfflineMessageNotification = 7523
k_EMsgClientChatRequestOfflineMessageCount = 7524
k_EMsgClientChatGetFriendMessageHistory = 7525
k_EMsgClientChatGetFriendMessageHistoryResponse = 7526
k_EMsgClientChatGetFriendMessageHistoryForOfflineMessages = 7527
k_EMsgClientFSGetFriendsSteamLevels = 7528
k_EMsgClientFSGetFriendsSteamLevelsResponse = 7529
k_EMsgAMRequestFriendData = 7530
k_EMsgDRMRange2 = 7600
k_EMsgCEGVersionSetEnableDisableRequest = 7600
k_EMsgCEGVersionSetEnableDisableResponse = 7601
k_EMsgCEGPropStatusDRMSRequest = 7602
k_EMsgCEGPropStatusDRMSResponse = 7603
k_EMsgCEGWhackFailureReportRequest = 7604
k_EMsgCEGWhackFailureReportResponse = 7605
k_EMsgDRMSFetchVersionSet = 7606
k_EMsgDRMSFetchVersionSetResponse = 7607
k_EMsgEconBase = 7700
k_EMsgEconTrading_InitiateTradeRequest = 7701
k_EMsgEconTrading_InitiateTradeProposed = 7702
k_EMsgEconTrading_InitiateTradeResponse = 7703
k_EMsgEconTrading_InitiateTradeResult = 7704
k_EMsgEconTrading_StartSession = 7705
k_EMsgEconTrading_CancelTradeRequest = 7706
k_EMsgEconFlushInventoryCache = 7707
k_EMsgEconFlushInventoryCacheResponse = 7708
k_EMsgEconCDKeyProcessTransaction = 7711
k_EMsgEconCDKeyProcessTransactionResponse = 7712
k_EMsgEconGetErrorLogs = 7713
k_EMsgEconGetErrorLogsResponse = 7714
k_EMsgRMRange = 7800
k_EMsgRMTestVerisignOTP = 7800
k_EMsgRMTestVerisignOTPResponse = 7801
k_EMsgRMDeleteMemcachedKeys = 7803
k_EMsgRMRemoteInvoke = 7804
k_EMsgBadLoginIPList = 7805
k_EMsgRMMsgTraceAddTrigger = 7806
k_EMsgRMMsgTraceRemoveTrigger = 7807
k_EMsgRMMsgTraceEvent = 7808
k_EMsgUGSBase = 7900
k_EMsgUGSUpdateGlobalStats = 7900
k_EMsgClientUGSGetGlobalStats = 7901
k_EMsgClientUGSGetGlobalStatsResponse = 7902
k_EMsgStoreBase = 8000
k_EMsgUMQBase = 8100
k_EMsgUMQLogonRequest = 8100
k_EMsgUMQLogonResponse = 8101
k_EMsgUMQLogoffRequest = 8102
k_EMsgUMQLogoffResponse = 8103
k_EMsgUMQSendChatMessage = 8104
k_EMsgUMQIncomingChatMessage = 8105
k_EMsgUMQPoll = 8106
k_EMsgUMQPollResults = 8107
k_EMsgUMQ2AM_ClientMsgBatch = 8108
k_EMsgWorkshopBase = 8200
k_EMsgWebAPIBase = 8300
k_EMsgWebAPIValidateOAuth2Token = 8300
k_EMsgWebAPIValidateOAuth2TokenResponse = 8301
k_EMsgWebAPIRegisterGCInterfaces = 8303
k_EMsgWebAPIInvalidateOAuthClientCache = 8304
k_EMsgWebAPIInvalidateOAuthTokenCache = 8305
k_EMsgWebAPISetSecrets = 8306
k_EMsgBackpackBase = 8400
k_EMsgBackpackAddToCurrency = 8401
k_EMsgBackpackAddToCurrencyResponse = 8402
k_EMsgCREBase = 8500
k_EMsgCREItemVoteSummary = 8503
k_EMsgCREItemVoteSummaryResponse = 8504
k_EMsgCREUpdateUserPublishedItemVote = 8507
k_EMsgCREUpdateUserPublishedItemVoteResponse = 8508
k_EMsgCREGetUserPublishedItemVoteDetails = 8509
k_EMsgCREGetUserPublishedItemVoteDetailsResponse = 8510
k_EMsgSecretsBase = 8600
k_EMsgSecretsRequestCredentialPair = 8600
k_EMsgSecretsCredentialPairResponse = 8601
k_EMsgBoxMonitorBase = 8700
k_EMsgBoxMonitorReportRequest = 8700
k_EMsgBoxMonitorReportResponse = 8701
k_EMsgLogsinkBase = 8800
k_EMsgLogsinkWriteReport = 8800
k_EMsgPICSBase = 8900
k_EMsgClientPICSChangesSinceRequest = 8901
k_EMsgClientPICSChangesSinceResponse = 8902
k_EMsgClientPICSProductInfoRequest = 8903
k_EMsgClientPICSProductInfoResponse = 8904
k_EMsgClientPICSAccessTokenRequest = 8905
k_EMsgClientPICSAccessTokenResponse = 8906
k_EMsgWorkerProcess = 9000
k_EMsgWorkerProcessPingRequest = 9000
k_EMsgWorkerProcessPingResponse = 9001
k_EMsgWorkerProcessShutdown = 9002
k_EMsgDRMWorkerProcess = 9100
k_EMsgDRMWorkerProcessDRMAndSign = 9100
k_EMsgDRMWorkerProcessDRMAndSignResponse = 9101
k_EMsgDRMWorkerProcessSteamworksInfoRequest = 9102
k_EMsgDRMWorkerProcessSteamworksInfoResponse = 9103
k_EMsgDRMWorkerProcessInstallDRMDLLRequest = 9104
k_EMsgDRMWorkerProcessInstallDRMDLLResponse = 9105
k_EMsgDRMWorkerProcessSecretIdStringRequest = 9106
k_EMsgDRMWorkerProcessSecretIdStringResponse = 9107
k_EMsgDRMWorkerProcessInstallProcessedFilesRequest = 9110
k_EMsgDRMWorkerProcessInstallProcessedFilesResponse = 9111
k_EMsgDRMWorkerProcessExamineBlobRequest = 9112
k_EMsgDRMWorkerProcessExamineBlobResponse = 9113
k_EMsgDRMWorkerProcessDescribeSecretRequest = 9114
k_EMsgDRMWorkerProcessDescribeSecretResponse = 9115
k_EMsgDRMWorkerProcessBackfillOriginalRequest = 9116
k_EMsgDRMWorkerProcessBackfillOriginalResponse = 9117
k_EMsgDRMWorkerProcessValidateDRMDLLRequest = 9118
k_EMsgDRMWorkerProcessValidateDRMDLLResponse = 9119
k_EMsgDRMWorkerProcessValidateFileRequest = 9120
k_EMsgDRMWorkerProcessValidateFileResponse = 9121
k_EMsgDRMWorkerProcessSplitAndInstallRequest = 9122
k_EMsgDRMWorkerProcessSplitAndInstallResponse = 9123
k_EMsgDRMWorkerProcessGetBlobRequest = 9124
k_EMsgDRMWorkerProcessGetBlobResponse = 9125
k_EMsgDRMWorkerProcessEvaluateCrashRequest = 9126
k_EMsgDRMWorkerProcessEvaluateCrashResponse = 9127
k_EMsgDRMWorkerProcessAnalyzeFileRequest = 9128
k_EMsgDRMWorkerProcessAnalyzeFileResponse = 9129
k_EMsgDRMWorkerProcessUnpackBlobRequest = 9130
k_EMsgDRMWorkerProcessUnpackBlobResponse = 9131
k_EMsgDRMWorkerProcessInstallAllRequest = 9132
k_EMsgDRMWorkerProcessInstallAllResponse = 9133
k_EMsgTestWorkerProcess = 9200
k_EMsgTestWorkerProcessLoadUnloadModuleRequest = 9200
k_EMsgTestWorkerProcessLoadUnloadModuleResponse = 9201
k_EMsgTestWorkerProcessServiceModuleCallRequest = 9202
k_EMsgTestWorkerProcessServiceModuleCallResponse = 9203
k_EMsgQuestServerBase = 9300
k_EMsgClientGetEmoticonList = 9330
k_EMsgClientEmoticonList = 9331
k_EMsgSLCBase = 9400
k_EMsgSLCUserSessionStatus = 9400
k_EMsgSLCRequestUserSessionStatus = 9401
k_EMsgSLCSharedLicensesLockStatus = 9402
k_EMsgClientSharedLibraryLockStatus = 9405
k_EMsgClientSharedLibraryStopPlaying = 9406
k_EMsgSLCOwnerLibraryChanged = 9407
k_EMsgSLCSharedLibraryChanged = 9408
k_EMsgRemoteClientBase = 9500
k_EMsgRemoteClientAuth_OBSOLETE = 9500
k_EMsgRemoteClientAuthResponse_OBSOLETE = 9501
k_EMsgRemoteClientAppStatus = 9502
k_EMsgRemoteClientStartStream = 9503
k_EMsgRemoteClientStartStreamResponse = 9504
k_EMsgRemoteClientPing = 9505
k_EMsgRemoteClientPingResponse = 9506
k_EMsgClientUnlockStreaming = 9507
k_EMsgClientUnlockStreamingResponse = 9508
k_EMsgRemoteClientAcceptEULA = 9509
k_EMsgRemoteClientGetControllerConfig = 9510
k_EMsgRemoteClientGetControllerConfigResponse = 9511
k_EMsgRemoteClientStreamingEnabled = 9512
k_EMsgClientUnlockHEVC = 9513
k_EMsgClientUnlockHEVCResponse = 9514
k_EMsgRemoteClientStatusRequest = 9515
k_EMsgRemoteClientStatusResponse = 9516
k_EMsgClientConcurrentSessionsBase = 9600
k_EMsgClientPlayingSessionState = 9600
k_EMsgClientKickPlayingSession = 9601
k_EMsgClientBroadcastBase = 9700
k_EMsgClientBroadcastInit = 9700
k_EMsgClientBroadcastFrames = 9701
k_EMsgClientBroadcastDisconnect = 9702
k_EMsgClientBroadcastScreenshot = 9703
k_EMsgClientBroadcastUploadConfig = 9704
k_EMsgBaseClient3 = 9800
k_EMsgClientVoiceCallPreAuthorize = 9800
k_EMsgClientVoiceCallPreAuthorizeResponse = 9801
k_EMsgClientServerTimestampRequest = 9802
k_EMsgClientServerTimestampResponse = 9803
k_EMsgServiceMethodCallFromClientNonAuthed = 9804
k_EMsgClientHello = 9805
k_EMsgClientEnableOrDisableDownloads = 9806
k_EMsgClientEnableOrDisableDownloadsResponse = 9807
k_EMsgClientLANP2PBase = 9900
k_EMsgClientLANP2PRequestChunk = 9900
k_EMsgClientLANP2PRequestChunkResponse = 9901
k_EMsgClientLANP2PMax = 9999
k_EMsgBaseWatchdogServer = 10000
k_EMsgNotifyWatchdog = 10000
k_EMsgClientSiteLicenseBase = 10100
k_EMsgClientSiteLicenseSiteInfoNotification = 10100
k_EMsgClientSiteLicenseCheckout = 10101
k_EMsgClientSiteLicenseCheckoutResponse = 10102
k_EMsgClientSiteLicenseGetAvailableSeats = 10103
k_EMsgClientSiteLicenseGetAvailableSeatsResponse = 10104
k_EMsgClientSiteLicenseGetContentCacheInfo = 10105
k_EMsgClientSiteLicenseGetContentCacheInfoResponse = 10106
k_EMsgBaseChatServer = 12000
k_EMsgChatServerGetPendingNotificationCount = 12000
k_EMsgChatServerGetPendingNotificationCountResponse = 12001
k_EMsgBaseSecretServer = 12100
k_EMsgServerSecretChanged = 12100
k_EClientPersonaStateFlagStatus = 1
k_EClientPersonaStateFlagPlayerName = 2
k_EClientPersonaStateFlagQueryPort = 4
k_EClientPersonaStateFlagSourceID = 8
k_EClientPersonaStateFlagPresence = 16
k_EClientPersonaStateFlagLastSeen = 64
k_EClientPersonaStateFlagUserClanRank = 128
k_EClientPersonaStateGameExtraInfo = 256
k_EClientPersonaStateGameDataBlob = 512
k_EClientPersonaStateFlagClanData = 1024
k_EClientPersonaStateFlagFacebook = 2048
k_EClientPersonaStateFlagRichPresence = 4096
k_EClientPersonaStateFlagBroadcast = 8192
k_EClientPersonaStateFlagWatching = 16384
k_EMsgClanAccountFlagPublic = 1
k_EMsgClanAccountFlagLarge = 2
k_EMsgClanAccountFlagLocked = 4
k_EMsgClanAccountFlagDisabled = 8
k_EMsgClanAccountFlagOGG = 16
k_ESteamReviewScore_OverwhelminglyPositive = 9
k_ESteamReviewScore_VeryPositive = 8
k_ESteamReviewScore_Positive = 7
k_ESteamReviewScore_MostlyPositive = 6
k_ESteamReviewScore_Mixed = 5
k_ESteamReviewScore_MostlyNegative = 4
k_ESteamReviewScore_Negative = 3
k_ESteamReviewScore_VeryNegative = 2
k_ESteamReviewScore_OverwhelminglyNegative = 1
k_ESteamReviewScore_None = 0


DESCRIPTOR.enum_types_by_name['EMsg'] = _EMSG
DESCRIPTOR.enum_types_by_name['EClientPersonaStateFlag'] = _ECLIENTPERSONASTATEFLAG
DESCRIPTOR.enum_types_by_name['EMsgClanAccountFlags'] = _EMSGCLANACCOUNTFLAGS
DESCRIPTOR.enum_types_by_name['ESteamReviewScore'] = _ESTEAMREVIEWSCORE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
_EMSG._options = None
# @@protoc_insertion_point(module_scope)
