# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_2.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"steammessages_clientserver_2.proto\x1a\x18steammessages_base.proto\"w\n\x1c\x43MsgClientUpdateUserGameInfo\x12\x14\n\x0csteamid_idgs\x18\x01 \x01(\x06\x12\x0e\n\x06gameid\x18\x02 \x01(\x06\x12\x0f\n\x07game_ip\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\r\n\x05token\x18\x05 \x01(\x0c\"S\n\x1c\x43MsgClientRichPresenceUpload\x12\x18\n\x10rich_presence_kv\x18\x01 \x01(\x0c\x12\x19\n\x11steamid_broadcast\x18\x02 \x03(\x06\"8\n\x1d\x43MsgClientRichPresenceRequest\x12\x17\n\x0fsteamid_request\x18\x01 \x03(\x06\"\x9d\x01\n\x1a\x43MsgClientRichPresenceInfo\x12?\n\rrich_presence\x18\x01 \x03(\x0b\x32(.CMsgClientRichPresenceInfo.RichPresence\x1a>\n\x0cRichPresence\x12\x14\n\x0csteamid_user\x18\x01 \x01(\x06\x12\x18\n\x10rich_presence_kv\x18\x02 \x01(\x0c\".\n\x1c\x43MsgClientCheckFileSignature\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"\xf7\x01\n$CMsgClientCheckFileSignatureResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x0f\n\x07\x65result\x18\x03 \x01(\r\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x18\n\x10\x65signatureresult\x18\x05 \x01(\r\x12\x10\n\x08sha_file\x18\x06 \x01(\x0c\x12\x17\n\x0fsignatureheader\x18\x07 \x01(\x0c\x12\x10\n\x08\x66ilesize\x18\x08 \x01(\r\x12\x14\n\x0cgetlasterror\x18\t \x01(\r\x12\"\n\x1a\x65valvesignaturecheckdetail\x18\n \x01(\r\"P\n\x19\x43MsgClientReadMachineAuth\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x11\n\tcubtoread\x18\x03 \x01(\r\"\xce\x01\n!CMsgClientReadMachineAuthResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\x12\x10\n\x08\x66ilesize\x18\x03 \x01(\r\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x14\n\x0cgetlasterror\x18\x05 \x01(\r\x12\x0e\n\x06offset\x18\x06 \x01(\r\x12\x0f\n\x07\x63ubread\x18\x07 \x01(\r\x12\x12\n\nbytes_read\x18\x08 \x01(\x0c\x12\x17\n\x0f\x66ilename_sentry\x18\t \x01(\t\"\xbd\x01\n\x1b\x43MsgClientUpdateMachineAuth\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x12\n\ncubtowrite\x18\x03 \x01(\r\x12\r\n\x05\x62ytes\x18\x04 \x01(\x0c\x12\x10\n\x08otp_type\x18\x05 \x01(\r\x12\x16\n\x0eotp_identifier\x18\x06 \x01(\t\x12\x18\n\x10otp_sharedsecret\x18\x07 \x01(\x0c\x12\x15\n\rotp_timedrift\x18\x08 \x01(\r\"\xe1\x01\n#CMsgClientUpdateMachineAuthResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\x12\x10\n\x08\x66ilesize\x18\x03 \x01(\r\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x14\n\x0cgetlasterror\x18\x05 \x01(\r\x12\x0e\n\x06offset\x18\x06 \x01(\r\x12\x10\n\x08\x63ubwrote\x18\x07 \x01(\r\x12\x10\n\x08otp_type\x18\x08 \x01(\x05\x12\x11\n\totp_value\x18\t \x01(\r\x12\x16\n\x0eotp_identifier\x18\n \x01(\t\"\xa1\x02\n\x1c\x43MsgClientRequestMachineAuth\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x1a\n\x12\x65result_sentryfile\x18\x02 \x01(\r\x12\x10\n\x08\x66ilesize\x18\x03 \x01(\r\x12\x16\n\x0esha_sentryfile\x18\x04 \x01(\x0c\x12\x1b\n\x13lock_account_action\x18\x06 \x01(\x05\x12\x10\n\x08otp_type\x18\x07 \x01(\r\x12\x16\n\x0eotp_identifier\x18\x08 \x01(\t\x12\x18\n\x10otp_sharedsecret\x18\t \x01(\x0c\x12\x11\n\totp_value\x18\n \x01(\r\x12\x14\n\x0cmachine_name\x18\x0b \x01(\t\x12\x1f\n\x17machine_name_userchosen\x18\x0c \x01(\t\"7\n$CMsgClientRequestMachineAuthResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"$\n\x15\x43MsgClientRegisterKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"p\n\x1a\x43MsgClientPurchaseResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17purchase_result_details\x18\x02 \x01(\x05\x12\x1d\n\x15purchase_receipt_info\x18\x03 \x01(\x0c\"\xc5\x01\n\x1c\x43MsgClientActivateOEMLicense\x12\x19\n\x11\x62ios_manufacturer\x18\x01 \x01(\t\x12\x19\n\x11\x62ios_serialnumber\x18\x02 \x01(\t\x12\x14\n\x0clicense_file\x18\x03 \x01(\x0c\x12\x1e\n\x16mainboard_manufacturer\x18\x04 \x01(\t\x12\x19\n\x11mainboard_product\x18\x05 \x01(\t\x12\x1e\n\x16mainboard_serialnumber\x18\x06 \x01(\t\"9\n\x1c\x43MsgClientRegisterOEMMachine\x12\x19\n\x11oem_register_file\x18\x01 \x01(\x0c\"7\n$CMsgClientRegisterOEMMachineResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"K\n\x1f\x43MsgClientPurchaseWithMachineID\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x14\n\x0cmachine_info\x18\x02 \x01(\x0c\"g\n CMsgTrading_InitiateTradeRequest\x12\x18\n\x10trade_request_id\x18\x01 \x01(\r\x12\x15\n\rother_steamid\x18\x02 \x01(\x04\x12\x12\n\nother_name\x18\x03 \x01(\t\"\xd2\x02\n!CMsgTrading_InitiateTradeResponse\x12\x10\n\x08response\x18\x01 \x01(\r\x12\x18\n\x10trade_request_id\x18\x02 \x01(\r\x12\x15\n\rother_steamid\x18\x03 \x01(\x04\x12 \n\x18steamguard_required_days\x18\x04 \x01(\r\x12 \n\x18new_device_cooldown_days\x18\x05 \x01(\r\x12-\n%default_password_reset_probation_days\x18\x06 \x01(\r\x12%\n\x1dpassword_reset_probation_days\x18\x07 \x01(\r\x12+\n#default_email_change_probation_days\x18\x08 \x01(\r\x12#\n\x1b\x65mail_change_probation_days\x18\t \x01(\r\"7\n\x1e\x43MsgTrading_CancelTradeRequest\x12\x15\n\rother_steamid\x18\x01 \x01(\x04\"1\n\x18\x43MsgTrading_StartSession\x12\x15\n\rother_steamid\x18\x01 \x01(\x04\"P\n\x19\x43MsgClientGetCDNAuthToken\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"C\n\x1f\x43MsgClientGetDepotDecryptionKey\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"m\n\'CMsgClientGetDepotDecryptionKeyResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x1c\n\x14\x64\x65pot_encryption_key\x18\x03 \x01(\x0c\"X\n\x1e\x43MsgClientCheckAppBetaPassword\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x14\n\x0c\x62\x65tapassword\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\x05\"\xda\x01\n&CMsgClientCheckAppBetaPasswordResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12K\n\rbetapasswords\x18\x04 \x03(\x0b\x32\x34.CMsgClientCheckAppBetaPasswordResponse.BetaPassword\x1aO\n\x0c\x42\x65taPassword\x12\x10\n\x08\x62\x65taname\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x65tapassword\x18\x02 \x01(\t\x12\x17\n\x0f\x62\x65tadescription\x18\x03 \x01(\t\"\xbe\x04\n\x1c\x43MsgClientUpdateAppJobReport\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tdepot_ids\x18\x02 \x03(\r\x12\x11\n\tapp_state\x18\x03 \x01(\r\x12\x15\n\rjob_app_error\x18\x04 \x01(\r\x12\x15\n\rerror_details\x18\x05 \x01(\t\x12\x14\n\x0cjob_duration\x18\x06 \x01(\r\x12\x1f\n\x17\x66iles_validation_failed\x18\x07 \x01(\r\x12\x1c\n\x14job_bytes_downloaded\x18\x08 \x01(\x04\x12\x18\n\x10job_bytes_staged\x18\t \x01(\x04\x12\x16\n\x0e\x62ytes_comitted\x18\n \x01(\x04\x12\x17\n\x0fstart_app_state\x18\x0b \x01(\r\x12\x18\n\x10stats_machine_id\x18\x0c \x01(\x06\x12\x13\n\x0b\x62ranch_name\x18\r \x01(\t\x12\x1e\n\x16total_bytes_downloaded\x18\x0e \x01(\x04\x12\x1a\n\x12total_bytes_staged\x18\x0f \x01(\x04\x12\x1c\n\x14total_bytes_restored\x18\x10 \x01(\x04\x12\x13\n\x0bis_borrowed\x18\x11 \x01(\x08\x12\x17\n\x0fis_free_weekend\x18\x12 \x01(\x08\x12\x1a\n\x12total_bytes_legacy\x18\x13 \x01(\x04\x12\x1b\n\x13total_bytes_patched\x18\x14 \x01(\x04\x12\x19\n\x11total_bytes_saved\x18\x15 \x01(\x04\x12\x0f\n\x07\x63\x65ll_id\x18\x16 \x01(\r\"\xcb\x01\n\x1e\x43MsgClientDPContentStatsReport\x12\x18\n\x10stats_machine_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x0f\n\x07os_type\x18\x03 \x01(\x05\x12\x10\n\x08language\x18\x04 \x01(\x05\x12\x1b\n\x13num_install_folders\x18\x05 \x01(\r\x12\x1b\n\x13num_installed_games\x18\x06 \x01(\r\x12\x1c\n\x14size_installed_games\x18\x07 \x01(\x04\"_\n!CMsgClientGetCDNAuthTokenResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05token\x18\x02 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x03 \x01(\r\"\xb4\x02\n\x1a\x43MsgDownloadRateStatistics\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x34\n\x05stats\x18\x02 \x03(\x0b\x32%.CMsgDownloadRateStatistics.StatsInfo\x12\x17\n\x0fthrottling_kbps\x18\x03 \x01(\r\x12\x13\n\x0bsteam_realm\x18\x04 \x01(\r\x1a\xa0\x01\n\tStatsInfo\x12\x13\n\x0bsource_type\x18\x01 \x01(\r\x12\x11\n\tsource_id\x18\x02 \x01(\r\x12\x0f\n\x07seconds\x18\x03 \x01(\r\x12\r\n\x05\x62ytes\x18\x04 \x01(\x04\x12\x11\n\thost_name\x18\x05 \x01(\t\x12\x14\n\x0cmicroseconds\x18\x06 \x01(\x04\x12\x11\n\tused_ipv6\x18\x07 \x01(\x08\x12\x0f\n\x07proxied\x18\x08 \x01(\x08\"H\n\x1c\x43MsgClientRequestAccountData\x12\x18\n\x10\x61\x63\x63ount_or_email\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\r\"\xd7\x01\n$CMsgClientRequestAccountDataResponse\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\x12\x12\n\nct_matches\x18\x04 \x01(\r\x12 \n\x18\x61\x63\x63ount_name_suggestion1\x18\x05 \x01(\t\x12 \n\x18\x61\x63\x63ount_name_suggestion2\x18\x06 \x01(\t\x12 \n\x18\x61\x63\x63ount_name_suggestion3\x18\x07 \x01(\t\"\x99\x01\n\x1b\x43MsgClientUGSGetGlobalStats\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\x1e\n\x16history_days_requested\x18\x02 \x01(\r\x12\x1b\n\x13time_last_requested\x18\x03 \x01(\x07\x12\x18\n\x10\x66irst_day_cached\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x61ys_cached\x18\x05 \x01(\r\"\x95\x02\n#CMsgClientUGSGetGlobalStatsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x11\n\ttimestamp\x18\x02 \x01(\x07\x12\x13\n\x0b\x64\x61y_current\x18\x03 \x01(\x05\x12\x36\n\x04\x64\x61ys\x18\x04 \x03(\x0b\x32(.CMsgClientUGSGetGlobalStatsResponse.Day\x1az\n\x03\x44\x61y\x12\x0e\n\x06\x64\x61y_id\x18\x01 \x01(\r\x12<\n\x05stats\x18\x02 \x03(\x0b\x32-.CMsgClientUGSGetGlobalStatsResponse.Day.Stat\x1a%\n\x04Stat\x12\x0f\n\x07stat_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x03\"2\n\x19\x43MsgClientRedeemGuestPass\x12\x15\n\rguest_pass_id\x18\x01 \x01(\x06\"c\n!CMsgClientRedeemGuestPassResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x12\n\npackage_id\x18\x02 \x01(\r\x12\x16\n\x0emust_own_appid\x18\x03 \x01(\r\"8\n\x1f\x43MsgClientGetClanActivityCounts\x12\x15\n\rsteamid_clans\x18\x01 \x03(\x04\"=\n\'CMsgClientGetClanActivityCountsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"y\n\x19\x43MsgClientOGSReportString\x12\x13\n\x0b\x61\x63\x63umulated\x18\x01 \x01(\x08\x12\x11\n\tsessionid\x18\x02 \x01(\x04\x12\x10\n\x08severity\x18\x03 \x01(\x05\x12\x11\n\tformatter\x18\x04 \x01(\t\x12\x0f\n\x07varargs\x18\x05 \x01(\x0c\"P\n\x16\x43MsgClientOGSReportBug\x12\x11\n\tsessionid\x18\x01 \x01(\x04\x12\x0f\n\x07\x62ugtext\x18\x02 \x01(\t\x12\x12\n\nscreenshot\x18\x03 \x01(\x0c\"\x14\n\x12\x43MsgClientSentLogs\"l\n\x0c\x43MsgGCClient\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07msgtype\x18\x02 \x01(\r\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x0e\n\x06gcname\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\r\".\n\x1c\x43MsgClientRequestFreeLicense\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"n\n$CMsgClientRequestFreeLicenseResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x1a\n\x12granted_packageids\x18\x02 \x03(\r\x12\x16\n\x0egranted_appids\x18\x03 \x03(\r\"\xd3\x01\n#CMsgDRMDownloadRequestWithCrashData\x12\x16\n\x0e\x64ownload_flags\x18\x01 \x01(\r\x12\x1c\n\x14\x64ownload_types_known\x18\x02 \x01(\r\x12\x10\n\x08guid_drm\x18\x03 \x01(\x0c\x12\x12\n\nguid_split\x18\x04 \x01(\x0c\x12\x12\n\nguid_merge\x18\x05 \x01(\x0c\x12\x13\n\x0bmodule_name\x18\x06 \x01(\t\x12\x13\n\x0bmodule_path\x18\x07 \x01(\t\x12\x12\n\ncrash_data\x18\x08 \x01(\x0c\"\xdb\x01\n\x17\x43MsgDRMDownloadResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x1a\n\x12\x62lob_download_type\x18\x03 \x01(\r\x12\x12\n\nmerge_guid\x18\x04 \x01(\x0c\x12\x1c\n\x14\x64ownload_file_dfs_ip\x18\x05 \x01(\r\x12\x1e\n\x16\x64ownload_file_dfs_port\x18\x06 \x01(\r\x12\x19\n\x11\x64ownload_file_url\x18\x07 \x01(\t\x12\x13\n\x0bmodule_path\x18\x08 \x01(\t\"\xd7\x01\n\x12\x43MsgDRMFinalResult\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x1a\n\x12\x62lob_download_type\x18\x03 \x01(\r\x12\x14\n\x0c\x65rror_detail\x18\x04 \x01(\r\x12\x12\n\nmerge_guid\x18\x05 \x01(\x0c\x12\x1c\n\x14\x64ownload_file_dfs_ip\x18\x06 \x01(\r\x12\x1e\n\x16\x64ownload_file_dfs_port\x18\x07 \x01(\r\x12\x19\n\x11\x64ownload_file_url\x18\x08 \x01(\t\"3\n\x1e\x43MsgClientDPCheckSpecialSurvey\x12\x11\n\tsurvey_id\x18\x01 \x01(\r\"\x96\x01\n&CMsgClientDPCheckSpecialSurveyResponse\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05state\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\ncustom_url\x18\x04 \x01(\t\x12\x18\n\x10include_software\x18\x05 \x01(\x08\x12\r\n\x05token\x18\x06 \x01(\x0c\"H\n%CMsgClientDPSendSpecialSurveyResponse\x12\x11\n\tsurvey_id\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"O\n*CMsgClientDPSendSpecialSurveyResponseReply\x12\x12\n\x07\x65Result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05token\x18\x02 \x01(\x0c\"W\n\'CMsgClientRequestForgottenPasswordEmail\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x16\n\x0epassword_tried\x18\x02 \x01(\t\"_\n/CMsgClientRequestForgottenPasswordEmailResponse\x12\x0f\n\x07\x65Result\x18\x01 \x01(\r\x12\x1b\n\x13use_secret_question\x18\x02 \x01(\x08\"\xf6\x01\n\x1b\x43MsgClientItemAnnouncements\x12\x17\n\x0f\x63ount_new_items\x18\x01 \x01(\r\x12=\n\x0cunseen_items\x18\x02 \x03(\x0b\x32\'.CMsgClientItemAnnouncements.UnseenItem\x1a\x7f\n\nUnseenItem\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ncontext_id\x18\x02 \x01(\x04\x12\x10\n\x08\x61sset_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12\x16\n\x0ertime32_gained\x18\x05 \x01(\x07\x12\x14\n\x0csource_appid\x18\x06 \x01(\r\"$\n\"CMsgClientRequestItemAnnouncements\"\x9e\x01\n\x1b\x43MsgClientUserNotifications\x12@\n\rnotifications\x18\x01 \x03(\x0b\x32).CMsgClientUserNotifications.Notification\x1a=\n\x0cNotification\x12\x1e\n\x16user_notification_type\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\x88\x01\n\x1e\x43MsgClientCommentNotifications\x12\x1a\n\x12\x63ount_new_comments\x18\x01 \x01(\r\x12 \n\x18\x63ount_new_comments_owner\x18\x02 \x01(\r\x12(\n count_new_comments_subscriptions\x18\x03 \x01(\r\"\'\n%CMsgClientRequestCommentNotifications\"g\n$CMsgClientOfflineMessageNotification\x12\x18\n\x10offline_messages\x18\x01 \x01(\r\x12%\n\x1d\x66riends_with_offline_messages\x18\x02 \x03(\r\"&\n$CMsgClientRequestOfflineMessageCount\"8\n%CMsgClientChatGetFriendMessageHistory\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xf9\x01\n-CMsgClientChatGetFriendMessageHistoryResponse\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07success\x18\x02 \x01(\r\x12N\n\x08messages\x18\x03 \x03(\x0b\x32<.CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage\x1aV\n\rFriendMessage\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06unread\x18\x04 \x01(\x08\"9\n7CMsgClientChatGetFriendMessageHistoryForOfflineMessages\"7\n!CMsgClientFSGetFriendsSteamLevels\x12\x12\n\naccountids\x18\x01 \x03(\r\"\x9b\x01\n)CMsgClientFSGetFriendsSteamLevelsResponse\x12\x42\n\x07\x66riends\x18\x01 \x03(\x0b\x32\x31.CMsgClientFSGetFriendsSteamLevelsResponse.Friend\x1a*\n\x06\x46riend\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\r\n\x05level\x18\x02 \x01(\r\"\xeb\x01\n\x17\x43MsgClientEmailAddrInfo\x12\x15\n\remail_address\x18\x01 \x01(\t\x12\x1a\n\x12\x65mail_is_validated\x18\x02 \x01(\x08\x12 \n\x18\x65mail_validation_changed\x18\x03 \x01(\x08\x12\'\n\x1f\x63redential_change_requires_code\x18\x04 \x01(\x08\x12\x31\n)password_or_secretqa_change_requires_code\x18\x05 \x01(\x08\x12\x1f\n\x17remind_user_about_email\x18\x06 \x01(\x08\"\x8b\x01\n\x16\x43MsgCREItemVoteSummary\x12\x43\n\x12published_file_ids\x18\x01 \x03(\x0b\x32\'.CMsgCREItemVoteSummary.PublishedFileId\x1a,\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xfa\x01\n\x1e\x43MsgCREItemVoteSummaryResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12L\n\x13item_vote_summaries\x18\x02 \x03(\x0b\x32/.CMsgCREItemVoteSummaryResponse.ItemVoteSummary\x1av\n\x0fItemVoteSummary\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x11\n\tvotes_for\x18\x02 \x01(\x05\x12\x15\n\rvotes_against\x18\x03 \x01(\x05\x12\x0f\n\x07reports\x18\x04 \x01(\x05\x12\r\n\x05score\x18\x05 \x01(\x02\"P\n\"CMsgCREUpdateUserPublishedItemVote\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"@\n*CMsgCREUpdateUserPublishedItemVoteResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\xab\x01\n&CMsgCREGetUserPublishedItemVoteDetails\x12S\n\x12published_file_ids\x18\x01 \x03(\x0b\x32\x37.CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId\x1a,\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\"\xea\x01\n.CMsgCREGetUserPublishedItemVoteDetailsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x62\n\x16user_item_vote_details\x18\x02 \x03(\x0b\x32\x42.CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail\x1a@\n\x12UserItemVoteDetail\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0f\n\x04vote\x18\x02 \x01(\x05:\x01\x30\"*\n\x16\x43MsgFSGetFollowerCount\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"F\n\x1e\x43MsgFSGetFollowerCountResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x05\x63ount\x18\x02 \x01(\x05:\x01\x30\"(\n\x14\x43MsgFSGetIsFollowing\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"O\n\x1c\x43MsgFSGetIsFollowingResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1b\n\x0cis_following\x18\x02 \x01(\x08:\x05\x66\x61lse\"3\n\x1c\x43MsgFSEnumerateFollowingList\x12\x13\n\x0bstart_index\x18\x01 \x01(\r\"d\n$CMsgFSEnumerateFollowingListResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x15\n\rtotal_results\x18\x02 \x01(\x05\x12\x11\n\tsteam_ids\x18\x03 \x03(\x06\"0\n\x1f\x43MsgDPGetNumberOfCurrentPlayers\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"S\n\'CMsgDPGetNumberOfCurrentPlayersResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x14\n\x0cplayer_count\x18\x02 \x01(\x05\"a\n#CMsgClientFriendUserStatusPublished\x12\x16\n\x0e\x66riend_steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0bstatus_text\x18\x03 \x01(\t\"h\n\x1d\x43MsgClientServiceMethodLegacy\x12\x13\n\x0bmethod_name\x18\x01 \x01(\t\x12\x19\n\x11serialized_method\x18\x02 \x01(\x0c\x12\x17\n\x0fis_notification\x18\x03 \x01(\x08\"`\n%CMsgClientServiceMethodLegacyResponse\x12\x13\n\x0bmethod_name\x18\x01 \x01(\t\x12\"\n\x1aserialized_method_response\x18\x02 \x01(\x0c\"5\n\x10\x43MsgClientUIMode\x12\x0e\n\x06uimode\x18\x01 \x01(\r\x12\x11\n\tchat_mode\x18\x02 \x01(\r\"<\n&CMsgClientVanityURLChangedNotification\x12\x12\n\nvanity_url\x18\x01 \x01(\t\"y\n%CMsgClientAuthorizeLocalDeviceRequest\x12\x1a\n\x12\x64\x65vice_description\x18\x01 \x01(\t\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12local_device_token\x18\x03 \x01(\x04\"k\n\x1e\x43MsgClientAuthorizeLocalDevice\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1b\n\x13\x61uthed_device_token\x18\x03 \x01(\x04\"v\n*CMsgClientAuthorizeLocalDeviceNotification\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12local_device_token\x18\x03 \x01(\x04\"n\n\"CMsgClientDeauthorizeDeviceRequest\x12\"\n\x1a\x64\x65\x61uthorization_account_id\x18\x01 \x01(\r\x12$\n\x1c\x64\x65\x61uthorization_device_token\x18\x02 \x01(\x04\"U\n\x1b\x43MsgClientDeauthorizeDevice\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\"\n\x1a\x64\x65\x61uthorization_account_id\x18\x02 \x01(\r\"\xd1\x01\n&CMsgClientUseLocalDeviceAuthorizations\x12 \n\x18\x61uthorization_account_id\x18\x01 \x03(\r\x12J\n\rdevice_tokens\x18\x02 \x03(\x0b\x32\x33.CMsgClientUseLocalDeviceAuthorizations.DeviceToken\x1a\x39\n\x0b\x44\x65viceToken\x12\x18\n\x10owner_account_id\x18\x01 \x01(\r\x12\x10\n\x08token_id\x18\x02 \x01(\x04\" \n\x1e\x43MsgClientGetAuthorizedDevices\"\xad\x02\n&CMsgClientGetAuthorizedDevicesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12S\n\x11\x61uthorized_device\x18\x02 \x03(\x0b\x32\x38.CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice\x1a\x99\x01\n\x10\x41uthorizedDevice\x12\x19\n\x11\x61uth_device_token\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x18\n\x10last_access_time\x18\x03 \x01(\r\x12\x13\n\x0b\x62orrower_id\x18\x04 \x01(\r\x12\x12\n\nis_pending\x18\x05 \x01(\x08\x12\x12\n\napp_played\x18\x06 \x01(\r\"\xc2\x01\n!CMsgClientSharedLibraryLockStatus\x12H\n\x0elocked_library\x18\x01 \x03(\x0b\x32\x30.CMsgClientSharedLibraryLockStatus.LockedLibrary\x12\x1d\n\x15own_library_locked_by\x18\x02 \x01(\r\x1a\x34\n\rLockedLibrary\x12\x10\n\x08owner_id\x18\x01 \x01(\r\x12\x11\n\tlocked_by\x18\x02 \x01(\r\"\xa7\x01\n\"CMsgClientSharedLibraryStopPlaying\x12\x14\n\x0cseconds_left\x18\x01 \x01(\x05\x12>\n\tstop_apps\x18\x02 \x03(\x0b\x32+.CMsgClientSharedLibraryStopPlaying.StopApp\x1a+\n\x07StopApp\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08owner_id\x18\x02 \x01(\r\"\x81\x02\n\x15\x43MsgClientServiceCall\x12\x15\n\rsysid_routing\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63\x61ll_handle\x18\x02 \x01(\r\x12\x12\n\nmodule_crc\x18\x03 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x04 \x01(\x0c\x12\x13\n\x0b\x66unction_id\x18\x05 \x01(\r\x12\x16\n\x0e\x63ub_output_max\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x15\n\rcallparameter\x18\x08 \x01(\x0c\x12\x11\n\tping_only\x18\t \x01(\x08\x12\x1d\n\x15max_outstanding_calls\x18\n \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x0b \x01(\r\"Z\n\x17\x43MsgClientServiceModule\x12\x12\n\nmodule_crc\x18\x01 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x02 \x01(\x0c\x12\x16\n\x0emodule_content\x18\x03 \x01(\x0c\"\xb8\x04\n\x1d\x43MsgClientServiceCallResponse\x12\x15\n\rsysid_routing\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63\x61ll_handle\x18\x02 \x01(\r\x12\x12\n\nmodule_crc\x18\x03 \x01(\r\x12\x13\n\x0bmodule_hash\x18\x04 \x01(\x0c\x12\x13\n\x0b\x65\x63\x61llresult\x18\x05 \x01(\r\x12\x16\n\x0eresult_content\x18\x06 \x01(\x0c\x12\x17\n\x0fos_version_info\x18\x07 \x01(\x0c\x12\x13\n\x0bsystem_info\x18\x08 \x01(\x0c\x12\x14\n\x0cload_address\x18\t \x01(\x06\x12\x18\n\x10\x65xception_record\x18\n \x01(\x0c\x12 \n\x18portable_os_version_info\x18\x0b \x01(\x0c\x12\x1c\n\x14portable_system_info\x18\x0c \x01(\x0c\x12\x15\n\rwas_converted\x18\r \x01(\x08\x12\x17\n\x0finternal_result\x18\x0e \x01(\r\x12\x15\n\rcurrent_count\x18\x0f \x01(\r\x12\x18\n\x10last_call_handle\x18\x10 \x01(\r\x12\x1c\n\x14last_call_module_crc\x18\x11 \x01(\r\x12\x1f\n\x17last_call_sysid_routing\x18\x12 \x01(\x0c\x12\x18\n\x10last_ecallresult\x18\x13 \x01(\r\x12\x1c\n\x14last_callissue_delta\x18\x14 \x01(\r\x12\x1f\n\x17last_callcomplete_delta\x18\x15 \x01(\r\"\x17\n\x15\x43MsgAMUnlockStreaming\"K\n\x1d\x43MsgAMUnlockStreamingResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0e\x65ncryption_key\x18\x02 \x01(\x0c\"\x12\n\x10\x43MsgAMUnlockHEVC\".\n\x18\x43MsgAMUnlockHEVCResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"M\n\x1d\x43MsgClientPlayingSessionState\x12\x17\n\x0fplaying_blocked\x18\x02 \x01(\x08\x12\x13\n\x0bplaying_app\x18\x03 \x01(\r\"6\n\x1c\x43MsgClientKickPlayingSession\x12\x16\n\x0eonly_stop_game\x18\x01 \x01(\x08\"v\n\x1f\x43MsgClientVoiceCallPreAuthorize\x12\x16\n\x0e\x63\x61ller_steamid\x18\x01 \x01(\x06\x12\x18\n\x10receiver_steamid\x18\x02 \x01(\x06\x12\x11\n\tcaller_id\x18\x03 \x01(\x05\x12\x0e\n\x06hangup\x18\x04 \x01(\x08\"\x82\x01\n\'CMsgClientVoiceCallPreAuthorizeResponse\x12\x16\n\x0e\x63\x61ller_steamid\x18\x01 \x01(\x06\x12\x18\n\x10receiver_steamid\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\x12\x11\n\tcaller_id\x18\x04 \x01(\x05\"B\n\x1c\x43MsgBadgeCraftedNotification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0b\x62\x61\x64ge_level\x18\x02 \x01(\rB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTUPDATEUSERGAMEINFO = _descriptor.Descriptor(
  name='CMsgClientUpdateUserGameInfo',
  full_name='CMsgClientUpdateUserGameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_idgs', full_name='CMsgClientUpdateUserGameInfo.steamid_idgs', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CMsgClientUpdateUserGameInfo.gameid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_ip', full_name='CMsgClientUpdateUserGameInfo.game_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgClientUpdateUserGameInfo.game_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientUpdateUserGameInfo.token', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=183,
)


_CMSGCLIENTRICHPRESENCEUPLOAD = _descriptor.Descriptor(
  name='CMsgClientRichPresenceUpload',
  full_name='CMsgClientRichPresenceUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rich_presence_kv', full_name='CMsgClientRichPresenceUpload.rich_presence_kv', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_broadcast', full_name='CMsgClientRichPresenceUpload.steamid_broadcast', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=268,
)


_CMSGCLIENTRICHPRESENCEREQUEST = _descriptor.Descriptor(
  name='CMsgClientRichPresenceRequest',
  full_name='CMsgClientRichPresenceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_request', full_name='CMsgClientRichPresenceRequest.steamid_request', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=326,
)


_CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE = _descriptor.Descriptor(
  name='RichPresence',
  full_name='CMsgClientRichPresenceInfo.RichPresence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_user', full_name='CMsgClientRichPresenceInfo.RichPresence.steamid_user', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rich_presence_kv', full_name='CMsgClientRichPresenceInfo.RichPresence.rich_presence_kv', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=486,
)

_CMSGCLIENTRICHPRESENCEINFO = _descriptor.Descriptor(
  name='CMsgClientRichPresenceInfo',
  full_name='CMsgClientRichPresenceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rich_presence', full_name='CMsgClientRichPresenceInfo.rich_presence', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=486,
)


_CMSGCLIENTCHECKFILESIGNATURE = _descriptor.Descriptor(
  name='CMsgClientCheckFileSignature',
  full_name='CMsgClientCheckFileSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientCheckFileSignature.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=534,
)


_CMSGCLIENTCHECKFILESIGNATURERESPONSE = _descriptor.Descriptor(
  name='CMsgClientCheckFileSignatureResponse',
  full_name='CMsgClientCheckFileSignatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientCheckFileSignatureResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='CMsgClientCheckFileSignatureResponse.pid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientCheckFileSignatureResponse.eresult', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientCheckFileSignatureResponse.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esignatureresult', full_name='CMsgClientCheckFileSignatureResponse.esignatureresult', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientCheckFileSignatureResponse.sha_file', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatureheader', full_name='CMsgClientCheckFileSignatureResponse.signatureheader', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesize', full_name='CMsgClientCheckFileSignatureResponse.filesize', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getlasterror', full_name='CMsgClientCheckFileSignatureResponse.getlasterror', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evalvesignaturecheckdetail', full_name='CMsgClientCheckFileSignatureResponse.evalvesignaturecheckdetail', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=784,
)


_CMSGCLIENTREADMACHINEAUTH = _descriptor.Descriptor(
  name='CMsgClientReadMachineAuth',
  full_name='CMsgClientReadMachineAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientReadMachineAuth.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='CMsgClientReadMachineAuth.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cubtoread', full_name='CMsgClientReadMachineAuth.cubtoread', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=786,
  serialized_end=866,
)


_CMSGCLIENTREADMACHINEAUTHRESPONSE = _descriptor.Descriptor(
  name='CMsgClientReadMachineAuthResponse',
  full_name='CMsgClientReadMachineAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientReadMachineAuthResponse.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientReadMachineAuthResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesize', full_name='CMsgClientReadMachineAuthResponse.filesize', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientReadMachineAuthResponse.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getlasterror', full_name='CMsgClientReadMachineAuthResponse.getlasterror', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='CMsgClientReadMachineAuthResponse.offset', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cubread', full_name='CMsgClientReadMachineAuthResponse.cubread', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_read', full_name='CMsgClientReadMachineAuthResponse.bytes_read', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename_sentry', full_name='CMsgClientReadMachineAuthResponse.filename_sentry', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=1075,
)


_CMSGCLIENTUPDATEMACHINEAUTH = _descriptor.Descriptor(
  name='CMsgClientUpdateMachineAuth',
  full_name='CMsgClientUpdateMachineAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientUpdateMachineAuth.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='CMsgClientUpdateMachineAuth.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cubtowrite', full_name='CMsgClientUpdateMachineAuth.cubtowrite', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='CMsgClientUpdateMachineAuth.bytes', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_type', full_name='CMsgClientUpdateMachineAuth.otp_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_identifier', full_name='CMsgClientUpdateMachineAuth.otp_identifier', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_sharedsecret', full_name='CMsgClientUpdateMachineAuth.otp_sharedsecret', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_timedrift', full_name='CMsgClientUpdateMachineAuth.otp_timedrift', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1267,
)


_CMSGCLIENTUPDATEMACHINEAUTHRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUpdateMachineAuthResponse',
  full_name='CMsgClientUpdateMachineAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientUpdateMachineAuthResponse.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUpdateMachineAuthResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesize', full_name='CMsgClientUpdateMachineAuthResponse.filesize', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUpdateMachineAuthResponse.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getlasterror', full_name='CMsgClientUpdateMachineAuthResponse.getlasterror', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='CMsgClientUpdateMachineAuthResponse.offset', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cubwrote', full_name='CMsgClientUpdateMachineAuthResponse.cubwrote', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_type', full_name='CMsgClientUpdateMachineAuthResponse.otp_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_value', full_name='CMsgClientUpdateMachineAuthResponse.otp_value', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_identifier', full_name='CMsgClientUpdateMachineAuthResponse.otp_identifier', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1495,
)


_CMSGCLIENTREQUESTMACHINEAUTH = _descriptor.Descriptor(
  name='CMsgClientRequestMachineAuth',
  full_name='CMsgClientRequestMachineAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientRequestMachineAuth.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult_sentryfile', full_name='CMsgClientRequestMachineAuth.eresult_sentryfile', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesize', full_name='CMsgClientRequestMachineAuth.filesize', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_sentryfile', full_name='CMsgClientRequestMachineAuth.sha_sentryfile', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_account_action', full_name='CMsgClientRequestMachineAuth.lock_account_action', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_type', full_name='CMsgClientRequestMachineAuth.otp_type', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_identifier', full_name='CMsgClientRequestMachineAuth.otp_identifier', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_sharedsecret', full_name='CMsgClientRequestMachineAuth.otp_sharedsecret', index=7,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otp_value', full_name='CMsgClientRequestMachineAuth.otp_value', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CMsgClientRequestMachineAuth.machine_name', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name_userchosen', full_name='CMsgClientRequestMachineAuth.machine_name_userchosen', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1787,
)


_CMSGCLIENTREQUESTMACHINEAUTHRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestMachineAuthResponse',
  full_name='CMsgClientRequestMachineAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRequestMachineAuthResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1789,
  serialized_end=1844,
)


_CMSGCLIENTREGISTERKEY = _descriptor.Descriptor(
  name='CMsgClientRegisterKey',
  full_name='CMsgClientRegisterKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CMsgClientRegisterKey.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1846,
  serialized_end=1882,
)


_CMSGCLIENTPURCHASERESPONSE = _descriptor.Descriptor(
  name='CMsgClientPurchaseResponse',
  full_name='CMsgClientPurchaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientPurchaseResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_result_details', full_name='CMsgClientPurchaseResponse.purchase_result_details', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_receipt_info', full_name='CMsgClientPurchaseResponse.purchase_receipt_info', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1884,
  serialized_end=1996,
)


_CMSGCLIENTACTIVATEOEMLICENSE = _descriptor.Descriptor(
  name='CMsgClientActivateOEMLicense',
  full_name='CMsgClientActivateOEMLicense',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bios_manufacturer', full_name='CMsgClientActivateOEMLicense.bios_manufacturer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bios_serialnumber', full_name='CMsgClientActivateOEMLicense.bios_serialnumber', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license_file', full_name='CMsgClientActivateOEMLicense.license_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mainboard_manufacturer', full_name='CMsgClientActivateOEMLicense.mainboard_manufacturer', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mainboard_product', full_name='CMsgClientActivateOEMLicense.mainboard_product', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mainboard_serialnumber', full_name='CMsgClientActivateOEMLicense.mainboard_serialnumber', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1999,
  serialized_end=2196,
)


_CMSGCLIENTREGISTEROEMMACHINE = _descriptor.Descriptor(
  name='CMsgClientRegisterOEMMachine',
  full_name='CMsgClientRegisterOEMMachine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oem_register_file', full_name='CMsgClientRegisterOEMMachine.oem_register_file', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2198,
  serialized_end=2255,
)


_CMSGCLIENTREGISTEROEMMACHINERESPONSE = _descriptor.Descriptor(
  name='CMsgClientRegisterOEMMachineResponse',
  full_name='CMsgClientRegisterOEMMachineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRegisterOEMMachineResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2257,
  serialized_end=2312,
)


_CMSGCLIENTPURCHASEWITHMACHINEID = _descriptor.Descriptor(
  name='CMsgClientPurchaseWithMachineID',
  full_name='CMsgClientPurchaseWithMachineID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_id', full_name='CMsgClientPurchaseWithMachineID.package_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_info', full_name='CMsgClientPurchaseWithMachineID.machine_info', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2314,
  serialized_end=2389,
)


_CMSGTRADING_INITIATETRADEREQUEST = _descriptor.Descriptor(
  name='CMsgTrading_InitiateTradeRequest',
  full_name='CMsgTrading_InitiateTradeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_request_id', full_name='CMsgTrading_InitiateTradeRequest.trade_request_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_steamid', full_name='CMsgTrading_InitiateTradeRequest.other_steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_name', full_name='CMsgTrading_InitiateTradeRequest.other_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2494,
)


_CMSGTRADING_INITIATETRADERESPONSE = _descriptor.Descriptor(
  name='CMsgTrading_InitiateTradeResponse',
  full_name='CMsgTrading_InitiateTradeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgTrading_InitiateTradeResponse.response', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_request_id', full_name='CMsgTrading_InitiateTradeResponse.trade_request_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_steamid', full_name='CMsgTrading_InitiateTradeResponse.other_steamid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_required_days', full_name='CMsgTrading_InitiateTradeResponse.steamguard_required_days', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_device_cooldown_days', full_name='CMsgTrading_InitiateTradeResponse.new_device_cooldown_days', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_password_reset_probation_days', full_name='CMsgTrading_InitiateTradeResponse.default_password_reset_probation_days', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_reset_probation_days', full_name='CMsgTrading_InitiateTradeResponse.password_reset_probation_days', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_email_change_probation_days', full_name='CMsgTrading_InitiateTradeResponse.default_email_change_probation_days', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_change_probation_days', full_name='CMsgTrading_InitiateTradeResponse.email_change_probation_days', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2497,
  serialized_end=2835,
)


_CMSGTRADING_CANCELTRADEREQUEST = _descriptor.Descriptor(
  name='CMsgTrading_CancelTradeRequest',
  full_name='CMsgTrading_CancelTradeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='other_steamid', full_name='CMsgTrading_CancelTradeRequest.other_steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2837,
  serialized_end=2892,
)


_CMSGTRADING_STARTSESSION = _descriptor.Descriptor(
  name='CMsgTrading_StartSession',
  full_name='CMsgTrading_StartSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='other_steamid', full_name='CMsgTrading_StartSession.other_steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2894,
  serialized_end=2943,
)


_CMSGCLIENTGETCDNAUTHTOKEN = _descriptor.Descriptor(
  name='CMsgClientGetCDNAuthToken',
  full_name='CMsgClientGetCDNAuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientGetCDNAuthToken.depot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='CMsgClientGetCDNAuthToken.host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetCDNAuthToken.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2945,
  serialized_end=3025,
)


_CMSGCLIENTGETDEPOTDECRYPTIONKEY = _descriptor.Descriptor(
  name='CMsgClientGetDepotDecryptionKey',
  full_name='CMsgClientGetDepotDecryptionKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientGetDepotDecryptionKey.depot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetDepotDecryptionKey.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3027,
  serialized_end=3094,
)


_CMSGCLIENTGETDEPOTDECRYPTIONKEYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetDepotDecryptionKeyResponse',
  full_name='CMsgClientGetDepotDecryptionKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetDepotDecryptionKeyResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientGetDepotDecryptionKeyResponse.depot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_encryption_key', full_name='CMsgClientGetDepotDecryptionKeyResponse.depot_encryption_key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3096,
  serialized_end=3205,
)


_CMSGCLIENTCHECKAPPBETAPASSWORD = _descriptor.Descriptor(
  name='CMsgClientCheckAppBetaPassword',
  full_name='CMsgClientCheckAppBetaPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientCheckAppBetaPassword.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='betapassword', full_name='CMsgClientCheckAppBetaPassword.betapassword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgClientCheckAppBetaPassword.language', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3207,
  serialized_end=3295,
)


_CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD = _descriptor.Descriptor(
  name='BetaPassword',
  full_name='CMsgClientCheckAppBetaPasswordResponse.BetaPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='betaname', full_name='CMsgClientCheckAppBetaPasswordResponse.BetaPassword.betaname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='betapassword', full_name='CMsgClientCheckAppBetaPasswordResponse.BetaPassword.betapassword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='betadescription', full_name='CMsgClientCheckAppBetaPasswordResponse.BetaPassword.betadescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3437,
  serialized_end=3516,
)

_CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE = _descriptor.Descriptor(
  name='CMsgClientCheckAppBetaPasswordResponse',
  full_name='CMsgClientCheckAppBetaPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientCheckAppBetaPasswordResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='betapasswords', full_name='CMsgClientCheckAppBetaPasswordResponse.betapasswords', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3298,
  serialized_end=3516,
)


_CMSGCLIENTUPDATEAPPJOBREPORT = _descriptor.Descriptor(
  name='CMsgClientUpdateAppJobReport',
  full_name='CMsgClientUpdateAppJobReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUpdateAppJobReport.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_ids', full_name='CMsgClientUpdateAppJobReport.depot_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_state', full_name='CMsgClientUpdateAppJobReport.app_state', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_app_error', full_name='CMsgClientUpdateAppJobReport.job_app_error', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_details', full_name='CMsgClientUpdateAppJobReport.error_details', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_duration', full_name='CMsgClientUpdateAppJobReport.job_duration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files_validation_failed', full_name='CMsgClientUpdateAppJobReport.files_validation_failed', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_bytes_downloaded', full_name='CMsgClientUpdateAppJobReport.job_bytes_downloaded', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_bytes_staged', full_name='CMsgClientUpdateAppJobReport.job_bytes_staged', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_comitted', full_name='CMsgClientUpdateAppJobReport.bytes_comitted', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_app_state', full_name='CMsgClientUpdateAppJobReport.start_app_state', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_machine_id', full_name='CMsgClientUpdateAppJobReport.stats_machine_id', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_name', full_name='CMsgClientUpdateAppJobReport.branch_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_downloaded', full_name='CMsgClientUpdateAppJobReport.total_bytes_downloaded', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_staged', full_name='CMsgClientUpdateAppJobReport.total_bytes_staged', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_restored', full_name='CMsgClientUpdateAppJobReport.total_bytes_restored', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_borrowed', full_name='CMsgClientUpdateAppJobReport.is_borrowed', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_free_weekend', full_name='CMsgClientUpdateAppJobReport.is_free_weekend', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_legacy', full_name='CMsgClientUpdateAppJobReport.total_bytes_legacy', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_patched', full_name='CMsgClientUpdateAppJobReport.total_bytes_patched', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bytes_saved', full_name='CMsgClientUpdateAppJobReport.total_bytes_saved', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientUpdateAppJobReport.cell_id', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3519,
  serialized_end=4093,
)


_CMSGCLIENTDPCONTENTSTATSREPORT = _descriptor.Descriptor(
  name='CMsgClientDPContentStatsReport',
  full_name='CMsgClientDPContentStatsReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_machine_id', full_name='CMsgClientDPContentStatsReport.stats_machine_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgClientDPContentStatsReport.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os_type', full_name='CMsgClientDPContentStatsReport.os_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgClientDPContentStatsReport.language', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_install_folders', full_name='CMsgClientDPContentStatsReport.num_install_folders', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_installed_games', full_name='CMsgClientDPContentStatsReport.num_installed_games', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_installed_games', full_name='CMsgClientDPContentStatsReport.size_installed_games', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4096,
  serialized_end=4299,
)


_CMSGCLIENTGETCDNAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetCDNAuthTokenResponse',
  full_name='CMsgClientGetCDNAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetCDNAuthTokenResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientGetCDNAuthTokenResponse.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='CMsgClientGetCDNAuthTokenResponse.expiration_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4301,
  serialized_end=4396,
)


_CMSGDOWNLOADRATESTATISTICS_STATSINFO = _descriptor.Descriptor(
  name='StatsInfo',
  full_name='CMsgDownloadRateStatistics.StatsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_type', full_name='CMsgDownloadRateStatistics.StatsInfo.source_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='CMsgDownloadRateStatistics.StatsInfo.source_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='CMsgDownloadRateStatistics.StatsInfo.seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='CMsgDownloadRateStatistics.StatsInfo.bytes', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='CMsgDownloadRateStatistics.StatsInfo.host_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='microseconds', full_name='CMsgDownloadRateStatistics.StatsInfo.microseconds', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_ipv6', full_name='CMsgDownloadRateStatistics.StatsInfo.used_ipv6', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxied', full_name='CMsgDownloadRateStatistics.StatsInfo.proxied', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4547,
  serialized_end=4707,
)

_CMSGDOWNLOADRATESTATISTICS = _descriptor.Descriptor(
  name='CMsgDownloadRateStatistics',
  full_name='CMsgDownloadRateStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgDownloadRateStatistics.cell_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgDownloadRateStatistics.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttling_kbps', full_name='CMsgDownloadRateStatistics.throttling_kbps', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_realm', full_name='CMsgDownloadRateStatistics.steam_realm', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOWNLOADRATESTATISTICS_STATSINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4399,
  serialized_end=4707,
)


_CMSGCLIENTREQUESTACCOUNTDATA = _descriptor.Descriptor(
  name='CMsgClientRequestAccountData',
  full_name='CMsgClientRequestAccountData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_or_email', full_name='CMsgClientRequestAccountData.account_or_email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='CMsgClientRequestAccountData.action', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4709,
  serialized_end=4781,
)


_CMSGCLIENTREQUESTACCOUNTDATARESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestAccountDataResponse',
  full_name='CMsgClientRequestAccountDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='CMsgClientRequestAccountDataResponse.action', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRequestAccountDataResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CMsgClientRequestAccountDataResponse.account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ct_matches', full_name='CMsgClientRequestAccountDataResponse.ct_matches', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name_suggestion1', full_name='CMsgClientRequestAccountDataResponse.account_name_suggestion1', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name_suggestion2', full_name='CMsgClientRequestAccountDataResponse.account_name_suggestion2', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name_suggestion3', full_name='CMsgClientRequestAccountDataResponse.account_name_suggestion3', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4784,
  serialized_end=4999,
)


_CMSGCLIENTUGSGETGLOBALSTATS = _descriptor.Descriptor(
  name='CMsgClientUGSGetGlobalStats',
  full_name='CMsgClientUGSGetGlobalStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CMsgClientUGSGetGlobalStats.gameid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history_days_requested', full_name='CMsgClientUGSGetGlobalStats.history_days_requested', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_requested', full_name='CMsgClientUGSGetGlobalStats.time_last_requested', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_day_cached', full_name='CMsgClientUGSGetGlobalStats.first_day_cached', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days_cached', full_name='CMsgClientUGSGetGlobalStats.days_cached', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5002,
  serialized_end=5155,
)


_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='CMsgClientUGSGetGlobalStatsResponse.Day.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientUGSGetGlobalStatsResponse.Day.Stat.stat_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgClientUGSGetGlobalStatsResponse.Day.Stat.data', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5398,
  serialized_end=5435,
)

_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY = _descriptor.Descriptor(
  name='Day',
  full_name='CMsgClientUGSGetGlobalStatsResponse.Day',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='day_id', full_name='CMsgClientUGSGetGlobalStatsResponse.Day.day_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgClientUGSGetGlobalStatsResponse.Day.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5313,
  serialized_end=5435,
)

_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUGSGetGlobalStatsResponse',
  full_name='CMsgClientUGSGetGlobalStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUGSGetGlobalStatsResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgClientUGSGetGlobalStatsResponse.timestamp', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day_current', full_name='CMsgClientUGSGetGlobalStatsResponse.day_current', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days', full_name='CMsgClientUGSGetGlobalStatsResponse.days', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5158,
  serialized_end=5435,
)


_CMSGCLIENTREDEEMGUESTPASS = _descriptor.Descriptor(
  name='CMsgClientRedeemGuestPass',
  full_name='CMsgClientRedeemGuestPass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='guest_pass_id', full_name='CMsgClientRedeemGuestPass.guest_pass_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5437,
  serialized_end=5487,
)


_CMSGCLIENTREDEEMGUESTPASSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRedeemGuestPassResponse',
  full_name='CMsgClientRedeemGuestPassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRedeemGuestPassResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_id', full_name='CMsgClientRedeemGuestPassResponse.package_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='must_own_appid', full_name='CMsgClientRedeemGuestPassResponse.must_own_appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5489,
  serialized_end=5588,
)


_CMSGCLIENTGETCLANACTIVITYCOUNTS = _descriptor.Descriptor(
  name='CMsgClientGetClanActivityCounts',
  full_name='CMsgClientGetClanActivityCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_clans', full_name='CMsgClientGetClanActivityCounts.steamid_clans', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5590,
  serialized_end=5646,
)


_CMSGCLIENTGETCLANACTIVITYCOUNTSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClanActivityCountsResponse',
  full_name='CMsgClientGetClanActivityCountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetClanActivityCountsResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5648,
  serialized_end=5709,
)


_CMSGCLIENTOGSREPORTSTRING = _descriptor.Descriptor(
  name='CMsgClientOGSReportString',
  full_name='CMsgClientOGSReportString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accumulated', full_name='CMsgClientOGSReportString.accumulated', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CMsgClientOGSReportString.sessionid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='CMsgClientOGSReportString.severity', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatter', full_name='CMsgClientOGSReportString.formatter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='varargs', full_name='CMsgClientOGSReportString.varargs', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5711,
  serialized_end=5832,
)


_CMSGCLIENTOGSREPORTBUG = _descriptor.Descriptor(
  name='CMsgClientOGSReportBug',
  full_name='CMsgClientOGSReportBug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CMsgClientOGSReportBug.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugtext', full_name='CMsgClientOGSReportBug.bugtext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screenshot', full_name='CMsgClientOGSReportBug.screenshot', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5834,
  serialized_end=5914,
)


_CMSGCLIENTSENTLOGS = _descriptor.Descriptor(
  name='CMsgClientSentLogs',
  full_name='CMsgClientSentLogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5916,
  serialized_end=5936,
)


_CMSGGCCLIENT = _descriptor.Descriptor(
  name='CMsgGCClient',
  full_name='CMsgGCClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgGCClient.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgtype', full_name='CMsgGCClient.msgtype', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='CMsgGCClient.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCClient.steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gcname', full_name='CMsgGCClient.gcname', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgGCClient.ip', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5938,
  serialized_end=6046,
)


_CMSGCLIENTREQUESTFREELICENSE = _descriptor.Descriptor(
  name='CMsgClientRequestFreeLicense',
  full_name='CMsgClientRequestFreeLicense',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CMsgClientRequestFreeLicense.appids', index=0,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6048,
  serialized_end=6094,
)


_CMSGCLIENTREQUESTFREELICENSERESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestFreeLicenseResponse',
  full_name='CMsgClientRequestFreeLicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRequestFreeLicenseResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granted_packageids', full_name='CMsgClientRequestFreeLicenseResponse.granted_packageids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granted_appids', full_name='CMsgClientRequestFreeLicenseResponse.granted_appids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6096,
  serialized_end=6206,
)


_CMSGDRMDOWNLOADREQUESTWITHCRASHDATA = _descriptor.Descriptor(
  name='CMsgDRMDownloadRequestWithCrashData',
  full_name='CMsgDRMDownloadRequestWithCrashData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_flags', full_name='CMsgDRMDownloadRequestWithCrashData.download_flags', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_types_known', full_name='CMsgDRMDownloadRequestWithCrashData.download_types_known', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guid_drm', full_name='CMsgDRMDownloadRequestWithCrashData.guid_drm', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guid_split', full_name='CMsgDRMDownloadRequestWithCrashData.guid_split', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guid_merge', full_name='CMsgDRMDownloadRequestWithCrashData.guid_merge', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='CMsgDRMDownloadRequestWithCrashData.module_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_path', full_name='CMsgDRMDownloadRequestWithCrashData.module_path', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crash_data', full_name='CMsgDRMDownloadRequestWithCrashData.crash_data', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6209,
  serialized_end=6420,
)


_CMSGDRMDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='CMsgDRMDownloadResponse',
  full_name='CMsgDRMDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDRMDownloadResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgDRMDownloadResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_download_type', full_name='CMsgDRMDownloadResponse.blob_download_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_guid', full_name='CMsgDRMDownloadResponse.merge_guid', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_dfs_ip', full_name='CMsgDRMDownloadResponse.download_file_dfs_ip', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_dfs_port', full_name='CMsgDRMDownloadResponse.download_file_dfs_port', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_url', full_name='CMsgDRMDownloadResponse.download_file_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_path', full_name='CMsgDRMDownloadResponse.module_path', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6423,
  serialized_end=6642,
)


_CMSGDRMFINALRESULT = _descriptor.Descriptor(
  name='CMsgDRMFinalResult',
  full_name='CMsgDRMFinalResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eResult', full_name='CMsgDRMFinalResult.eResult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgDRMFinalResult.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_download_type', full_name='CMsgDRMFinalResult.blob_download_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_detail', full_name='CMsgDRMFinalResult.error_detail', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_guid', full_name='CMsgDRMFinalResult.merge_guid', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_dfs_ip', full_name='CMsgDRMFinalResult.download_file_dfs_ip', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_dfs_port', full_name='CMsgDRMFinalResult.download_file_dfs_port', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_file_url', full_name='CMsgDRMFinalResult.download_file_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6645,
  serialized_end=6860,
)


_CMSGCLIENTDPCHECKSPECIALSURVEY = _descriptor.Descriptor(
  name='CMsgClientDPCheckSpecialSurvey',
  full_name='CMsgClientDPCheckSpecialSurvey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='survey_id', full_name='CMsgClientDPCheckSpecialSurvey.survey_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6862,
  serialized_end=6913,
)


_CMSGCLIENTDPCHECKSPECIALSURVEYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientDPCheckSpecialSurveyResponse',
  full_name='CMsgClientDPCheckSpecialSurveyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eResult', full_name='CMsgClientDPCheckSpecialSurveyResponse.eResult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgClientDPCheckSpecialSurveyResponse.state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientDPCheckSpecialSurveyResponse.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_url', full_name='CMsgClientDPCheckSpecialSurveyResponse.custom_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_software', full_name='CMsgClientDPCheckSpecialSurveyResponse.include_software', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientDPCheckSpecialSurveyResponse.token', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6916,
  serialized_end=7066,
)


_CMSGCLIENTDPSENDSPECIALSURVEYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientDPSendSpecialSurveyResponse',
  full_name='CMsgClientDPSendSpecialSurveyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='survey_id', full_name='CMsgClientDPSendSpecialSurveyResponse.survey_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgClientDPSendSpecialSurveyResponse.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7068,
  serialized_end=7140,
)


_CMSGCLIENTDPSENDSPECIALSURVEYRESPONSEREPLY = _descriptor.Descriptor(
  name='CMsgClientDPSendSpecialSurveyResponseReply',
  full_name='CMsgClientDPSendSpecialSurveyResponseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eResult', full_name='CMsgClientDPSendSpecialSurveyResponseReply.eResult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientDPSendSpecialSurveyResponseReply.token', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7142,
  serialized_end=7221,
)


_CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAIL = _descriptor.Descriptor(
  name='CMsgClientRequestForgottenPasswordEmail',
  full_name='CMsgClientRequestForgottenPasswordEmail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CMsgClientRequestForgottenPasswordEmail.account_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_tried', full_name='CMsgClientRequestForgottenPasswordEmail.password_tried', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7223,
  serialized_end=7310,
)


_CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAILRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestForgottenPasswordEmailResponse',
  full_name='CMsgClientRequestForgottenPasswordEmailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eResult', full_name='CMsgClientRequestForgottenPasswordEmailResponse.eResult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_secret_question', full_name='CMsgClientRequestForgottenPasswordEmailResponse.use_secret_question', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7312,
  serialized_end=7407,
)


_CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM = _descriptor.Descriptor(
  name='UnseenItem',
  full_name='CMsgClientItemAnnouncements.UnseenItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientItemAnnouncements.UnseenItem.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context_id', full_name='CMsgClientItemAnnouncements.UnseenItem.context_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='CMsgClientItemAnnouncements.UnseenItem.asset_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='CMsgClientItemAnnouncements.UnseenItem.amount', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_gained', full_name='CMsgClientItemAnnouncements.UnseenItem.rtime32_gained', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_appid', full_name='CMsgClientItemAnnouncements.UnseenItem.source_appid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7529,
  serialized_end=7656,
)

_CMSGCLIENTITEMANNOUNCEMENTS = _descriptor.Descriptor(
  name='CMsgClientItemAnnouncements',
  full_name='CMsgClientItemAnnouncements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count_new_items', full_name='CMsgClientItemAnnouncements.count_new_items', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unseen_items', full_name='CMsgClientItemAnnouncements.unseen_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7410,
  serialized_end=7656,
)


_CMSGCLIENTREQUESTITEMANNOUNCEMENTS = _descriptor.Descriptor(
  name='CMsgClientRequestItemAnnouncements',
  full_name='CMsgClientRequestItemAnnouncements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7658,
  serialized_end=7694,
)


_CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='CMsgClientUserNotifications.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_notification_type', full_name='CMsgClientUserNotifications.Notification.user_notification_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgClientUserNotifications.Notification.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7794,
  serialized_end=7855,
)

_CMSGCLIENTUSERNOTIFICATIONS = _descriptor.Descriptor(
  name='CMsgClientUserNotifications',
  full_name='CMsgClientUserNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notifications', full_name='CMsgClientUserNotifications.notifications', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7697,
  serialized_end=7855,
)


_CMSGCLIENTCOMMENTNOTIFICATIONS = _descriptor.Descriptor(
  name='CMsgClientCommentNotifications',
  full_name='CMsgClientCommentNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count_new_comments', full_name='CMsgClientCommentNotifications.count_new_comments', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_new_comments_owner', full_name='CMsgClientCommentNotifications.count_new_comments_owner', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_new_comments_subscriptions', full_name='CMsgClientCommentNotifications.count_new_comments_subscriptions', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7858,
  serialized_end=7994,
)


_CMSGCLIENTREQUESTCOMMENTNOTIFICATIONS = _descriptor.Descriptor(
  name='CMsgClientRequestCommentNotifications',
  full_name='CMsgClientRequestCommentNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7996,
  serialized_end=8035,
)


_CMSGCLIENTOFFLINEMESSAGENOTIFICATION = _descriptor.Descriptor(
  name='CMsgClientOfflineMessageNotification',
  full_name='CMsgClientOfflineMessageNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offline_messages', full_name='CMsgClientOfflineMessageNotification.offline_messages', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friends_with_offline_messages', full_name='CMsgClientOfflineMessageNotification.friends_with_offline_messages', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8037,
  serialized_end=8140,
)


_CMSGCLIENTREQUESTOFFLINEMESSAGECOUNT = _descriptor.Descriptor(
  name='CMsgClientRequestOfflineMessageCount',
  full_name='CMsgClientRequestOfflineMessageCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8142,
  serialized_end=8180,
)


_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORY = _descriptor.Descriptor(
  name='CMsgClientChatGetFriendMessageHistory',
  full_name='CMsgClientChatGetFriendMessageHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientChatGetFriendMessageHistory.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8182,
  serialized_end=8238,
)


_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE = _descriptor.Descriptor(
  name='FriendMessage',
  full_name='CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread', full_name='CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage.unread', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8404,
  serialized_end=8490,
)

_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientChatGetFriendMessageHistoryResponse',
  full_name='CMsgClientChatGetFriendMessageHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientChatGetFriendMessageHistoryResponse.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgClientChatGetFriendMessageHistoryResponse.success', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='CMsgClientChatGetFriendMessageHistoryResponse.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8241,
  serialized_end=8490,
)


_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYFOROFFLINEMESSAGES = _descriptor.Descriptor(
  name='CMsgClientChatGetFriendMessageHistoryForOfflineMessages',
  full_name='CMsgClientChatGetFriendMessageHistoryForOfflineMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8492,
  serialized_end=8549,
)


_CMSGCLIENTFSGETFRIENDSSTEAMLEVELS = _descriptor.Descriptor(
  name='CMsgClientFSGetFriendsSteamLevels',
  full_name='CMsgClientFSGetFriendsSteamLevels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountids', full_name='CMsgClientFSGetFriendsSteamLevels.accountids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8551,
  serialized_end=8606,
)


_CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND = _descriptor.Descriptor(
  name='Friend',
  full_name='CMsgClientFSGetFriendsSteamLevelsResponse.Friend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgClientFSGetFriendsSteamLevelsResponse.Friend.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgClientFSGetFriendsSteamLevelsResponse.Friend.level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8722,
  serialized_end=8764,
)

_CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientFSGetFriendsSteamLevelsResponse',
  full_name='CMsgClientFSGetFriendsSteamLevelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friends', full_name='CMsgClientFSGetFriendsSteamLevelsResponse.friends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8609,
  serialized_end=8764,
)


_CMSGCLIENTEMAILADDRINFO = _descriptor.Descriptor(
  name='CMsgClientEmailAddrInfo',
  full_name='CMsgClientEmailAddrInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email_address', full_name='CMsgClientEmailAddrInfo.email_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_is_validated', full_name='CMsgClientEmailAddrInfo.email_is_validated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_validation_changed', full_name='CMsgClientEmailAddrInfo.email_validation_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credential_change_requires_code', full_name='CMsgClientEmailAddrInfo.credential_change_requires_code', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_or_secretqa_change_requires_code', full_name='CMsgClientEmailAddrInfo.password_or_secretqa_change_requires_code', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remind_user_about_email', full_name='CMsgClientEmailAddrInfo.remind_user_about_email', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8767,
  serialized_end=9002,
)


_CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='PublishedFileId',
  full_name='CMsgCREItemVoteSummary.PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREItemVoteSummary.PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9100,
  serialized_end=9144,
)

_CMSGCREITEMVOTESUMMARY = _descriptor.Descriptor(
  name='CMsgCREItemVoteSummary',
  full_name='CMsgCREItemVoteSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_ids', full_name='CMsgCREItemVoteSummary.published_file_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9005,
  serialized_end=9144,
)


_CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY = _descriptor.Descriptor(
  name='ItemVoteSummary',
  full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_for', full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary.votes_for', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes_against', full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary.votes_against', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary.reports', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgCREItemVoteSummaryResponse.ItemVoteSummary.score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9279,
  serialized_end=9397,
)

_CMSGCREITEMVOTESUMMARYRESPONSE = _descriptor.Descriptor(
  name='CMsgCREItemVoteSummaryResponse',
  full_name='CMsgCREItemVoteSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgCREItemVoteSummaryResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_vote_summaries', full_name='CMsgCREItemVoteSummaryResponse.item_vote_summaries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9147,
  serialized_end=9397,
)


_CMSGCREUPDATEUSERPUBLISHEDITEMVOTE = _descriptor.Descriptor(
  name='CMsgCREUpdateUserPublishedItemVote',
  full_name='CMsgCREUpdateUserPublishedItemVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREUpdateUserPublishedItemVote.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_up', full_name='CMsgCREUpdateUserPublishedItemVote.vote_up', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9399,
  serialized_end=9479,
)


_CMSGCREUPDATEUSERPUBLISHEDITEMVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgCREUpdateUserPublishedItemVoteResponse',
  full_name='CMsgCREUpdateUserPublishedItemVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgCREUpdateUserPublishedItemVoteResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9481,
  serialized_end=9545,
)


_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID = _descriptor.Descriptor(
  name='PublishedFileId',
  full_name='CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9100,
  serialized_end=9144,
)

_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS = _descriptor.Descriptor(
  name='CMsgCREGetUserPublishedItemVoteDetails',
  full_name='CMsgCREGetUserPublishedItemVoteDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_ids', full_name='CMsgCREGetUserPublishedItemVoteDetails.published_file_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9548,
  serialized_end=9719,
)


_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL = _descriptor.Descriptor(
  name='UserItemVoteDetail',
  full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='published_file_id', full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail.published_file_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail.vote', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9892,
  serialized_end=9956,
)

_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgCREGetUserPublishedItemVoteDetailsResponse',
  full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_item_vote_details', full_name='CMsgCREGetUserPublishedItemVoteDetailsResponse.user_item_vote_details', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9722,
  serialized_end=9956,
)


_CMSGFSGETFOLLOWERCOUNT = _descriptor.Descriptor(
  name='CMsgFSGetFollowerCount',
  full_name='CMsgFSGetFollowerCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgFSGetFollowerCount.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9958,
  serialized_end=10000,
)


_CMSGFSGETFOLLOWERCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgFSGetFollowerCountResponse',
  full_name='CMsgFSGetFollowerCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgFSGetFollowerCountResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgFSGetFollowerCountResponse.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10002,
  serialized_end=10072,
)


_CMSGFSGETISFOLLOWING = _descriptor.Descriptor(
  name='CMsgFSGetIsFollowing',
  full_name='CMsgFSGetIsFollowing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgFSGetIsFollowing.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10074,
  serialized_end=10114,
)


_CMSGFSGETISFOLLOWINGRESPONSE = _descriptor.Descriptor(
  name='CMsgFSGetIsFollowingResponse',
  full_name='CMsgFSGetIsFollowingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgFSGetIsFollowingResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_following', full_name='CMsgFSGetIsFollowingResponse.is_following', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10116,
  serialized_end=10195,
)


_CMSGFSENUMERATEFOLLOWINGLIST = _descriptor.Descriptor(
  name='CMsgFSEnumerateFollowingList',
  full_name='CMsgFSEnumerateFollowingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_index', full_name='CMsgFSEnumerateFollowingList.start_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10197,
  serialized_end=10248,
)


_CMSGFSENUMERATEFOLLOWINGLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgFSEnumerateFollowingListResponse',
  full_name='CMsgFSEnumerateFollowingListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgFSEnumerateFollowingListResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgFSEnumerateFollowingListResponse.total_results', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_ids', full_name='CMsgFSEnumerateFollowingListResponse.steam_ids', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10250,
  serialized_end=10350,
)


_CMSGDPGETNUMBEROFCURRENTPLAYERS = _descriptor.Descriptor(
  name='CMsgDPGetNumberOfCurrentPlayers',
  full_name='CMsgDPGetNumberOfCurrentPlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgDPGetNumberOfCurrentPlayers.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10352,
  serialized_end=10400,
)


_CMSGDPGETNUMBEROFCURRENTPLAYERSRESPONSE = _descriptor.Descriptor(
  name='CMsgDPGetNumberOfCurrentPlayersResponse',
  full_name='CMsgDPGetNumberOfCurrentPlayersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDPGetNumberOfCurrentPlayersResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_count', full_name='CMsgDPGetNumberOfCurrentPlayersResponse.player_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10402,
  serialized_end=10485,
)


_CMSGCLIENTFRIENDUSERSTATUSPUBLISHED = _descriptor.Descriptor(
  name='CMsgClientFriendUserStatusPublished',
  full_name='CMsgClientFriendUserStatusPublished',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friend_steamid', full_name='CMsgClientFriendUserStatusPublished.friend_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientFriendUserStatusPublished.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_text', full_name='CMsgClientFriendUserStatusPublished.status_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10487,
  serialized_end=10584,
)


_CMSGCLIENTSERVICEMETHODLEGACY = _descriptor.Descriptor(
  name='CMsgClientServiceMethodLegacy',
  full_name='CMsgClientServiceMethodLegacy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method_name', full_name='CMsgClientServiceMethodLegacy.method_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_method', full_name='CMsgClientServiceMethodLegacy.serialized_method', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_notification', full_name='CMsgClientServiceMethodLegacy.is_notification', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10586,
  serialized_end=10690,
)


_CMSGCLIENTSERVICEMETHODLEGACYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientServiceMethodLegacyResponse',
  full_name='CMsgClientServiceMethodLegacyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method_name', full_name='CMsgClientServiceMethodLegacyResponse.method_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_method_response', full_name='CMsgClientServiceMethodLegacyResponse.serialized_method_response', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10692,
  serialized_end=10788,
)


_CMSGCLIENTUIMODE = _descriptor.Descriptor(
  name='CMsgClientUIMode',
  full_name='CMsgClientUIMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uimode', full_name='CMsgClientUIMode.uimode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_mode', full_name='CMsgClientUIMode.chat_mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10790,
  serialized_end=10843,
)


_CMSGCLIENTVANITYURLCHANGEDNOTIFICATION = _descriptor.Descriptor(
  name='CMsgClientVanityURLChangedNotification',
  full_name='CMsgClientVanityURLChangedNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vanity_url', full_name='CMsgClientVanityURLChangedNotification.vanity_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10845,
  serialized_end=10905,
)


_CMSGCLIENTAUTHORIZELOCALDEVICEREQUEST = _descriptor.Descriptor(
  name='CMsgClientAuthorizeLocalDeviceRequest',
  full_name='CMsgClientAuthorizeLocalDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_description', full_name='CMsgClientAuthorizeLocalDeviceRequest.device_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgClientAuthorizeLocalDeviceRequest.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_device_token', full_name='CMsgClientAuthorizeLocalDeviceRequest.local_device_token', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10907,
  serialized_end=11028,
)


_CMSGCLIENTAUTHORIZELOCALDEVICE = _descriptor.Descriptor(
  name='CMsgClientAuthorizeLocalDevice',
  full_name='CMsgClientAuthorizeLocalDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAuthorizeLocalDevice.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgClientAuthorizeLocalDevice.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authed_device_token', full_name='CMsgClientAuthorizeLocalDevice.authed_device_token', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11030,
  serialized_end=11137,
)


_CMSGCLIENTAUTHORIZELOCALDEVICENOTIFICATION = _descriptor.Descriptor(
  name='CMsgClientAuthorizeLocalDeviceNotification',
  full_name='CMsgClientAuthorizeLocalDeviceNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAuthorizeLocalDeviceNotification.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgClientAuthorizeLocalDeviceNotification.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_device_token', full_name='CMsgClientAuthorizeLocalDeviceNotification.local_device_token', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11139,
  serialized_end=11257,
)


_CMSGCLIENTDEAUTHORIZEDEVICEREQUEST = _descriptor.Descriptor(
  name='CMsgClientDeauthorizeDeviceRequest',
  full_name='CMsgClientDeauthorizeDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deauthorization_account_id', full_name='CMsgClientDeauthorizeDeviceRequest.deauthorization_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deauthorization_device_token', full_name='CMsgClientDeauthorizeDeviceRequest.deauthorization_device_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11259,
  serialized_end=11369,
)


_CMSGCLIENTDEAUTHORIZEDEVICE = _descriptor.Descriptor(
  name='CMsgClientDeauthorizeDevice',
  full_name='CMsgClientDeauthorizeDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientDeauthorizeDevice.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deauthorization_account_id', full_name='CMsgClientDeauthorizeDevice.deauthorization_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11371,
  serialized_end=11456,
)


_CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN = _descriptor.Descriptor(
  name='DeviceToken',
  full_name='CMsgClientUseLocalDeviceAuthorizations.DeviceToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgClientUseLocalDeviceAuthorizations.DeviceToken.owner_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_id', full_name='CMsgClientUseLocalDeviceAuthorizations.DeviceToken.token_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11611,
  serialized_end=11668,
)

_CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS = _descriptor.Descriptor(
  name='CMsgClientUseLocalDeviceAuthorizations',
  full_name='CMsgClientUseLocalDeviceAuthorizations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorization_account_id', full_name='CMsgClientUseLocalDeviceAuthorizations.authorization_account_id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_tokens', full_name='CMsgClientUseLocalDeviceAuthorizations.device_tokens', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11459,
  serialized_end=11668,
)


_CMSGCLIENTGETAUTHORIZEDDEVICES = _descriptor.Descriptor(
  name='CMsgClientGetAuthorizedDevices',
  full_name='CMsgClientGetAuthorizedDevices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11670,
  serialized_end=11702,
)


_CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE = _descriptor.Descriptor(
  name='AuthorizedDevice',
  full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_device_token', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.auth_device_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_access_time', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.last_access_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='borrower_id', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.borrower_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pending', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.is_pending', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_played', full_name='CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice.app_played', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11853,
  serialized_end=12006,
)

_CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetAuthorizedDevicesResponse',
  full_name='CMsgClientGetAuthorizedDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetAuthorizedDevicesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorized_device', full_name='CMsgClientGetAuthorizedDevicesResponse.authorized_device', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11705,
  serialized_end=12006,
)


_CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY = _descriptor.Descriptor(
  name='LockedLibrary',
  full_name='CMsgClientSharedLibraryLockStatus.LockedLibrary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientSharedLibraryLockStatus.LockedLibrary.owner_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked_by', full_name='CMsgClientSharedLibraryLockStatus.LockedLibrary.locked_by', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12151,
  serialized_end=12203,
)

_CMSGCLIENTSHAREDLIBRARYLOCKSTATUS = _descriptor.Descriptor(
  name='CMsgClientSharedLibraryLockStatus',
  full_name='CMsgClientSharedLibraryLockStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locked_library', full_name='CMsgClientSharedLibraryLockStatus.locked_library', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own_library_locked_by', full_name='CMsgClientSharedLibraryLockStatus.own_library_locked_by', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12009,
  serialized_end=12203,
)


_CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP = _descriptor.Descriptor(
  name='StopApp',
  full_name='CMsgClientSharedLibraryStopPlaying.StopApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientSharedLibraryStopPlaying.StopApp.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientSharedLibraryStopPlaying.StopApp.owner_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12330,
  serialized_end=12373,
)

_CMSGCLIENTSHAREDLIBRARYSTOPPLAYING = _descriptor.Descriptor(
  name='CMsgClientSharedLibraryStopPlaying',
  full_name='CMsgClientSharedLibraryStopPlaying',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds_left', full_name='CMsgClientSharedLibraryStopPlaying.seconds_left', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_apps', full_name='CMsgClientSharedLibraryStopPlaying.stop_apps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12206,
  serialized_end=12373,
)


_CMSGCLIENTSERVICECALL = _descriptor.Descriptor(
  name='CMsgClientServiceCall',
  full_name='CMsgClientServiceCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sysid_routing', full_name='CMsgClientServiceCall.sysid_routing', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_handle', full_name='CMsgClientServiceCall.call_handle', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_crc', full_name='CMsgClientServiceCall.module_crc', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_hash', full_name='CMsgClientServiceCall.module_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_id', full_name='CMsgClientServiceCall.function_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cub_output_max', full_name='CMsgClientServiceCall.cub_output_max', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgClientServiceCall.flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callparameter', full_name='CMsgClientServiceCall.callparameter', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_only', full_name='CMsgClientServiceCall.ping_only', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_outstanding_calls', full_name='CMsgClientServiceCall.max_outstanding_calls', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientServiceCall.app_id', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12376,
  serialized_end=12633,
)


_CMSGCLIENTSERVICEMODULE = _descriptor.Descriptor(
  name='CMsgClientServiceModule',
  full_name='CMsgClientServiceModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_crc', full_name='CMsgClientServiceModule.module_crc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_hash', full_name='CMsgClientServiceModule.module_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_content', full_name='CMsgClientServiceModule.module_content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12635,
  serialized_end=12725,
)


_CMSGCLIENTSERVICECALLRESPONSE = _descriptor.Descriptor(
  name='CMsgClientServiceCallResponse',
  full_name='CMsgClientServiceCallResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sysid_routing', full_name='CMsgClientServiceCallResponse.sysid_routing', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_handle', full_name='CMsgClientServiceCallResponse.call_handle', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_crc', full_name='CMsgClientServiceCallResponse.module_crc', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_hash', full_name='CMsgClientServiceCallResponse.module_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecallresult', full_name='CMsgClientServiceCallResponse.ecallresult', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_content', full_name='CMsgClientServiceCallResponse.result_content', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os_version_info', full_name='CMsgClientServiceCallResponse.os_version_info', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_info', full_name='CMsgClientServiceCallResponse.system_info', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_address', full_name='CMsgClientServiceCallResponse.load_address', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exception_record', full_name='CMsgClientServiceCallResponse.exception_record', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portable_os_version_info', full_name='CMsgClientServiceCallResponse.portable_os_version_info', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portable_system_info', full_name='CMsgClientServiceCallResponse.portable_system_info', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='was_converted', full_name='CMsgClientServiceCallResponse.was_converted', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_result', full_name='CMsgClientServiceCallResponse.internal_result', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_count', full_name='CMsgClientServiceCallResponse.current_count', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_call_handle', full_name='CMsgClientServiceCallResponse.last_call_handle', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_call_module_crc', full_name='CMsgClientServiceCallResponse.last_call_module_crc', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_call_sysid_routing', full_name='CMsgClientServiceCallResponse.last_call_sysid_routing', index=17,
      number=18, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_ecallresult', full_name='CMsgClientServiceCallResponse.last_ecallresult', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_callissue_delta', full_name='CMsgClientServiceCallResponse.last_callissue_delta', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_callcomplete_delta', full_name='CMsgClientServiceCallResponse.last_callcomplete_delta', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12728,
  serialized_end=13296,
)


_CMSGAMUNLOCKSTREAMING = _descriptor.Descriptor(
  name='CMsgAMUnlockStreaming',
  full_name='CMsgAMUnlockStreaming',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13298,
  serialized_end=13321,
)


_CMSGAMUNLOCKSTREAMINGRESPONSE = _descriptor.Descriptor(
  name='CMsgAMUnlockStreamingResponse',
  full_name='CMsgAMUnlockStreamingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgAMUnlockStreamingResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_key', full_name='CMsgAMUnlockStreamingResponse.encryption_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13323,
  serialized_end=13398,
)


_CMSGAMUNLOCKHEVC = _descriptor.Descriptor(
  name='CMsgAMUnlockHEVC',
  full_name='CMsgAMUnlockHEVC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13400,
  serialized_end=13418,
)


_CMSGAMUNLOCKHEVCRESPONSE = _descriptor.Descriptor(
  name='CMsgAMUnlockHEVCResponse',
  full_name='CMsgAMUnlockHEVCResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgAMUnlockHEVCResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13420,
  serialized_end=13466,
)


_CMSGCLIENTPLAYINGSESSIONSTATE = _descriptor.Descriptor(
  name='CMsgClientPlayingSessionState',
  full_name='CMsgClientPlayingSessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='playing_blocked', full_name='CMsgClientPlayingSessionState.playing_blocked', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playing_app', full_name='CMsgClientPlayingSessionState.playing_app', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13468,
  serialized_end=13545,
)


_CMSGCLIENTKICKPLAYINGSESSION = _descriptor.Descriptor(
  name='CMsgClientKickPlayingSession',
  full_name='CMsgClientKickPlayingSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='only_stop_game', full_name='CMsgClientKickPlayingSession.only_stop_game', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13547,
  serialized_end=13601,
)


_CMSGCLIENTVOICECALLPREAUTHORIZE = _descriptor.Descriptor(
  name='CMsgClientVoiceCallPreAuthorize',
  full_name='CMsgClientVoiceCallPreAuthorize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_steamid', full_name='CMsgClientVoiceCallPreAuthorize.caller_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_steamid', full_name='CMsgClientVoiceCallPreAuthorize.receiver_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='CMsgClientVoiceCallPreAuthorize.caller_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hangup', full_name='CMsgClientVoiceCallPreAuthorize.hangup', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13603,
  serialized_end=13721,
)


_CMSGCLIENTVOICECALLPREAUTHORIZERESPONSE = _descriptor.Descriptor(
  name='CMsgClientVoiceCallPreAuthorizeResponse',
  full_name='CMsgClientVoiceCallPreAuthorizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_steamid', full_name='CMsgClientVoiceCallPreAuthorizeResponse.caller_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_steamid', full_name='CMsgClientVoiceCallPreAuthorizeResponse.receiver_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientVoiceCallPreAuthorizeResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='CMsgClientVoiceCallPreAuthorizeResponse.caller_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13724,
  serialized_end=13854,
)


_CMSGBADGECRAFTEDNOTIFICATION = _descriptor.Descriptor(
  name='CMsgBadgeCraftedNotification',
  full_name='CMsgBadgeCraftedNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgBadgeCraftedNotification.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='badge_level', full_name='CMsgBadgeCraftedNotification.badge_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13856,
  serialized_end=13922,
)

_CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE.containing_type = _CMSGCLIENTRICHPRESENCEINFO
_CMSGCLIENTRICHPRESENCEINFO.fields_by_name['rich_presence'].message_type = _CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE
_CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD.containing_type = _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE
_CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE.fields_by_name['betapasswords'].message_type = _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD
_CMSGDOWNLOADRATESTATISTICS_STATSINFO.containing_type = _CMSGDOWNLOADRATESTATISTICS
_CMSGDOWNLOADRATESTATISTICS.fields_by_name['stats'].message_type = _CMSGDOWNLOADRATESTATISTICS_STATSINFO
_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT.containing_type = _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY
_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY.fields_by_name['stats'].message_type = _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT
_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY.containing_type = _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE
_CMSGCLIENTUGSGETGLOBALSTATSRESPONSE.fields_by_name['days'].message_type = _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY
_CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM.containing_type = _CMSGCLIENTITEMANNOUNCEMENTS
_CMSGCLIENTITEMANNOUNCEMENTS.fields_by_name['unseen_items'].message_type = _CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM
_CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION.containing_type = _CMSGCLIENTUSERNOTIFICATIONS
_CMSGCLIENTUSERNOTIFICATIONS.fields_by_name['notifications'].message_type = _CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION
_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE.containing_type = _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE
_CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE.fields_by_name['messages'].message_type = _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE
_CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND.containing_type = _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE
_CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE.fields_by_name['friends'].message_type = _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND
_CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID.containing_type = _CMSGCREITEMVOTESUMMARY
_CMSGCREITEMVOTESUMMARY.fields_by_name['published_file_ids'].message_type = _CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID
_CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY.containing_type = _CMSGCREITEMVOTESUMMARYRESPONSE
_CMSGCREITEMVOTESUMMARYRESPONSE.fields_by_name['item_vote_summaries'].message_type = _CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY
_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID.containing_type = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS
_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS.fields_by_name['published_file_ids'].message_type = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID
_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL.containing_type = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE
_CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE.fields_by_name['user_item_vote_details'].message_type = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL
_CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN.containing_type = _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS
_CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS.fields_by_name['device_tokens'].message_type = _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN
_CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE.containing_type = _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE
_CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE.fields_by_name['authorized_device'].message_type = _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE
_CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY.containing_type = _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS
_CMSGCLIENTSHAREDLIBRARYLOCKSTATUS.fields_by_name['locked_library'].message_type = _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY
_CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP.containing_type = _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING
_CMSGCLIENTSHAREDLIBRARYSTOPPLAYING.fields_by_name['stop_apps'].message_type = _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP
DESCRIPTOR.message_types_by_name['CMsgClientUpdateUserGameInfo'] = _CMSGCLIENTUPDATEUSERGAMEINFO
DESCRIPTOR.message_types_by_name['CMsgClientRichPresenceUpload'] = _CMSGCLIENTRICHPRESENCEUPLOAD
DESCRIPTOR.message_types_by_name['CMsgClientRichPresenceRequest'] = _CMSGCLIENTRICHPRESENCEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientRichPresenceInfo'] = _CMSGCLIENTRICHPRESENCEINFO
DESCRIPTOR.message_types_by_name['CMsgClientCheckFileSignature'] = _CMSGCLIENTCHECKFILESIGNATURE
DESCRIPTOR.message_types_by_name['CMsgClientCheckFileSignatureResponse'] = _CMSGCLIENTCHECKFILESIGNATURERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientReadMachineAuth'] = _CMSGCLIENTREADMACHINEAUTH
DESCRIPTOR.message_types_by_name['CMsgClientReadMachineAuthResponse'] = _CMSGCLIENTREADMACHINEAUTHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUpdateMachineAuth'] = _CMSGCLIENTUPDATEMACHINEAUTH
DESCRIPTOR.message_types_by_name['CMsgClientUpdateMachineAuthResponse'] = _CMSGCLIENTUPDATEMACHINEAUTHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRequestMachineAuth'] = _CMSGCLIENTREQUESTMACHINEAUTH
DESCRIPTOR.message_types_by_name['CMsgClientRequestMachineAuthResponse'] = _CMSGCLIENTREQUESTMACHINEAUTHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRegisterKey'] = _CMSGCLIENTREGISTERKEY
DESCRIPTOR.message_types_by_name['CMsgClientPurchaseResponse'] = _CMSGCLIENTPURCHASERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientActivateOEMLicense'] = _CMSGCLIENTACTIVATEOEMLICENSE
DESCRIPTOR.message_types_by_name['CMsgClientRegisterOEMMachine'] = _CMSGCLIENTREGISTEROEMMACHINE
DESCRIPTOR.message_types_by_name['CMsgClientRegisterOEMMachineResponse'] = _CMSGCLIENTREGISTEROEMMACHINERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPurchaseWithMachineID'] = _CMSGCLIENTPURCHASEWITHMACHINEID
DESCRIPTOR.message_types_by_name['CMsgTrading_InitiateTradeRequest'] = _CMSGTRADING_INITIATETRADEREQUEST
DESCRIPTOR.message_types_by_name['CMsgTrading_InitiateTradeResponse'] = _CMSGTRADING_INITIATETRADERESPONSE
DESCRIPTOR.message_types_by_name['CMsgTrading_CancelTradeRequest'] = _CMSGTRADING_CANCELTRADEREQUEST
DESCRIPTOR.message_types_by_name['CMsgTrading_StartSession'] = _CMSGTRADING_STARTSESSION
DESCRIPTOR.message_types_by_name['CMsgClientGetCDNAuthToken'] = _CMSGCLIENTGETCDNAUTHTOKEN
DESCRIPTOR.message_types_by_name['CMsgClientGetDepotDecryptionKey'] = _CMSGCLIENTGETDEPOTDECRYPTIONKEY
DESCRIPTOR.message_types_by_name['CMsgClientGetDepotDecryptionKeyResponse'] = _CMSGCLIENTGETDEPOTDECRYPTIONKEYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientCheckAppBetaPassword'] = _CMSGCLIENTCHECKAPPBETAPASSWORD
DESCRIPTOR.message_types_by_name['CMsgClientCheckAppBetaPasswordResponse'] = _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUpdateAppJobReport'] = _CMSGCLIENTUPDATEAPPJOBREPORT
DESCRIPTOR.message_types_by_name['CMsgClientDPContentStatsReport'] = _CMSGCLIENTDPCONTENTSTATSREPORT
DESCRIPTOR.message_types_by_name['CMsgClientGetCDNAuthTokenResponse'] = _CMSGCLIENTGETCDNAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDownloadRateStatistics'] = _CMSGDOWNLOADRATESTATISTICS
DESCRIPTOR.message_types_by_name['CMsgClientRequestAccountData'] = _CMSGCLIENTREQUESTACCOUNTDATA
DESCRIPTOR.message_types_by_name['CMsgClientRequestAccountDataResponse'] = _CMSGCLIENTREQUESTACCOUNTDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUGSGetGlobalStats'] = _CMSGCLIENTUGSGETGLOBALSTATS
DESCRIPTOR.message_types_by_name['CMsgClientUGSGetGlobalStatsResponse'] = _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRedeemGuestPass'] = _CMSGCLIENTREDEEMGUESTPASS
DESCRIPTOR.message_types_by_name['CMsgClientRedeemGuestPassResponse'] = _CMSGCLIENTREDEEMGUESTPASSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientGetClanActivityCounts'] = _CMSGCLIENTGETCLANACTIVITYCOUNTS
DESCRIPTOR.message_types_by_name['CMsgClientGetClanActivityCountsResponse'] = _CMSGCLIENTGETCLANACTIVITYCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientOGSReportString'] = _CMSGCLIENTOGSREPORTSTRING
DESCRIPTOR.message_types_by_name['CMsgClientOGSReportBug'] = _CMSGCLIENTOGSREPORTBUG
DESCRIPTOR.message_types_by_name['CMsgClientSentLogs'] = _CMSGCLIENTSENTLOGS
DESCRIPTOR.message_types_by_name['CMsgGCClient'] = _CMSGGCCLIENT
DESCRIPTOR.message_types_by_name['CMsgClientRequestFreeLicense'] = _CMSGCLIENTREQUESTFREELICENSE
DESCRIPTOR.message_types_by_name['CMsgClientRequestFreeLicenseResponse'] = _CMSGCLIENTREQUESTFREELICENSERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDRMDownloadRequestWithCrashData'] = _CMSGDRMDOWNLOADREQUESTWITHCRASHDATA
DESCRIPTOR.message_types_by_name['CMsgDRMDownloadResponse'] = _CMSGDRMDOWNLOADRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDRMFinalResult'] = _CMSGDRMFINALRESULT
DESCRIPTOR.message_types_by_name['CMsgClientDPCheckSpecialSurvey'] = _CMSGCLIENTDPCHECKSPECIALSURVEY
DESCRIPTOR.message_types_by_name['CMsgClientDPCheckSpecialSurveyResponse'] = _CMSGCLIENTDPCHECKSPECIALSURVEYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientDPSendSpecialSurveyResponse'] = _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientDPSendSpecialSurveyResponseReply'] = _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSEREPLY
DESCRIPTOR.message_types_by_name['CMsgClientRequestForgottenPasswordEmail'] = _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAIL
DESCRIPTOR.message_types_by_name['CMsgClientRequestForgottenPasswordEmailResponse'] = _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAILRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientItemAnnouncements'] = _CMSGCLIENTITEMANNOUNCEMENTS
DESCRIPTOR.message_types_by_name['CMsgClientRequestItemAnnouncements'] = _CMSGCLIENTREQUESTITEMANNOUNCEMENTS
DESCRIPTOR.message_types_by_name['CMsgClientUserNotifications'] = _CMSGCLIENTUSERNOTIFICATIONS
DESCRIPTOR.message_types_by_name['CMsgClientCommentNotifications'] = _CMSGCLIENTCOMMENTNOTIFICATIONS
DESCRIPTOR.message_types_by_name['CMsgClientRequestCommentNotifications'] = _CMSGCLIENTREQUESTCOMMENTNOTIFICATIONS
DESCRIPTOR.message_types_by_name['CMsgClientOfflineMessageNotification'] = _CMSGCLIENTOFFLINEMESSAGENOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgClientRequestOfflineMessageCount'] = _CMSGCLIENTREQUESTOFFLINEMESSAGECOUNT
DESCRIPTOR.message_types_by_name['CMsgClientChatGetFriendMessageHistory'] = _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORY
DESCRIPTOR.message_types_by_name['CMsgClientChatGetFriendMessageHistoryResponse'] = _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientChatGetFriendMessageHistoryForOfflineMessages'] = _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYFOROFFLINEMESSAGES
DESCRIPTOR.message_types_by_name['CMsgClientFSGetFriendsSteamLevels'] = _CMSGCLIENTFSGETFRIENDSSTEAMLEVELS
DESCRIPTOR.message_types_by_name['CMsgClientFSGetFriendsSteamLevelsResponse'] = _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientEmailAddrInfo'] = _CMSGCLIENTEMAILADDRINFO
DESCRIPTOR.message_types_by_name['CMsgCREItemVoteSummary'] = _CMSGCREITEMVOTESUMMARY
DESCRIPTOR.message_types_by_name['CMsgCREItemVoteSummaryResponse'] = _CMSGCREITEMVOTESUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgCREUpdateUserPublishedItemVote'] = _CMSGCREUPDATEUSERPUBLISHEDITEMVOTE
DESCRIPTOR.message_types_by_name['CMsgCREUpdateUserPublishedItemVoteResponse'] = _CMSGCREUPDATEUSERPUBLISHEDITEMVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgCREGetUserPublishedItemVoteDetails'] = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS
DESCRIPTOR.message_types_by_name['CMsgCREGetUserPublishedItemVoteDetailsResponse'] = _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgFSGetFollowerCount'] = _CMSGFSGETFOLLOWERCOUNT
DESCRIPTOR.message_types_by_name['CMsgFSGetFollowerCountResponse'] = _CMSGFSGETFOLLOWERCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgFSGetIsFollowing'] = _CMSGFSGETISFOLLOWING
DESCRIPTOR.message_types_by_name['CMsgFSGetIsFollowingResponse'] = _CMSGFSGETISFOLLOWINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgFSEnumerateFollowingList'] = _CMSGFSENUMERATEFOLLOWINGLIST
DESCRIPTOR.message_types_by_name['CMsgFSEnumerateFollowingListResponse'] = _CMSGFSENUMERATEFOLLOWINGLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDPGetNumberOfCurrentPlayers'] = _CMSGDPGETNUMBEROFCURRENTPLAYERS
DESCRIPTOR.message_types_by_name['CMsgDPGetNumberOfCurrentPlayersResponse'] = _CMSGDPGETNUMBEROFCURRENTPLAYERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientFriendUserStatusPublished'] = _CMSGCLIENTFRIENDUSERSTATUSPUBLISHED
DESCRIPTOR.message_types_by_name['CMsgClientServiceMethodLegacy'] = _CMSGCLIENTSERVICEMETHODLEGACY
DESCRIPTOR.message_types_by_name['CMsgClientServiceMethodLegacyResponse'] = _CMSGCLIENTSERVICEMETHODLEGACYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUIMode'] = _CMSGCLIENTUIMODE
DESCRIPTOR.message_types_by_name['CMsgClientVanityURLChangedNotification'] = _CMSGCLIENTVANITYURLCHANGEDNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgClientAuthorizeLocalDeviceRequest'] = _CMSGCLIENTAUTHORIZELOCALDEVICEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientAuthorizeLocalDevice'] = _CMSGCLIENTAUTHORIZELOCALDEVICE
DESCRIPTOR.message_types_by_name['CMsgClientAuthorizeLocalDeviceNotification'] = _CMSGCLIENTAUTHORIZELOCALDEVICENOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgClientDeauthorizeDeviceRequest'] = _CMSGCLIENTDEAUTHORIZEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientDeauthorizeDevice'] = _CMSGCLIENTDEAUTHORIZEDEVICE
DESCRIPTOR.message_types_by_name['CMsgClientUseLocalDeviceAuthorizations'] = _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS
DESCRIPTOR.message_types_by_name['CMsgClientGetAuthorizedDevices'] = _CMSGCLIENTGETAUTHORIZEDDEVICES
DESCRIPTOR.message_types_by_name['CMsgClientGetAuthorizedDevicesResponse'] = _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSharedLibraryLockStatus'] = _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS
DESCRIPTOR.message_types_by_name['CMsgClientSharedLibraryStopPlaying'] = _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING
DESCRIPTOR.message_types_by_name['CMsgClientServiceCall'] = _CMSGCLIENTSERVICECALL
DESCRIPTOR.message_types_by_name['CMsgClientServiceModule'] = _CMSGCLIENTSERVICEMODULE
DESCRIPTOR.message_types_by_name['CMsgClientServiceCallResponse'] = _CMSGCLIENTSERVICECALLRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAMUnlockStreaming'] = _CMSGAMUNLOCKSTREAMING
DESCRIPTOR.message_types_by_name['CMsgAMUnlockStreamingResponse'] = _CMSGAMUNLOCKSTREAMINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAMUnlockHEVC'] = _CMSGAMUNLOCKHEVC
DESCRIPTOR.message_types_by_name['CMsgAMUnlockHEVCResponse'] = _CMSGAMUNLOCKHEVCRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPlayingSessionState'] = _CMSGCLIENTPLAYINGSESSIONSTATE
DESCRIPTOR.message_types_by_name['CMsgClientKickPlayingSession'] = _CMSGCLIENTKICKPLAYINGSESSION
DESCRIPTOR.message_types_by_name['CMsgClientVoiceCallPreAuthorize'] = _CMSGCLIENTVOICECALLPREAUTHORIZE
DESCRIPTOR.message_types_by_name['CMsgClientVoiceCallPreAuthorizeResponse'] = _CMSGCLIENTVOICECALLPREAUTHORIZERESPONSE
DESCRIPTOR.message_types_by_name['CMsgBadgeCraftedNotification'] = _CMSGBADGECRAFTEDNOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientUpdateUserGameInfo = _reflection.GeneratedProtocolMessageType('CMsgClientUpdateUserGameInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUPDATEUSERGAMEINFO,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUpdateUserGameInfo)
  })
_sym_db.RegisterMessage(CMsgClientUpdateUserGameInfo)

CMsgClientRichPresenceUpload = _reflection.GeneratedProtocolMessageType('CMsgClientRichPresenceUpload', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTRICHPRESENCEUPLOAD,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRichPresenceUpload)
  })
_sym_db.RegisterMessage(CMsgClientRichPresenceUpload)

CMsgClientRichPresenceRequest = _reflection.GeneratedProtocolMessageType('CMsgClientRichPresenceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTRICHPRESENCEREQUEST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRichPresenceRequest)
  })
_sym_db.RegisterMessage(CMsgClientRichPresenceRequest)

CMsgClientRichPresenceInfo = _reflection.GeneratedProtocolMessageType('CMsgClientRichPresenceInfo', (_message.Message,), {

  'RichPresence' : _reflection.GeneratedProtocolMessageType('RichPresence', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTRICHPRESENCEINFO_RICHPRESENCE,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientRichPresenceInfo.RichPresence)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTRICHPRESENCEINFO,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRichPresenceInfo)
  })
_sym_db.RegisterMessage(CMsgClientRichPresenceInfo)
_sym_db.RegisterMessage(CMsgClientRichPresenceInfo.RichPresence)

CMsgClientCheckFileSignature = _reflection.GeneratedProtocolMessageType('CMsgClientCheckFileSignature', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHECKFILESIGNATURE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCheckFileSignature)
  })
_sym_db.RegisterMessage(CMsgClientCheckFileSignature)

CMsgClientCheckFileSignatureResponse = _reflection.GeneratedProtocolMessageType('CMsgClientCheckFileSignatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHECKFILESIGNATURERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCheckFileSignatureResponse)
  })
_sym_db.RegisterMessage(CMsgClientCheckFileSignatureResponse)

CMsgClientReadMachineAuth = _reflection.GeneratedProtocolMessageType('CMsgClientReadMachineAuth', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREADMACHINEAUTH,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientReadMachineAuth)
  })
_sym_db.RegisterMessage(CMsgClientReadMachineAuth)

CMsgClientReadMachineAuthResponse = _reflection.GeneratedProtocolMessageType('CMsgClientReadMachineAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREADMACHINEAUTHRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientReadMachineAuthResponse)
  })
_sym_db.RegisterMessage(CMsgClientReadMachineAuthResponse)

CMsgClientUpdateMachineAuth = _reflection.GeneratedProtocolMessageType('CMsgClientUpdateMachineAuth', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUPDATEMACHINEAUTH,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUpdateMachineAuth)
  })
_sym_db.RegisterMessage(CMsgClientUpdateMachineAuth)

CMsgClientUpdateMachineAuthResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUpdateMachineAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUPDATEMACHINEAUTHRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUpdateMachineAuthResponse)
  })
_sym_db.RegisterMessage(CMsgClientUpdateMachineAuthResponse)

CMsgClientRequestMachineAuth = _reflection.GeneratedProtocolMessageType('CMsgClientRequestMachineAuth', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTMACHINEAUTH,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestMachineAuth)
  })
_sym_db.RegisterMessage(CMsgClientRequestMachineAuth)

CMsgClientRequestMachineAuthResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestMachineAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTMACHINEAUTHRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestMachineAuthResponse)
  })
_sym_db.RegisterMessage(CMsgClientRequestMachineAuthResponse)

CMsgClientRegisterKey = _reflection.GeneratedProtocolMessageType('CMsgClientRegisterKey', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREGISTERKEY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRegisterKey)
  })
_sym_db.RegisterMessage(CMsgClientRegisterKey)

CMsgClientPurchaseResponse = _reflection.GeneratedProtocolMessageType('CMsgClientPurchaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTPURCHASERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPurchaseResponse)
  })
_sym_db.RegisterMessage(CMsgClientPurchaseResponse)

CMsgClientActivateOEMLicense = _reflection.GeneratedProtocolMessageType('CMsgClientActivateOEMLicense', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTACTIVATEOEMLICENSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientActivateOEMLicense)
  })
_sym_db.RegisterMessage(CMsgClientActivateOEMLicense)

CMsgClientRegisterOEMMachine = _reflection.GeneratedProtocolMessageType('CMsgClientRegisterOEMMachine', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREGISTEROEMMACHINE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRegisterOEMMachine)
  })
_sym_db.RegisterMessage(CMsgClientRegisterOEMMachine)

CMsgClientRegisterOEMMachineResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRegisterOEMMachineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREGISTEROEMMACHINERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRegisterOEMMachineResponse)
  })
_sym_db.RegisterMessage(CMsgClientRegisterOEMMachineResponse)

CMsgClientPurchaseWithMachineID = _reflection.GeneratedProtocolMessageType('CMsgClientPurchaseWithMachineID', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTPURCHASEWITHMACHINEID,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPurchaseWithMachineID)
  })
_sym_db.RegisterMessage(CMsgClientPurchaseWithMachineID)

CMsgTrading_InitiateTradeRequest = _reflection.GeneratedProtocolMessageType('CMsgTrading_InitiateTradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTRADING_INITIATETRADEREQUEST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTrading_InitiateTradeRequest)
  })
_sym_db.RegisterMessage(CMsgTrading_InitiateTradeRequest)

CMsgTrading_InitiateTradeResponse = _reflection.GeneratedProtocolMessageType('CMsgTrading_InitiateTradeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTRADING_INITIATETRADERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTrading_InitiateTradeResponse)
  })
_sym_db.RegisterMessage(CMsgTrading_InitiateTradeResponse)

CMsgTrading_CancelTradeRequest = _reflection.GeneratedProtocolMessageType('CMsgTrading_CancelTradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTRADING_CANCELTRADEREQUEST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTrading_CancelTradeRequest)
  })
_sym_db.RegisterMessage(CMsgTrading_CancelTradeRequest)

CMsgTrading_StartSession = _reflection.GeneratedProtocolMessageType('CMsgTrading_StartSession', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTRADING_STARTSESSION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTrading_StartSession)
  })
_sym_db.RegisterMessage(CMsgTrading_StartSession)

CMsgClientGetCDNAuthToken = _reflection.GeneratedProtocolMessageType('CMsgClientGetCDNAuthToken', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCDNAUTHTOKEN,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetCDNAuthToken)
  })
_sym_db.RegisterMessage(CMsgClientGetCDNAuthToken)

CMsgClientGetDepotDecryptionKey = _reflection.GeneratedProtocolMessageType('CMsgClientGetDepotDecryptionKey', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETDEPOTDECRYPTIONKEY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetDepotDecryptionKey)
  })
_sym_db.RegisterMessage(CMsgClientGetDepotDecryptionKey)

CMsgClientGetDepotDecryptionKeyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetDepotDecryptionKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETDEPOTDECRYPTIONKEYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetDepotDecryptionKeyResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetDepotDecryptionKeyResponse)

CMsgClientCheckAppBetaPassword = _reflection.GeneratedProtocolMessageType('CMsgClientCheckAppBetaPassword', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHECKAPPBETAPASSWORD,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCheckAppBetaPassword)
  })
_sym_db.RegisterMessage(CMsgClientCheckAppBetaPassword)

CMsgClientCheckAppBetaPasswordResponse = _reflection.GeneratedProtocolMessageType('CMsgClientCheckAppBetaPasswordResponse', (_message.Message,), {

  'BetaPassword' : _reflection.GeneratedProtocolMessageType('BetaPassword', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE_BETAPASSWORD,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientCheckAppBetaPasswordResponse.BetaPassword)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTCHECKAPPBETAPASSWORDRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCheckAppBetaPasswordResponse)
  })
_sym_db.RegisterMessage(CMsgClientCheckAppBetaPasswordResponse)
_sym_db.RegisterMessage(CMsgClientCheckAppBetaPasswordResponse.BetaPassword)

CMsgClientUpdateAppJobReport = _reflection.GeneratedProtocolMessageType('CMsgClientUpdateAppJobReport', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUPDATEAPPJOBREPORT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUpdateAppJobReport)
  })
_sym_db.RegisterMessage(CMsgClientUpdateAppJobReport)

CMsgClientDPContentStatsReport = _reflection.GeneratedProtocolMessageType('CMsgClientDPContentStatsReport', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDPCONTENTSTATSREPORT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDPContentStatsReport)
  })
_sym_db.RegisterMessage(CMsgClientDPContentStatsReport)

CMsgClientGetCDNAuthTokenResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetCDNAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCDNAUTHTOKENRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetCDNAuthTokenResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetCDNAuthTokenResponse)

CMsgDownloadRateStatistics = _reflection.GeneratedProtocolMessageType('CMsgDownloadRateStatistics', (_message.Message,), {

  'StatsInfo' : _reflection.GeneratedProtocolMessageType('StatsInfo', (_message.Message,), {
    'DESCRIPTOR' : _CMSGDOWNLOADRATESTATISTICS_STATSINFO,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDownloadRateStatistics.StatsInfo)
    })
  ,
  'DESCRIPTOR' : _CMSGDOWNLOADRATESTATISTICS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDownloadRateStatistics)
  })
_sym_db.RegisterMessage(CMsgDownloadRateStatistics)
_sym_db.RegisterMessage(CMsgDownloadRateStatistics.StatsInfo)

CMsgClientRequestAccountData = _reflection.GeneratedProtocolMessageType('CMsgClientRequestAccountData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTACCOUNTDATA,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestAccountData)
  })
_sym_db.RegisterMessage(CMsgClientRequestAccountData)

CMsgClientRequestAccountDataResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestAccountDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTACCOUNTDATARESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestAccountDataResponse)
  })
_sym_db.RegisterMessage(CMsgClientRequestAccountDataResponse)

CMsgClientUGSGetGlobalStats = _reflection.GeneratedProtocolMessageType('CMsgClientUGSGetGlobalStats', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUGSGETGLOBALSTATS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUGSGetGlobalStats)
  })
_sym_db.RegisterMessage(CMsgClientUGSGetGlobalStats)

CMsgClientUGSGetGlobalStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUGSGetGlobalStatsResponse', (_message.Message,), {

  'Day' : _reflection.GeneratedProtocolMessageType('Day', (_message.Message,), {

    'Stat' : _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY_STAT,
      '__module__' : 'steammessages_clientserver_2_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientUGSGetGlobalStatsResponse.Day.Stat)
      })
    ,
    'DESCRIPTOR' : _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE_DAY,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUGSGetGlobalStatsResponse.Day)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUGSGETGLOBALSTATSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUGSGetGlobalStatsResponse)
  })
_sym_db.RegisterMessage(CMsgClientUGSGetGlobalStatsResponse)
_sym_db.RegisterMessage(CMsgClientUGSGetGlobalStatsResponse.Day)
_sym_db.RegisterMessage(CMsgClientUGSGetGlobalStatsResponse.Day.Stat)

CMsgClientRedeemGuestPass = _reflection.GeneratedProtocolMessageType('CMsgClientRedeemGuestPass', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREDEEMGUESTPASS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRedeemGuestPass)
  })
_sym_db.RegisterMessage(CMsgClientRedeemGuestPass)

CMsgClientRedeemGuestPassResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRedeemGuestPassResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREDEEMGUESTPASSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRedeemGuestPassResponse)
  })
_sym_db.RegisterMessage(CMsgClientRedeemGuestPassResponse)

CMsgClientGetClanActivityCounts = _reflection.GeneratedProtocolMessageType('CMsgClientGetClanActivityCounts', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLANACTIVITYCOUNTS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClanActivityCounts)
  })
_sym_db.RegisterMessage(CMsgClientGetClanActivityCounts)

CMsgClientGetClanActivityCountsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClanActivityCountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLANACTIVITYCOUNTSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClanActivityCountsResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetClanActivityCountsResponse)

CMsgClientOGSReportString = _reflection.GeneratedProtocolMessageType('CMsgClientOGSReportString', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTOGSREPORTSTRING,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientOGSReportString)
  })
_sym_db.RegisterMessage(CMsgClientOGSReportString)

CMsgClientOGSReportBug = _reflection.GeneratedProtocolMessageType('CMsgClientOGSReportBug', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTOGSREPORTBUG,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientOGSReportBug)
  })
_sym_db.RegisterMessage(CMsgClientOGSReportBug)

CMsgClientSentLogs = _reflection.GeneratedProtocolMessageType('CMsgClientSentLogs', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSENTLOGS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSentLogs)
  })
_sym_db.RegisterMessage(CMsgClientSentLogs)

CMsgGCClient = _reflection.GeneratedProtocolMessageType('CMsgGCClient', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGCCLIENT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClient)
  })
_sym_db.RegisterMessage(CMsgGCClient)

CMsgClientRequestFreeLicense = _reflection.GeneratedProtocolMessageType('CMsgClientRequestFreeLicense', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTFREELICENSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestFreeLicense)
  })
_sym_db.RegisterMessage(CMsgClientRequestFreeLicense)

CMsgClientRequestFreeLicenseResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestFreeLicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTFREELICENSERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestFreeLicenseResponse)
  })
_sym_db.RegisterMessage(CMsgClientRequestFreeLicenseResponse)

CMsgDRMDownloadRequestWithCrashData = _reflection.GeneratedProtocolMessageType('CMsgDRMDownloadRequestWithCrashData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGDRMDOWNLOADREQUESTWITHCRASHDATA,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDRMDownloadRequestWithCrashData)
  })
_sym_db.RegisterMessage(CMsgDRMDownloadRequestWithCrashData)

CMsgDRMDownloadResponse = _reflection.GeneratedProtocolMessageType('CMsgDRMDownloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGDRMDOWNLOADRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDRMDownloadResponse)
  })
_sym_db.RegisterMessage(CMsgDRMDownloadResponse)

CMsgDRMFinalResult = _reflection.GeneratedProtocolMessageType('CMsgDRMFinalResult', (_message.Message,), {
  'DESCRIPTOR' : _CMSGDRMFINALRESULT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDRMFinalResult)
  })
_sym_db.RegisterMessage(CMsgDRMFinalResult)

CMsgClientDPCheckSpecialSurvey = _reflection.GeneratedProtocolMessageType('CMsgClientDPCheckSpecialSurvey', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDPCHECKSPECIALSURVEY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDPCheckSpecialSurvey)
  })
_sym_db.RegisterMessage(CMsgClientDPCheckSpecialSurvey)

CMsgClientDPCheckSpecialSurveyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientDPCheckSpecialSurveyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDPCHECKSPECIALSURVEYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDPCheckSpecialSurveyResponse)
  })
_sym_db.RegisterMessage(CMsgClientDPCheckSpecialSurveyResponse)

CMsgClientDPSendSpecialSurveyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientDPSendSpecialSurveyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDPSendSpecialSurveyResponse)
  })
_sym_db.RegisterMessage(CMsgClientDPSendSpecialSurveyResponse)

CMsgClientDPSendSpecialSurveyResponseReply = _reflection.GeneratedProtocolMessageType('CMsgClientDPSendSpecialSurveyResponseReply', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDPSENDSPECIALSURVEYRESPONSEREPLY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDPSendSpecialSurveyResponseReply)
  })
_sym_db.RegisterMessage(CMsgClientDPSendSpecialSurveyResponseReply)

CMsgClientRequestForgottenPasswordEmail = _reflection.GeneratedProtocolMessageType('CMsgClientRequestForgottenPasswordEmail', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAIL,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestForgottenPasswordEmail)
  })
_sym_db.RegisterMessage(CMsgClientRequestForgottenPasswordEmail)

CMsgClientRequestForgottenPasswordEmailResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestForgottenPasswordEmailResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTFORGOTTENPASSWORDEMAILRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestForgottenPasswordEmailResponse)
  })
_sym_db.RegisterMessage(CMsgClientRequestForgottenPasswordEmailResponse)

CMsgClientItemAnnouncements = _reflection.GeneratedProtocolMessageType('CMsgClientItemAnnouncements', (_message.Message,), {

  'UnseenItem' : _reflection.GeneratedProtocolMessageType('UnseenItem', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTITEMANNOUNCEMENTS_UNSEENITEM,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientItemAnnouncements.UnseenItem)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTITEMANNOUNCEMENTS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientItemAnnouncements)
  })
_sym_db.RegisterMessage(CMsgClientItemAnnouncements)
_sym_db.RegisterMessage(CMsgClientItemAnnouncements.UnseenItem)

CMsgClientRequestItemAnnouncements = _reflection.GeneratedProtocolMessageType('CMsgClientRequestItemAnnouncements', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTITEMANNOUNCEMENTS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestItemAnnouncements)
  })
_sym_db.RegisterMessage(CMsgClientRequestItemAnnouncements)

CMsgClientUserNotifications = _reflection.GeneratedProtocolMessageType('CMsgClientUserNotifications', (_message.Message,), {

  'Notification' : _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTUSERNOTIFICATIONS_NOTIFICATION,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUserNotifications.Notification)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUSERNOTIFICATIONS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUserNotifications)
  })
_sym_db.RegisterMessage(CMsgClientUserNotifications)
_sym_db.RegisterMessage(CMsgClientUserNotifications.Notification)

CMsgClientCommentNotifications = _reflection.GeneratedProtocolMessageType('CMsgClientCommentNotifications', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCOMMENTNOTIFICATIONS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCommentNotifications)
  })
_sym_db.RegisterMessage(CMsgClientCommentNotifications)

CMsgClientRequestCommentNotifications = _reflection.GeneratedProtocolMessageType('CMsgClientRequestCommentNotifications', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTCOMMENTNOTIFICATIONS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestCommentNotifications)
  })
_sym_db.RegisterMessage(CMsgClientRequestCommentNotifications)

CMsgClientOfflineMessageNotification = _reflection.GeneratedProtocolMessageType('CMsgClientOfflineMessageNotification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTOFFLINEMESSAGENOTIFICATION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientOfflineMessageNotification)
  })
_sym_db.RegisterMessage(CMsgClientOfflineMessageNotification)

CMsgClientRequestOfflineMessageCount = _reflection.GeneratedProtocolMessageType('CMsgClientRequestOfflineMessageCount', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTOFFLINEMESSAGECOUNT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestOfflineMessageCount)
  })
_sym_db.RegisterMessage(CMsgClientRequestOfflineMessageCount)

CMsgClientChatGetFriendMessageHistory = _reflection.GeneratedProtocolMessageType('CMsgClientChatGetFriendMessageHistory', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChatGetFriendMessageHistory)
  })
_sym_db.RegisterMessage(CMsgClientChatGetFriendMessageHistory)

CMsgClientChatGetFriendMessageHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgClientChatGetFriendMessageHistoryResponse', (_message.Message,), {

  'FriendMessage' : _reflection.GeneratedProtocolMessageType('FriendMessage', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE_FRIENDMESSAGE,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChatGetFriendMessageHistoryResponse)
  })
_sym_db.RegisterMessage(CMsgClientChatGetFriendMessageHistoryResponse)
_sym_db.RegisterMessage(CMsgClientChatGetFriendMessageHistoryResponse.FriendMessage)

CMsgClientChatGetFriendMessageHistoryForOfflineMessages = _reflection.GeneratedProtocolMessageType('CMsgClientChatGetFriendMessageHistoryForOfflineMessages', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHATGETFRIENDMESSAGEHISTORYFOROFFLINEMESSAGES,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChatGetFriendMessageHistoryForOfflineMessages)
  })
_sym_db.RegisterMessage(CMsgClientChatGetFriendMessageHistoryForOfflineMessages)

CMsgClientFSGetFriendsSteamLevels = _reflection.GeneratedProtocolMessageType('CMsgClientFSGetFriendsSteamLevels', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFSGETFRIENDSSTEAMLEVELS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFSGetFriendsSteamLevels)
  })
_sym_db.RegisterMessage(CMsgClientFSGetFriendsSteamLevels)

CMsgClientFSGetFriendsSteamLevelsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientFSGetFriendsSteamLevelsResponse', (_message.Message,), {

  'Friend' : _reflection.GeneratedProtocolMessageType('Friend', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE_FRIEND,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientFSGetFriendsSteamLevelsResponse.Friend)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTFSGETFRIENDSSTEAMLEVELSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFSGetFriendsSteamLevelsResponse)
  })
_sym_db.RegisterMessage(CMsgClientFSGetFriendsSteamLevelsResponse)
_sym_db.RegisterMessage(CMsgClientFSGetFriendsSteamLevelsResponse.Friend)

CMsgClientEmailAddrInfo = _reflection.GeneratedProtocolMessageType('CMsgClientEmailAddrInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTEMAILADDRINFO,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEmailAddrInfo)
  })
_sym_db.RegisterMessage(CMsgClientEmailAddrInfo)

CMsgCREItemVoteSummary = _reflection.GeneratedProtocolMessageType('CMsgCREItemVoteSummary', (_message.Message,), {

  'PublishedFileId' : _reflection.GeneratedProtocolMessageType('PublishedFileId', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCREITEMVOTESUMMARY_PUBLISHEDFILEID,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgCREItemVoteSummary.PublishedFileId)
    })
  ,
  'DESCRIPTOR' : _CMSGCREITEMVOTESUMMARY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREItemVoteSummary)
  })
_sym_db.RegisterMessage(CMsgCREItemVoteSummary)
_sym_db.RegisterMessage(CMsgCREItemVoteSummary.PublishedFileId)

CMsgCREItemVoteSummaryResponse = _reflection.GeneratedProtocolMessageType('CMsgCREItemVoteSummaryResponse', (_message.Message,), {

  'ItemVoteSummary' : _reflection.GeneratedProtocolMessageType('ItemVoteSummary', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCREITEMVOTESUMMARYRESPONSE_ITEMVOTESUMMARY,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgCREItemVoteSummaryResponse.ItemVoteSummary)
    })
  ,
  'DESCRIPTOR' : _CMSGCREITEMVOTESUMMARYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREItemVoteSummaryResponse)
  })
_sym_db.RegisterMessage(CMsgCREItemVoteSummaryResponse)
_sym_db.RegisterMessage(CMsgCREItemVoteSummaryResponse.ItemVoteSummary)

CMsgCREUpdateUserPublishedItemVote = _reflection.GeneratedProtocolMessageType('CMsgCREUpdateUserPublishedItemVote', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCREUPDATEUSERPUBLISHEDITEMVOTE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREUpdateUserPublishedItemVote)
  })
_sym_db.RegisterMessage(CMsgCREUpdateUserPublishedItemVote)

CMsgCREUpdateUserPublishedItemVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgCREUpdateUserPublishedItemVoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCREUPDATEUSERPUBLISHEDITEMVOTERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREUpdateUserPublishedItemVoteResponse)
  })
_sym_db.RegisterMessage(CMsgCREUpdateUserPublishedItemVoteResponse)

CMsgCREGetUserPublishedItemVoteDetails = _reflection.GeneratedProtocolMessageType('CMsgCREGetUserPublishedItemVoteDetails', (_message.Message,), {

  'PublishedFileId' : _reflection.GeneratedProtocolMessageType('PublishedFileId', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS_PUBLISHEDFILEID,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId)
    })
  ,
  'DESCRIPTOR' : _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREGetUserPublishedItemVoteDetails)
  })
_sym_db.RegisterMessage(CMsgCREGetUserPublishedItemVoteDetails)
_sym_db.RegisterMessage(CMsgCREGetUserPublishedItemVoteDetails.PublishedFileId)

CMsgCREGetUserPublishedItemVoteDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgCREGetUserPublishedItemVoteDetailsResponse', (_message.Message,), {

  'UserItemVoteDetail' : _reflection.GeneratedProtocolMessageType('UserItemVoteDetail', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE_USERITEMVOTEDETAIL,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail)
    })
  ,
  'DESCRIPTOR' : _CMSGCREGETUSERPUBLISHEDITEMVOTEDETAILSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCREGetUserPublishedItemVoteDetailsResponse)
  })
_sym_db.RegisterMessage(CMsgCREGetUserPublishedItemVoteDetailsResponse)
_sym_db.RegisterMessage(CMsgCREGetUserPublishedItemVoteDetailsResponse.UserItemVoteDetail)

CMsgFSGetFollowerCount = _reflection.GeneratedProtocolMessageType('CMsgFSGetFollowerCount', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSGETFOLLOWERCOUNT,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSGetFollowerCount)
  })
_sym_db.RegisterMessage(CMsgFSGetFollowerCount)

CMsgFSGetFollowerCountResponse = _reflection.GeneratedProtocolMessageType('CMsgFSGetFollowerCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSGETFOLLOWERCOUNTRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSGetFollowerCountResponse)
  })
_sym_db.RegisterMessage(CMsgFSGetFollowerCountResponse)

CMsgFSGetIsFollowing = _reflection.GeneratedProtocolMessageType('CMsgFSGetIsFollowing', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSGETISFOLLOWING,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSGetIsFollowing)
  })
_sym_db.RegisterMessage(CMsgFSGetIsFollowing)

CMsgFSGetIsFollowingResponse = _reflection.GeneratedProtocolMessageType('CMsgFSGetIsFollowingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSGETISFOLLOWINGRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSGetIsFollowingResponse)
  })
_sym_db.RegisterMessage(CMsgFSGetIsFollowingResponse)

CMsgFSEnumerateFollowingList = _reflection.GeneratedProtocolMessageType('CMsgFSEnumerateFollowingList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSENUMERATEFOLLOWINGLIST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSEnumerateFollowingList)
  })
_sym_db.RegisterMessage(CMsgFSEnumerateFollowingList)

CMsgFSEnumerateFollowingListResponse = _reflection.GeneratedProtocolMessageType('CMsgFSEnumerateFollowingListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGFSENUMERATEFOLLOWINGLISTRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFSEnumerateFollowingListResponse)
  })
_sym_db.RegisterMessage(CMsgFSEnumerateFollowingListResponse)

CMsgDPGetNumberOfCurrentPlayers = _reflection.GeneratedProtocolMessageType('CMsgDPGetNumberOfCurrentPlayers', (_message.Message,), {
  'DESCRIPTOR' : _CMSGDPGETNUMBEROFCURRENTPLAYERS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDPGetNumberOfCurrentPlayers)
  })
_sym_db.RegisterMessage(CMsgDPGetNumberOfCurrentPlayers)

CMsgDPGetNumberOfCurrentPlayersResponse = _reflection.GeneratedProtocolMessageType('CMsgDPGetNumberOfCurrentPlayersResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGDPGETNUMBEROFCURRENTPLAYERSRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDPGetNumberOfCurrentPlayersResponse)
  })
_sym_db.RegisterMessage(CMsgDPGetNumberOfCurrentPlayersResponse)

CMsgClientFriendUserStatusPublished = _reflection.GeneratedProtocolMessageType('CMsgClientFriendUserStatusPublished', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTFRIENDUSERSTATUSPUBLISHED,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientFriendUserStatusPublished)
  })
_sym_db.RegisterMessage(CMsgClientFriendUserStatusPublished)

CMsgClientServiceMethodLegacy = _reflection.GeneratedProtocolMessageType('CMsgClientServiceMethodLegacy', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSERVICEMETHODLEGACY,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServiceMethodLegacy)
  })
_sym_db.RegisterMessage(CMsgClientServiceMethodLegacy)

CMsgClientServiceMethodLegacyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientServiceMethodLegacyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSERVICEMETHODLEGACYRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServiceMethodLegacyResponse)
  })
_sym_db.RegisterMessage(CMsgClientServiceMethodLegacyResponse)

CMsgClientUIMode = _reflection.GeneratedProtocolMessageType('CMsgClientUIMode', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUIMODE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUIMode)
  })
_sym_db.RegisterMessage(CMsgClientUIMode)

CMsgClientVanityURLChangedNotification = _reflection.GeneratedProtocolMessageType('CMsgClientVanityURLChangedNotification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTVANITYURLCHANGEDNOTIFICATION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientVanityURLChangedNotification)
  })
_sym_db.RegisterMessage(CMsgClientVanityURLChangedNotification)

CMsgClientAuthorizeLocalDeviceRequest = _reflection.GeneratedProtocolMessageType('CMsgClientAuthorizeLocalDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAUTHORIZELOCALDEVICEREQUEST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthorizeLocalDeviceRequest)
  })
_sym_db.RegisterMessage(CMsgClientAuthorizeLocalDeviceRequest)

CMsgClientAuthorizeLocalDevice = _reflection.GeneratedProtocolMessageType('CMsgClientAuthorizeLocalDevice', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAUTHORIZELOCALDEVICE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthorizeLocalDevice)
  })
_sym_db.RegisterMessage(CMsgClientAuthorizeLocalDevice)

CMsgClientAuthorizeLocalDeviceNotification = _reflection.GeneratedProtocolMessageType('CMsgClientAuthorizeLocalDeviceNotification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAUTHORIZELOCALDEVICENOTIFICATION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthorizeLocalDeviceNotification)
  })
_sym_db.RegisterMessage(CMsgClientAuthorizeLocalDeviceNotification)

CMsgClientDeauthorizeDeviceRequest = _reflection.GeneratedProtocolMessageType('CMsgClientDeauthorizeDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDEAUTHORIZEDEVICEREQUEST,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeauthorizeDeviceRequest)
  })
_sym_db.RegisterMessage(CMsgClientDeauthorizeDeviceRequest)

CMsgClientDeauthorizeDevice = _reflection.GeneratedProtocolMessageType('CMsgClientDeauthorizeDevice', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDEAUTHORIZEDEVICE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeauthorizeDevice)
  })
_sym_db.RegisterMessage(CMsgClientDeauthorizeDevice)

CMsgClientUseLocalDeviceAuthorizations = _reflection.GeneratedProtocolMessageType('CMsgClientUseLocalDeviceAuthorizations', (_message.Message,), {

  'DeviceToken' : _reflection.GeneratedProtocolMessageType('DeviceToken', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS_DEVICETOKEN,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUseLocalDeviceAuthorizations.DeviceToken)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUSELOCALDEVICEAUTHORIZATIONS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUseLocalDeviceAuthorizations)
  })
_sym_db.RegisterMessage(CMsgClientUseLocalDeviceAuthorizations)
_sym_db.RegisterMessage(CMsgClientUseLocalDeviceAuthorizations.DeviceToken)

CMsgClientGetAuthorizedDevices = _reflection.GeneratedProtocolMessageType('CMsgClientGetAuthorizedDevices', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETAUTHORIZEDDEVICES,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAuthorizedDevices)
  })
_sym_db.RegisterMessage(CMsgClientGetAuthorizedDevices)

CMsgClientGetAuthorizedDevicesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetAuthorizedDevicesResponse', (_message.Message,), {

  'AuthorizedDevice' : _reflection.GeneratedProtocolMessageType('AuthorizedDevice', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE_AUTHORIZEDDEVICE,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETAUTHORIZEDDEVICESRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAuthorizedDevicesResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetAuthorizedDevicesResponse)
_sym_db.RegisterMessage(CMsgClientGetAuthorizedDevicesResponse.AuthorizedDevice)

CMsgClientSharedLibraryLockStatus = _reflection.GeneratedProtocolMessageType('CMsgClientSharedLibraryLockStatus', (_message.Message,), {

  'LockedLibrary' : _reflection.GeneratedProtocolMessageType('LockedLibrary', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS_LOCKEDLIBRARY,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientSharedLibraryLockStatus.LockedLibrary)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSHAREDLIBRARYLOCKSTATUS,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSharedLibraryLockStatus)
  })
_sym_db.RegisterMessage(CMsgClientSharedLibraryLockStatus)
_sym_db.RegisterMessage(CMsgClientSharedLibraryLockStatus.LockedLibrary)

CMsgClientSharedLibraryStopPlaying = _reflection.GeneratedProtocolMessageType('CMsgClientSharedLibraryStopPlaying', (_message.Message,), {

  'StopApp' : _reflection.GeneratedProtocolMessageType('StopApp', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING_STOPAPP,
    '__module__' : 'steammessages_clientserver_2_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientSharedLibraryStopPlaying.StopApp)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSHAREDLIBRARYSTOPPLAYING,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSharedLibraryStopPlaying)
  })
_sym_db.RegisterMessage(CMsgClientSharedLibraryStopPlaying)
_sym_db.RegisterMessage(CMsgClientSharedLibraryStopPlaying.StopApp)

CMsgClientServiceCall = _reflection.GeneratedProtocolMessageType('CMsgClientServiceCall', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSERVICECALL,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServiceCall)
  })
_sym_db.RegisterMessage(CMsgClientServiceCall)

CMsgClientServiceModule = _reflection.GeneratedProtocolMessageType('CMsgClientServiceModule', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSERVICEMODULE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServiceModule)
  })
_sym_db.RegisterMessage(CMsgClientServiceModule)

CMsgClientServiceCallResponse = _reflection.GeneratedProtocolMessageType('CMsgClientServiceCallResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSERVICECALLRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServiceCallResponse)
  })
_sym_db.RegisterMessage(CMsgClientServiceCallResponse)

CMsgAMUnlockStreaming = _reflection.GeneratedProtocolMessageType('CMsgAMUnlockStreaming', (_message.Message,), {
  'DESCRIPTOR' : _CMSGAMUNLOCKSTREAMING,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAMUnlockStreaming)
  })
_sym_db.RegisterMessage(CMsgAMUnlockStreaming)

CMsgAMUnlockStreamingResponse = _reflection.GeneratedProtocolMessageType('CMsgAMUnlockStreamingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGAMUNLOCKSTREAMINGRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAMUnlockStreamingResponse)
  })
_sym_db.RegisterMessage(CMsgAMUnlockStreamingResponse)

CMsgAMUnlockHEVC = _reflection.GeneratedProtocolMessageType('CMsgAMUnlockHEVC', (_message.Message,), {
  'DESCRIPTOR' : _CMSGAMUNLOCKHEVC,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAMUnlockHEVC)
  })
_sym_db.RegisterMessage(CMsgAMUnlockHEVC)

CMsgAMUnlockHEVCResponse = _reflection.GeneratedProtocolMessageType('CMsgAMUnlockHEVCResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGAMUNLOCKHEVCRESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAMUnlockHEVCResponse)
  })
_sym_db.RegisterMessage(CMsgAMUnlockHEVCResponse)

CMsgClientPlayingSessionState = _reflection.GeneratedProtocolMessageType('CMsgClientPlayingSessionState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTPLAYINGSESSIONSTATE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPlayingSessionState)
  })
_sym_db.RegisterMessage(CMsgClientPlayingSessionState)

CMsgClientKickPlayingSession = _reflection.GeneratedProtocolMessageType('CMsgClientKickPlayingSession', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTKICKPLAYINGSESSION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientKickPlayingSession)
  })
_sym_db.RegisterMessage(CMsgClientKickPlayingSession)

CMsgClientVoiceCallPreAuthorize = _reflection.GeneratedProtocolMessageType('CMsgClientVoiceCallPreAuthorize', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTVOICECALLPREAUTHORIZE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientVoiceCallPreAuthorize)
  })
_sym_db.RegisterMessage(CMsgClientVoiceCallPreAuthorize)

CMsgClientVoiceCallPreAuthorizeResponse = _reflection.GeneratedProtocolMessageType('CMsgClientVoiceCallPreAuthorizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTVOICECALLPREAUTHORIZERESPONSE,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientVoiceCallPreAuthorizeResponse)
  })
_sym_db.RegisterMessage(CMsgClientVoiceCallPreAuthorizeResponse)

CMsgBadgeCraftedNotification = _reflection.GeneratedProtocolMessageType('CMsgBadgeCraftedNotification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGBADGECRAFTEDNOTIFICATION,
  '__module__' : 'steammessages_clientserver_2_pb2'
  # @@protoc_insertion_point(class_scope:CMsgBadgeCraftedNotification)
  })
_sym_db.RegisterMessage(CMsgBadgeCraftedNotification)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
